import { EventEmitter, OnInit, QueryList } from '@angular/core';
import { BaseStatesDirective } from '@eui/components/shared';
import { EuiAlertTitleComponent } from './eui-alert-title.component';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * Alert displays a short, important message to attract the user's attention without interrupting its task.
 */
export declare class EuiAlertComponent implements OnInit {
    baseStatesDirective: BaseStatesDirective;
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * Sets the `role` attribute for the host element.
     *
     * @default 'alert'
     */
    role: string;
    /**
     * Sets the `aria-describedby` attribute for the host element.
     *
     * @default `alertContent-${uniqueId}`
     * @returns The ID of the element associated with the alert.
     */
    get ariaDescribedBy(): string;
    /**
     * Sets the `tabindex` attribute for the host element.
     *
     * @returns '0' if defined as focusable else '1' as string.
     */
    get tabindex(): string;
    /**
     * Sets the `data-e2e` attribute for the host element. Default: `eui-alert`.
     *
     * @default 'eui-alert'
     */
    e2eAttr: string;
    /**
     * Removes the left border and icon from the alert.
     *
     * @default false
     */
    isMuted: boolean;
    /**
     * Removes the left border and icon from the alert.
     *
     * @default false
     */
    isBordered: boolean;
    /**
     * Allows the alert to be closed by the user.
     *
     * @default false
     */
    isCloseable: boolean;
    /**
     * Allows the alert to be focused by the user.
     *
     * @default false
     */
    isFocusable: boolean;
    /**
     * Controls the visibility of the alert. Default: true
     *
     * @default true
     */
    isVisible: boolean;
    /**
     * Event emitted when the alert is closed.
     */
    closeAlert: EventEmitter<boolean>;
    /**
     * Content for the alert title given by `<eui-alert-title>`.
     */
    alertTitle: QueryList<EuiAlertTitleComponent>;
    /**
     * @deprecated It is not being used in the component.
     */
    alertIconType: string;
    /**
     * @deprecated It is not being used in the component.
     */
    alertIconFillColor: string;
    /**
     * @description
     * Unique identifier for the alert component.
     * This ID is used to associate the alert with its content for accessibility purposes.
     * It is generated using the `crypto` API to ensure uniqueness.
     *
     * @private
     */
    private uniqueId;
    /**
     * @description
     * Lifecycle hook that is called after the component has been initialized.
     */
    ngOnInit(): void;
    /**
     * Hide the alert and emits the `closeAlert` event when the close button is clicked.
     */
    onCloseClick(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiAlertComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiAlertComponent, "div[euiAlert], eui-alert", never, { "ariaDescribedBy": { "alias": "ariaDescribedBy"; "required": false; }; "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "isMuted": { "alias": "isMuted"; "required": false; }; "isBordered": { "alias": "isBordered"; "required": false; }; "isCloseable": { "alias": "isCloseable"; "required": false; }; "isFocusable": { "alias": "isFocusable"; "required": false; }; "isVisible": { "alias": "isVisible"; "required": false; }; }, { "closeAlert": "closeAlert"; }, ["alertTitle"], ["*", "eui-alert-title", "*", "*", "*", "*"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiSuccess": "euiSuccess"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiVariant": "euiVariant"; }; outputs: {}; }]>;
    static ngAcceptInputType_isMuted: unknown;
    static ngAcceptInputType_isBordered: unknown;
    static ngAcceptInputType_isCloseable: unknown;
    static ngAcceptInputType_isFocusable: unknown;
    static ngAcceptInputType_isVisible: unknown;
}
//# sourceMappingURL=eui-alert.component.d.ts.map