import { BaseStatesDirective } from '@eui/components/shared';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * Component for displaying avatars in the EUI design system.
 *
 * An avatar is a visual representation of a user or entity and can contain
 * an image, text, or an icon. This component serves as the container for
 * various avatar subcomponents, such as EuiAvatarImage, EuiAvatarText,
 * EuiAvatarIcon, and EuiAvatarBadge.
 *
 * The component supports various customizations, including colors (via state directives),
 * sizes, shapes, and appearance modifiers.
 *
 */
export declare class EuiAvatarComponent {
    /**
     * Gets the CSS classes to be applied to the host element.
     * Combines base classes with modifier classes.
     * @returns {string} The combined CSS classes
     */
    get cssClasses(): string;
    /**
     * Data attribute for E2E testing
     * @default 'eui-avatar'
     */
    e2eAttr: string;
    /**
     * ARIA role for accessibility
     * @default 'status'
     */
    role: string;
    /**
     * ARIA label for accessibility
     * @default 'avatar'
     */
    ariaLabel: string | null;
    /**
     * Whether the avatar should have a shadow effect
     * @default false
     */
    hasShadow: boolean;
    /**
     * Whether the avatar shape should be square instead of circular
     * @default false
     */
    isShapeSquare: boolean;
    /**
     * Whether the avatar should have a flat appearance
     * @default false
     */
    isFlat: boolean;
    /**
     * Whether the avatar should have no background color
     * @default false
     */
    hasNoBackground: boolean;
    /**
     * Whether the avatar reverse layout with content
     * @default false
     */
    isReverse: boolean;
    /**
     * Reference to the BaseStatesDirective providing state-based styling
     * @internal
     */
    protected baseStatesDirective: BaseStatesDirective;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiAvatarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiAvatarComponent, "div[euiAvatar], span[euiAvatar], eui-avatar", never, { "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "ariaLabel": { "alias": "aria-label"; "required": false; }; "hasShadow": { "alias": "hasShadow"; "required": false; }; "isShapeSquare": { "alias": "isShapeSquare"; "required": false; }; "isFlat": { "alias": "isFlat"; "required": false; }; "hasNoBackground": { "alias": "hasNoBackground"; "required": false; }; "isReverse": { "alias": "isReverse"; "required": false; }; }, {}, never, ["eui-avatar-icon", "eui-avatar-text", "eui-avatar-image", "eui-avatar-badge", "eui-avatar-content"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiPrimary": "euiPrimary"; "euiSecondary": "euiSecondary"; "euiSuccess": "euiSuccess"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiAccent": "euiAccent"; "euiVariant": "euiVariant"; "euiSizeXS": "euiSizeXS"; "euiSizeS": "euiSizeS"; "euiSizeL": "euiSizeL"; "euiSizeXL": "euiSizeXL"; "euiSize2XL": "euiSize2XL"; "euiSizeVariant": "euiSizeVariant"; }; outputs: {}; }]>;
    static ngAcceptInputType_hasShadow: unknown;
    static ngAcceptInputType_isShapeSquare: unknown;
    static ngAcceptInputType_isFlat: unknown;
    static ngAcceptInputType_hasNoBackground: unknown;
    static ngAcceptInputType_isReverse: unknown;
}
//# sourceMappingURL=eui-avatar.component.d.ts.map