import { AfterContentInit, EventEmitter, QueryList } from '@angular/core';
import { EuiButtonComponent } from '@eui/components/eui-button';
import * as i0 from "@angular/core";
/**
 * @description
 * Component for grouping multiple buttons together with optional checkbox or radio button behavior.
 */
export declare class EuiButtonGroupComponent implements AfterContentInit {
    /** CSS classes applied to the host element */
    get cssClasses(): string;
    /**
     * Whether the buttons should behave like checkboxes (multiple selection)
     * @default false
     */
    isCheckboxButtons: boolean;
    /**
     * Whether the buttons should behave like radio buttons (single selection)
     * @default false
     */
    isRadioButtons: boolean;
    /**
     * Event emitted when any button in the group is clicked
     * Emits the clicked EuiButtonComponent instance
     */
    buttonClick: EventEmitter<EuiButtonComponent>;
    /**
     * Query list of all EuiButtonComponent instances within the group
     */
    buttons: QueryList<EuiButtonComponent>;
    /**
     * Initializes button click subscriptions after content is initialized
     */
    ngAfterContentInit(): void;
    /**
     * Handles button click events based on group configuration
     * - For checkbox buttons: Toggles the clicked button's checked state
     * - For radio buttons: Sets the clicked button as checked and unchecks others
     * - Emits the buttonClick event with the clicked button instance
     *
     * @param button - The EuiButtonComponent that was clicked
     * @internal
     */
    private handleInnerButtonClick;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiButtonGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiButtonGroupComponent, "eui-button-group", never, { "isCheckboxButtons": { "alias": "isCheckboxButtons"; "required": false; }; "isRadioButtons": { "alias": "isRadioButtons"; "required": false; }; }, { "buttonClick": "buttonClick"; }, ["buttons"], ["*"], true, never>;
    static ngAcceptInputType_isCheckboxButtons: unknown;
    static ngAcceptInputType_isRadioButtons: unknown;
}
/**
 * @deprecated Import the standalone {@link EUI_BUTTON_GROUP} instead.
 * This module is maintained for backward compatibility.
 *
 */
export declare class EuiButtonGroupModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiButtonGroupModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<EuiButtonGroupModule, never, [typeof EuiButtonGroupComponent], [typeof EuiButtonGroupComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<EuiButtonGroupModule>;
}
//# sourceMappingURL=eui-button-group.component.d.ts.map