import { EventEmitter } from '@angular/core';
import { UiStateService } from '../../services/ui-state.service';
import * as i0 from "@angular/core";
/**
 * @description
 * The eui-card-header component provides the header options of the eui-card.
 */
export declare class EuiCardHeaderComponent {
    uiStateService: UiStateService;
    /**
     * Binds the class to the component.
     *
     * @default 'eui-card-header'
     */
    string: string;
    /**
     * Sets the expandLabel Input property.
     *
     * @default 'expand'
     */
    expandLabel: string;
    /**
     * Sets the collapseLabel Input property.
     *
     * @default 'collapse'
     */
    collapseLabel: string;
    /**
     * Input property to enable/disable the header click toggle.
     *
     * @default true
     */
    hasHeaderClickToggle: boolean;
    /**
     * Input property to expand the bottom part of the card header.
     *
     * @default false
     */
    hasBottomExpander: boolean;
    /**
     * Input property to display the title within the full card container's width.
     *
     * @default false
     */
    hasFullTitle: boolean;
    /**
     * Input property to display the title & subtitle content in multiple lines.
     *
     * @default false
     */
    isHeaderMultilines: boolean;
    /**
     * Event emitted when the card header collapses.
     */
    collapse: EventEmitter<boolean>;
    /**
     * Fires when the icon button expander is clicked/pressed to expand/collapse the bottom expander.
     *
     * @param event The event that fires the toggle.
     */
    onToggle(event: Event): void;
    /**
     * Toggles the header when the header is clicked and emits the isCollapsed state.
     *
     */
    onToggleHeader(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiCardHeaderComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiCardHeaderComponent, "eui-card-header", never, { "expandLabel": { "alias": "expandLabel"; "required": false; }; "collapseLabel": { "alias": "collapseLabel"; "required": false; }; "hasHeaderClickToggle": { "alias": "hasHeaderClickToggle"; "required": false; }; "hasBottomExpander": { "alias": "hasBottomExpander"; "required": false; }; "hasFullTitle": { "alias": "hasFullTitle"; "required": false; }; "isHeaderMultilines": { "alias": "isHeaderMultilines"; "required": false; }; }, { "collapse": "collapse"; }, never, ["eui-card-header-left-content", "*", "*", "*", "*", "*", "*", "eui-card-header-body", "eui-card-header-title", "eui-card-header-subtitle", "eui-card-header-right-content"], true, never>;
    static ngAcceptInputType_hasHeaderClickToggle: unknown;
    static ngAcceptInputType_hasBottomExpander: unknown;
    static ngAcceptInputType_hasFullTitle: unknown;
    static ngAcceptInputType_isHeaderMultilines: unknown;
}
//# sourceMappingURL=eui-card-header.component.d.ts.map