import { OnDestroy, EventEmitter, OnInit, OnChanges, SimpleChanges, AfterContentInit } from '@angular/core';
import { UiStateService } from './services/ui-state.service';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * The eui-card component is based on Material Design and provides a content container for text, photos and actions in the context of a single subject.
 */
export declare class EuiCardComponent implements AfterContentInit, OnDestroy, OnInit, OnChanges {
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * Sets the `data-e2e` attribute at the host element.
     *
     * @default 'eui-card'
     */
    e2eAttr: string;
    /**
     * Sets the `euiSelected` attribute in order to show the card header as selected.
     *
     * @default false
     */
    euiSelected: boolean;
    /**
     * Sets the `euiCollapsible` attribute which shows the collapsible toggle in the header.
     *
     * @default false
     */
    euiCollapsible: boolean;
    /**
     * Sets the `euiCollapsed` attribute which collapses the card content.
     *
     * @default false
     */
    euiCollapsed: boolean;
    /**
     * Sets the `euiUrgent` attribute in order to show the card header as urgent.
     *
     * @default false
     */
    euiUrgent: boolean;
    /**
     * Sets the `euiNoShadow` attribute in order to remove the shadow from the card.
     *
     * @default false
     */
    euiNoShadow: boolean;
    /**
     * Sets the `euiNoContentPadding` attribute in order to remove the padding from the card content.
     *
     * @default false
     */
    euiNoContentPadding: boolean;
    /**
     * Sets the `euiHoverable` attribute in order to show the hover effect on the card.
     *
     * @default false
     */
    euiHoverable: boolean;
    /**
     * Event emitted when the card collapses.
     */
    collapse: EventEmitter<boolean>;
    uiStateService: UiStateService;
    private destroy$;
    private baseStatesDirective;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngOnDestroy(): void;
    /**
     * Sets the card state in the UIStateService.
     * This method is called when the component is initialized and when the input properties change.
     */
    private _setCardState;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiCardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiCardComponent, "eui-card", never, { "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "euiSelected": { "alias": "euiSelected"; "required": false; }; "euiCollapsible": { "alias": "euiCollapsible"; "required": false; }; "euiCollapsed": { "alias": "euiCollapsed"; "required": false; }; "euiUrgent": { "alias": "euiUrgent"; "required": false; }; "euiNoShadow": { "alias": "euiNoShadow"; "required": false; }; "euiNoContentPadding": { "alias": "euiNoContentPadding"; "required": false; }; "euiHoverable": { "alias": "euiHoverable"; "required": false; }; }, { "collapse": "collapse"; }, never, ["eui-card-header", "eui-card-media", "eui-card-content", "eui-card-footer"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiPrimary": "euiPrimary"; "euiSecondary": "euiSecondary"; "euiInfo": "euiInfo"; "euiSuccess": "euiSuccess"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiAccent": "euiAccent"; "euiHighlighted": "euiHighlighted"; "euiDisabled": "euiDisabled"; "euiLoading": "euiLoading"; "euiSizeXS": "euiSizeXS"; "euiSizeS": "euiSizeS"; "euiSizeM": "euiSizeM"; "euiSizeL": "euiSizeL"; "euiSizeXL": "euiSizeXL"; "euiSize2XL": "euiSize2XL"; "euiSizeVariant": "euiSizeVariant"; }; outputs: {}; }]>;
    static ngAcceptInputType_euiSelected: unknown;
    static ngAcceptInputType_euiCollapsible: unknown;
    static ngAcceptInputType_euiCollapsed: unknown;
    static ngAcceptInputType_euiUrgent: unknown;
    static ngAcceptInputType_euiNoShadow: unknown;
    static ngAcceptInputType_euiNoContentPadding: unknown;
    static ngAcceptInputType_euiHoverable: unknown;
}
//# sourceMappingURL=eui-card.component.d.ts.map