import { QueryList, AfterContentInit, EventEmitter, ElementRef } from '@angular/core';
import { BaseStatesDirective } from '@eui/components/shared';
import { EuiIconSvgComponent } from '@eui/components/eui-icon';
import { EuiChip } from './models/eui-chip.model';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * Chips are compact elements that allow users to enter information, select a choice, filter content or trigger an action.
 * The eui-chip component can also be displayed dynamically as a group of multiple interactive elements, see eui-chip-list.
 */
export declare class EuiChipComponent implements AfterContentInit {
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * Sets the `role` attribute for the host element.
     *
     * @default 'status'
     */
    role: string;
    /**
     * Sets the `aria-label` attribute for the host element.
     *
     * @default 'Chip content'
     */
    ariaLabel: string;
    /**
     * Sets the `data-e2e` attribute for the host element.
     *
     * @default 'eui-chip'
     */
    e2eAttr: string;
    /**
     * Sets the euiInternalId of the chip.
     *
     * @default null
     */
    euiInternalId: string;
    /**
     * Sets the label of the tooltip to diaply on hover.
     */
    tooltipMessage: string;
    /**
     * Sets the id of the chip.
     */
    id: string | number;
    /**
     * Sets the data of the chip like tooltip configuration.
     */
    data: any;
    /**
     * Wether the chip can be removed.
     *
     * @default false
     */
    isChipRemovable: boolean;
    /**
     * @deprecated This option is not applicable anymore to comply design System.
     */
    isSquared: boolean;
    /**
     * Wether the chip is filled with color.
     *
     * @default false
     */
    isFilled: boolean;
    /**
     * Event emitted when the chip is removed.
     */
    remove: EventEmitter<EuiChip | EuiChipComponent | {
        chip: EuiChipComponent | EuiChip;
        event?: Event;
    }>;
    /**
     * Icon declares by user in the chip
     */
    euiIcons: QueryList<EuiIconSvgComponent>;
    chipLabel: ElementRef<HTMLInputElement>;
    baseStatesDirective: BaseStatesDirective;
    private _elementRef;
    ngAfterContentInit(): void;
    /**
     * Remove chip handler
     *
     * @param event Click event
     */
    onRemove(event?: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiChipComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiChipComponent, "eui-chip, span[euiChip], li[euiChip]", never, { "ariaLabel": { "alias": "ariaLabel"; "required": false; }; "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "euiInternalId": { "alias": "euiInternalId"; "required": false; }; "tooltipMessage": { "alias": "tooltipMessage"; "required": false; }; "id": { "alias": "id"; "required": false; }; "data": { "alias": "data"; "required": false; }; "isChipRemovable": { "alias": "isChipRemovable"; "required": false; }; "isSquared": { "alias": "isSquared"; "required": false; }; "isFilled": { "alias": "isFilled"; "required": false; }; }, { "remove": "remove"; }, ["euiIcons"], ["*"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiPrimary": "euiPrimary"; "euiSecondary": "euiSecondary"; "euiSuccess": "euiSuccess"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiAccent": "euiAccent"; "euiVariant": "euiVariant"; "euiSizeS": "euiSizeS"; "euiOutline": "euiOutline"; "euiDisabled": "euiDisabled"; }; outputs: {}; }]>;
    static ngAcceptInputType_isChipRemovable: unknown;
    static ngAcceptInputType_isSquared: unknown;
    static ngAcceptInputType_isFilled: unknown;
}
//# sourceMappingURL=eui-chip.component.d.ts.map