import { EventEmitter } from '@angular/core';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * The eui-card component is based on Material Design and provides a content container for text, photos and actions in the context of a single subject.
 */
export declare class EuiContentCardComponent {
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * Sets the `data-e2e` attribute at the host element.
     *
     * @default 'eui-card'
     */
    e2eAttr: string;
    /**
     * Sets the `isSelected` attribute in order to show the card header as selected.
     *
     * @default false
     */
    isSelected: boolean;
    /**
     * Sets the `isSelectable` attribute in order to show the card header checkbox for selection
     *
     * @default false
     */
    isSelectable: boolean;
    /**
     * Sets the `isCollapsible` attribute which shows the collapsible toggle in the header.
     *
     * @default false
     */
    isCollapsible: boolean;
    /**
     * Sets the `isCollapsed` attribute which collapses the card content.
     *
     * @default false
     */
    isCollapsed: boolean;
    /**
     * Sets the `isBookmarkable` attribute which is adding a bookmark toggle to the card header end-block.
     *
     * @default false
     */
    isBookmarkable: boolean;
    /**
     * Sets the `isBookmarkable` attribute which is adding a bookmark toggle to the card header end-block.
     *
     * @default false
     */
    isBookmarked: boolean;
    /**
     * Event emitted when the card is selected.
     */
    cardSelect: EventEmitter<boolean>;
    /**
     * Event emitted when the card is bookmarked.
     */
    cardBookmark: EventEmitter<boolean>;
    /**
     * Event emitted when the card is bookmarked.
     */
    cardCollapse: EventEmitter<boolean>;
    private baseStatesDirective;
    toggleCollapse(): void;
    toggleBookmark(): void;
    protected onSelect(event: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiContentCardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiContentCardComponent, "eui-content-card", never, { "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "isSelected": { "alias": "isSelected"; "required": false; }; "isSelectable": { "alias": "isSelectable"; "required": false; }; "isCollapsible": { "alias": "isCollapsible"; "required": false; }; "isCollapsed": { "alias": "isCollapsed"; "required": false; }; "isBookmarkable": { "alias": "isBookmarkable"; "required": false; }; "isBookmarked": { "alias": "isBookmarked"; "required": false; }; }, { "cardSelect": "cardSelect"; "cardBookmark": "cardBookmark"; "cardCollapse": "cardCollapse"; }, never, ["eui-content-card-media", "eui-content-card-header", "eui-content-card-body", "eui-content-card-footer"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: {}; outputs: {}; }]>;
    static ngAcceptInputType_isSelected: unknown;
    static ngAcceptInputType_isSelectable: unknown;
    static ngAcceptInputType_isCollapsible: unknown;
    static ngAcceptInputType_isCollapsed: unknown;
    static ngAcceptInputType_isBookmarkable: unknown;
    static ngAcceptInputType_isBookmarked: unknown;
}
//# sourceMappingURL=eui-content-card.component.d.ts.map