import { OnInit, EventEmitter, QueryList } from '@angular/core';
import { BaseStatesDirective } from '@eui/components/shared';
import { EuiDashboardCardContentComponent } from './eui-dashboard-card-content';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
import * as i2 from "./eui-dashboard-card-content";
import * as i3 from "./eui-dashboard-card-content-header";
import * as i4 from "./eui-dashboard-card-content-header-icon";
import * as i5 from "./eui-dashboard-card-content-header-title";
import * as i6 from "./eui-dashboard-card-content-header-action";
import * as i7 from "./eui-dashboard-card-content-body";
import * as i8 from "./eui-dashboard-card-status-content.component";
/**
 * @description
 * Dashboard card component that can display content with various styling options,
 * including avatar/icon, labels, and clickable behavior.
 */
export declare class EuiDashboardCardComponent implements OnInit {
    /**
     * @description
     * Computes and returns the CSS classes for the dashboard card component based on its current state:
     * - Adds base dashboard card classes
     * - Adds horizontal layout class if isHorizontal is true
     * - Adds link class if the card is clickable or has a URL
     * - Adds flat class if isFlat is true
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /** Element attribute for e2e testing */
    e2eAttr: string;
    /** Primary label/title of the card */
    label: string;
    /** Secondary label/subtitle of the card */
    subLabel: string;
    /**
     * Maximum number of lines for the primary label
     * @default 2
     */
    labelMaxLines: 1 | 2 | 3 | 4 | 5;
    /**
     * Maximum number of lines for the secondary label
     * @default 2
     */
    subLabelMaxLines: 1 | 2 | 3 | 4 | 5;
    /** URL for the avatar image */
    imageUrl: string;
    /** Name of the icon to display */
    iconSvgName: string;
    /**
     * Size of the icon
     * @default 'm'
     */
    iconSvgSize: '2xs' | 'xs' | 's' | 'm' | 'l' | 'xl' | '2xl' | '3xl' | '4xl';
    /** Label for the icon (accessibility) */
    iconLabel: string;
    /** Internal router link URL */
    url: string;
    /** External URL */
    urlExternal: string;
    /** Target attribute for external URLs */
    urlExternalTarget: string;
    /** Tab index for keyboard navigation */
    get tabindex(): string;
    /** Whether to display the card in horizontal layout */
    isHorizontal: boolean;
    /** Whether to display the avatar without elevation */
    isFlatAvatar: boolean;
    /** Whether to display the avatar without background */
    hasNoBackgroundAvatar: boolean;
    /** Whether the card is clickable */
    isClickeable: boolean;
    /** Whether to display the card without elevation */
    isFlat: boolean;
    /** Whether to display the card without elevation */
    isStacked: boolean;
    /** Event emitted when the card is clicked */
    cardClick: EventEmitter<MouseEvent>;
    /** Reference to the custom content component */
    customContent: QueryList<EuiDashboardCardContentComponent>;
    baseStatesDirective: BaseStatesDirective;
    /** Handles card click events */
    onClick(event: MouseEvent): void;
    /** Sets default size and variant if not provided */
    ngOnInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiDashboardCardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiDashboardCardComponent, "eui-dashboard-card", never, { "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "label": { "alias": "label"; "required": false; }; "subLabel": { "alias": "subLabel"; "required": false; }; "labelMaxLines": { "alias": "labelMaxLines"; "required": false; }; "subLabelMaxLines": { "alias": "subLabelMaxLines"; "required": false; }; "imageUrl": { "alias": "imageUrl"; "required": false; }; "iconSvgName": { "alias": "iconSvgName"; "required": false; }; "iconSvgSize": { "alias": "iconSvgSize"; "required": false; }; "iconLabel": { "alias": "iconLabel"; "required": false; }; "url": { "alias": "url"; "required": false; }; "urlExternal": { "alias": "urlExternal"; "required": false; }; "urlExternalTarget": { "alias": "urlExternalTarget"; "required": false; }; "isHorizontal": { "alias": "isHorizontal"; "required": false; }; "isFlatAvatar": { "alias": "isFlatAvatar"; "required": false; }; "hasNoBackgroundAvatar": { "alias": "hasNoBackgroundAvatar"; "required": false; }; "isClickeable": { "alias": "isClickeable"; "required": false; }; "isFlat": { "alias": "isFlat"; "required": false; }; "isStacked": { "alias": "isStacked"; "required": false; }; }, { "cardClick": "cardClick"; }, ["customContent"], ["eui-dashboard-card-content", "eui-dashboard-card-status-content", "*"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiPrimary": "euiPrimary"; "euiSecondary": "euiSecondary"; "euiSuccess": "euiSuccess"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiAccent": "euiAccent"; "euiVariant": "euiVariant"; "euiSizeXS": "euiSizeXS"; "euiSizeS": "euiSizeS"; "euiSizeM": "euiSizeM"; "euiSizeL": "euiSizeL"; "euiSizeXL": "euiSizeXL"; "euiSize2XL": "euiSize2XL"; "euiSizeVariant": "euiSizeVariant"; "euiDisabled": "euiDisabled"; "euiOutline": "euiOutline"; }; outputs: {}; }]>;
    static ngAcceptInputType_isHorizontal: unknown;
    static ngAcceptInputType_isFlatAvatar: unknown;
    static ngAcceptInputType_hasNoBackgroundAvatar: unknown;
    static ngAcceptInputType_isClickeable: unknown;
    static ngAcceptInputType_isFlat: unknown;
    static ngAcceptInputType_isStacked: unknown;
}
/**
 * @deprecated Import the standalone {@link EUI_DASHBOARD_CARD} instead.
 * This module is maintained for backward compatibility.
 */
export declare class EuiDashboardCardModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiDashboardCardModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<EuiDashboardCardModule, never, [typeof EuiDashboardCardComponent, typeof i2.EuiDashboardCardContentComponent, typeof i3.EuiDashboardCardContentHeaderComponent, typeof i4.EuiDashboardCardContentHeaderIconComponent, typeof i5.EuiDashboardCardContentHeaderTitleComponent, typeof i6.EuiDashboardCardContentHeaderActionComponent, typeof i7.EuiDashboardCardContentBodyComponent, typeof i8.EuiDashboardCardStatusContentComponent], [typeof EuiDashboardCardComponent, typeof i2.EuiDashboardCardContentComponent, typeof i3.EuiDashboardCardContentHeaderComponent, typeof i4.EuiDashboardCardContentHeaderIconComponent, typeof i5.EuiDashboardCardContentHeaderTitleComponent, typeof i6.EuiDashboardCardContentHeaderActionComponent, typeof i7.EuiDashboardCardContentBodyComponent, typeof i8.EuiDashboardCardStatusContentComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<EuiDashboardCardModule>;
}
//# sourceMappingURL=eui-dashboard-card.component.d.ts.map