import { BooleanInput } from '@angular/cdk/coercion';
import { EuiAppShellService } from '@eui/core';
import * as i0 from "@angular/core";
/**
 * EuiDimmerComponent provides a dimming overlay on the page.
 *
 * The dimmer can be manually activated by setting `isDimmerActive` to true,
 * or automatically controlled via browser navigation events.
 *
 */
export declare class EuiDimmerComponent {
    asService: EuiAppShellService;
    /**
     * Gets the active state of the dimmer.
     *
     * @returns {boolean} True if dimmer is active, false otherwise.
     */
    get isDimmerActive(): boolean;
    /**
     * Sets the active state of the dimmer.
     *
     * @param {BooleanInput} value - The value to set for the dimmer active state.
     */
    set isDimmerActive(value: BooleanInput);
    /**
     * Gets the CSS classes to apply to the host element.
     * Adds the 'eui-dimmer--active' class when the dimmer is active.
     *
     * @returns {string} The CSS classes as a space-separated string.
     */
    get cssClasses(): string;
    /**
     * E2E testing attribute for the component.
     */
    e2eAttr: string;
    /** The active state of the dimmer. */
    private _isDimmerActive;
    /** Debug flag to control logging. */
    private _DEBUG;
    /**
     * Creates an instance of EuiDimmerComponent.
     *
     * Listens to router navigation events to handle dimmer state during navigation,
     * particularly when the user navigates back in browser history.
     *
     * @param {EuiAppShellService} asService - The app shell service for dimmer state management.
     * @param {Router} router - The Angular router service for navigation event monitoring.
     */
    constructor();
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiDimmerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiDimmerComponent, "eui-dimmer", never, { "isDimmerActive": { "alias": "isDimmerActive"; "required": false; }; "e2eAttr": { "alias": "e2eAttr"; "required": false; }; }, {}, never, never, true, never>;
}
//# sourceMappingURL=dimmer.component.d.ts.map