import { OnChanges, SimpleChange, SimpleChanges } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * @description
 * Component that provides functionality to disable content and show a visual overlay.
 * When disabled, it adds a semi-transparent overlay and handles focus management.
 */
export declare class EuiDisableContentComponent implements OnChanges {
    /**
     * Text to display in an eui-growl (type info) notification when clicking
     * the disabled content.
     */
    disabledText: import("@angular/core").InputSignal<string>;
    /**
     * Controls whether the content is disabled. If disabled, a semi-transparent
     * overlay with spinner is shown.
     */
    isDisabled: import("@angular/core").InputSignalWithTransform<boolean, unknown>;
    /** Stores the last active element before disabling */
    private lastActiveElement;
    /** Reference to the component's element */
    private elRef;
    /** Service for displaying growl notifications */
    private growlService;
    /** Renderer for DOM manipulations */
    private renderer;
    /**
     * Initializes the component and sets up an effect to handle disabled state changes
     */
    constructor();
    /**
     * Handles changes to component inputs
     * @param changes Object containing changed properties
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Checks if the component is about to enter a blocked state
     * @param change The change object to evaluate
     * @returns True if the component is transitioning to blocked state
     * @deprecated It will become private in the next major version.
     * @internal
     */
    isAboutToBlock(change: SimpleChange): boolean;
    /**
     * Stores the currently active element before disabling
     * @param activeElement The element to deactivate
     * @deprecated It will become private in the next major version.
     * @internal
     */
    desactivateElement(activeElement: HTMLElement): void;
    /**
     * Reactivates the last active element
     * @deprecated It will become private in the next major version.
     * @internal
     */
    reactivateElement(): void;
    /**
     * Gets the currently focused element within the component
     * @returns The focused HTML element or null
     * @deprecated It will become private in the next major version.
     * @internal
     */
    getActiveElement(): HTMLElement;
    /**
     * Handles click events on the disabled content
     * Shows a growl notification if content is disabled and has disabled text
     * @deprecated It will become private in the next major version.
     * @internal
     */
    protected onClick(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiDisableContentComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiDisableContentComponent, "eui-disable-content", never, { "disabledText": { "alias": "disabledText"; "required": false; "isSignal": true; }; "isDisabled": { "alias": "isDisabled"; "required": false; "isSignal": true; }; }, {}, never, ["*"], true, never>;
}
/**
 * Module that declares and exports the EuiDisableContentComponent
 *
 * @deprecated Use the {@link EUI_DISABLE_CONTENT} directly instead of this module.
 */
export declare class EuiDisableContentModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiDisableContentModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<EuiDisableContentModule, never, [typeof EuiDisableContentComponent], [typeof EuiDisableContentComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<EuiDisableContentModule>;
}
//# sourceMappingURL=eui-disable-content.component.d.ts.map