import { BooleanInput } from '@angular/cdk/coercion';
import * as i0 from "@angular/core";
/**
 * @description
 * Component for displaying individual items within a discussion thread.
 * This component represents a single entry in a conversation or thread timeline,
 * displaying information such as the author, date, content body, and optional tooltip.
 *
 * The component applies the ARIA role 'listitem' to maintain proper accessibility
 * and includes support for styling variants through the typeClass property.
 */
export declare class EuiDiscussionThreadItemComponent {
    /**
     * Sets CSS classes on the host element based on the typeClass property.
     * This helps maintain consistent styling with the parent theme variant.
     * @returns {string} The CSS class to be applied
     */
    get cssClasses(): string;
    /**
     * ARIA role for the host element to ensure proper accessibility.
     * @default 'listitem'
     */
    role: string;
    /**
     * Unique identifier for the discussion thread item.
     */
    id: string;
    /**
     * Type class defining the visual style of the item (e.g., 'info', 'warning', 'error').
     * This affects the color scheme applied to the item.
     */
    typeClass: string;
    /**
     * Date when the thread item was created or modified.
     */
    date: string;
    /**
     * Name or identifier of the author who created the item.
     */
    author: string;
    /**
     * Content body of the discussion thread item.
     */
    body: string;
    /**
     * Tooltip text to display additional information when hovering over the item.
     */
    tooltip: string;
    /**
     * Indicates if this item is in an odd position in the list.
     * Used for alternating styling patterns within the thread.
     */
    get isOdd(): boolean;
    set isOdd(value: BooleanInput);
    private _isOdd;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiDiscussionThreadItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiDiscussionThreadItemComponent, "eui-discussion-thread-item", never, { "id": { "alias": "id"; "required": false; }; "typeClass": { "alias": "typeClass"; "required": false; }; "date": { "alias": "date"; "required": false; }; "author": { "alias": "author"; "required": false; }; "body": { "alias": "body"; "required": false; }; "tooltip": { "alias": "tooltip"; "required": false; }; "isOdd": { "alias": "isOdd"; "required": false; }; }, {}, never, never, true, never>;
}
//# sourceMappingURL=eui-discussion-thread-item.component.d.ts.map