import { EuiDiscussionThreadItem } from './models/eui-discussion-thread-item.model';
import * as i0 from "@angular/core";
/**
 * @description
 * Component for displaying a discussion thread or conversation timeline.
 * This component renders a list of discussion thread items in a structured format,
 * with support for titles, subtitles, and tooltips for additional context.
 *
 * The component applies the ARIA role 'list' to the host element to maintain proper
 * accessibility for screen readers.
 *
 */
export declare class EuiDiscussionThreadComponent {
    /**
     * Gets the CSS classes to apply to the host element.
     *
     * @returns {string} The CSS classes as a space-separated string.
     */
    get cssClasses(): string;
    /**
     * ARIA role for the host element to ensure proper accessibility.
     * @default 'list'
     */
    role: string;
    /**
     * Array of discussion thread items to be displayed.
     * Each item should conform to the EuiDiscussionThreadItem interface.
     */
    items: EuiDiscussionThreadItem[];
    /**
     * The main title label for the discussion thread.
     */
    titleLabel: string;
    /**
     * The subtitle label for the discussion thread, typically used to provide
     * additional context or categorization.
     */
    subTitleLabel: string;
    /**
     * Tooltip text to display when hovering over the discussion thread.
     */
    tooltip: string;
    /**
     * Track by function for ngFor directive to improve rendering performance.
     * Uses the id property of each discussion thread item.
     *
     * @deprecated It will be removed in the next major version.
     *
     * @param index - The index of the current item in the array
     * @param item - The current discussion thread item
     * @returns The unique identifier for the item
     */
    trackByFn(index: number, item: EuiDiscussionThreadItem): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiDiscussionThreadComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiDiscussionThreadComponent, "eui-discussion-thread", never, { "items": { "alias": "items"; "required": false; }; "titleLabel": { "alias": "titleLabel"; "required": false; }; "subTitleLabel": { "alias": "subTitleLabel"; "required": false; }; "tooltip": { "alias": "tooltip"; "required": false; }; }, {}, never, ["*"], true, never>;
}
//# sourceMappingURL=eui-discussion-thread.component.d.ts.map