/**
 * @description
 * Interface defining the structure of an item within a discussion thread.
 *
 * This interface encapsulates all the necessary properties to display
 * a single message or entry, including metadata like author, date,
 * and styling information.
 *
 * @see EuiDiscussionThreadComponent
 * @see EuiDiscussionThreadItemComponent
 */
export interface EuiDiscussionThreadItem {
    /**
     * Unique identifier for the discussion thread item.
     * Used for tracking and reference purposes.
     */
    id: string;
    /**
     * CSS class identifier that defines the visual style of the item.
     * Common values include 'info', 'warning', 'error', etc.
     */
    typeClass: string;
    /**
     * Date when the thread item was created or modified.
     * Typically formatted as an ISO string or similar date format.
     */
    date: string;
    /**
     * Name or identifier of the author who created the item.
     */
    author: string;
    /**
     * Content body of the discussion thread item.
     * Contains the main message or comment text.
     */
    body: string;
    /**
     * Optional tooltip text to display additional information
     * when hovering over the item.
     */
    tooltip?: string;
}
//# sourceMappingURL=eui-discussion-thread-item.model.d.ts.map