import { BaseStatesDirective } from '@eui/components/shared';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * A feedback message component that displays various types of feedback to users.
 * Supports different states (primary, secondary, info, etc.) and can be muted.
 */
export declare class EuiFeedbackMessageComponent {
    /**
     * @description
     * Computes and returns the CSS classes for the feedback message component.
     * Combines base state classes with muted state if applicable.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * @description
     * Type attribute bound to the host element.
     * Used to identify the component type in the DOM.
     *
     * @protected
     */
    protected type: string;
    /**
     * @description
     * Controls whether the feedback message should be displayed in a muted state.
     * When true, the message will have reduced visual prominence. The status
     * icon won't show before the message.
     *
     * @default false
     */
    isMuted: boolean;
    /**
     * @description
     * Instance of BaseStatesDirective used to manage component states.
     * Injected using the inject function.
     *
     * @protected
     */
    protected baseStatesDirective: BaseStatesDirective;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiFeedbackMessageComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiFeedbackMessageComponent, "eui-feedback-message", never, { "isMuted": { "alias": "isMuted"; "required": false; }; }, {}, never, ["*"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiPrimary": "euiPrimary"; "euiSecondary": "euiSecondary"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiSuccess": "euiSuccess"; "euiDanger": "euiDanger"; "euiAccent": "euiAccent"; "euiVariant": "euiVariant"; }; outputs: {}; }]>;
    static ngAcceptInputType_isMuted: unknown;
}
//# sourceMappingURL=eui-feedback-message.component.d.ts.map