import { AfterContentInit, EventEmitter, QueryList, TemplateRef } from '@angular/core';
import { EuiTemplateDirective } from '@eui/components/directives';
import { BaseStatesDirective } from '@eui/components/shared';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * Directive for projecting content into the right side of the fieldset label
 */
export declare class EuiFieldsetLabelRightContentTagDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiFieldsetLabelRightContentTagDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EuiFieldsetLabelRightContentTagDirective, "euiFieldsetLabelRightContent", never, {}, {}, never, never, true, never>;
}
/**
 * Directive for projecting extra content into the fieldset label area
 */
export declare class EuiFieldsetLabelExtraContentTagDirective {
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiFieldsetLabelExtraContentTagDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<EuiFieldsetLabelExtraContentTagDirective, "euiFieldsetLabelExtraContent", never, {}, {}, never, never, true, never>;
}
/**
 * Fieldset component that provides a grouped container with optional expand/collapse functionality
 * and customizable label content.
 */
export declare class EuiFieldsetComponent implements AfterContentInit {
    /** CSS classes applied to the host element */
    get cssClasses(): string;
    /** Element attribute for e2e testing */
    e2eAttr: string;
    /** Unique identifier for the fieldset */
    id: string;
    /** Label text displayed in the fieldset header */
    label: string;
    /** CSS class for the icon */
    iconClass: string;
    /** Name of the SVG icon to display */
    iconSvgName: string;
    /** Fill color for the SVG icon */
    iconSvgFillColor: string;
    /** Whether to show the default icon */
    hasDefaultIcon: boolean;
    /** Whether the fieldset can be expanded/collapsed */
    isExpandable: boolean;
    /** Whether the fieldset is currently expanded */
    isExpanded: boolean;
    /** Whether to use large size styling */
    isLarge: boolean;
    /** Whether this is the first fieldset in a group */
    isFirst: boolean;
    /** Event emitted when the fieldset is expanded or collapsed */
    expand: EventEmitter<string>;
    /** Label for expand button accessibility */
    expandMenuLabel: string;
    /** Label for collapse button accessibility */
    collapseMenuLabel: string;
    /**
     * @deprecated Use iconSvgName instead
     */
    iconSvgType: string;
    /** Template reference for lazy-loaded content */
    protected lazyContent: TemplateRef<HTMLElement>;
    /** Query list of template directives for content projection */
    templates: QueryList<EuiTemplateDirective>;
    protected baseStatesDirective: BaseStatesDirective;
    /**
     * Initializes lazy content template if provided
     */
    ngAfterContentInit(): void;
    /**
     * Handles expand/collapse toggle events
     * Emits the fieldset ID when toggled
     */
    onToggle(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiFieldsetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiFieldsetComponent, "eui-fieldset", never, { "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "id": { "alias": "id"; "required": false; }; "label": { "alias": "label"; "required": false; }; "iconClass": { "alias": "iconClass"; "required": false; }; "iconSvgName": { "alias": "iconSvgName"; "required": false; }; "iconSvgFillColor": { "alias": "iconSvgFillColor"; "required": false; }; "hasDefaultIcon": { "alias": "hasDefaultIcon"; "required": false; }; "isExpandable": { "alias": "isExpandable"; "required": false; }; "isExpanded": { "alias": "isExpanded"; "required": false; }; "isLarge": { "alias": "isLarge"; "required": false; }; "isFirst": { "alias": "isFirst"; "required": false; }; }, { "expand": "expand"; }, ["templates"], ["euiFieldsetLabelExtraContent", "euiFieldsetLabelRightContent", "*"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiPrimary": "euiPrimary"; "euiSecondary": "euiSecondary"; "euiSuccess": "euiSuccess"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiAccent": "euiAccent"; "euiVariant": "euiVariant"; "euiHighlighted": "euiHighlighted"; }; outputs: {}; }]>;
    static ngAcceptInputType_hasDefaultIcon: unknown;
    static ngAcceptInputType_isExpandable: unknown;
    static ngAcceptInputType_isExpanded: unknown;
    static ngAcceptInputType_isLarge: unknown;
    static ngAcceptInputType_isFirst: unknown;
}
//# sourceMappingURL=eui-fieldset.component.d.ts.map