import { DoCheck, ElementRef, OnChanges, Renderer2, SimpleChanges, OnInit, EventEmitter } from '@angular/core';
import { ControlValueAccessor, NgControl } from '@angular/forms';
import { InputDirective } from '@eui/components/shared';
import { BooleanInput } from '@angular/cdk/coercion';
import * as i0 from "@angular/core";
/**
 * Angular component that provides a custom checkbox input implementation.
 * Extends {@link InputDirective} and implements form control functionality.
 *
 * @component
 * @selector input[euiInputCheckBox]
 * @implements {@link OnInit}
 * @implements {@link DoCheck}
 * @implements {@link OnChanges}
 * @implements {@link ControlValueAccessor}
 */
export declare class EuiInputCheckboxComponent extends InputDirective implements OnInit, DoCheck, OnChanges, ControlValueAccessor {
    /**
     * Gets the CSS classes for the checkbox component.
     * Combines base classes with validation state classes.
     *
     * @returns {string} Space-separated list of CSS classes
     */
    get cssClasses(): string;
    /**
     * Event emitter that fires when the indeterminate state changes.
     *
     * @event indeterminateChange
     * @type {EventEmitter<boolean>}
     */
    readonly indeterminateChange: EventEmitter<boolean>;
    /**
     * Controls the indeterminate (mixed) state of the checkbox.
     * When true, the checkbox appears in an indeterminate state.
     * This state is automatically cleared when the checkbox is clicked.
     *
     * @property {boolean} indeterminate
     */
    get indeterminate(): boolean;
    set indeterminate(value: BooleanInput);
    /**
     * Controls the invalid state of the checkbox. Used for displaying validation errors.
     *
     * @property {boolean} isInvalid
     */
    get isInvalid(): boolean;
    set isInvalid(state: any);
    protected _isInvalid: boolean;
    protected type: string;
    /**
     * Controls the checked state of the checkbox.
     *
     * @property {boolean} checked
     */
    get checked(): boolean;
    set checked(value: BooleanInput);
    protected ngControl: NgControl;
    protected _elementRef: ElementRef<HTMLInputElement>;
    protected _renderer: Renderer2;
    protected _checked: boolean;
    private _indeterminate;
    constructor();
    /**
     * Lifecycle hook that is called after data-bound properties are initialized.
     * Sets the default control value if needed.
     */
    ngOnInit(): void;
    /**
     * Lifecycle hook that performs custom change detection.
     * Updates invalid state based on control status.
     */
    ngDoCheck(): void;
    /**
     * Lifecycle hook that is called when data-bound properties change.
     * Handles changes to checked and readonly states.
     *
     * @param {SimpleChanges} changes - Object containing changed properties
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Implements ControlValueAccessor writeValue method.
     * Updates the checked state of the checkbox.
     *
     * @param {boolean} obj - The value to write
     */
    writeValue(obj: boolean): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState?(isDisabled: boolean): void;
    /**
     * Event handler for checkbox change events.
     *
     * @param {boolean} checked - The new checked state
     * @protected
     */
    protected onChanged(checked: boolean): void;
    /**
     * Event handler for space key press.
     * Prevents space key action when checkbox is readonly.
     *
     * @param {KeyboardEvent} event - The keyboard event
     * @protected
     */
    protected onSpacePressed(event: KeyboardEvent): void;
    protected onChange: <T>(_: T) => void;
    protected onBlur: (_: any) => void;
    /**
     * Sets the invalid state of the checkbox.
     *
     * @param {any} state - The invalid state to set (true/false)
     * @protected
     */
    protected setInvalid(state?: boolean): void;
    /**
     * Sets the indeterminate state of the checkbox. This is also known as "mixed" mode and can be used to
     * represent a checkbox with three states, e.g. a checkbox that represents a nested list of
     * check-able items.
     *
     * @param value
     */
    private _syncIndeterminate;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiInputCheckboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiInputCheckboxComponent, "input[euiInputCheckBox]", never, { "indeterminate": { "alias": "indeterminate"; "required": false; }; "isInvalid": { "alias": "isInvalid"; "required": false; }; "checked": { "alias": "checked"; "required": false; }; }, { "indeterminateChange": "indeterminateChange"; }, never, never, true, never>;
}
//# sourceMappingURL=eui-input-checkbox.component.d.ts.map