import { BaseStatesDirective } from '@eui/components/shared';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * A versatile label component that can be used as a standard label, sublabel, or other text elements.
 * Supports various states, sizes, and appearance modifications through host directives.
 */
export declare class EuiLabelComponent {
    /**
     * @description
     * Computes and returns the CSS classes for the label component based on its current state.
     * Combines base states, required status, readonly status, and sublabel type.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * @description Indicates if the label should be marked as required
     * @default false
     */
    euiRequired: boolean;
    /**
     * @description Indicates if the label should be displayed in readonly state
     * @default false
     */
    euiReadonly: boolean;
    /**
     * @description Indicates if the component should be rendered as a sublabel
     * @default false
     */
    euiSublabel: boolean;
    baseStatesDirective: BaseStatesDirective;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiLabelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiLabelComponent, "label[euiLabel], span[euiLabel], div[euiLabel], a[euiLabel], eui-label,               label[euiSublabel], span[euiSublabel], div[euiSublabel], a[euiSublabel], eui-sublabel", never, { "euiRequired": { "alias": "euiRequired"; "required": false; }; "euiReadonly": { "alias": "euiReadonly"; "required": false; }; "euiSublabel": { "alias": "euiSublabel"; "required": false; }; }, {}, never, ["*"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiPrimary": "euiPrimary"; "euiSecondary": "euiSecondary"; "euiSuccess": "euiSuccess"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiSizeS": "euiSizeS"; "euiSizeM": "euiSizeM"; "euiSizeL": "euiSizeL"; "euiDisabled": "euiDisabled"; }; outputs: {}; }]>;
    static ngAcceptInputType_euiRequired: unknown;
    static ngAcceptInputType_euiReadonly: unknown;
    static ngAcceptInputType_euiSublabel: unknown;
}
/**
 * @description
 * Module that declares and exports the EuiLabelComponent.
 *
 * @deprecated Use {@link EUI_LABEL} instead
 */
export declare class EuiLabelModule {
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiLabelModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<EuiLabelModule, never, [typeof EuiLabelComponent], [typeof EuiLabelComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<EuiLabelModule>;
}
//# sourceMappingURL=eui-label.component.d.ts.map