import { AfterContentInit, QueryList } from '@angular/core';
import { EuiListItemComponent } from './eui-list-item/eui-list-item.component';
import * as i0 from "@angular/core";
/**
 * @description
 * Component that provides a navigable list implementation with keyboard interaction support.
 * Works with Angular CDK's FocusKeyManager to enable keyboard navigation between list items.
 *
 * The component automatically manages focus between nested lists and supports rich content
 * navigation. It can contain multiple EuiListItemComponents as children.
 */
export declare class EuiListComponent implements AfterContentInit {
    /**
     * CSS class binding that applies the 'eui-list' class to the host element.
     * This class applies the basic styling for the list component.
     *
     * @returns {string} The CSS class to be applied to the host element
     */
    get cssClasses(): string;
    /**
     * Binds the 'list' ARIA role to the host element for accessibility.
     * This informs screen readers that this component functions as a list.
     */
    role: string;
    /**
     * Binds the tabIndex attribute to the host element.
     * Controls whether the list can receive keyboard focus.
     * Set to '0' for top-level lists and '-1' for nested lists.
     */
    tabIndex: string;
    /**
     * Collection of all list item components that are children of this list.
     * Includes items from nested lists due to the 'descendants: true' option.
     */
    items: QueryList<EuiListItemComponent>;
    private focusKeyManager;
    /**
     * Handles keyboard events for navigating the list.
     * Supports Enter key for selection and arrow keys for navigation.
     *
     * @param {KeyboardEvent} event - The keyboard event to handle
     */
    onKeydown(event: KeyboardEvent): void;
    /**
     * Initializes the component after content (list items) has been initialized.
     * Sets up the FocusKeyManager for keyboard navigation and configures tabindex
     * attributes based on nested list structure.
     */
    ngAfterContentInit(): void;
    /**
     * Manages focus state of rich content navigation within list items.
     * Handles the focus transition between list item elements and their navigable content.
     * Called when right/left arrow keys are pressed on items with navigable content.
     */
    checkRichContentFocusState(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiListComponent, "[euiList], eui-list", never, {}, {}, ["items"], ["*"], true, never>;
}
//# sourceMappingURL=eui-list.component.d.ts.map