import { ConnectedOverlayPositionChange, ConnectionPositionPair } from '@angular/cdk/overlay';
/**
 * Represents the four possible positions for a popover element.
 */
export type EuiPopoverPosition = 'top' | 'right' | 'bottom' | 'left';
/**
 * Position configuration for a popover appearing above its origin element.
 * Centers the popover horizontally relative to the origin.
 */
export declare const TOP: ConnectionPositionPair;
/**
 * Position configuration for a popover appearing below its origin element.
 * Centers the popover horizontally relative to the origin.
 */
export declare const BOTTOM: ConnectionPositionPair;
/**
 * Position configuration for a popover appearing to the left of its origin element.
 * Centers the popover vertically relative to the origin.
 */
export declare const LEFT: ConnectionPositionPair;
/**
 * Position configuration for a popover appearing to the right of its origin element.
 * Centers the popover vertically relative to the origin.
 */
export declare const RIGHT: ConnectionPositionPair;
/**
 * Converts a ConnectedOverlayPositionChange object to an EuiPopoverPosition string.
 * Used to determine which predefined position the overlay has settled on.
 *
 * @param connectionPair - The position change event from the CDK overlay
 * @returns The string representation of the popover position ('top', 'right', 'bottom', 'left')
 */
export declare const getPosition: ({ connectionPair }: ConnectedOverlayPositionChange) => EuiPopoverPosition;
//# sourceMappingURL=eui-popover-position.model.d.ts.map