import { EventEmitter, ChangeDetectorRef, OnInit } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BaseStatesDirective } from '@eui/components/shared';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * Rating component that can be used as a standalone start rating or within reactive forms.
 *
 * @implements {ControlValueAccessor}
 */
export declare class EuiRatingComponent implements ControlValueAccessor, OnInit {
    /** CSS classes applied to the host element */
    get cssClasses(): string;
    /**
     * Unique identifier for the toggle
     * @default Generated unique ID with 'eui-rating-' prefix
    */
    /**
     * Whether the toggle is disabled
     * @default false
    */
    euiDisabled: boolean;
    /**
     * Current numbers of stars rating to display
     * @default 5
    */
    numberOfStars: number;
    /**
     * Current rating number
     * @default 0
    */
    rating: number;
    /**
     * Event emitted when toggle state changes
     * @emits boolean - The new toggle state
    */
    ratingChange: EventEmitter<number>;
    /**
     * Binds the tabindex attribute to the component.
    *
    * @default 0
    */
    tabindex: number;
    onKeydown(event: KeyboardEvent): void;
    protected numbers: any[];
    protected baseStatesDirective: BaseStatesDirective;
    protected cd: ChangeDetectorRef;
    ngOnInit(): void;
    /**
     * Implements ControlValueAccessor
     * Updates the toggle's checked state
    */
    writeValue(value: number): void;
    /**
     * Implements ControlValueAccessor
     * Updates the rating's disabled state
    */
    setDisabledState(isDisabled: boolean): void;
    /**
     * Handles focus out event
     * Notifies form control of touch event
    */
    onFocusOut(): void;
    /**
     * Implements ControlValueAccessor
     * Registers change handler
     * @todo Improve type definition or make generic
     */
    registerOnChange(fn: any): void;
    /**
     * Implements ControlValueAccessor
     * Registers touch handler
     * @todo Improve type definition or make generic
     */
    registerOnTouched(fn: any): void;
    /**
     * Toggles the current state if not disabled
     * Emits the new state and notifies form control
     */
    protected onUpdate(rating: number): void;
    private initState;
    private updateState;
    private updateRating;
    private onChange;
    private onTouch;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiRatingComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiRatingComponent, "eui-rating", never, { "euiDisabled": { "alias": "euiDisabled"; "required": false; }; "numberOfStars": { "alias": "numberOfStars"; "required": false; }; "rating": { "alias": "rating"; "required": false; }; }, { "ratingChange": "ratingChange"; }, never, never, true, [{ directive: typeof i1.BaseStatesDirective; inputs: {}; outputs: {}; }]>;
    static ngAcceptInputType_euiDisabled: unknown;
    static ngAcceptInputType_numberOfStars: unknown;
    static ngAcceptInputType_rating: unknown;
}
//# sourceMappingURL=eui-rating.component.d.ts.map