import { BaseStatesDirective } from '@eui/components/shared';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * A skeleton loading component that provides various shapes and sizes for placeholder content.
 * Used to indicate loading states in the UI with different geometric shapes.
 */
export declare class EuiSkeletonComponent {
    /**
     * @description
     * Computes and returns the CSS classes for the skeleton component
     * by delegating to the private getCssClasses method.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * @description
     * When true, renders the skeleton as a circle shape
     * @default false
     */
    circle: boolean;
    /**
     * @description
     * When true, renders the skeleton as a line shape
     * @default false
     */
    line: boolean;
    /**
     * @description
     * When true, renders the skeleton as a square shape
     * @default false
     */
    square: boolean;
    /**
     * @description
     * When true, renders the skeleton as a rectangle shape
     * @default false
     */
    rectangle: boolean;
    /**
     * @description
     * Instance of BaseStatesDirective used to manage component states
     */
    baseStatesDirective: BaseStatesDirective;
    /**
     * @description
     * Combines all CSS classes based on the component's current state and shape inputs
     *
     * @private
     * @returns {string} Space-separated string of CSS class names
     */
    private getCssClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiSkeletonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiSkeletonComponent, "eui-skeleton", never, { "circle": { "alias": "circle"; "required": false; }; "line": { "alias": "line"; "required": false; }; "square": { "alias": "square"; "required": false; }; "rectangle": { "alias": "rectangle"; "required": false; }; }, {}, never, never, true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiSizeXS": "euiSizeXS"; "euiSizeS": "euiSizeS"; "euiSizeM": "euiSizeM"; "euiSizeL": "euiSizeL"; "euiSizeXL": "euiSizeXL"; "euiRounded": "euiRounded"; "euiSizeVariant": "euiSizeVariant"; }; outputs: {}; }]>;
    static ngAcceptInputType_circle: unknown;
    static ngAcceptInputType_line: unknown;
    static ngAcceptInputType_square: unknown;
    static ngAcceptInputType_rectangle: unknown;
}
//# sourceMappingURL=eui-skeleton.component.d.ts.map