import { OnInit, EventEmitter, OnDestroy, ElementRef } from '@angular/core';
import { FormGroup, FormControl } from '@angular/forms';
import { BehaviorSubject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * @description
 * Component used with `eui-table-v2` to add a filter feature to the table.
 */
export declare class EuiTableV2FilterComponent implements OnInit, OnDestroy {
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * Placeholder text for the filter input.
     */
    placeholder: string;
    /**
     * Event emitted when the value of the input changes.
     */
    filterChange: EventEmitter<string>;
    filterInput: ElementRef<HTMLInputElement>;
    filter$: BehaviorSubject<string>;
    form: FormGroup<{
        filter: FormControl<string>;
    }>;
    private destroy$;
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Set the filter value and emit the change event.
     *
     * @param value Value of the input.
     */
    setFilter(value: string): void;
    /**
     * Reset the filter and emit the change event.
     */
    resetFilter(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiTableV2FilterComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiTableV2FilterComponent, "eui-table-v2-filter", never, { "placeholder": { "alias": "placeholder"; "required": false; }; }, { "filterChange": "filterChange"; }, never, never, true, never>;
}
//# sourceMappingURL=eui-table-v2-filter.component.d.ts.map