import { BehaviorSubject, Observable } from 'rxjs';
import { Sort, SortOrder } from '../models/sort.model';
import * as i0 from "@angular/core";
/**
 * Service to manage the sorting state of columns in a table.
 * Uses a `BehaviorSubject` to store and emit the current sorting values.
 */
export declare class EuiTableV2SortService {
    /**
     * BehaviorSubject containing the current sorting information.
     */
    sorts$: BehaviorSubject<Sort[]>;
    /**
     * Observable stream of sorting values.
     */
    get sorts(): Observable<Sort[]>;
    private isCurrentMultiSortable;
    /**
     * Sets the ordering order for a given column
     *
     * @param sort The name of the column to sort.
     * @param order The sorting order (ascending or descending).
     * @param isMultiSortable Whether multi-sorting is allowed.
     */
    setSort(sort: string, order: SortOrder, isMultiSortable: boolean): void;
    /**
     * Sets the full list of sorting values.
     *
     * @param sorts The list of sorts to apply.
     */
    setSorts(sorts: Sort[]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiTableV2SortService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<EuiTableV2SortService>;
}
//# sourceMappingURL=eui-table-v2-sort.service.d.ts.map