import { AfterContentInit } from '@angular/core';
import { BaseStatesDirective } from '@eui/components/shared';
import { EuiTimelineComponent } from './eui-timeline.component';
import * as i0 from "@angular/core";
import * as i1 from "@eui/components/shared";
/**
 * @description
 * A timeline item component that represents a single event or activity within a timeline.
 * Can display labels, dates, times, and custom content with various visual states.
 */
export declare class EuiTimelineItemComponent implements AfterContentInit {
    /**
     * @description
     * Computes and returns the CSS classes for the timeline item
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses(): string;
    /**
     * @description Data attribute for e2e testing
     * @default 'eui-timeline-item'
     */
    e2eAttr: string;
    /**
     * @description Primary text content of the timeline item
     */
    label: string;
    /**
     * @description Secondary text content displayed below the label
     */
    subLabel: string;
    /**
     * @description Date to display for the timeline item
     */
    date: string;
    /**
     * @description Additional CSS class to apply to the date element
     * @default ''
     */
    dateStyleClass: string;
    /**
     * @description Time to display for the timeline item
     */
    time: string;
    /**
     * @description Additional CSS class to apply to the time element
     * @default ''
     */
    timeStyleClass: string;
    /**
     * @description Controls the alignment of content within the timeline item
     * Inherited from parent timeline component
     */
    isLeftAligned: boolean;
    /**
     * @description Indicates if this item represents a group of events
     * Changes the visual appearance accordingly
     */
    isGroup: boolean;
    /**
     * @description Instance of BaseStatesDirective for managing component states
     */
    baseStatesDirective: BaseStatesDirective;
    /**
     * @description Reference to parent timeline component for alignment inheritance
     */
    timelineComponent: EuiTimelineComponent;
    /**
     * @description
     * After content initialization, inherits left alignment from parent timeline component
     */
    ngAfterContentInit(): void;
    /**
     * @description
     * Combines CSS classes based on the component's current state and group status
     *
     * @private
     * @returns {string} Space-separated string of CSS class names
     */
    private getCssClasses;
    static ɵfac: i0.ɵɵFactoryDeclaration<EuiTimelineItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EuiTimelineItemComponent, "eui-timeline-item", never, { "e2eAttr": { "alias": "e2eAttr"; "required": false; }; "label": { "alias": "label"; "required": false; }; "subLabel": { "alias": "subLabel"; "required": false; }; "date": { "alias": "date"; "required": false; }; "dateStyleClass": { "alias": "dateStyleClass"; "required": false; }; "time": { "alias": "time"; "required": false; }; "timeStyleClass": { "alias": "timeStyleClass"; "required": false; }; "isLeftAligned": { "alias": "isLeftAligned"; "required": false; }; "isGroup": { "alias": "isGroup"; "required": false; }; }, {}, never, ["*"], true, [{ directive: typeof i1.BaseStatesDirective; inputs: { "euiSecondary": "euiSecondary"; "euiPrimary": "euiPrimary"; "euiSuccess": "euiSuccess"; "euiInfo": "euiInfo"; "euiWarning": "euiWarning"; "euiDanger": "euiDanger"; "euiAccent": "euiAccent"; "euiVariant": "euiVariant"; }; outputs: {}; }]>;
    static ngAcceptInputType_isLeftAligned: unknown;
    static ngAcceptInputType_isGroup: unknown;
}
//# sourceMappingURL=eui-timeline-item.component.d.ts.map