/**
 * Configuration interface for the EUI DateTime Picker component.
 * Defines the structure and behavior settings for the datetime picker.
 *
 * @interface EuiDateTimePickerConfig
 */
export interface EuiDateTimePickerConfig {
    /**
     * Initial hours value (0-23)
     */
    hours: number;
    /**
     * Initial minutes value (0-59)
     */
    mins: number;
    /**
     * Optional initial seconds value (0-59)
     */
    secs?: number;
    /**
     * Indicates if the component is used as a datetime picker
     */
    isDatetimepicker: boolean;
    /**
     * Controls whether seconds selection is enabled
     */
    hasSeconds: boolean;
    /**
     * When true, displays a single input field for time entry instead of separate inputs
     */
    isOneInputField: boolean;
    /**
     * Step interval for hours increment/decrement
     */
    stepHours: number;
    /**
     * Step interval for minutes increment/decrement
     */
    stepMinutes: number;
    /**
     * Step interval for seconds increment/decrement
     */
    stepSeconds: number;
    /**
     * Callback function triggered when time value changes
     *
     * @param hours - The selected hours value
     * @param mins - The selected minutes value
     * @param secs - The selected seconds value (if enabled)
     */
    callbackFn: (hours: number, mins: number, secs?: number) => void;
}
//# sourceMappingURL=eui-date-time-picker.config.model.d.ts.map