import * as i0 from '@angular/core';
import { Input, HostBinding, Component, NgModule } from '@angular/core';
import { coerceBooleanProperty } from '@angular/cdk/coercion';
import * as i2 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import * as i1 from '@eui/components/eui-label';
import { EUI_LABEL } from '@eui/components/eui-label';
import * as i3 from '@eui/components/eui-icon-state';
import { EUI_ICON_STATE } from '@eui/components/eui-icon-state';
import { DatePipe } from '@angular/common';

/**
 * @description
 * Component for displaying individual items within a discussion thread.
 * This component represents a single entry in a conversation or thread timeline,
 * displaying information such as the author, date, content body, and optional tooltip.
 *
 * The component applies the ARIA role 'listitem' to maintain proper accessibility
 * and includes support for styling variants through the typeClass property.
 */
class EuiDiscussionThreadItemComponent {
    constructor() {
        /**
         * ARIA role for the host element to ensure proper accessibility.
         * @default 'listitem'
         */
        this.role = 'listitem';
        this._isOdd = false;
    }
    /**
     * Sets CSS classes on the host element based on the typeClass property.
     * This helps maintain consistent styling with the parent theme variant.
     * @returns {string} The CSS class to be applied
     */
    get cssClasses() {
        return `eui--${this.typeClass}`; // simulate parent variant for icon auto-contrast color fill
    }
    /**
     * Indicates if this item is in an odd position in the list.
     * Used for alternating styling patterns within the thread.
     */
    get isOdd() {
        return this._isOdd;
    }
    set isOdd(value) {
        this._isOdd = coerceBooleanProperty(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadItemComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.12", type: EuiDiscussionThreadItemComponent, isStandalone: true, selector: "eui-discussion-thread-item", inputs: { id: "id", typeClass: "typeClass", date: "date", author: "author", body: "body", tooltip: "tooltip", isOdd: "isOdd" }, host: { properties: { "class": "this.cssClasses", "attr.role": "this.role" } }, ngImport: i0, template: "<li role=\"none\" class=\"eui-discussion-thread__item\" [class.eui-discussion-thread__item--inverted]=\"isOdd\">\n    <div class=\"eui-discussion-thread__item-badge eui-discussion-thread__item-badge--{{ typeClass }}\" title=\"{{ tooltip }}\">\n        <eui-icon-state [euiVariant]=\"typeClass\" size=\"xl\" class=\"eui-alert__icon-type\"/>\n    </div>\n    <div class=\"eui-discussion-thread__item-panel\">\n        <div class=\"eui-discussion-thread__item-panel-header\">\n            <div class=\"eui-discussion-thread__item-panel-heading\">\n                <div class=\"eui-discussion-thread__item-panel-title\">\n                    {{ date | date: 'dd/MM/YYYY' }}\n                </div>\n                <div class=\"eui-discussion-thread__item-panel-time\">\n                    <eui-icon-svg icon=\"time\" set=\"outline\" size=\"s\" fillColor=\"neutral-light\" class=\"eui-discussion-thread__item-panel-time-icon\"></eui-icon-svg>\n                    <span euiLabel euiSizeS>{{ date | date: 'HH:mm' }}</span>\n                </div>\n            </div>\n            <div class=\"eui-discussion-thread__item-panel-subheading\">\n                {{ author }}\n            </div>\n        </div>\n        <div class=\"eui-discussion-thread__item-panel-body\">\n            <p class=\"eui-discussion-thread__item-panel-body-word-break\" [innerHTML]=\"body\"></p>\n        </div>\n    </div>\n</li>\n", styles: [".eui-19 :host .eui-discussion-thread__item{margin-bottom:var(--eui-s-m);position:relative}.eui-19 :host .eui-discussion-thread__item:before,.eui-19 :host .eui-discussion-thread__item:after{content:\" \";display:table}.eui-19 :host .eui-discussion-thread__item:after{clear:both}.eui-19 :host .eui-discussion-thread__item-panel{background-color:var(--eui-c-white);border:var(--eui-bw-xs) solid var(--eui-c-divider);border-radius:var(--eui-br-xl);box-shadow:var(--eui-sh-card);float:left;padding:var(--eui-s-m) var(--eui-s-m) 0;position:relative;width:44%}.eui-19 :host .eui-discussion-thread__item-panel:before{border-bottom:15px solid transparent;border-left:15px solid #ccc;border-right:0 solid #ccc;border-top:15px solid transparent;content:\" \";display:inline-block;position:absolute;right:-15px;top:26px}.eui-19 :host .eui-discussion-thread__item-panel:after{border-bottom:14px solid transparent;border-left:14px solid var(--eui-c-white);border-right:0 solid var(--eui-c-white);border-top:14px solid transparent;content:\" \";display:inline-block;position:absolute;right:-14px;top:27px}.eui-19 :host .eui-discussion-thread__item-badge{background-color:var(--eui-c-white);position:absolute;left:50%;width:50px;margin-left:-22px;top:22px}.eui-19 :host .eui-discussion-thread__item-panel-header{border-bottom:1px solid var(--eui-c-divider);margin-bottom:var(--eui-s-s);padding-bottom:var(--eui-s-s)}.eui-19 :host .eui-discussion-thread__item-panel-heading{align-items:center;display:flex;justify-content:space-between}.eui-19 :host .eui-discussion-thread__item-panel-heading .eui-discussion-thread__item-panel-title{align-items:center;display:flex;font:var(--eui-f-m-bold)}.eui-19 :host .eui-discussion-thread__item-panel-heading .eui-discussion-thread__item-panel-time{align-items:center;display:flex;margin-left:auto;font:var(--eui-f-s)}.eui-19 :host .eui-discussion-thread__item-panel-heading .eui-discussion-thread__item-panel-time-icon{margin-right:var(--eui-s-xs)}.eui-19 :host .eui-discussion-thread__item-panel-subheading{margin-top:var(--eui-s-xs)}.eui-19 :host .eui-discussion-thread__item-panel-body{margin:var(--eui-s-m) 0}.eui-19 :host .eui-discussion-thread__item-panel-body__word-break{word-break:break-word}.eui-19 :host hr .eui-discussion-thread-separator{border-top:1px solid var(--eui-c-black);height:1px;margin:0!important;opacity:.4}.eui-19 :host .eui-discussion-thread__item-panel-body>p,.eui-19 :host .eui-discussion-thread__item-panel-body>ul{margin-bottom:0}.eui-19 :host .eui-discussion-thread__item-panel-body>p+p{margin-top:5px}.eui-19 :host .eui-discussion-thread__item-panel-footer{border-top:1px solid rgba(0,0,0,.2);margin:0 0 .5rem}.eui-19 :host .eui-discussion-thread__item-panel-tooltip{background-color:#000000bf;font:var(--eui-f-s)}.eui-19 :host .eui-discussion-thread__item--inverted .eui-discussion-thread__item-panel{float:right}.eui-19 :host .eui-discussion-thread__item--inverted .eui-discussion-thread__item-panel:before{border-left-width:0;border-right-width:15px;left:-15px;right:auto}.eui-19 :host .eui-discussion-thread__item--inverted .eui-discussion-thread__item-panel:after{border-left-width:0;border-right-width:14px;left:-14px;right:auto}@media screen and (min-width: 1140px){.eui-19 :host .eui-discussion-thread-panel{width:42%}}@media screen and (min-width: 768px) and (max-width: 995px){.eui-19 :host .eui-discussion-thread-panel{float:right;width:calc(100% - 90px);width:-moz-calc(100% - 90px);width:-webkit-calc(100% - 90px)}.eui-19 :host .eui-discussion-thread-badge{left:15px;margin-left:0;top:16px}.eui-19 :host .eui-discussion-thread-panel:before{border-left-width:0;border-right-width:15px;left:-15px;right:auto}.eui-19 :host .eui-discussion-thread-panel:after{border-left-width:0;border-right-width:14px;left:-14px;right:auto}}\n"], dependencies: [{ kind: "component", type: i1.EuiLabelComponent, selector: "label[euiLabel], span[euiLabel], div[euiLabel], a[euiLabel], eui-label,               label[euiSublabel], span[euiSublabel], div[euiSublabel], a[euiSublabel], eui-sublabel", inputs: ["euiRequired", "euiReadonly", "euiSublabel"] }, { kind: "component", type: i2.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i3.EuiIconStateComponent, selector: "eui-icon-state", inputs: ["size", "ariaLabel"] }, { kind: "pipe", type: DatePipe, name: "date" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-discussion-thread-item', imports: [
                        ...EUI_LABEL,
                        ...EUI_ICON,
                        ...EUI_ICON_STATE,
                        DatePipe,
                    ], template: "<li role=\"none\" class=\"eui-discussion-thread__item\" [class.eui-discussion-thread__item--inverted]=\"isOdd\">\n    <div class=\"eui-discussion-thread__item-badge eui-discussion-thread__item-badge--{{ typeClass }}\" title=\"{{ tooltip }}\">\n        <eui-icon-state [euiVariant]=\"typeClass\" size=\"xl\" class=\"eui-alert__icon-type\"/>\n    </div>\n    <div class=\"eui-discussion-thread__item-panel\">\n        <div class=\"eui-discussion-thread__item-panel-header\">\n            <div class=\"eui-discussion-thread__item-panel-heading\">\n                <div class=\"eui-discussion-thread__item-panel-title\">\n                    {{ date | date: 'dd/MM/YYYY' }}\n                </div>\n                <div class=\"eui-discussion-thread__item-panel-time\">\n                    <eui-icon-svg icon=\"time\" set=\"outline\" size=\"s\" fillColor=\"neutral-light\" class=\"eui-discussion-thread__item-panel-time-icon\"></eui-icon-svg>\n                    <span euiLabel euiSizeS>{{ date | date: 'HH:mm' }}</span>\n                </div>\n            </div>\n            <div class=\"eui-discussion-thread__item-panel-subheading\">\n                {{ author }}\n            </div>\n        </div>\n        <div class=\"eui-discussion-thread__item-panel-body\">\n            <p class=\"eui-discussion-thread__item-panel-body-word-break\" [innerHTML]=\"body\"></p>\n        </div>\n    </div>\n</li>\n", styles: [".eui-19 :host .eui-discussion-thread__item{margin-bottom:var(--eui-s-m);position:relative}.eui-19 :host .eui-discussion-thread__item:before,.eui-19 :host .eui-discussion-thread__item:after{content:\" \";display:table}.eui-19 :host .eui-discussion-thread__item:after{clear:both}.eui-19 :host .eui-discussion-thread__item-panel{background-color:var(--eui-c-white);border:var(--eui-bw-xs) solid var(--eui-c-divider);border-radius:var(--eui-br-xl);box-shadow:var(--eui-sh-card);float:left;padding:var(--eui-s-m) var(--eui-s-m) 0;position:relative;width:44%}.eui-19 :host .eui-discussion-thread__item-panel:before{border-bottom:15px solid transparent;border-left:15px solid #ccc;border-right:0 solid #ccc;border-top:15px solid transparent;content:\" \";display:inline-block;position:absolute;right:-15px;top:26px}.eui-19 :host .eui-discussion-thread__item-panel:after{border-bottom:14px solid transparent;border-left:14px solid var(--eui-c-white);border-right:0 solid var(--eui-c-white);border-top:14px solid transparent;content:\" \";display:inline-block;position:absolute;right:-14px;top:27px}.eui-19 :host .eui-discussion-thread__item-badge{background-color:var(--eui-c-white);position:absolute;left:50%;width:50px;margin-left:-22px;top:22px}.eui-19 :host .eui-discussion-thread__item-panel-header{border-bottom:1px solid var(--eui-c-divider);margin-bottom:var(--eui-s-s);padding-bottom:var(--eui-s-s)}.eui-19 :host .eui-discussion-thread__item-panel-heading{align-items:center;display:flex;justify-content:space-between}.eui-19 :host .eui-discussion-thread__item-panel-heading .eui-discussion-thread__item-panel-title{align-items:center;display:flex;font:var(--eui-f-m-bold)}.eui-19 :host .eui-discussion-thread__item-panel-heading .eui-discussion-thread__item-panel-time{align-items:center;display:flex;margin-left:auto;font:var(--eui-f-s)}.eui-19 :host .eui-discussion-thread__item-panel-heading .eui-discussion-thread__item-panel-time-icon{margin-right:var(--eui-s-xs)}.eui-19 :host .eui-discussion-thread__item-panel-subheading{margin-top:var(--eui-s-xs)}.eui-19 :host .eui-discussion-thread__item-panel-body{margin:var(--eui-s-m) 0}.eui-19 :host .eui-discussion-thread__item-panel-body__word-break{word-break:break-word}.eui-19 :host hr .eui-discussion-thread-separator{border-top:1px solid var(--eui-c-black);height:1px;margin:0!important;opacity:.4}.eui-19 :host .eui-discussion-thread__item-panel-body>p,.eui-19 :host .eui-discussion-thread__item-panel-body>ul{margin-bottom:0}.eui-19 :host .eui-discussion-thread__item-panel-body>p+p{margin-top:5px}.eui-19 :host .eui-discussion-thread__item-panel-footer{border-top:1px solid rgba(0,0,0,.2);margin:0 0 .5rem}.eui-19 :host .eui-discussion-thread__item-panel-tooltip{background-color:#000000bf;font:var(--eui-f-s)}.eui-19 :host .eui-discussion-thread__item--inverted .eui-discussion-thread__item-panel{float:right}.eui-19 :host .eui-discussion-thread__item--inverted .eui-discussion-thread__item-panel:before{border-left-width:0;border-right-width:15px;left:-15px;right:auto}.eui-19 :host .eui-discussion-thread__item--inverted .eui-discussion-thread__item-panel:after{border-left-width:0;border-right-width:14px;left:-14px;right:auto}@media screen and (min-width: 1140px){.eui-19 :host .eui-discussion-thread-panel{width:42%}}@media screen and (min-width: 768px) and (max-width: 995px){.eui-19 :host .eui-discussion-thread-panel{float:right;width:calc(100% - 90px);width:-moz-calc(100% - 90px);width:-webkit-calc(100% - 90px)}.eui-19 :host .eui-discussion-thread-badge{left:15px;margin-left:0;top:16px}.eui-19 :host .eui-discussion-thread-panel:before{border-left-width:0;border-right-width:15px;left:-15px;right:auto}.eui-19 :host .eui-discussion-thread-panel:after{border-left-width:0;border-right-width:14px;left:-14px;right:auto}}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], id: [{
                type: Input
            }], typeClass: [{
                type: Input
            }], date: [{
                type: Input
            }], author: [{
                type: Input
            }], body: [{
                type: Input
            }], tooltip: [{
                type: Input
            }], isOdd: [{
                type: Input
            }] } });

/**
 * @description
 * Component for displaying a discussion thread or conversation timeline.
 * This component renders a list of discussion thread items in a structured format,
 * with support for titles, subtitles, and tooltips for additional context.
 *
 * The component applies the ARIA role 'list' to the host element to maintain proper
 * accessibility for screen readers.
 *
 */
class EuiDiscussionThreadComponent {
    constructor() {
        /**
         * ARIA role for the host element to ensure proper accessibility.
         * @default 'list'
         */
        this.role = 'list';
    }
    /**
     * Gets the CSS classes to apply to the host element.
     *
     * @returns {string} The CSS classes as a space-separated string.
     */
    get cssClasses() {
        return ['eui-discussion-thread'].join(' ').trim();
    }
    /**
     * Track by function for ngFor directive to improve rendering performance.
     * Uses the id property of each discussion thread item.
     *
     * @deprecated It will be removed in the next major version.
     *
     * @param index - The index of the current item in the array
     * @param item - The current discussion thread item
     * @returns The unique identifier for the item
     */
    trackByFn(index, item) {
        return item.id;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiDiscussionThreadComponent, isStandalone: true, selector: "eui-discussion-thread", inputs: { items: "items", titleLabel: "titleLabel", subTitleLabel: "subTitleLabel", tooltip: "tooltip" }, host: { properties: { "class": "this.cssClasses", "attr.role": "this.role" } }, ngImport: i0, template: "<div class=\"eui-discussion-thread-wrapper-header\">\n    <div class=\"eui-discussion-thread-wrapper-header__title\">{{ titleLabel }}</div>\n    <div class=\"eui-discussion-thread-wrapper-header__subtitle\">{{ subTitleLabel }}</div>\n</div>\n<ul role=\"none\" class=\"eui-discussion-thread-content\">\n    @if (items) {\n        @for (item of items; track item.id; let o = $odd; let e = $even;) {\n            <eui-discussion-thread-item\n                [isOdd]=\"o\"\n                id=\"{{ item.id }}\"\n                typeClass=\"{{ item.typeClass }}\"\n                date=\"{{ item.date }}\"\n                author=\"{{ item.author }}\"\n                body=\"{{ item.body }}\"\n                tooltip=\"{{ item.tooltip }}\">\n            </eui-discussion-thread-item>\n        }\n    }\n\n    @if (!items) {\n        <ng-content></ng-content>\n    }\n</ul>\n", styles: [".eui-19 :host.eui-discussion-thread{margin:0;padding:0;position:relative}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-wrapper-header{display:flex;flex-direction:column;position:relative;width:100%}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-wrapper-header__title{border-bottom:1px solid var(--eui-c-divider);display:flex;margin-bottom:var(--eui-s-xs);padding-bottom:var(--eui-s-2xs);width:100%;font:var(--eui-f-m-bold)}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-wrapper-header__subtitle{color:var(--eui-c-neutral);display:flex;width:100%;font:var(--eui-f-m)}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-content{list-style:none;padding:20px 0;position:relative}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-content:before{background-color:var(--eui-c-neutral-lightest);bottom:0;content:\" \";left:50%;margin-left:-1.5px;position:absolute;top:0;width:2px}\n"], dependencies: [{ kind: "component", type: EuiDiscussionThreadItemComponent, selector: "eui-discussion-thread-item", inputs: ["id", "typeClass", "date", "author", "body", "tooltip", "isOdd"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-discussion-thread', imports: [
                        EuiDiscussionThreadItemComponent,
                        ...EUI_ICON,
                        ...EUI_LABEL,
                    ], template: "<div class=\"eui-discussion-thread-wrapper-header\">\n    <div class=\"eui-discussion-thread-wrapper-header__title\">{{ titleLabel }}</div>\n    <div class=\"eui-discussion-thread-wrapper-header__subtitle\">{{ subTitleLabel }}</div>\n</div>\n<ul role=\"none\" class=\"eui-discussion-thread-content\">\n    @if (items) {\n        @for (item of items; track item.id; let o = $odd; let e = $even;) {\n            <eui-discussion-thread-item\n                [isOdd]=\"o\"\n                id=\"{{ item.id }}\"\n                typeClass=\"{{ item.typeClass }}\"\n                date=\"{{ item.date }}\"\n                author=\"{{ item.author }}\"\n                body=\"{{ item.body }}\"\n                tooltip=\"{{ item.tooltip }}\">\n            </eui-discussion-thread-item>\n        }\n    }\n\n    @if (!items) {\n        <ng-content></ng-content>\n    }\n</ul>\n", styles: [".eui-19 :host.eui-discussion-thread{margin:0;padding:0;position:relative}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-wrapper-header{display:flex;flex-direction:column;position:relative;width:100%}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-wrapper-header__title{border-bottom:1px solid var(--eui-c-divider);display:flex;margin-bottom:var(--eui-s-xs);padding-bottom:var(--eui-s-2xs);width:100%;font:var(--eui-f-m-bold)}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-wrapper-header__subtitle{color:var(--eui-c-neutral);display:flex;width:100%;font:var(--eui-f-m)}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-content{list-style:none;padding:20px 0;position:relative}.eui-19 :host.eui-discussion-thread .eui-discussion-thread-content:before{background-color:var(--eui-c-neutral-lightest);bottom:0;content:\" \";left:50%;margin-left:-1.5px;position:absolute;top:0;width:2px}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], items: [{
                type: Input
            }], titleLabel: [{
                type: Input
            }], subTitleLabel: [{
                type: Input
            }], tooltip: [{
                type: Input
            }] } });

/**
 * @description
 * Provides components for displaying structured discussion threads and conversation timelines.
 *
 * @deprecated Use {@link EUI_DISCUSSION_THREAD} instead.
 *
 * @see EuiDiscussionThreadComponent
 * @see EuiDiscussionThreadItemComponent
 */
class EuiDiscussionThreadModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadModule, imports: [EuiDiscussionThreadComponent, EuiDiscussionThreadItemComponent], exports: [EuiDiscussionThreadComponent, EuiDiscussionThreadItemComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadModule, imports: [EuiDiscussionThreadComponent, EuiDiscussionThreadItemComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDiscussionThreadModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiDiscussionThreadComponent, EuiDiscussionThreadItemComponent],
                    exports: [EuiDiscussionThreadComponent, EuiDiscussionThreadItemComponent],
                }]
        }] });

const EUI_DISCUSSION_THREAD = [
    EuiDiscussionThreadComponent,
    EuiDiscussionThreadItemComponent,
];

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_DISCUSSION_THREAD, EuiDiscussionThreadComponent, EuiDiscussionThreadItemComponent, EuiDiscussionThreadModule };
//# sourceMappingURL=eui-components-eui-discussion-thread.mjs.map
