import * as i0 from '@angular/core';
import { Pipe, EventEmitter, inject, ChangeDetectorRef, booleanAttribute, ContentChildren, Input, Output, ViewEncapsulation, ChangeDetectionStrategy, Component, HostListener, ViewChildren, HostBinding, Injectable, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import * as i1$1 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';
import * as i1 from '@eui/components/eui-button';
import { EUI_BUTTON } from '@eui/components/eui-button';
import * as i2 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import { EuiTemplateDirective } from '@eui/components/directives';
import { NgTemplateOutlet } from '@angular/common';
import * as i3 from '@eui/components/eui-label';
import { EUI_LABEL } from '@eui/components/eui-label';
import { HttpClient, HttpEventType } from '@angular/common/http';
import { tap, filter, map } from 'rxjs/operators';
import { pipe, zip, of, Observable } from 'rxjs';

/**
 * A pipe that transforms a file size in bytes into a human-readable format (e.g., KB, MB, GB).
 *
 * @example
 * {{ 1024 | filesize }}  // Outputs: "1.00 KB"
 * {{ 1048576 | filesize:1 }}  // Outputs: "1.0 MB"
 *
 * @param {number} bytes - The file size in bytes.
 * @param {number} [precision=2] - The number of decimal places to include in the output.
 * @returns {string} The formatted file size with the appropriate unit.
 */
class EuiFileSizePipe {
    constructor() {
        this.units = ['bytes', 'KB', 'MB', 'GB', 'TB', 'PB'];
    }
    /**
     * Method used to format a size.
     *
     * @param bytes Bytes to format.
     * @param precision Number of decimal
     * @returns String with formated size and unit.
     */
    transform(bytes = 0, precision = 2) {
        if (isNaN(parseFloat(String(bytes))) || !isFinite(bytes)) {
            return '?';
        }
        let unit = 0;
        while (bytes >= 1024) {
            bytes /= 1024;
            unit++;
        }
        return bytes.toFixed(+precision) + ' ' + this.units[unit];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileSizePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiFileSizePipe, isStandalone: true, name: "filesize" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileSizePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'filesize',
                }]
        }] });

/**
 * @description
 * Internal class used by `eui-file-upload` to display the files to be uploaded.
 */
class EuiFilePreviewComponent {
    constructor() {
        /**
         * Object matching extension and icon.
         */
        this.previewAsIconConfig = {
            avi: 'eui-file-video',
            html: 'eui-file-html',
            htm: 'eui-file-code',
            js: 'eui-file-code',
            json: 'eui-file-code',
            mp3: 'eui-file-audio',
            mp4: 'eui-file-video',
            pdf: 'eui-file-pdf',
            png: 'eui-file-image',
            svg: 'eui-file-image',
            txt: 'eui-file-text',
            xml: 'eui-file-code',
            jpeg: 'eui-file-image',
            jpg: 'eui-file-image',
            zip: 'eui-file-archive',
            doc: 'eui-file-word',
            docx: 'eui-file-word-o',
            xls: 'eui-file-excel-o',
            xlsx: 'eui-file-excel-o',
            ppt: 'eui-file-powerpoint',
            csv: 'eui-file-text',
            rtf: 'eui-file-text',
        };
        /**
         * Event emitted when the remove button is clicked.
         */
        this.removeFromList = new EventEmitter();
        this.isLoading = false;
        /**
         * Event emitted when a chosen file to upload is clicked.
         */
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.itemClick = new EventEmitter();
        /**
         * Whether a preview, image or icon, is displayed for a file to upload.
         *
         * @default true
         */
        this.hasPreview = true;
        /**
         * Whether the filename is displayed.
         *
         * @default true
         */
        this.isFilenameDisplayed = true;
        /**
         * Whether the filesize is displayed.
         *
         * @default true
         */
        this.isFilesizeDisplayed = true;
        /**
         * Whether the file type is displayed.
         *
         * @default true
         */
        this.isFiletypeDisplayed = true;
        /**
         * Whether a preview is displayed as image.
         *
         * @default true
         */
        this.hasPreviewAsImage = true;
        /**
         * Whether a preview is displayed as a file format icon.
         *
         * @default false
         */
        this.hasPreviewAsIcon = false;
        /**
         * Whether items can be clicked. `itemClick` event is emitted.
         *
         * @default false
         */
        this.isItemsClickable = false;
        /**
         * Whether the file is `File` or has been provided by the user as initial value.
         *
         * @default false
         */
        this.isFileObject = false;
        this.cd = inject(ChangeDetectorRef);
    }
    ngOnInit() {
        if (this.hasPreviewAsIcon) {
            this.hasPreviewAsImage = false;
        }
        if (this.file instanceof Blob) {
            const reader = new FileReader();
            reader.readAsArrayBuffer(this.file);
            // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            reader.onload = (event) => {
                this.url = event.target.result;
                this.fileExtension = this.getFileExtension(this.file.name);
                this.icon = this.getIconForMime(this.fileExtension);
                const blob = new Blob([reader.result], { type: this.file.type });
                const imageUrl = URL.createObjectURL(blob);
                this.previewData = this.getPreviewForMime(this.fileExtension, imageUrl);
                this.cd.detectChanges();
            };
            reader.onloadstart = (event) => {
                this.isLoading = true;
                this.cd.detectChanges();
            };
            reader.onloadend = (event) => {
                this.isLoading = false;
                this.cd.detectChanges();
            };
        }
        else {
            this.url = this.file.url;
            this.fileExtension = this.getFileExtension(this.file.name);
            this.icon = this.getIconForMime(this.fileExtension);
            this.previewData = this.getPreviewForMime(this.fileExtension, this.url);
            this.cd.detectChanges();
        }
    }
    ngAfterViewInit() {
        this.templates.forEach((item) => {
            if (item.getType() === 'uploadedFile') {
                this.uploadedFileTemplate = item.template;
            }
        });
    }
    /**
     * Remove from the list handler.
     */
    onRemoveFromList() {
        this.removeFromList.emit(this.index);
    }
    /**
     * Click item handler.
     * @param e The item clicked.
     */
    onItemClick(e) {
        this.itemClick.emit(this.file);
        e.preventDefault();
    }
    /**
     * Method returning a file extension.
     *
     * @param fileName Filename of the file
     * @returns the extension as a string
     */
    getFileExtension(fileName) {
        const ext = fileName.split('.');
        return ext[ext.length - 1];
    }
    /**
     * Method that returns the preview for a file.
     *
     * @param fileExtension Extension of the file
     * @param imgUrl URL of the file
     * @returns The image URL of valid image otherwise an icon of the extension
     */
    getPreviewForMime(fileExtension, imgUrl) {
        const f = fileExtension.toLowerCase();
        const image = f === 'jpeg' || f === 'jpg' || f === 'png' || f === 'gif' ? true : false;
        const display = f === 'jpeg' || f === 'jpg' || f === 'png' || f === 'gif' ? imgUrl : this.getIconForMime(f);
        return { image, display };
    }
    /**
     * Method that return the icon for a MIME type.
     *
     * @param fileExtension Extension of the file
     * @returns An icon string
     */
    getIconForMime(fileExtension) {
        const f = fileExtension.toLowerCase();
        return !this.previewAsIconConfig[f] ? 'eui-file-empty-o' : this.previewAsIconConfig[f];
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFilePreviewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiFilePreviewComponent, isStandalone: true, selector: "eui-file-preview", inputs: { file: "file", uploadedFileTemplate: "uploadedFileTemplate", index: "index", previewAsIconConfig: "previewAsIconConfig", hasPreview: ["hasPreview", "hasPreview", booleanAttribute], isFilenameDisplayed: ["isFilenameDisplayed", "isFilenameDisplayed", booleanAttribute], isFilesizeDisplayed: ["isFilesizeDisplayed", "isFilesizeDisplayed", booleanAttribute], isFiletypeDisplayed: ["isFiletypeDisplayed", "isFiletypeDisplayed", booleanAttribute], hasPreviewAsImage: ["hasPreviewAsImage", "hasPreviewAsImage", booleanAttribute], hasPreviewAsIcon: ["hasPreviewAsIcon", "hasPreviewAsIcon", booleanAttribute], isItemsClickable: ["isItemsClickable", "isItemsClickable", booleanAttribute], isFileObject: ["isFileObject", "isFileObject", booleanAttribute] }, outputs: { removeFromList: "removeFromList", itemClick: "itemClick" }, queries: [{ propertyName: "templates", predicate: EuiTemplateDirective }], ngImport: i0, template: "@if (uploadedFileTemplate) {\n    <ng-template\n        [ngTemplateOutlet]=\"uploadedFileTemplate\"\n        [ngTemplateOutletContext]=\"{ $implicit: { file: { id: file.id, name: file.name, url: file.url || previewData?.display, size: file.size, type: file.type }, index, isFileObject } }\" />\n} @else {\n    <div class=\"eui-file-upload__preview\">\n        <div class=\"eui-file-upload__preview--left\">\n            @if (hasPreview && hasPreviewAsImage) {\n                <div class=\"eui-file-upload__preview--left__image\">\n                    @if (url && previewData.image) {\n                        <img [src]=\"previewData.display\" />\n                    }\n                    @if (previewData && !previewData.image) {\n                        <eui-icon-svg icon=\"{{ previewData.display }}\" size=\"l\" fillColor=\"info-100\" class=\"eui-u-mr-s\"></eui-icon-svg>\n                    }\n                    @if (isLoading) {\n                        <div class=\"loading-container\">\n                            <eui-icon-svg isLoading size=\"2xl\"></eui-icon-svg>\n                        </div>\n                    }\n                </div>\n            }\n            @if (hasPreview && hasPreviewAsIcon) {\n                <div>\n                    <eui-icon-svg icon=\"{{ icon }}\" size=\"l\" fillColor=\"info-100\" class=\"eui-u-mr-s\"></eui-icon-svg>\n                </div>\n            }\n            @if (isFilenameDisplayed) {\n                <div class=\"eui-file-upload__preview--left__filename eui-u-text-truncate\">\n                    @if (!isItemsClickable) {\n                        {{ file.name }}\n                    }\n                    @if (isItemsClickable) {\n                        <a href=\"#\" (click)=\"onItemClick($event)\" class=\"eui-u-text-link eui-u-text-truncate\">{{ file.name }}</a>\n                    }\n                </div>\n            }\n        </div>\n        <div class=\"eui-file-upload__preview--right\">\n            @if (isFilesizeDisplayed) {\n                <div class=\"eui-u-text-no-wrap\">{{ file.size | filesize }}</div>\n            }\n            @if (isFiletypeDisplayed) {\n                <div><span euiLabel>{{ file.type }}</span></div>\n            }\n            <div>\n                <button euiButton euiDanger euiRounded euiIconButton euiBasicButton type=\"button\" (click)=\"onRemoveFromList()\">\n                    <eui-icon-svg icon=\"trash:outline\"></eui-icon-svg>\n                </button>\n            </div>\n        </div>\n    </div>\n}\n", dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i1.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }, { kind: "component", type: i2.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i3.EuiLabelComponent, selector: "label[euiLabel], span[euiLabel], div[euiLabel], a[euiLabel], eui-label,               label[euiSublabel], span[euiSublabel], div[euiSublabel], a[euiSublabel], eui-sublabel", inputs: ["euiRequired", "euiReadonly", "euiSublabel"] }, { kind: "pipe", type: EuiFileSizePipe, name: "filesize" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFilePreviewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-file-preview', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [
                        NgTemplateOutlet,
                        ...EUI_BUTTON,
                        ...EUI_ICON,
                        ...EUI_LABEL,
                        EuiFileSizePipe,
                    ], template: "@if (uploadedFileTemplate) {\n    <ng-template\n        [ngTemplateOutlet]=\"uploadedFileTemplate\"\n        [ngTemplateOutletContext]=\"{ $implicit: { file: { id: file.id, name: file.name, url: file.url || previewData?.display, size: file.size, type: file.type }, index, isFileObject } }\" />\n} @else {\n    <div class=\"eui-file-upload__preview\">\n        <div class=\"eui-file-upload__preview--left\">\n            @if (hasPreview && hasPreviewAsImage) {\n                <div class=\"eui-file-upload__preview--left__image\">\n                    @if (url && previewData.image) {\n                        <img [src]=\"previewData.display\" />\n                    }\n                    @if (previewData && !previewData.image) {\n                        <eui-icon-svg icon=\"{{ previewData.display }}\" size=\"l\" fillColor=\"info-100\" class=\"eui-u-mr-s\"></eui-icon-svg>\n                    }\n                    @if (isLoading) {\n                        <div class=\"loading-container\">\n                            <eui-icon-svg isLoading size=\"2xl\"></eui-icon-svg>\n                        </div>\n                    }\n                </div>\n            }\n            @if (hasPreview && hasPreviewAsIcon) {\n                <div>\n                    <eui-icon-svg icon=\"{{ icon }}\" size=\"l\" fillColor=\"info-100\" class=\"eui-u-mr-s\"></eui-icon-svg>\n                </div>\n            }\n            @if (isFilenameDisplayed) {\n                <div class=\"eui-file-upload__preview--left__filename eui-u-text-truncate\">\n                    @if (!isItemsClickable) {\n                        {{ file.name }}\n                    }\n                    @if (isItemsClickable) {\n                        <a href=\"#\" (click)=\"onItemClick($event)\" class=\"eui-u-text-link eui-u-text-truncate\">{{ file.name }}</a>\n                    }\n                </div>\n            }\n        </div>\n        <div class=\"eui-file-upload__preview--right\">\n            @if (isFilesizeDisplayed) {\n                <div class=\"eui-u-text-no-wrap\">{{ file.size | filesize }}</div>\n            }\n            @if (isFiletypeDisplayed) {\n                <div><span euiLabel>{{ file.type }}</span></div>\n            }\n            <div>\n                <button euiButton euiDanger euiRounded euiIconButton euiBasicButton type=\"button\" (click)=\"onRemoveFromList()\">\n                    <eui-icon-svg icon=\"trash:outline\"></eui-icon-svg>\n                </button>\n            </div>\n        </div>\n    </div>\n}\n" }]
        }], propDecorators: { file: [{
                type: Input
            }], uploadedFileTemplate: [{
                type: Input
            }], index: [{
                type: Input
            }], previewAsIconConfig: [{
                type: Input
            }], removeFromList: [{
                type: Output
            }], itemClick: [{
                type: Output
            }], hasPreview: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isFilenameDisplayed: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isFilesizeDisplayed: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isFiletypeDisplayed: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasPreviewAsImage: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasPreviewAsIcon: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isItemsClickable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isFileObject: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], templates: [{
                type: ContentChildren,
                args: [EuiTemplateDirective]
            }] } });

class EuiFileUploadProgressComponent {
    constructor() {
        /**
         * Sets the progress of upload to be displayed by the progress bar.
         *
         * @type {number}
         */
        this.progress = 0;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadProgressComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiFileUploadProgressComponent, isStandalone: true, selector: "eui-file-upload-progress", inputs: { progress: "progress" }, ngImport: i0, template: "@if (progress > 0) {\n    <div class=\"eui-file-upload__progress-bar-container\">\n        <div class=\"progress-bar\" [style.width]=\"progress + '%'\"></div>\n    </div>\n    <div>{{ progress }}%</div>\n}\n", changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadProgressComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-file-upload-progress', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, template: "@if (progress > 0) {\n    <div class=\"eui-file-upload__progress-bar-container\">\n        <div class=\"progress-bar\" [style.width]=\"progress + '%'\"></div>\n    </div>\n    <div>{{ progress }}%</div>\n}\n" }]
        }], propDecorators: { progress: [{
                type: Input
            }] } });

/**
 * @description
 * `eui-file-upload` allows the user to upload a file to a server. It can be use in the classic simple file way or with a drag and drop feature.
 */
class EuiFileUploadComponent {
    constructor() {
        /**
         * Sets the `data-e2e` attribute for the host element.
         *
         * @default 'eui-file-upload'
         */
        this.e2eAttr = 'eui-file-upload';
        /**
         * A comma separated list of extension allowed to be uploaded by the user.
         *
         * @default '*' (all)
         */
        this.accept = '*';
        /**
         * Event emitted when a file is drag and dropped in the component.
         */
        this.fileDrop = new EventEmitter();
        /**
         * Event emitted when a choosen file to upload is clicked.
         */
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.itemClick = new EventEmitter();
        this.files = [];
        this.filesTotalSize = 0;
        /**
         * Random number generated to give an unique id to the field.
         */
        this.randomNumberId = Math.floor(Math.random() * 10000);
        /**
         * List of existing files to display in the component.
         *
         * @type {EuiUploadedFileInterface[]}
         */
        this.uploadedFiles = [];
        // eslint-disable-next-line
        this.dragEntered = false;
        /**
         * Wheter multiple files can be choosen.
         *
         * @default true
         */
        this.isMultiple = true;
        /**
         * Wheter a progress bar is displayed to indicate the upload progress.
         *
         * @default true
         */
        this.hasProgressBar = true;
        /**
         * Wheter a preview, image or icon, is displayed for a file to upload.
         *
         * @default true
         */
        this.hasPreview = true;
        /**
         * Wheter a preview is displayed as image.
         *
         * @default true
         */
        this.hasPreviewAsImage = true;
        /**
         * Wheter a preview is displayed as a file format icon.
         *
         * @default false
         */
        this.hasPreviewAsIcon = false;
        /**
         * Wheter the total size that will be uploaded is displayed.
         *
         * @default true
         */
        this.hasTotalSizeDisplayed = true;
        /**
         * Wheter a reset list button is displayed.
         *
         * @default true
         */
        this.hasResetButton = true;
        /**
         * Wheter files can be drag and dropped in the component.
         *
         * @default false
         */
        this.hasDragArea = false;
        /**
         * Wheter items can be clicked. `itemClick` event is emitted.
         *
         * @default false
         */
        this.isItemsClickable = false;
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.onChange = () => { };
    }
    /**
     * Sets the `class` attribute for the host element.
     *
     * @returns A string with all CSS classes applied.
     */
    get cssClasses() {
        return [
            'eui-file-upload',
        ]
            .join(' ')
            .trim();
    }
    /**
     * Drag and drop area listener.
     *
     * @param fileList `FileList` containing dropped file and initial file.
     */
    emitFiles(fileList) {
        let i = [...this.uploadedFiles, ...this.files].length;
        for (const property in fileList) {
            if (fileList[property] && typeof fileList[property] === 'object' && (!this.maxFiles || i < this.maxFiles)) {
                const fileName = fileList[property].name.split('.');
                const fileExtension = fileName[fileName.length - 1];
                if (this.accept.indexOf(fileExtension.toLowerCase()) !== -1 || this.accept === '*') {
                    this.files.push(fileList[property]);
                }
                i++;
            }
        }
        this.getTotalSize();
        // eslint-disable-next-line
        this.uploadedFiles ? this.onChange([...this.uploadedFiles, ...this.files]) : this.onChange(this.files);
        if (this.fileInputs) {
            this.fileInputs.first.nativeElement.value = '';
            this.fileInputs.last.nativeElement.value = '';
        }
        this.dragEntered = false;
        this.fileDrop.emit();
    }
    /**
     * Determines whether the reset button should be displayed.
     *
     * @returns {boolean} `true` if the reset button should be shown, otherwise `false`.
     */
    get showResetBtn() {
        return this.hasResetButton && this.isMultiple && (this.files.length > 0 || this.uploadedFiles.length > 0);
    }
    /**
     * Determines whether the drop area should be disabled.
     *
     * @returns {boolean} `true` if the drop area is disabled, otherwise `false`.
     */
    get isDropAreaDisabled() {
        return (!this.isMultiple && this.files.length === 1) || [...this.uploadedFiles, ...this.files].length === this.maxFiles;
    }
    ngOnInit() {
        if (this.hasPreviewAsIcon) {
            this.hasPreviewAsImage = false;
        }
    }
    ngAfterViewInit() {
        // TODO EUI19: Change detection to OnPush to get rid of setTimeout workaround.
        setTimeout(() => {
            this.templates.forEach((item) => {
                if (item.getType() === 'uploadedFile') {
                    this.uploadedFileTemplate = item.template;
                }
                if (item.getType() === 'browseButton') {
                    this.browseButtonTemplate = item.template;
                }
                if (item.getType() === 'resetButton') {
                    this.resetButtonTemplate = item.template;
                }
                if (item.getType() === 'progressBar') {
                    this.progressBarTemplate = item.template;
                }
            });
        });
    }
    onDragEnter() {
        if (!this.isDropAreaDisabled) {
            this.dragEntered = true;
        }
    }
    onDragLeave() {
        this.dragEntered = false;
    }
    /**
     * Remove a file from the array of files choosen by the user.
     *
     * @param index Index of the file to remove in the array.
     */
    removeFromList(index) {
        this.files = this.files.filter((f, i) => i !== index);
        if (this.files.length === 0) {
            this.progress = 0;
        }
        this.getTotalSize();
        this.onChange([...this.uploadedFiles, ...this.files]);
    }
    /**
     * Remove a file from the array of files provided to the component as existing values.
     *
     * @param index Index of the file to remove in the array.
     */
    removeFromUploadedList(index) {
        this.uploadedFiles = this.uploadedFiles.filter((f, i) => i !== index);
        if (this.files.length === 0) {
            this.progress = 0;
        }
        this.getTotalSize();
        this.onChange([...this.uploadedFiles, ...this.files]);
    }
    /**
     * Reset the list of files in the component.
     */
    resetList() {
        this.files = [];
        this.uploadedFiles = [];
        this.getTotalSize();
        this.progress = 0;
        this.onChange([...this.uploadedFiles, ...this.files]);
    }
    openBrowseWindow() {
        this.fileInputs.first.nativeElement.click();
    }
    /**
     * Click item handler.
     * @param e The item clicked. Will be a `Blob` for a file to be uploaded, `EuiUploadedFileInterface` for an initial file.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    onItemClick(e) {
        this.itemClick.emit(e);
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    writeValue(value) {
        this.uploadedFiles = value || [];
        this.files = [];
        this.getTotalSize();
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnChange(fn) {
        this.onChange = fn;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnTouched(fn) { }
    /**
     * Calculates the total size to be uploaded.
     */
    getTotalSize() {
        this.filesTotalSize = 0;
        this.files.forEach((f) => {
            this.filesTotalSize += f.size;
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiFileUploadComponent, isStandalone: true, selector: "eui-file-upload", inputs: { e2eAttr: "e2eAttr", progress: "progress", accept: "accept", maxFiles: "maxFiles", isMultiple: ["isMultiple", "isMultiple", booleanAttribute], hasProgressBar: ["hasProgressBar", "hasProgressBar", booleanAttribute], hasPreview: ["hasPreview", "hasPreview", booleanAttribute], hasPreviewAsImage: ["hasPreviewAsImage", "hasPreviewAsImage", booleanAttribute], hasPreviewAsIcon: ["hasPreviewAsIcon", "hasPreviewAsIcon", booleanAttribute], hasTotalSizeDisplayed: ["hasTotalSizeDisplayed", "hasTotalSizeDisplayed", booleanAttribute], hasResetButton: ["hasResetButton", "hasResetButton", booleanAttribute], hasDragArea: ["hasDragArea", "hasDragArea", booleanAttribute], isItemsClickable: ["isItemsClickable", "isItemsClickable", booleanAttribute] }, outputs: { fileDrop: "fileDrop", itemClick: "itemClick" }, host: { listeners: { "change": "emitFiles($event.target.files)" }, properties: { "class": "this.cssClasses" } }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: EuiFileUploadComponent,
                multi: true,
            },
        ], queries: [{ propertyName: "templates", predicate: EuiTemplateDirective }], viewQueries: [{ propertyName: "fileInputs", predicate: ["input"], descendants: true }], ngImport: i0, template: "@if (hasDragArea) {\n    <div\n        class=\"eui-file-upload__drop-area\"\n        [class.eui-file-upload__drop-area--active]=\"dragEntered\"\n        [class.eui-file-upload__drop-area--disabled]=\"isDropAreaDisabled\">\n        <span class=\"eui-file-upload__fake-btn\">{{ 'eui.euifileupload.CHOOSE-FILE' | translate }}</span>\n        <span>{{ 'eui.euifileupload.DRAG-AND-DROP-FILE-HERE' | translate }}</span>\n        <input\n            #input\n            class=\"eui-file-upload__file-input\"\n            attr.aria-label=\"{{ 'eui.euifileupload.CHOOSE-FILE' | translate }} 'or' {{\n                'eui.euifileupload.DRAG-AND-DROP-FILE-HERE' | translate\n            }}\"\n            type=\"file\"\n            accept=\"{{ accept }}\"\n            [attr.disabled]=\"isDropAreaDisabled ? 'disabled' : null\"\n            [multiple]=\"isMultiple\"\n            (dragenter)=\"onDragEnter()\"\n            (dragleave)=\"onDragLeave()\" />\n    </div>\n} @else {\n    <div class=\"eui-file-upload__simple-input-file\">\n        <label for=\"file-{{ randomNumberId }}\">\n            @if (browseButtonTemplate) {\n                <ng-template [ngTemplateOutlet]=\"browseButtonTemplate\"></ng-template>\n            } @else {\n                <button euiButton type=\"button\" (click)=\"openBrowseWindow()\">{{ 'eui.euifileupload.CHOOSE-FILE' | translate }}</button>\n            }\n        </label>\n    \n        @if (isMultiple) {\n            <input\n                #input\n                aria-label=\"Choose Multiple Files\"\n                class=\"file-input\"\n                id=\"file-{{ randomNumberId }}\"\n                type=\"file\"\n                accept=\"{{ accept }}\"\n                multiple />\n        } @else {\n            <input\n                #input\n                aria-label=\"Choose a single file\"\n                class=\"file-input\"\n                id=\"file-{{ randomNumberId }}\"\n                type=\"file\"\n                accept=\"{{ accept }}\" />\n        }\n    </div>\n}\n\n@if (hasProgressBar) {\n    @if (progressBarTemplate) {\n        <ng-template [ngTemplateOutlet]=\"progressBarTemplate\"\n            [ngTemplateOutletContext]=\"{ $implicit: { progress } }\" />\n    } @else {\n        <eui-file-upload-progress [progress]=\"progress\" />\n    }\n}\n\n@for (uploadedFile of uploadedFiles; let i = $index; track $index) {\n    <div>\n        <eui-file-preview\n            [isItemsClickable]=\"isItemsClickable\"\n            [index]=\"i\"\n            [file]=\"uploadedFile\"\n            [hasPreview]=\"hasPreview\"\n            [hasPreviewAsImage]=\"hasPreviewAsImage\"\n            [hasPreviewAsIcon]=\"hasPreviewAsIcon\"\n            [uploadedFileTemplate]=\"uploadedFileTemplate\"\n            (itemClick)=\"onItemClick($event)\"\n            (removeFromList)=\"removeFromUploadedList($event)\">\n        </eui-file-preview>\n    </div>\n}\n\n@for (file of files; let i = $index; track $index) {\n    <div>\n        <eui-file-preview\n            isFileObject\n            [isItemsClickable]=\"isItemsClickable\"\n            [index]=\"i\"\n            [file]=\"file\"\n            [hasPreview]=\"hasPreview\"\n            [hasPreviewAsImage]=\"hasPreviewAsImage\"\n            [hasPreviewAsIcon]=\"hasPreviewAsIcon\"\n            [uploadedFileTemplate]=\"uploadedFileTemplate\"\n            (itemClick)=\"onItemClick($event)\"\n            (removeFromList)=\"removeFromList($event)\">\n        </eui-file-preview>\n    </div>\n}\n\n@if (filesTotalSize && hasTotalSizeDisplayed) {\n    <div class=\"eui-file-upload__total-size\">\n        {{ filesTotalSize | filesize }} {{ 'eui.euifileupload.TOTAL-SIZE' | translate }}\n    </div>\n}\n\n<ng-content />\n\n@if (showResetBtn) {\n    @if (resetButtonTemplate) {\n        <ng-template [ngTemplateOutlet]=\"resetButtonTemplate\" />\n    } @else {\n        <button euiButton type=\"button\" (click)=\"resetList()\">\n            {{ 'eui.euifileupload.RESET-LIST' | translate }}\n        </button>\n    }\n}\n", styles: [".eui-19 .eui-file-upload__total-size{margin-bottom:1rem;font:var(--eui-f-m-bold)}.eui-19 .eui-file-upload__drop-area{outline:1px dashed var(--eui-c-s-primary-base);border-radius:var(--eui-br-m);margin:0 0 10px;padding:30px;position:relative;-webkit-transition:.2s;transition:.2s}.eui-19 .eui-file-upload__drop-area--active{background-color:var(--eui-c-active-bg);outline:3px dashed var(--eui-c-s-primary-base);border-radius:var(--eui-br-m);margin:0 0 10px;padding:30px;position:relative;-webkit-transition:.2s;transition:.2s}.eui-19 .eui-file-upload__drop-area--disabled{opacity:.75;cursor:not-allowed}.eui-19 .eui-file-upload__drop-area--disabled .file-input{cursor:default}.eui-19 .eui-file-upload__fake-btn{background-color:#fff;border:var(--eui-bw-xs) solid #9e9ec4;border-radius:var(--eui-br-m);margin-right:8px;padding:8px 15px}.eui-19 .eui-file-upload__file-input{height:100%;left:0;opacity:0;position:absolute;top:0;width:100%}.eui-19 .eui-file-upload__file-input:not(:disabled){cursor:pointer}.eui-19 .eui-file-upload__simple-input-file{margin-bottom:var(--eui-s-xs)}.eui-19 .eui-file-upload__simple-input-file .file-input{display:none}.eui-19 .eui-file-upload__preview{align-items:center;display:flex;justify-content:space-between;margin:5px 0}.eui-19 .eui-file-upload__preview--left{align-items:center;display:flex;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.eui-19 .eui-file-upload__preview--left__image{margin-right:var(--eui-s-m)}.eui-19 .eui-file-upload__preview--left__image img{width:180px}.eui-19 .eui-file-upload__preview--left__image .loading-container{text-align:center;width:180px}.eui-19 .eui-file-upload__preview--left__filename{display:block}.eui-19 .eui-file-upload__preview--right{align-items:center;display:flex;margin-left:auto;gap:var(--eui-s-m)}.eui-19 .eui-file-upload__progress-bar-container{margin-bottom:var(--eui-s-2xs)}.eui-19 .eui-file-upload__progress-bar-container .progress-bar{background-color:var(--eui-c-s-primary-base);height:var(--eui-s-2xs)}\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "ngmodule", type: TranslateModule }, { kind: "pipe", type: i1$1.TranslatePipe, name: "translate" }, { kind: "component", type: EuiFilePreviewComponent, selector: "eui-file-preview", inputs: ["file", "uploadedFileTemplate", "index", "previewAsIconConfig", "hasPreview", "isFilenameDisplayed", "isFilesizeDisplayed", "isFiletypeDisplayed", "hasPreviewAsImage", "hasPreviewAsIcon", "isItemsClickable", "isFileObject"], outputs: ["removeFromList", "itemClick"] }, { kind: "component", type: EuiFileUploadProgressComponent, selector: "eui-file-upload-progress", inputs: ["progress"] }, { kind: "pipe", type: EuiFileSizePipe, name: "filesize" }, { kind: "component", type: i1.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-file-upload', providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: EuiFileUploadComponent,
                            multi: true,
                        },
                    ], encapsulation: ViewEncapsulation.None, imports: [
                        NgTemplateOutlet,
                        TranslateModule,
                        EuiFilePreviewComponent,
                        EuiFileUploadProgressComponent,
                        EuiFileSizePipe,
                        ...EUI_BUTTON,
                        ...EUI_ICON,
                    ], template: "@if (hasDragArea) {\n    <div\n        class=\"eui-file-upload__drop-area\"\n        [class.eui-file-upload__drop-area--active]=\"dragEntered\"\n        [class.eui-file-upload__drop-area--disabled]=\"isDropAreaDisabled\">\n        <span class=\"eui-file-upload__fake-btn\">{{ 'eui.euifileupload.CHOOSE-FILE' | translate }}</span>\n        <span>{{ 'eui.euifileupload.DRAG-AND-DROP-FILE-HERE' | translate }}</span>\n        <input\n            #input\n            class=\"eui-file-upload__file-input\"\n            attr.aria-label=\"{{ 'eui.euifileupload.CHOOSE-FILE' | translate }} 'or' {{\n                'eui.euifileupload.DRAG-AND-DROP-FILE-HERE' | translate\n            }}\"\n            type=\"file\"\n            accept=\"{{ accept }}\"\n            [attr.disabled]=\"isDropAreaDisabled ? 'disabled' : null\"\n            [multiple]=\"isMultiple\"\n            (dragenter)=\"onDragEnter()\"\n            (dragleave)=\"onDragLeave()\" />\n    </div>\n} @else {\n    <div class=\"eui-file-upload__simple-input-file\">\n        <label for=\"file-{{ randomNumberId }}\">\n            @if (browseButtonTemplate) {\n                <ng-template [ngTemplateOutlet]=\"browseButtonTemplate\"></ng-template>\n            } @else {\n                <button euiButton type=\"button\" (click)=\"openBrowseWindow()\">{{ 'eui.euifileupload.CHOOSE-FILE' | translate }}</button>\n            }\n        </label>\n    \n        @if (isMultiple) {\n            <input\n                #input\n                aria-label=\"Choose Multiple Files\"\n                class=\"file-input\"\n                id=\"file-{{ randomNumberId }}\"\n                type=\"file\"\n                accept=\"{{ accept }}\"\n                multiple />\n        } @else {\n            <input\n                #input\n                aria-label=\"Choose a single file\"\n                class=\"file-input\"\n                id=\"file-{{ randomNumberId }}\"\n                type=\"file\"\n                accept=\"{{ accept }}\" />\n        }\n    </div>\n}\n\n@if (hasProgressBar) {\n    @if (progressBarTemplate) {\n        <ng-template [ngTemplateOutlet]=\"progressBarTemplate\"\n            [ngTemplateOutletContext]=\"{ $implicit: { progress } }\" />\n    } @else {\n        <eui-file-upload-progress [progress]=\"progress\" />\n    }\n}\n\n@for (uploadedFile of uploadedFiles; let i = $index; track $index) {\n    <div>\n        <eui-file-preview\n            [isItemsClickable]=\"isItemsClickable\"\n            [index]=\"i\"\n            [file]=\"uploadedFile\"\n            [hasPreview]=\"hasPreview\"\n            [hasPreviewAsImage]=\"hasPreviewAsImage\"\n            [hasPreviewAsIcon]=\"hasPreviewAsIcon\"\n            [uploadedFileTemplate]=\"uploadedFileTemplate\"\n            (itemClick)=\"onItemClick($event)\"\n            (removeFromList)=\"removeFromUploadedList($event)\">\n        </eui-file-preview>\n    </div>\n}\n\n@for (file of files; let i = $index; track $index) {\n    <div>\n        <eui-file-preview\n            isFileObject\n            [isItemsClickable]=\"isItemsClickable\"\n            [index]=\"i\"\n            [file]=\"file\"\n            [hasPreview]=\"hasPreview\"\n            [hasPreviewAsImage]=\"hasPreviewAsImage\"\n            [hasPreviewAsIcon]=\"hasPreviewAsIcon\"\n            [uploadedFileTemplate]=\"uploadedFileTemplate\"\n            (itemClick)=\"onItemClick($event)\"\n            (removeFromList)=\"removeFromList($event)\">\n        </eui-file-preview>\n    </div>\n}\n\n@if (filesTotalSize && hasTotalSizeDisplayed) {\n    <div class=\"eui-file-upload__total-size\">\n        {{ filesTotalSize | filesize }} {{ 'eui.euifileupload.TOTAL-SIZE' | translate }}\n    </div>\n}\n\n<ng-content />\n\n@if (showResetBtn) {\n    @if (resetButtonTemplate) {\n        <ng-template [ngTemplateOutlet]=\"resetButtonTemplate\" />\n    } @else {\n        <button euiButton type=\"button\" (click)=\"resetList()\">\n            {{ 'eui.euifileupload.RESET-LIST' | translate }}\n        </button>\n    }\n}\n", styles: [".eui-19 .eui-file-upload__total-size{margin-bottom:1rem;font:var(--eui-f-m-bold)}.eui-19 .eui-file-upload__drop-area{outline:1px dashed var(--eui-c-s-primary-base);border-radius:var(--eui-br-m);margin:0 0 10px;padding:30px;position:relative;-webkit-transition:.2s;transition:.2s}.eui-19 .eui-file-upload__drop-area--active{background-color:var(--eui-c-active-bg);outline:3px dashed var(--eui-c-s-primary-base);border-radius:var(--eui-br-m);margin:0 0 10px;padding:30px;position:relative;-webkit-transition:.2s;transition:.2s}.eui-19 .eui-file-upload__drop-area--disabled{opacity:.75;cursor:not-allowed}.eui-19 .eui-file-upload__drop-area--disabled .file-input{cursor:default}.eui-19 .eui-file-upload__fake-btn{background-color:#fff;border:var(--eui-bw-xs) solid #9e9ec4;border-radius:var(--eui-br-m);margin-right:8px;padding:8px 15px}.eui-19 .eui-file-upload__file-input{height:100%;left:0;opacity:0;position:absolute;top:0;width:100%}.eui-19 .eui-file-upload__file-input:not(:disabled){cursor:pointer}.eui-19 .eui-file-upload__simple-input-file{margin-bottom:var(--eui-s-xs)}.eui-19 .eui-file-upload__simple-input-file .file-input{display:none}.eui-19 .eui-file-upload__preview{align-items:center;display:flex;justify-content:space-between;margin:5px 0}.eui-19 .eui-file-upload__preview--left{align-items:center;display:flex;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.eui-19 .eui-file-upload__preview--left__image{margin-right:var(--eui-s-m)}.eui-19 .eui-file-upload__preview--left__image img{width:180px}.eui-19 .eui-file-upload__preview--left__image .loading-container{text-align:center;width:180px}.eui-19 .eui-file-upload__preview--left__filename{display:block}.eui-19 .eui-file-upload__preview--right{align-items:center;display:flex;margin-left:auto;gap:var(--eui-s-m)}.eui-19 .eui-file-upload__progress-bar-container{margin-bottom:var(--eui-s-2xs)}.eui-19 .eui-file-upload__progress-bar-container .progress-bar{background-color:var(--eui-c-s-primary-base);height:var(--eui-s-2xs)}\n"] }]
        }], propDecorators: { e2eAttr: [{
                type: Input
            }], progress: [{
                type: Input
            }], accept: [{
                type: Input
            }], maxFiles: [{
                type: Input
            }], fileDrop: [{
                type: Output
            }], itemClick: [{
                type: Output
            }], cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], templates: [{
                type: ContentChildren,
                args: [EuiTemplateDirective]
            }], fileInputs: [{
                type: ViewChildren,
                args: ['input']
            }], isMultiple: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasProgressBar: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasPreview: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasPreviewAsImage: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasPreviewAsIcon: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasTotalSizeDisplayed: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasResetButton: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasDragArea: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isItemsClickable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], emitFiles: [{
                type: HostListener,
                args: ['change', ['$event.target.files']]
            }] } });

class EuiFileUploadUtilsService {
    constructor() {
        this.httpClient = inject(HttpClient);
    }
    /**
     * @description
     * Method that will format data in `FormData` and send them to backend.
     *
     * @example
     * Call the method and log the response in the console.
     *
     * ```
     * this.euiFileUploadUtilsService.sendData(this.form.value, 'http://localhost:3000/api/fake-api').pipe(
     *     this.euiFileUploadUtilsService.uploadProgress((progress) => {
     *         console.log(progress);
     *     }),
     *     this.euiFileUploadUtilsService.toResponseBody(),
     * ).subscribe((response) => {
     *      console.log(response);
     * });
     * ```
     *
     * @param data Data to send to backend
     * @param APIEndPoint Endpoint URL
     * @returns The backend response.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    sendData(data, APIEndPoint) {
        return this.httpClient.post(APIEndPoint, this.toFormData(data), {
            reportProgress: true,
            observe: 'events',
        });
    }
    /**
     * @description
     * Method that will return the upload progress.
     *
     * @example
     * Call the method and log the progress in the console.
     *
     * ```
     * this.euiFileUploadUtilsService.sendData(this.form.value, 'http://localhost:3000/api/fake-api').pipe(
     *     this.euiFileUploadUtilsService.uploadProgress((progress) => {
     *         console.log(progress);
     *     }),
     *     this.euiFileUploadUtilsService.toResponseBody(),
     * ).subscribe((response) => {
     *      console.log(response);
     * });
     * ```
     *
     * @param cb A method to execute on each progress step.
     * @returns A number between 0 and 100.
     */
    uploadProgress(cb) {
        return tap((event) => {
            if (event.type === HttpEventType.UploadProgress) {
                cb(Math.round((100 * event.loaded) / event.total));
            }
        });
    }
    /**
     * @description
     * Method that will return only the body of the backend response.
     *
     * @example
     * Call the method and log the response in the console.
     *
     * ```
     * this.euiFileUploadUtilsService.sendData(this.form.value, 'http://localhost:3000/api/fake-api').pipe(
     *     this.euiFileUploadUtilsService.uploadProgress((progress) => {
     *         console.log(progress);
     *     }),
     *     this.euiFileUploadUtilsService.toResponseBody(),
     * ).subscribe((response) => {
     *      console.log(response);
     * });
     * ```
     *
     * @returns The backend response.
     */
    toResponseBody() {
        return pipe(filter((event) => event.type === HttpEventType.Response), map((res) => res.body));
    }
    /**
     * @description
     * Return the icon to be used with eui-icon-svg of the given extension or a default file icon
     *
     * @param fileExtension
     * @returns Icon name as string
     */
    getIconForExtension(fileExtension) {
        const previewAsIconConfig = {
            avi: 'eui-file-video',
            html: 'eui-file-html',
            htm: 'eui-file-code',
            js: 'eui-file-code',
            json: 'eui-file-code',
            mp3: 'eui-file-audio',
            mp4: 'eui-file-video',
            pdf: 'eui-file-pdf',
            png: 'eui-file-image',
            svg: 'eui-file-image',
            txt: 'eui-file-text',
            xml: 'eui-file-code',
            jpeg: 'eui-file-image',
            jpg: 'eui-file-image',
            zip: 'eui-file-archive',
            doc: 'eui-file-word',
            docx: 'eui-file-word-o',
            xls: 'eui-file-excel-o',
            xlsx: 'eui-file-excel-o',
            ppt: 'eui-file-powerpoint',
            csv: 'eui-file-text',
            rtf: 'eui-file-text',
        };
        const f = fileExtension.toLowerCase();
        return !previewAsIconConfig[f] ? 'eui-file-empty-o' : previewAsIconConfig[f];
    }
    /**
     * Internal method returning `FormData` object.
     *
     * @param formValue Data to send to form
     * @returns A `FormData` object
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    toFormData(formValue) {
        const formData = new FormData();
        for (const key of Object.keys(formValue)) {
            if (Array.isArray(formValue[key])) {
                let fileIndex = 0;
                // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                formValue[key].forEach((value) => {
                    if (value instanceof File) {
                        formData.append(key + fileIndex, value);
                        fileIndex++;
                    }
                });
                const a = [];
                // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                formValue[key].forEach((value) => {
                    a.push(value);
                });
                formData.append(key, JSON.stringify(a));
            }
            else {
                if (typeof formValue[key] === 'string') {
                    formData.set(key, formValue[key]);
                }
                else {
                    formData.set(key, JSON.stringify(formValue[key]));
                }
            }
        }
        return formData;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadUtilsService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadUtilsService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadUtilsService, decorators: [{
            type: Injectable
        }] });

/**
 * @description
 * Module that provides the EuiFileUpload component and its dependencies
 *
 * @deprecated Use {@link EUI_FILE_UPLOAD} instead
 */
class EuiFileUploadModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadModule, imports: [EuiFileUploadComponent, EuiFileSizePipe, EuiFilePreviewComponent, EuiFileUploadProgressComponent], exports: [EuiFileUploadComponent, EuiFileSizePipe, EuiFilePreviewComponent, EuiFileUploadProgressComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadModule, providers: [EuiFileUploadUtilsService], imports: [EuiFileUploadComponent, EuiFilePreviewComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiFileUploadModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiFileUploadComponent, EuiFileSizePipe, EuiFilePreviewComponent, EuiFileUploadProgressComponent],
                    exports: [EuiFileUploadComponent, EuiFileSizePipe, EuiFilePreviewComponent, EuiFileUploadProgressComponent],
                    providers: [EuiFileUploadUtilsService],
                }]
        }] });

const getMimeType = (header) => {
    // convert Uint8Array to hex string
    const hex = uint8ArrayToHexString(header);
    // map hex string to mime type
    if (hex.startsWith('ffd8ffe000104a46'))
        return 'image/jpeg';
    if (hex.startsWith('89504e47'))
        return 'image/png';
    if (hex.startsWith('464c4946'))
        return 'image/flif';
    if (hex.startsWith('67696d7020786366'))
        return 'image/x-xcf';
    if (hex.startsWith('49492a00'))
        return 'image/x-canon-cr2';
    if (hex.startsWith('49492a00'))
        return 'image/x-canon-cr3';
    if (hex.startsWith('49492a00'))
        return 'image/tiff';
    if (hex.startsWith('424d'))
        return 'image/bmp';
    if (hex.startsWith('69636e73'))
        return 'image/icns';
    if (hex.startsWith('49491a0000004845415050'))
        return 'image/vnd.ms-photo';
    if (hex.startsWith('38425053'))
        return 'image/vnd.adobe.photoshop';
    if (hex.startsWith('06054b50'))
        return 'application/x-indesign';
    if (hex.startsWith('504b0304'))
        return 'application/epub+zip';
    if (hex.startsWith('504b0304'))
        return 'application/x-xpinstall';
    if (hex.startsWith('504b0304'))
        return 'application/vnd.oasis.opendocument.text';
    if (hex.startsWith('504b0304'))
        return 'application/vnd.oasis.opendocument.spreadsheet';
    if (hex.startsWith('504b0304'))
        return 'application/vnd.oasis.opendocument.presentation';
    if (hex.startsWith('504b0304'))
        return 'application/vnd.openxmlformats-officedocument.wordprocessingml.document';
    if (hex.startsWith('504b0304'))
        return 'application/vnd.openxmlformats-officedocument.presentationml.presentation';
    if (hex.startsWith('504b0304'))
        return 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet';
    if (hex.startsWith('504b0304'))
        return 'application/zip';
    if (hex.startsWith('7b2274797065223a226a736f6e227d'))
        return 'application/json';
    if (hex.startsWith('7573746172'))
        return 'application/x-tar';
    if (hex.startsWith('526172211a0700'))
        return 'application/x-rar-compressed';
    if (hex.startsWith('1f8b08'))
        return 'application/gzip';
    if (hex.startsWith('425a68'))
        return 'application/x-bzip2';
    if (hex.startsWith('377abcaf271c'))
        return 'application/x-7z-compressed';
    if (hex.startsWith('78da'))
        return 'application/x-apple-diskimage';
    if (hex.startsWith('00000020667479706d70'))
        return 'video/mp4';
    if (hex.startsWith('4d546864'))
        return 'audio/midi';
    if (hex.startsWith('1a45dfa393428288'))
        return 'video/x-matroska';
    if (hex.startsWith('1a45dfa3'))
        return 'video/webm';
    if (hex.startsWith('00000014667479707174'))
        return 'video/quicktime';
    if (hex.startsWith('52494646'))
        return 'video/vnd.avi';
    if (hex.startsWith('52494646'))
        return 'audio/vnd.wave';
    if (hex.startsWith('0a010301'))
        return 'audio/qcelp';
    if (hex.startsWith('3026b2758e66cf11'))
        return 'audio/x-ms-asf';
    if (hex.startsWith('3026b2758e66cf11'))
        return 'video/x-ms-asf';
    if (hex.startsWith('3026b2758e66cf11'))
        return 'application/vnd.ms-asf';
    if (hex.startsWith('000001ba'))
        return 'video/mpeg';
    if (hex.startsWith('00000020667479703367'))
        return 'video/3gpp';
    if (hex.startsWith('494433'))
        return 'audio/mpeg';
    if (hex.startsWith('00000020667479704d344120'))
        return 'audio/mp4';
    if (hex.startsWith('4f707573'))
        return 'audio/opus';
    if (hex.startsWith('4f676753'))
        return 'video/ogg';
    if (hex.startsWith('4f676753'))
        return 'audio/ogg';
    if (hex.startsWith('4f676753'))
        return 'application/ogg';
    if (hex.startsWith('664c6143'))
        return 'audio/x-flac';
    if (hex.startsWith('4d414320'))
        return 'audio/ape';
    if (hex.startsWith('7776706b'))
        return 'audio/wavpack';
    if (hex.startsWith('2321414d520a'))
        return 'audio/amr';
    if (hex.startsWith('255044462d312e'))
        return 'application/pdf';
    if (hex.startsWith('7f454c46'))
        return 'application/x-elf';
    if (hex.startsWith('4d5a'))
        return 'application/x-msdownload';
    if (hex.startsWith('435753'))
        return 'application/x-shockwave-flash';
    if (hex.startsWith('7b5c72746631'))
        return 'application/rtf';
    if (hex.startsWith('0061736d'))
        return 'application/wasm';
    if (hex.startsWith('774f4646'))
        return 'font/woff';
    if (hex.startsWith('774f4632'))
        return 'font/woff2';
    if (hex.startsWith('000100000008'))
        return 'application/vnd.ms-fontobject';
    if (hex.startsWith('0001000000'))
        return 'font/ttf';
    if (hex.startsWith('4f54544f00'))
        return 'font/otf';
    if (hex.startsWith('000001000100'))
        return 'image/x-icon';
    if (hex.startsWith('464c560105'))
        return 'video/x-flv';
    if (hex.startsWith('25215053'))
        return 'application/postscript';
    if (hex.startsWith('25215053'))
        return 'application/eps';
    if (hex.startsWith('fd377a585a00'))
        return 'application/x-xz';
    if (hex.startsWith('53514c69746520666f726d6174203300'))
        return 'application/x-sqlite3';
    if (hex.startsWith('4e45531a00000001'))
        return 'application/x-nintendo-nes-rom';
    if (hex.startsWith('504b0304'))
        return 'application/x-google-chrome-extension';
    if (hex.startsWith('4d534346'))
        return 'application/vnd.ms-cab-compressed';
    if (hex.startsWith('213c617263683e0a'))
        return 'application/x-deb';
    if (hex.startsWith('1f8b08'))
        return 'application/x-unix-archive';
    if (hex.startsWith('edabeedb'))
        return 'application/x-rpm';
    if (hex.startsWith('1f9d90'))
        return 'application/x-compress';
    if (hex.startsWith('4c5a4950'))
        return 'application/x-lzip';
    if (hex.startsWith('d0cf11e0a1b11ae1'))
        return 'application/x-cfb';
    if (hex.startsWith('4d49455f'))
        return 'application/x-mie';
    if (hex.startsWith('4141523146'))
        return 'application/x-apache-arrow';
    if (hex.startsWith('060e2b3402050101'))
        return 'application/mxf';
    if (hex.startsWith('47'))
        return 'video/mp2t';
    if (hex.startsWith('4250e4'))
        return 'application/x-blender';
    if (hex.startsWith('425047fb'))
        return 'image/bpg';
    if (hex.startsWith('ff4fff51'))
        return 'image/j2c';
    if (hex.startsWith('0000000c6a5020200d0a'))
        return 'image/jp2';
    if (hex.startsWith('6a5020200d0a870a'))
        return 'image/jpx';
    if (hex.startsWith('6a5020200d0a870a'))
        return 'image/jpm';
    if (hex.startsWith('0000000c6a5020200d0a'))
        return 'image/mj2';
    if (hex.startsWith('464f524d'))
        return 'audio/aiff';
    if (hex.startsWith('3c3f786d6c20'))
        return 'application/xml';
    if (hex.startsWith('424f4f4b4d4f4249'))
        return 'application/x-mobipocket-ebook';
    if (hex.startsWith('667479706174'))
        return 'image/heif';
    if (hex.startsWith('667479706174'))
        return 'image/heif-sequence';
    if (hex.startsWith('667479706174'))
        return 'image/heic';
    if (hex.startsWith('667479706174'))
        return 'image/heic-sequence';
    if (hex.startsWith('4b545820'))
        return 'image/ktx';
    if (hex.startsWith('4449434d'))
        return 'application/dicom';
    if (hex.startsWith('4d50434b'))
        return 'audio/x-musepack';
    if (hex.startsWith('56656e64'))
        return 'text/calendar';
    if (hex.startsWith('424547494e3a5643415244'))
        return 'text/vcard';
    if (hex.startsWith('676c5458'))
        return 'model/gltf-binary';
    if (hex.startsWith('d4c3b2a1'))
        return 'application/vnd.tcpdump.pcap';
    if (hex.startsWith('464f524d'))
        return 'audio/x-voc';
    if (hex.startsWith('64646f6c'))
        return 'audio/vnd.dolby.dd-raw';
    return null;
};
const uint8ArrayToHexString = (uint8Array) => {
    return Array.prototype.map.call(uint8Array, (byte) => ('00' + byte.toString(16)).slice(-2)).join('');
};

/**
 * @description
 * Validator that requires the maximum length of files that can be uploaded.
 *
 * @example
 * Validate that the user selected maximum 3 files:
 *
 * ```
 * const fileUpload = new FormControl(null, maxFilesValidator(3));
 * console.log(fileUpload.errors); // { maxFiles: 3 }
 * ```
 *
 * @param {MimeType[]} maxFiles - The maximum number of files allowed.
 * @returns A validator function that returns an error map with the
 * `maxFiles` if the validation check fails, otherwise `null`.
 */
const maxFilesValidator = (maxFiles) => (control) => control.value && control.value.length > maxFiles ? { maxFiles } : null;
/**
 * @description
 * Validator that requires the maximum size (in bytes) of files that can be uploaded.
 *
 * @example
 * Validate that the user doesn't select a file have a size up to 300Kb:
 *
 * ```
 * const fileUpload = new FormControl(null, maxSizeValidator(300000));
 * console.log(fileUpload.errors); // { maxSize: 300000 }
 * ```
 *
 * @param {MimeType[]} maxFileSize - The maximum filesize allowed.
 * @returns A validator function that returns an error map with the
 * `maxSize` if the validation check fails, otherwise `null`.
 */
const maxSizeValidator = (maxSize) => (control) => {
    let totalSize = 0;
    if (control.value) {
        control.value.forEach((file) => {
            totalSize += file.size;
        });
    }
    return control.value && totalSize > maxSize * 1.024 ? { maxSize } : null;
};
/**
 * @description
 * Validator that requires the maximum size (in bytes) per file that can be uploaded.
 *
 * @example
 * Validates that the user doesn't select a file that exceeds the provided size
 *
 * @param {MimeType[]} maxFileSize - The maximum filesize allowed.
 * @returns A validator function that returns an error map with the
 * `maxFileSize` and the `indexes` of the file/files that exceeded the max size if the validation check fails, otherwise `null`.
 */
const maxFileSizeValidator = (maxFileSize) => (control) => {
    const fileIndexes = [];
    let maxFileExceeded = false;
    if (control.value) {
        control.value.forEach((file, index) => {
            if (file.size > maxFileSize * 1.024) {
                fileIndexes.push(index);
                maxFileExceeded = true;
            }
        });
    }
    return control.value && maxFileExceeded ? { maxFileSize, indexes: fileIndexes } : null;
};
/**
 * @description
 * Validator that requires an array of mime type that can be uploaded.
 *
 * @example
 * Validate that the user doesn't select a file having another extension than .jpg or .jpeg:
 * ```
 * const fileUpload = new FormControl(null, mimeTypeExtensionValidator(['image/jpeg'])),
 * console.log(fileUpload.errors); // { invalidFileExtension: ['image/jpeg'] }
 * ```
 *
 * @param {MimeType[]} mimeTypes - The list of allowed MIME types.
 * @returns A validator function that returns an error map with the
 * `invalidFileExtension` if the validation check fails, otherwise `null`.
 */
const mimeTypeExtensionValidator = (mimeTypes) => (control) => {
    const invalidFileExtension = [];
    if (control.value) {
        control.value.forEach((file) => {
            if (mimeTypes.indexOf(file.type) === -1) {
                invalidFileExtension.push(file.name);
            }
        });
    }
    return control.value && invalidFileExtension.length > 0 ? { invalidFileExtension } : null;
};
/**
 * @description
 * Validator that requires an array of mime type that can be uploaded.
 *
 * @example
 * Validate that the user doesn't select a file having another extension than .jpg or .jpeg:
 *
 * ```
 * const fileUpload = new FormControl(null, mimeTypeExtensionValidator(['image/jpeg'])),
 * console.log(fileUpload.errors); // { invalidMimeFileType: ['image/jpeg'] }
 * ```
 * @param {MimeType[]} mimeTypes - The list of allowed MIME types.
 * @returns An Async validator function that returns an error map with the
 * `invalidMimeFileType` if the validation check fails, otherwise `null`.
 */
const asyncMimeTypeExtensionValidator = (mimeTypes) => (control) => {
    if (control.value) {
        const fileErrorObservables = [];
        // iterate over files
        control.value.forEach((file) => {
            // push observable which will check the mime validation type
            fileErrorObservables.push(validateFileMimeType(file, mimeTypes));
        });
        return zip(...fileErrorObservables).pipe(map((fileErrors) => {
            const errors = fileErrors.filter((fileError) => fileError !== null);
            // Error should be { fileName: FileType }
            return { invalidMimeFileType: errors };
        }));
    }
    return of(null);
};
/**
 * Validates the MIME type of a file against a list of allowed MIME types.
 *
 * @param {File} file - The file to validate.
 * @param {MimeType[]} mimeTypes - The list of allowed MIME types.
 * @returns {Observable<{ [key: string]: MimeType }>} An observable that emits an object containing the file name as the key and
 * its detected MIME type as the value if the file type is not allowed.
 */
const validateFileMimeType = (file, mimeTypes) => {
    return new Observable((subscriber) => {
        const reader = new FileReader();
        reader.onloadend = () => {
            const buffer = reader.result;
            const headerBytes = new Uint8Array(buffer).slice(0, 8);
            const mime = getMimeType(headerBytes);
            if (mimeTypes.indexOf(mime) === -1) {
                subscriber.next({ [file.name]: mime });
            }
            subscriber.complete();
        };
        reader.readAsArrayBuffer(file);
    });
};

const EUI_FILE_UPLOAD = [
    EuiFileUploadComponent,
    EuiFileUploadProgressComponent,
    EuiFilePreviewComponent,
    EuiFileSizePipe,
];

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_FILE_UPLOAD, EuiFilePreviewComponent, EuiFileSizePipe, EuiFileUploadComponent, EuiFileUploadModule, EuiFileUploadProgressComponent, EuiFileUploadUtilsService, asyncMimeTypeExtensionValidator, maxFileSizeValidator, maxFilesValidator, maxSizeValidator, mimeTypeExtensionValidator };
//# sourceMappingURL=eui-components-eui-file-upload.mjs.map
