import * as i0 from '@angular/core';
import { inject, ElementRef, EventEmitter, IterableDiffers, booleanAttribute, HostListener, Output, Input, HostBinding, ViewEncapsulation, Component, NgModule } from '@angular/core';
import * as i1 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';
import * as i2 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import * as i3 from '@eui/components/eui-icon-button';
import { EUI_ICON_BUTTON } from '@eui/components/eui-icon-button';
import * as i4 from '@eui/components/eui-icon-state';
import { EUI_ICON_STATE } from '@eui/components/eui-icon-state';
import { NgClass } from '@angular/common';

class EuiGrowlComponent {
    get cssClasses() {
        return ['eui-growl', `eui-growl--${this.position}`].join(' ').trim();
    }
    constructor() {
        this.el = inject(ElementRef);
        this.titleId = 'msg-title';
        this.contentId = 'msg-detail';
        this.e2eAttr = 'eui-growl';
        this.role = 'region';
        this.ariaLive = 'polite';
        this.ariaLabelledBy = this.titleId;
        this.ariaDescribedBy = this.contentId;
        this.sticky = false;
        this.life = 3000;
        this.value = [];
        this.closeAllSticky = false;
        this.growlClick = new EventEmitter();
        const differs = inject(IterableDiffers);
        this.differ = differs.find([]).create(undefined);
    }
    ngDoCheck() {
        const changes = this.differ.diff(this.value);
        if (changes) {
            // clear timeout in the queue to avoid memory leak
            changes.forEachRemovedItem(({ item }) => clearTimeout(item?.timeout));
            // for newly added items create timeout if they are not sticky
            changes.forEachAddedItem(({ item }) => this.createRemovalTimeout(item));
        }
    }
    /**
     * @param msg The text message to appear in the container
     */
    remove(msg) {
        this.value.splice(this.findMessageIndex(msg), 1);
    }
    /**
     * Removes all growl messages from the stack
     */
    removeAll() {
        if (this.value?.length) {
            this.value.splice(0, this.value.length);
        }
    }
    ngOnDestroy() {
        if (!this.sticky) {
            // make sure to clear any leftover async Timeout for messages
            this.value.forEach((v) => clearTimeout(v?.timeout));
        }
    }
    onClick() {
        this.growlClick.emit();
    }
    /**
     * check whether sticky growls are greater than two
     */
    isGrowlMoreThanTwo() {
        return this.value.filter((m) => m.sticky).length > 2;
    }
    /**
     * Removes all growl messages from the stack
     *
     * @param value
     */
    createRemovalTimeout(value) {
        // if message it's NOT sticky and there's not any async running timeout
        if (!value.sticky && !value.timeout) {
            // set Timeout callback for each message based on the given life value
            value.timeout = setTimeout(() => this.remove(value), value.life || this.life);
        }
    }
    /**
     * Finds UxMessage index of the array otherwise returns -1
     *
     * @param msg UxMessage
     */
    findMessageIndex(msg) {
        return this.value?.length ? this.value.findIndex((value) => value === msg) : -1;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiGrowlComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiGrowlComponent, isStandalone: true, selector: "eui-growl", inputs: { e2eAttr: "e2eAttr", sticky: ["sticky", "sticky", booleanAttribute], life: "life", value: "value", closeAllSticky: "closeAllSticky", position: "position" }, outputs: { growlClick: "growlClick" }, host: { listeners: { "click": "onClick()" }, properties: { "class": "this.cssClasses", "attr.data-e2e": "this.e2eAttr", "attr.role": "this.role", "attr.aria-live": "this.ariaLive", "attr.aria-labelledby": "this.ariaLabelledBy", "attr.aria-describedby": "this.ariaDescribedBy" } }, ngImport: i0, template: "@for (msg of value; track msg) {\n<div\n    class=\"eui-growl-item-container eui-u-anim eui-u-anim--fast\"\n    [ngClass]=\"{\n        'eui-growl-item-container--info eui--info': msg.severity === 'info',\n        'eui-growl-item-container--warning eui--warning': msg.severity === 'warning',\n        'eui-growl-item-container--danger eui--danger': msg.severity === 'danger',\n        'eui-growl-item-container--success eui--success': msg.severity === 'success',\n        'eui-growl-item-container--filled': msg.filled,\n        'eui-growl--sticky': sticky,\n    }\"\n    [class.eui-u-anim--slideInUp]=\"position === 'bottom-left' || position === 'bottom-center' || position === 'bottom-right'\"\n    [class.eui-u-anim--slideInDown]=\"position === 'top-left' || position === 'top-center' || position === 'top-right'\">\n\n    <div class=\"eui-growl-item\">\n        <div class=\"eui-growl-item-summary-wrapper\">\n            <eui-icon-state [euiVariant]=\"msg.severity\" class=\"eui-growl-item-icon\"/>\n            <span [id]=\"titleId\" class=\"eui-growl-item-title\">{{ msg.summary }}</span>\n        </div>\n        <div [id]=\"contentId\" class=\"eui-growl-item-content\" [innerHTML]=\"msg.detail\"></div>\n\n        <eui-icon-button\n            (buttonClick)=\"remove(msg)\"\n            icon=\"close:outline\"\n            fillColor=\"neutral-light\"\n            euiRounded\n            ariaLabel=\"Close growl icon\"\n            class=\"eui-growl-item-close\">\n        </eui-icon-button>\n    </div>\n\n</div>\n}\n@if (closeAllSticky && isGrowlMoreThanTwo()) {\n<div class=\"eui-growl-item-container eui-u-anim eui-u-anim--fast eui-growl-item-container--secondary\">\n    <div class=\"eui-growl-item\">\n        <div class=\"eui-growl-item-summary-wrapper\">\n            <eui-icon-svg icon=\"checkmark-done:sharp\"/>\n            <span class=\"eui-growl-item-title\">{{ 'eui.growl.dismiss-all' | translate }}</span>\n        </div>\n        <eui-icon-button (buttonClick)=\"removeAll()\"\n            icon=\"close:outline\"\n            fillColor=\"neutral-light\"\n            euiRounded\n            ariaLabel=\"Close growl icon\"\n            class=\"eui-growl-item-close\"/>\n    </div>\n</div>\n}\n", styles: [".eui-19 .eui-growl{--_color: var(--eui-growl-color, var(--eui-c-s-info-on-surface-light));--_bg-color: var(--eui-growl-bg-color, var(--eui-c-s-info-surface-light));--_color-on-bg: var(--eui-growl-color-on-bg, var(--eui-c-s-info-surface-light-contrast));--_close-hover-color: var(--eui-growl-close-hover-color, var(--eui-c-s-info-surface-light-hover));--eui-bottom-left-horizontal-offset: var(--eui-s-l);--eui-bottom-left-vertical-offset: var(--eui-s-l);--eui-bottom-right-horizontal-offset: var(--eui-s-l);--eui-bottom-right-vertical-offset: var(--eui-s-l)}.eui-19 .eui-growl-item-container--primary{--_color: var(--eui-c-s-primary);--_bg-color: var(--eui-c-s-primary-surface-light);--_color-on-bg: var(--eui-c-s-primary-surface-light-contrast);--_close-hover-color: var(--eui-c-s-primary-surface-light-hover)}.eui-19 .eui-growl-item-container--secondary{--_color: var(--eui-c-s-secondary);--_bg-color: var(--eui-c-s-secondary-surface-light);--_color-on-bg: var(--eui-c-s-secondary-surface-light-contrast);--_close-hover-color: var(--eui-c-s-secondary-surface-light-hover)}.eui-19 .eui-growl-item-container--info{--_color: var(--eui-c-s-info);--_bg-color: var(--eui-c-s-info-surface-light);--_color-on-bg: var(--eui-c-s-info-surface-light-contrast);--_close-hover-color: var(--eui-c-s-info-surface-light-hover)}.eui-19 .eui-growl-item-container--success{--_color: var(--eui-c-s-success);--_bg-color: var(--eui-c-s-success-surface-light);--_color-on-bg: var(--eui-c-s-success-surface-light-contrast);--_close-hover-color: var(--eui-c-s-success-surface-light-hover)}.eui-19 .eui-growl-item-container--warning{--_color: var(--eui-c-s-warning);--_bg-color: var(--eui-c-s-warning-surface-light);--_color-on-bg: var(--eui-c-s-warning-surface-light-contrast);--_close-hover-color: var(--eui-c-s-warning-surface-light-hover)}.eui-19 .eui-growl-item-container--danger{--_color: var(--eui-c-s-danger);--_bg-color: var(--eui-c-s-danger-surface-light);--_color-on-bg: var(--eui-c-s-danger-surface-light-contrast);--_close-hover-color: var(--eui-c-s-danger-surface-light-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--primary{--_bg-color: var(--eui-c-s-primary-surface);--_color-on-bg: var(--eui-c-s-primary-surface-contrast);--_color: var(--eui-c-s-primary-surface-contrast);--_icon-color: var(--eui-c-s-primary-surface-contrast);--_close-hover-color: var(--eui-c-s-primary-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--info{--_bg-color: var(--eui-c-s-info-surface);--_color-on-bg: var(--eui-c-s-info-surface-contrast);--_color: var(--eui-c-s-info-surface-contrast);--_icon-color: var(--eui-c-s-info-surface-contrast);--_close-hover-color: var(--eui-c-s-info-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--success{--_bg-color: var(--eui-c-s-success-surface);--_color-on-bg: var(--eui-c-s-success-surface-contrast);--_color: var(--eui-c-s-success-surface-contrast);--_icon-color: var(--eui-c-s-success-surface-contrast);--_close-hover-color: var(--eui-c-s-success-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--warning{--_bg-color: var(--eui-c-s-warning-surface);--_color-on-bg: var(--eui-c-s-warning-surface-contrast);--_color: var(--eui-c-s-warning-surface-contrast);--_icon-color: var(--eui-c-s-warning-surface-contrast);--_close-hover-color: var(--eui-c-s-warning-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--danger{--_bg-color: var(--eui-c-s-danger-surface);--_color-on-bg: var(--eui-c-s-danger-surface-contrast);--_color: var(--eui-c-s-danger-surface-contrast);--_icon-color: var(--eui-c-s-danger-surface-contrast);--_close-hover-color: var(--eui-c-s-danger-surface-hover)}.eui-19 .eui-growl{position:fixed;width:20rem;z-index:var(--eui-zi-growl-message)}.eui-19 .eui-growl--bottom-left{bottom:var(--eui-bottom-left-vertical-offset);left:var(--eui-bottom-left-horizontal-offset)}.eui-19 .eui-growl--bottom-center{bottom:var(--eui-s-l);right:50%;transform:translate(50%)}.eui-19 .eui-growl--bottom-right{bottom:var(--eui-bottom-right-vertical-offset);right:var(--eui-bottom-right-horizontal-offset)}.eui-19 .eui-growl--top-left{left:var(--eui-s-l);top:var(--eui-s-l)}.eui-19 .eui-growl--top-center{right:50%;top:var(--eui-s-l);transform:translate(50%)}.eui-19 .eui-growl--top-right{right:var(--eui-s-l);top:var(--eui-s-l)}.eui-19 .eui-growl a{text-decoration:underline}.eui-19 .eui-growl-item-container{margin-bottom:var(--eui-s-s);position:relative;background-color:var(--_bg-color);color:var(--_color-on-bg)}.eui-19 .eui-growl-item{display:flex;flex-direction:column;padding:var(--eui-s-m);position:relative;width:20rem;box-shadow:var(--eui-sh-3)}.eui-19 .eui-growl-item-summary-wrapper{display:flex;align-items:center;gap:var(--eui-s-xs)}.eui-19 .eui-growl-item-title{font:var(--eui-f-m-compact-bold);margin-right:var(--eui-s-xl);color:var(--_color)}.eui-19 .eui-growl-item-content:not(:empty){margin-top:var(--eui-s-xs);max-height:80vh;overflow-y:auto;overflow-wrap:break-word;font:var(--eui-f-m-compact)}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar{display:inherit;height:4px;width:4px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-growl-item-content:not(:empty){scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-growl-item-close{position:absolute;top:var(--eui-s-xs);right:var(--eui-s-xs)}.eui-19 .eui-growl-item-close .eui-icon-button__button:hover{background-color:var(--_close-hover-color)!important}.eui-19 .eui-growl-item-container--filled .eui-icon-svg svg{fill:var(--_icon-color)!important;color:var(--_icon-color)!important}.eui-19 .eui-growl-item-container--filled a,.eui-19 .eui-growl-item-container--filled code{color:var(--eui-c-white)!important}\n"], dependencies: [{ kind: "directive", type: NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "ngmodule", type: TranslateModule }, { kind: "pipe", type: i1.TranslatePipe, name: "translate" }, { kind: "component", type: i2.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i3.EuiIconButtonComponent, selector: "eui-icon-button", inputs: ["icon", "iconUrl", "fillColor", "size", "ariaLabel", "tabindex", "hasNoPadding", "hasFocusHoverColor", "hasFocusHoverBg", "euiRounded", "euiDisabled"], outputs: ["buttonClick"] }, { kind: "component", type: i4.EuiIconStateComponent, selector: "eui-icon-state", inputs: ["size", "ariaLabel"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiGrowlComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-growl', encapsulation: ViewEncapsulation.None, imports: [
                        NgClass,
                        TranslateModule,
                        ...EUI_ICON,
                        ...EUI_ICON_BUTTON,
                        ...EUI_ICON_STATE,
                    ], template: "@for (msg of value; track msg) {\n<div\n    class=\"eui-growl-item-container eui-u-anim eui-u-anim--fast\"\n    [ngClass]=\"{\n        'eui-growl-item-container--info eui--info': msg.severity === 'info',\n        'eui-growl-item-container--warning eui--warning': msg.severity === 'warning',\n        'eui-growl-item-container--danger eui--danger': msg.severity === 'danger',\n        'eui-growl-item-container--success eui--success': msg.severity === 'success',\n        'eui-growl-item-container--filled': msg.filled,\n        'eui-growl--sticky': sticky,\n    }\"\n    [class.eui-u-anim--slideInUp]=\"position === 'bottom-left' || position === 'bottom-center' || position === 'bottom-right'\"\n    [class.eui-u-anim--slideInDown]=\"position === 'top-left' || position === 'top-center' || position === 'top-right'\">\n\n    <div class=\"eui-growl-item\">\n        <div class=\"eui-growl-item-summary-wrapper\">\n            <eui-icon-state [euiVariant]=\"msg.severity\" class=\"eui-growl-item-icon\"/>\n            <span [id]=\"titleId\" class=\"eui-growl-item-title\">{{ msg.summary }}</span>\n        </div>\n        <div [id]=\"contentId\" class=\"eui-growl-item-content\" [innerHTML]=\"msg.detail\"></div>\n\n        <eui-icon-button\n            (buttonClick)=\"remove(msg)\"\n            icon=\"close:outline\"\n            fillColor=\"neutral-light\"\n            euiRounded\n            ariaLabel=\"Close growl icon\"\n            class=\"eui-growl-item-close\">\n        </eui-icon-button>\n    </div>\n\n</div>\n}\n@if (closeAllSticky && isGrowlMoreThanTwo()) {\n<div class=\"eui-growl-item-container eui-u-anim eui-u-anim--fast eui-growl-item-container--secondary\">\n    <div class=\"eui-growl-item\">\n        <div class=\"eui-growl-item-summary-wrapper\">\n            <eui-icon-svg icon=\"checkmark-done:sharp\"/>\n            <span class=\"eui-growl-item-title\">{{ 'eui.growl.dismiss-all' | translate }}</span>\n        </div>\n        <eui-icon-button (buttonClick)=\"removeAll()\"\n            icon=\"close:outline\"\n            fillColor=\"neutral-light\"\n            euiRounded\n            ariaLabel=\"Close growl icon\"\n            class=\"eui-growl-item-close\"/>\n    </div>\n</div>\n}\n", styles: [".eui-19 .eui-growl{--_color: var(--eui-growl-color, var(--eui-c-s-info-on-surface-light));--_bg-color: var(--eui-growl-bg-color, var(--eui-c-s-info-surface-light));--_color-on-bg: var(--eui-growl-color-on-bg, var(--eui-c-s-info-surface-light-contrast));--_close-hover-color: var(--eui-growl-close-hover-color, var(--eui-c-s-info-surface-light-hover));--eui-bottom-left-horizontal-offset: var(--eui-s-l);--eui-bottom-left-vertical-offset: var(--eui-s-l);--eui-bottom-right-horizontal-offset: var(--eui-s-l);--eui-bottom-right-vertical-offset: var(--eui-s-l)}.eui-19 .eui-growl-item-container--primary{--_color: var(--eui-c-s-primary);--_bg-color: var(--eui-c-s-primary-surface-light);--_color-on-bg: var(--eui-c-s-primary-surface-light-contrast);--_close-hover-color: var(--eui-c-s-primary-surface-light-hover)}.eui-19 .eui-growl-item-container--secondary{--_color: var(--eui-c-s-secondary);--_bg-color: var(--eui-c-s-secondary-surface-light);--_color-on-bg: var(--eui-c-s-secondary-surface-light-contrast);--_close-hover-color: var(--eui-c-s-secondary-surface-light-hover)}.eui-19 .eui-growl-item-container--info{--_color: var(--eui-c-s-info);--_bg-color: var(--eui-c-s-info-surface-light);--_color-on-bg: var(--eui-c-s-info-surface-light-contrast);--_close-hover-color: var(--eui-c-s-info-surface-light-hover)}.eui-19 .eui-growl-item-container--success{--_color: var(--eui-c-s-success);--_bg-color: var(--eui-c-s-success-surface-light);--_color-on-bg: var(--eui-c-s-success-surface-light-contrast);--_close-hover-color: var(--eui-c-s-success-surface-light-hover)}.eui-19 .eui-growl-item-container--warning{--_color: var(--eui-c-s-warning);--_bg-color: var(--eui-c-s-warning-surface-light);--_color-on-bg: var(--eui-c-s-warning-surface-light-contrast);--_close-hover-color: var(--eui-c-s-warning-surface-light-hover)}.eui-19 .eui-growl-item-container--danger{--_color: var(--eui-c-s-danger);--_bg-color: var(--eui-c-s-danger-surface-light);--_color-on-bg: var(--eui-c-s-danger-surface-light-contrast);--_close-hover-color: var(--eui-c-s-danger-surface-light-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--primary{--_bg-color: var(--eui-c-s-primary-surface);--_color-on-bg: var(--eui-c-s-primary-surface-contrast);--_color: var(--eui-c-s-primary-surface-contrast);--_icon-color: var(--eui-c-s-primary-surface-contrast);--_close-hover-color: var(--eui-c-s-primary-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--info{--_bg-color: var(--eui-c-s-info-surface);--_color-on-bg: var(--eui-c-s-info-surface-contrast);--_color: var(--eui-c-s-info-surface-contrast);--_icon-color: var(--eui-c-s-info-surface-contrast);--_close-hover-color: var(--eui-c-s-info-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--success{--_bg-color: var(--eui-c-s-success-surface);--_color-on-bg: var(--eui-c-s-success-surface-contrast);--_color: var(--eui-c-s-success-surface-contrast);--_icon-color: var(--eui-c-s-success-surface-contrast);--_close-hover-color: var(--eui-c-s-success-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--warning{--_bg-color: var(--eui-c-s-warning-surface);--_color-on-bg: var(--eui-c-s-warning-surface-contrast);--_color: var(--eui-c-s-warning-surface-contrast);--_icon-color: var(--eui-c-s-warning-surface-contrast);--_close-hover-color: var(--eui-c-s-warning-surface-hover)}.eui-19 .eui-growl-item-container.eui-growl-item-container--filled.eui-growl-item-container--danger{--_bg-color: var(--eui-c-s-danger-surface);--_color-on-bg: var(--eui-c-s-danger-surface-contrast);--_color: var(--eui-c-s-danger-surface-contrast);--_icon-color: var(--eui-c-s-danger-surface-contrast);--_close-hover-color: var(--eui-c-s-danger-surface-hover)}.eui-19 .eui-growl{position:fixed;width:20rem;z-index:var(--eui-zi-growl-message)}.eui-19 .eui-growl--bottom-left{bottom:var(--eui-bottom-left-vertical-offset);left:var(--eui-bottom-left-horizontal-offset)}.eui-19 .eui-growl--bottom-center{bottom:var(--eui-s-l);right:50%;transform:translate(50%)}.eui-19 .eui-growl--bottom-right{bottom:var(--eui-bottom-right-vertical-offset);right:var(--eui-bottom-right-horizontal-offset)}.eui-19 .eui-growl--top-left{left:var(--eui-s-l);top:var(--eui-s-l)}.eui-19 .eui-growl--top-center{right:50%;top:var(--eui-s-l);transform:translate(50%)}.eui-19 .eui-growl--top-right{right:var(--eui-s-l);top:var(--eui-s-l)}.eui-19 .eui-growl a{text-decoration:underline}.eui-19 .eui-growl-item-container{margin-bottom:var(--eui-s-s);position:relative;background-color:var(--_bg-color);color:var(--_color-on-bg)}.eui-19 .eui-growl-item{display:flex;flex-direction:column;padding:var(--eui-s-m);position:relative;width:20rem;box-shadow:var(--eui-sh-3)}.eui-19 .eui-growl-item-summary-wrapper{display:flex;align-items:center;gap:var(--eui-s-xs)}.eui-19 .eui-growl-item-title{font:var(--eui-f-m-compact-bold);margin-right:var(--eui-s-xl);color:var(--_color)}.eui-19 .eui-growl-item-content:not(:empty){margin-top:var(--eui-s-xs);max-height:80vh;overflow-y:auto;overflow-wrap:break-word;font:var(--eui-f-m-compact)}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar{display:inherit;height:4px;width:4px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-growl-item-content:not(:empty)::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-growl-item-content:not(:empty){scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-growl-item-close{position:absolute;top:var(--eui-s-xs);right:var(--eui-s-xs)}.eui-19 .eui-growl-item-close .eui-icon-button__button:hover{background-color:var(--_close-hover-color)!important}.eui-19 .eui-growl-item-container--filled .eui-icon-svg svg{fill:var(--_icon-color)!important;color:var(--_icon-color)!important}.eui-19 .eui-growl-item-container--filled a,.eui-19 .eui-growl-item-container--filled code{color:var(--eui-c-white)!important}\n"] }]
        }], ctorParameters: () => [], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], e2eAttr: [{
                type: HostBinding,
                args: ['attr.data-e2e']
            }, {
                type: Input
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], ariaLive: [{
                type: HostBinding,
                args: ['attr.aria-live']
            }], ariaLabelledBy: [{
                type: HostBinding,
                args: ['attr.aria-labelledby']
            }], ariaDescribedBy: [{
                type: HostBinding,
                args: ['attr.aria-describedby']
            }], sticky: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], life: [{
                type: Input
            }], value: [{
                type: Input
            }], closeAllSticky: [{
                type: Input
            }], position: [{
                type: Input
            }], growlClick: [{
                type: Output
            }], onClick: [{
                type: HostListener,
                args: ['click']
            }] } });

/**
 * Module for the EuiGrowl component.
 *
 * @deprecated Use {@link EUI_GROWL} directly instead.
 */
class EuiGrowlModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiGrowlModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiGrowlModule, imports: [EuiGrowlComponent], exports: [EuiGrowlComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiGrowlModule, imports: [EuiGrowlComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiGrowlModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiGrowlComponent],
                    exports: [EuiGrowlComponent],
                }]
        }] });

const EUI_GROWL = [EuiGrowlComponent];

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_GROWL, EuiGrowlComponent, EuiGrowlModule };
//# sourceMappingURL=eui-components-eui-growl.mjs.map
