import * as i0 from '@angular/core';
import { inject, booleanAttribute, Input, HostBinding, ViewEncapsulation, ChangeDetectionStrategy, Component, NgModule } from '@angular/core';
import { EUI_CONFIG_TOKEN } from '@eui/core';

/**
 * @description
 * The EuiIconSvgComponent is used to display SVG icons in the application.
 * It allows for customization of the icon's size, color, and other properties.
 *
 */
class EuiIconSvgComponent {
    constructor() {
        this.ariaRole = 'img';
        this.set = 'eui';
        this.size = 'm';
        this.style = '';
        this.transform = '';
        this.ariaLabel = 'Icon';
        this.assetsBaseUrl = 'assets';
        this.ariaHidden = true;
        this.focusable = false;
        this.isLoading = false;
        this.isInputIcon = false;
        this.euiStart = false;
        this.euiEnd = false;
        this.config = inject(EUI_CONFIG_TOKEN, { optional: true });
    }
    get cssClasses() {
        return [
            // Always refer to the baseStatesDirective
            'eui-icon-svg',
            `eui-icon-svg--size-${this.size}`,
            this.transform ? `eui-icon-svg--${this.transform}` : '',
            // own cmp state => reflected with the scss states
            this.euiStart ? 'eui-icon-svg--start' : '',
            this.euiEnd ? 'eui-icon-svg--end' : '',
            this.isInputIcon ? 'eui-icon-svg--input-icon' : '',
            this.isLoading ? 'eui-icon-svg--loading' : '',
        ]
            .join(' ')
            .trim();
    }
    ngOnInit() {
        const assetsBaseUrl = this.config?.appConfig?.global?.eui?.assetsBaseUrl;
        if (assetsBaseUrl) {
            this.assetsBaseUrl = this.config.appConfig.global.eui.assetsBaseUrl;
        }
        if (!this.size || this.size === '') {
            this.size = 'm';
        }
    }
    ngOnChanges(c) {
        if (c && c.set) {
            if (c.set.currentValue !== c.set.previousValue) {
                this._setIconAndSet();
            }
        }
        if (c && c.icon) {
            if (c.icon.currentValue !== c.icon.previousValue) {
                this._setIconAndSet();
            }
        }
        if (c && c.size) {
            if (c.size.currentValue !== c.size.previousValue) {
                this._setStyle();
            }
        }
        if (c && c.fillColor) {
            if (c.fillColor.currentValue !== c.fillColor.previousValue) {
                this._setStyle();
            }
        }
    }
    ngAfterContentInit() {
        this._setIconAndSet();
        this._setStyle();
    }
    _setIconAndSet() {
        if (this.icon && this.icon.indexOf(':') > -1) {
            const iconSet = this.icon.split(':');
            this.icon = iconSet[0];
            this.set = iconSet[1];
        }
        if (!this.set || this.set === '') {
            this.set = 'eui';
        }
        else {
            if (this.set === 'sharp' || this.set === 'outline' || this.set === 'filled') {
                this.iconName = `${this.icon}-${this.set}`;
            }
            else {
                this.iconName = this.icon;
            }
        }
    }
    _setStyle() {
        let fill = '';
        if (this.fillColor) {
            fill = `fill: var(--eui-c-${this.fillColor}); color: var(--eui-c-${this.fillColor});`;
        }
        // const height = `height: var(--eui-is-${this.size});`;
        // const width = `width: var(--eui-is-${this.size});`;
        // this.iconStyle = `${fill} ${height} ${width}`;
        this.iconStyle = `${fill}`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiIconSvgComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiIconSvgComponent, isStandalone: true, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: { icon: "icon", fillColor: "fillColor", set: "set", size: "size", style: "style", iconUrl: "iconUrl", transform: "transform", euiVariant: "euiVariant", ariaLabel: ["aria-label", "ariaLabel"], ariaHidden: ["ariaHidden", "ariaHidden", booleanAttribute], focusable: ["focusable", "focusable", booleanAttribute], isLoading: ["isLoading", "isLoading", booleanAttribute], isInputIcon: ["isInputIcon", "isInputIcon", booleanAttribute], euiStart: ["euiStart", "euiStart", booleanAttribute], euiEnd: ["euiEnd", "euiEnd", booleanAttribute] }, host: { properties: { "attr.role": "this.ariaRole", "class": "this.cssClasses", "attr.aria-label": "this.ariaLabel" } }, usesOnChanges: true, ngImport: i0, template: "@if (icon && !iconUrl && !isLoading) {\n    <svg\n        class=\"eui-sprite-{{icon}}\"\n        [class.eui-icon-svg--loading]=\"isLoading\"\n        [attr.aria-hidden]=\"ariaHidden\"\n        [attr.role]=\"'img'\"\n        [attr.focusable]=\"focusable\"\n        attr.style=\"{{iconStyle}}\">\n        <use [attr.href]=\"assetsBaseUrl + '/icons/sprites/' + set + '.svg#' + iconName\"></use>\n    </svg>\n    <ng-content />\n}\n\n@if (iconUrl) {\n    <svg class=\"eui-icon-svg\"\n         attr.style=\"{{iconStyle}} {{style}}\"\n         [attr.aria-hidden]=\"ariaHidden\"\n         [attr.role]=\"'img'\"\n         [attr.focusable]=\"focusable\">\n        <image [attr.href]=\"iconUrl\" [class]=\"'eui-icon-svg'\" attr.style=\"{{iconStyle}} {{style}}\"></image>\n    </svg>\n}\n", styles: [".eui-19 .eui-icon-svg{display:inline-flex;position:relative}.eui-19 .eui-icon-svg svg{pointer-events:none}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-facebook{color:#4267b2;fill:#4267b2}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-flickr{color:#000;fill:#000}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-foursquare{color:#ff577a;fill:#ff577a}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-gmail,.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-instagram{color:#000;fill:#000}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-linkedin{color:#0a66c2;fill:#0a66c2}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-mastodon{color:#2b90d9;fill:#2b90d9}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-messenger{color:#00b2ff;fill:#00b2ff}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-pinterest{color:#e60023;fill:#e60023}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-qzone{color:#fc0;fill:#fc0}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-reddit{color:#ff5700;fill:#ff5700}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-skype{color:#00aff0;fill:#00aff0}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-spotify{color:#1db954;fill:#1db954}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-telegram{color:#24a1de;fill:#24a1de}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-twitter{color:#1da1f2;fill:#1da1f2}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-typepad{color:#aab652;fill:#aab652}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-weibo{color:#e6162d;fill:#e6162d}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-whatasapp{color:#25d366;fill:#25d366}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-yahoomail{color:#6619df;fill:#6619df}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-yammer{color:#0078d4;fill:#0078d4}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-youtube{color:red;fill:red}.eui-19 .eui-icon-svg--start{margin-right:var(--eui-s-s)}.eui-19 .eui-icon-svg--end{margin-left:var(--eui-s-s)}.eui-19 .eui-icon-svg--input-icon{position:absolute}.eui-19 .eui-icon-svg--input-icon.eui-icon-svg--start{left:var(--eui-s-2xl)}.eui-19 .eui-icon-svg--input-icon.eui-icon-svg--end{right:var(--eui-s-xl)}.eui-19 .eui-icon-svg--loading{align-items:center;display:inline-flex;color:transparent;fill:transparent}.eui-19 .eui-icon-svg--loading:after,.eui-19 .eui-icon-svg--loading:before{content:\"\";position:absolute;height:100%;width:100%}.eui-19 .eui-icon-svg--loading:before{border:var(--eui-s-2xs) solid rgba(0,0,0,.25);border-radius:var(--eui-br-max)}.eui-19 .eui-icon-svg--loading:after{animation:eui-icon-loading-kf .8s linear;animation-iteration-count:infinite;border-color:rgba(255,255,255,.5) transparent transparent;border-radius:var(--eui-br-max);border-style:solid;border-width:var(--eui-s-2xs);box-shadow:0 0 0 1px transparent}.eui-19 .eui-icon-svg--loading--sm:before,.eui-19 .eui-icon-svg--loading--sm:after{height:var(--eui-s-m);width:var(--eui-s-m)}.eui-19 .eui-icon-svg.eui-icon-svg--spin>svg{animation:eui-icon-svg-spin 1.5s infinite linear}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-45{transform:rotate(45deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-90{transform:rotate(90deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-135{transform:rotate(135deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-180{transform:rotate(180deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-225{transform:rotate(225deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-270{transform:rotate(270deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-315{transform:rotate(315deg)}.eui-19 .eui-icon-svg.eui-icon-svg--flip-horizontal{-ms-filter:\"progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)\";transform:scaleX(-1)}.eui-19 .eui-icon-svg.eui-icon-svg--flip-vertical{-ms-filter:\"progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)\";transform:scaleY(-1)}.eui-19 .eui-icon-svg.eui-icon-svg--flip-both{-ms-filter:\"progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)\";transform:scale(-1)}.eui-19 .eui-icon-svg.eui-icon-svg--stack{position:absolute;transform:translate(-50%);margin-left:50%}@keyframes eui-icon-loading-kf{to{transform:rotate(360deg)}}@keyframes eui-icon-svg-spin{0%{transform:rotate(0)}to{transform:rotate(359deg)}}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-s{height:var(--eui-is-s);width:var(--eui-is-s)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-s:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-s:after{min-height:var(--eui-s-s);min-width:var(--eui-s-s)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-m{height:var(--eui-is-m);width:var(--eui-is-m)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-m:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-m:after{min-height:var(--eui-s-m);min-width:var(--eui-s-m)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-l{height:var(--eui-is-l);width:var(--eui-is-l)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-l:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-l:after{min-height:var(--eui-s-l);min-width:var(--eui-s-l)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-xl{height:var(--eui-is-xl);width:var(--eui-is-xl)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-xl:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-xl:after{min-height:var(--eui-s-xl);min-width:var(--eui-s-xl)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-2xl{height:var(--eui-is-2xl);width:var(--eui-is-2xl)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-2xl:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-2xl:after{min-height:var(--eui-s-2xl);min-width:var(--eui-s-2xl)}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiIconSvgComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-icon-svg, span[euiIconSvg], i[euiIconSvg]', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, template: "@if (icon && !iconUrl && !isLoading) {\n    <svg\n        class=\"eui-sprite-{{icon}}\"\n        [class.eui-icon-svg--loading]=\"isLoading\"\n        [attr.aria-hidden]=\"ariaHidden\"\n        [attr.role]=\"'img'\"\n        [attr.focusable]=\"focusable\"\n        attr.style=\"{{iconStyle}}\">\n        <use [attr.href]=\"assetsBaseUrl + '/icons/sprites/' + set + '.svg#' + iconName\"></use>\n    </svg>\n    <ng-content />\n}\n\n@if (iconUrl) {\n    <svg class=\"eui-icon-svg\"\n         attr.style=\"{{iconStyle}} {{style}}\"\n         [attr.aria-hidden]=\"ariaHidden\"\n         [attr.role]=\"'img'\"\n         [attr.focusable]=\"focusable\">\n        <image [attr.href]=\"iconUrl\" [class]=\"'eui-icon-svg'\" attr.style=\"{{iconStyle}} {{style}}\"></image>\n    </svg>\n}\n", styles: [".eui-19 .eui-icon-svg{display:inline-flex;position:relative}.eui-19 .eui-icon-svg svg{pointer-events:none}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-facebook{color:#4267b2;fill:#4267b2}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-flickr{color:#000;fill:#000}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-foursquare{color:#ff577a;fill:#ff577a}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-gmail,.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-instagram{color:#000;fill:#000}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-linkedin{color:#0a66c2;fill:#0a66c2}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-mastodon{color:#2b90d9;fill:#2b90d9}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-messenger{color:#00b2ff;fill:#00b2ff}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-pinterest{color:#e60023;fill:#e60023}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-qzone{color:#fc0;fill:#fc0}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-reddit{color:#ff5700;fill:#ff5700}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-skype{color:#00aff0;fill:#00aff0}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-spotify{color:#1db954;fill:#1db954}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-telegram{color:#24a1de;fill:#24a1de}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-twitter{color:#1da1f2;fill:#1da1f2}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-typepad{color:#aab652;fill:#aab652}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-weibo{color:#e6162d;fill:#e6162d}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-whatasapp{color:#25d366;fill:#25d366}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-yahoomail{color:#6619df;fill:#6619df}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-yammer{color:#0078d4;fill:#0078d4}.eui-19 .eui-icon-svg .eui-sprite-eui-ecl-youtube{color:red;fill:red}.eui-19 .eui-icon-svg--start{margin-right:var(--eui-s-s)}.eui-19 .eui-icon-svg--end{margin-left:var(--eui-s-s)}.eui-19 .eui-icon-svg--input-icon{position:absolute}.eui-19 .eui-icon-svg--input-icon.eui-icon-svg--start{left:var(--eui-s-2xl)}.eui-19 .eui-icon-svg--input-icon.eui-icon-svg--end{right:var(--eui-s-xl)}.eui-19 .eui-icon-svg--loading{align-items:center;display:inline-flex;color:transparent;fill:transparent}.eui-19 .eui-icon-svg--loading:after,.eui-19 .eui-icon-svg--loading:before{content:\"\";position:absolute;height:100%;width:100%}.eui-19 .eui-icon-svg--loading:before{border:var(--eui-s-2xs) solid rgba(0,0,0,.25);border-radius:var(--eui-br-max)}.eui-19 .eui-icon-svg--loading:after{animation:eui-icon-loading-kf .8s linear;animation-iteration-count:infinite;border-color:rgba(255,255,255,.5) transparent transparent;border-radius:var(--eui-br-max);border-style:solid;border-width:var(--eui-s-2xs);box-shadow:0 0 0 1px transparent}.eui-19 .eui-icon-svg--loading--sm:before,.eui-19 .eui-icon-svg--loading--sm:after{height:var(--eui-s-m);width:var(--eui-s-m)}.eui-19 .eui-icon-svg.eui-icon-svg--spin>svg{animation:eui-icon-svg-spin 1.5s infinite linear}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-45{transform:rotate(45deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-90{transform:rotate(90deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-135{transform:rotate(135deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-180{transform:rotate(180deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-225{transform:rotate(225deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-270{transform:rotate(270deg)}.eui-19 .eui-icon-svg.eui-icon-svg--rotate-315{transform:rotate(315deg)}.eui-19 .eui-icon-svg.eui-icon-svg--flip-horizontal{-ms-filter:\"progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)\";transform:scaleX(-1)}.eui-19 .eui-icon-svg.eui-icon-svg--flip-vertical{-ms-filter:\"progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)\";transform:scaleY(-1)}.eui-19 .eui-icon-svg.eui-icon-svg--flip-both{-ms-filter:\"progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)\";transform:scale(-1)}.eui-19 .eui-icon-svg.eui-icon-svg--stack{position:absolute;transform:translate(-50%);margin-left:50%}@keyframes eui-icon-loading-kf{to{transform:rotate(360deg)}}@keyframes eui-icon-svg-spin{0%{transform:rotate(0)}to{transform:rotate(359deg)}}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-s{height:var(--eui-is-s);width:var(--eui-is-s)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-s:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-s:after{min-height:var(--eui-s-s);min-width:var(--eui-s-s)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-m{height:var(--eui-is-m);width:var(--eui-is-m)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-m:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-m:after{min-height:var(--eui-s-m);min-width:var(--eui-s-m)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-l{height:var(--eui-is-l);width:var(--eui-is-l)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-l:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-l:after{min-height:var(--eui-s-l);min-width:var(--eui-s-l)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-xl{height:var(--eui-is-xl);width:var(--eui-is-xl)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-xl:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-xl:after{min-height:var(--eui-s-xl);min-width:var(--eui-s-xl)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-2xl{height:var(--eui-is-2xl);width:var(--eui-is-2xl)}.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-2xl:before,.eui-19 .eui-icon-svg--loading.eui-icon-svg--size-2xl:after{min-height:var(--eui-s-2xl);min-width:var(--eui-s-2xl)}\n"] }]
        }], propDecorators: { ariaRole: [{
                type: HostBinding,
                args: ['attr.role']
            }], icon: [{
                type: Input
            }], fillColor: [{
                type: Input
            }], set: [{
                type: Input
            }], size: [{
                type: Input
            }], style: [{
                type: Input
            }], iconUrl: [{
                type: Input
            }], transform: [{
                type: Input
            }], euiVariant: [{
                type: Input
            }], cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], ariaLabel: [{
                type: HostBinding,
                args: ['attr.aria-label']
            }, {
                type: Input,
                args: ['aria-label']
            }], ariaHidden: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], focusable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isLoading: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isInputIcon: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiStart: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiEnd: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });
/**
 * @description
 * A module for the icon component. This module imports the
 *
 * @deprecated Use the {@link EUI_ICON} instead
 */
class EuiIconModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiIconModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiIconModule, imports: [EuiIconSvgComponent], exports: [EuiIconSvgComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiIconModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiIconModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiIconSvgComponent],
                    exports: [EuiIconSvgComponent],
                }]
        }] });

const EUI_ICON = [
    EuiIconSvgComponent,
];
// export { EuiIconSvgComponent as EuiIcon } from './eui-icon-svg.component';

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_ICON, EuiIconModule, EuiIconSvgComponent };
//# sourceMappingURL=eui-components-eui-icon.mjs.map
