import * as i0 from '@angular/core';
import { inject, ViewEncapsulation, ChangeDetectionStrategy, Component, EventEmitter, ChangeDetectorRef, ElementRef, booleanAttribute, Output, Input, HostBinding, NgModule } from '@angular/core';
import { takeUntil, distinctUntilKeyChanged, map } from 'rxjs/operators';
import { Subject } from 'rxjs';
import { TranslateService } from '@ngx-translate/core';
import { EuiEuLanguages, EuiAppShellService } from '@eui/core';
import { DIALOG_COMPONENT_CONFIG, EuiDialogService, EuiDialogConfig, EUI_DIALOG } from '@eui/components/eui-dialog';
import * as i1 from '@eui/components/eui-button';
import { EUI_BUTTON } from '@eui/components/eui-button';
import * as i2 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import * as i1$1 from '@eui/components/eui-dropdown';
import { EUI_DROPDOWN } from '@eui/components/eui-dropdown';
import { AsyncPipe, NgTemplateOutlet } from '@angular/common';

class EuiModalSelectorComponent {
    constructor() {
        this.config = inject(DIALOG_COMPONENT_CONFIG);
        this.languageRows = [];
        this.additionaLanguageRows = [];
        this.euiDialogService = inject(EuiDialogService);
    }
    ngOnInit() {
        this.languageRows = this.prepareLanguageRows(EuiEuLanguages.filterEULanguages(this.config.languages));
        this.additionaLanguageRows = this.prepareLanguageRows(EuiEuLanguages.filterNonEULanguages(this.config.languages));
    }
    selectLanguage(languageCode) {
        if (this.selectedLanguage?.code !== languageCode.code) {
            for (const language of this.config.languages) {
                if (language.code === languageCode.code) {
                    this.selectedLanguage = language;
                    break;
                }
            }
        }
        this.config.languageChanged(languageCode);
        this.euiDialogService.closeDialog();
    }
    prepareLanguageRows(languages) {
        const rows = [];
        let row = [];
        for (let i = 0; i < languages.length; i++) {
            if (i % 4 === 0) {
                if (row.length > 0) {
                    rows.push(row);
                    row = [];
                }
            }
            row.push(languages[i]);
        }
        if (row.length > 0) {
            rows.push(row);
        }
        return rows;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiModalSelectorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiModalSelectorComponent, isStandalone: true, selector: "eui-modal-selector", ngImport: i0, template: "@if (additionaLanguageRows?.length > 0) {\n    <h4>EU official languages</h4>\n}\n@for (row of languageRows; track row) {\n    <div id=\"eu_languages\" class=\"row\">\n        @for (language of row; track language) {\n            <div class=\"col-md-6 mb-2\">\n                <button\n                    type=\"button\"\n                    e2eAttr=\"eui-language-selector-item_{{ language.code }}\"\n                    euiButton\n                    euiBlockButton\n                    [euiSecondary]=\"language.code !== config.selectedLanguage.code\"\n                    [euiPrimary]=\"language.code === config.selectedLanguage.code\"\n                    (click)=\"selectLanguage(language)\">\n                    {{ language.label }} ({{ language.code }})\n                </button>\n            </div>\n        }\n    </div>\n}\n@if (additionaLanguageRows?.length > 0) {\n    <br />\n    <h4>Non-EU Languages</h4>\n    @for (row of additionaLanguageRows; track row) {\n        <div id=\"extra_languages\" class=\"row\">\n            @for (language of row; track language) {\n                <div class=\"col-md-6 mb-2\">\n                    <button\n                        type=\"button\"\n                        e2eAttr=\"eui-language-selector-item_{{ language.code }}\"\n                        euiButton\n                        euiBlockButton\n                        [euiSecondary]=\"language.code !== config.selectedLanguage.code\"\n                        [euiPrimary]=\"language.code === config.selectedLanguage.code\"\n                        (click)=\"selectLanguage(language)\">\n                        {{ language.label }} ({{ language.code }})\n                    </button>\n                </div>\n            }\n        </div>\n    }\n}\n", dependencies: [{ kind: "component", type: i1.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiModalSelectorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-modal-selector', changeDetection: ChangeDetectionStrategy.Default, encapsulation: ViewEncapsulation.None, imports: [
                        ...EUI_BUTTON,
                    ], template: "@if (additionaLanguageRows?.length > 0) {\n    <h4>EU official languages</h4>\n}\n@for (row of languageRows; track row) {\n    <div id=\"eu_languages\" class=\"row\">\n        @for (language of row; track language) {\n            <div class=\"col-md-6 mb-2\">\n                <button\n                    type=\"button\"\n                    e2eAttr=\"eui-language-selector-item_{{ language.code }}\"\n                    euiButton\n                    euiBlockButton\n                    [euiSecondary]=\"language.code !== config.selectedLanguage.code\"\n                    [euiPrimary]=\"language.code === config.selectedLanguage.code\"\n                    (click)=\"selectLanguage(language)\">\n                    {{ language.label }} ({{ language.code }})\n                </button>\n            </div>\n        }\n    </div>\n}\n@if (additionaLanguageRows?.length > 0) {\n    <br />\n    <h4>Non-EU Languages</h4>\n    @for (row of additionaLanguageRows; track row) {\n        <div id=\"extra_languages\" class=\"row\">\n            @for (language of row; track language) {\n                <div class=\"col-md-6 mb-2\">\n                    <button\n                        type=\"button\"\n                        e2eAttr=\"eui-language-selector-item_{{ language.code }}\"\n                        euiButton\n                        euiBlockButton\n                        [euiSecondary]=\"language.code !== config.selectedLanguage.code\"\n                        [euiPrimary]=\"language.code === config.selectedLanguage.code\"\n                        (click)=\"selectLanguage(language)\">\n                        {{ language.label }} ({{ language.code }})\n                    </button>\n                </div>\n            }\n        </div>\n    }\n}\n" }]
        }] });

class EuiLanguageSelectorComponent {
    constructor() {
        this.hasLanguageSelection = true;
        this.isToolbarSelector = false;
        this.euiPrimary = false;
        this.languageSelectorClick = new EventEmitter();
        this.appShellService = inject(EuiAppShellService);
        this.destroy$ = new Subject();
        this.isAriaLabelChanged = false;
        this.cd = inject(ChangeDetectorRef);
        this.euiDialogService = inject(EuiDialogService);
        this.translateService = inject(TranslateService);
        this.elRef = inject(ElementRef);
    }
    get cssClasses() {
        return [
            'eui-language-selector',
            this.languages?.length <= 1 ? 'eui-language-selector--empty' : '',
            this.isToolbarSelector ? 'eui-language-selector--toolbar-selector' : '',
        ]
            .join(' ')
            .trim();
    }
    /**
     * returns true if there are at least one and max four languages.
     */
    get isShowDropDown() {
        return this.languages?.length > 1 && this.languages?.length < 4;
    }
    /**
     * returns true if there are at least five languages.
     */
    get isShowModal() {
        return this.languages?.length >= 4;
    }
    ngOnChanges(changes) {
        if (changes && changes['ariaLabel']) {
            this.isAriaLabelChanged = true;
            this.ariaLabel = changes['ariaLabel'].currentValue;
        }
    }
    ngOnInit() {
        // update languages array based on AppShell State 'language' changes
        this.appShellService.state$
            .pipe(takeUntil(this.destroy$), distinctUntilKeyChanged('languages'), map((state) => state.languages))
            .subscribe((languages) => {
            this.languages = languages ? EuiEuLanguages.getOrderedLanguages(languages) : EuiEuLanguages.getLanguages();
            this.cd.detectChanges();
        });
        // update activeLanguage array based on AppShell State 'language' changes
        this.appShellService.state$
            .pipe(takeUntil(this.destroy$), distinctUntilKeyChanged('activeLanguage'), map((state) => state.activeLanguage))
            .subscribe((activeLanguage) => {
            this.selectedLanguage = this.getLanguage(activeLanguage);
            if (!this.isAriaLabelChanged) {
                this.ariaLabel = `Change Language - Current Language: ${this.selectedLanguage.label}`;
            }
            this.cd.detectChanges();
        });
    }
    ngAfterViewInit() {
        let hasToolbarParent = false;
        try {
            hasToolbarParent = this.elRef.nativeElement.closest('eui-toolbar');
        }
        catch (e) {
            // do nothing
        }
        if (hasToolbarParent) {
            setTimeout(() => {
                this.isToolbarSelector = true;
            }, 1);
        }
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
    onLanguageChanged(language) {
        // Update the AppShellService state
        this.appShellService.setState({
            ...this.appShellService.state,
            activeLanguage: language.code,
        });
    }
    /**
     * Opens the modal that renders the UxLanguage array with modal actions bindings to this Component
     */
    onOpen(titleLabel = this.translateService.instant('eui.languageSelector.modalTitle')) {
        this.euiDialogService.openDialog(new EuiDialogConfig({
            title: titleLabel,
            hasFooter: false,
            hasClosedOnClickOutside: true,
            bodyComponent: {
                component: EuiModalSelectorComponent,
                config: {
                    languages: this.languages,
                    selectedLanguage: this.selectedLanguage,
                    languageChanged: (language) => this.onLanguageChanged(language),
                },
            },
        }));
    }
    onClick() {
        this.languageSelectorClick.emit();
    }
    /**
     * returns the UxLanguage Object from a given language code
     *
     * @param languageCode two char language code
     * @protected
     */
    getLanguage(languageCode) {
        return this.languages.find((lang) => lang.code === languageCode);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiLanguageSelectorComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiLanguageSelectorComponent, isStandalone: true, selector: "eui-language-selector", inputs: { hasLanguageSelection: ["hasLanguageSelection", "hasLanguageSelection", booleanAttribute], isToolbarSelector: ["isToolbarSelector", "isToolbarSelector", booleanAttribute], euiPrimary: ["euiPrimary", "euiPrimary", booleanAttribute], ariaLabel: ["aria-label", "ariaLabel"] }, outputs: { languageSelectorClick: "languageSelectorClick" }, host: { properties: { "class": "this.cssClasses" } }, providers: [
            EuiDialogService,
        ], usesOnChanges: true, ngImport: i0, template: "@if (!hasLanguageSelection) {\n    <button class=\"eui-language-selector__button\"\n        euiButton\n        euiBasicButton\n        [euiBranding]=\"isToolbarSelector\"\n        (click)=\"onClick()\"\n        [attr.aria-label]=\"ariaLabel\">\n        <ng-template *ngTemplateOutlet=\"languageSelectorIcon\"></ng-template>\n        <span class=\"eui-language-selector__code\">{{ (appShellService.state$ | async).activeLanguage }}</span>\n    </button>\n\n} @else if (hasLanguageSelection && isShowDropDown) {\n    <eui-dropdown>\n        <button class=\"eui-language-selector__button\"\n            [attr.aria-label]=\"ariaLabel\"\n            euiButton\n            euiBasicButton\n            [euiBranding]=\"isToolbarSelector\">\n            <ng-template *ngTemplateOutlet=\"languageSelectorIcon\"></ng-template>\n            <span class=\"eui-language-selector__code\">{{ (appShellService.state$ | async).activeLanguage }}</span>\n        </button>\n\n        <eui-dropdown-content>\n            <div class=\"eui-language-selector-menu\">\n                @for (language of languages; track language) {\n                    <button\n                        euiDropdownItem\n                        attr.data-e2e=\"eui-language-selector-item_{{ language.code }}\"\n                        class=\"eui-language-selector-menu-language-item\"\n                        (click)=\"onLanguageChanged(language)\">\n                        {{ language.label }} ({{ language.code }})\n                    </button>\n                }\n            </div>\n        </eui-dropdown-content>\n    </eui-dropdown>\n\n} @else if (hasLanguageSelection && isShowModal) {\n    <button class=\"eui-language-selector__button\"\n        euiButton euiBasicButton\n        [euiPrimary]=\"isToolbarSelector\"\n        (click)=\"onOpen()\"\n        [attr.aria-label]=\"ariaLabel\">\n        <ng-template *ngTemplateOutlet=\"languageSelectorIcon\"></ng-template>\n        <span class=\"eui-language-selector__code\">{{ (appShellService.state$ | async).activeLanguage }}</span>\n    </button>\n}\n\n<ng-template #languageSelectorIcon>\n    <eui-icon-svg icon=\"eui-ecl-global\" />\n</ng-template>\n", styles: [".eui-19 .eui-language-selector{align-items:center;cursor:pointer;display:flex;position:relative}.eui-19 .eui-language-selector__button{padding-left:var(--eui-s-s);padding-right:var(--eui-s-s)}.eui-19 .eui-language-selector__code{text-transform:uppercase}.eui-19 .eui-language-selector-menu-language-item{padding:var(--eui-s-m);border-bottom:1px solid var(--eui-c-neutral-bg-light);text-align:center;cursor:pointer}.eui-19 .eui-language-selector-menu-language-item:hover{background:var(--eui-c-neutral-bg-light)}.eui-19 .eui-language-selector--empty{display:none}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i1$1.EuiDropdownComponent, selector: "eui-dropdown", inputs: ["e2eAttr", "tabIndex", "width", "height", "position", "subDropdownPosition", "isBlock", "isDropDownRightAligned", "hasClosedOnClickInside", "isLabelUpdatedFromSelectedItem", "isExpandOnHover", "hasTabNavigation", "isRightClickEnabled", "euiDisabled"], outputs: ["expand"] }, { kind: "component", type: i1$1.EuiDropdownItemComponent, selector: "eui-dropdown-item, [euiDropdownItem]", inputs: ["subDropdown", "isActive", "isFocus"] }, { kind: "directive", type: i1$1.EuiDropdownContentDirective, selector: "eui-dropdown-content" }, { kind: "component", type: i2.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i1.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiLanguageSelectorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-language-selector', encapsulation: ViewEncapsulation.None, imports: [
                        AsyncPipe,
                        NgTemplateOutlet,
                        ...EUI_DIALOG,
                        ...EUI_DROPDOWN,
                        ...EUI_ICON,
                        ...EUI_BUTTON,
                    ], providers: [
                        EuiDialogService,
                    ], template: "@if (!hasLanguageSelection) {\n    <button class=\"eui-language-selector__button\"\n        euiButton\n        euiBasicButton\n        [euiBranding]=\"isToolbarSelector\"\n        (click)=\"onClick()\"\n        [attr.aria-label]=\"ariaLabel\">\n        <ng-template *ngTemplateOutlet=\"languageSelectorIcon\"></ng-template>\n        <span class=\"eui-language-selector__code\">{{ (appShellService.state$ | async).activeLanguage }}</span>\n    </button>\n\n} @else if (hasLanguageSelection && isShowDropDown) {\n    <eui-dropdown>\n        <button class=\"eui-language-selector__button\"\n            [attr.aria-label]=\"ariaLabel\"\n            euiButton\n            euiBasicButton\n            [euiBranding]=\"isToolbarSelector\">\n            <ng-template *ngTemplateOutlet=\"languageSelectorIcon\"></ng-template>\n            <span class=\"eui-language-selector__code\">{{ (appShellService.state$ | async).activeLanguage }}</span>\n        </button>\n\n        <eui-dropdown-content>\n            <div class=\"eui-language-selector-menu\">\n                @for (language of languages; track language) {\n                    <button\n                        euiDropdownItem\n                        attr.data-e2e=\"eui-language-selector-item_{{ language.code }}\"\n                        class=\"eui-language-selector-menu-language-item\"\n                        (click)=\"onLanguageChanged(language)\">\n                        {{ language.label }} ({{ language.code }})\n                    </button>\n                }\n            </div>\n        </eui-dropdown-content>\n    </eui-dropdown>\n\n} @else if (hasLanguageSelection && isShowModal) {\n    <button class=\"eui-language-selector__button\"\n        euiButton euiBasicButton\n        [euiPrimary]=\"isToolbarSelector\"\n        (click)=\"onOpen()\"\n        [attr.aria-label]=\"ariaLabel\">\n        <ng-template *ngTemplateOutlet=\"languageSelectorIcon\"></ng-template>\n        <span class=\"eui-language-selector__code\">{{ (appShellService.state$ | async).activeLanguage }}</span>\n    </button>\n}\n\n<ng-template #languageSelectorIcon>\n    <eui-icon-svg icon=\"eui-ecl-global\" />\n</ng-template>\n", styles: [".eui-19 .eui-language-selector{align-items:center;cursor:pointer;display:flex;position:relative}.eui-19 .eui-language-selector__button{padding-left:var(--eui-s-s);padding-right:var(--eui-s-s)}.eui-19 .eui-language-selector__code{text-transform:uppercase}.eui-19 .eui-language-selector-menu-language-item{padding:var(--eui-s-m);border-bottom:1px solid var(--eui-c-neutral-bg-light);text-align:center;cursor:pointer}.eui-19 .eui-language-selector-menu-language-item:hover{background:var(--eui-c-neutral-bg-light)}.eui-19 .eui-language-selector--empty{display:none}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], hasLanguageSelection: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isToolbarSelector: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiPrimary: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], ariaLabel: [{
                type: Input,
                args: ['aria-label']
            }], languageSelectorClick: [{
                type: Output
            }] } });

/**
 * @description
 * Module that declares and exports the EuiLanguageSelectorComponent.
 *
 * @deprecated Use {@link EUI_LANGUAGE_SELECTOR} instead
 */
class EuiLanguageSelectorModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiLanguageSelectorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiLanguageSelectorModule, imports: [EuiLanguageSelectorComponent, EuiModalSelectorComponent], exports: [EuiLanguageSelectorComponent, EuiModalSelectorComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiLanguageSelectorModule, imports: [EuiLanguageSelectorComponent, EuiModalSelectorComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiLanguageSelectorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiLanguageSelectorComponent, EuiModalSelectorComponent],
                    exports: [EuiLanguageSelectorComponent, EuiModalSelectorComponent],
                }]
        }] });

const EUI_LANGUAGE_SELECTOR = [
    EuiLanguageSelectorComponent,
    EuiModalSelectorComponent,
];

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_LANGUAGE_SELECTOR, EuiLanguageSelectorComponent, EuiLanguageSelectorModule, EuiModalSelectorComponent };
//# sourceMappingURL=eui-components-eui-language-selector.mjs.map
