import * as i0 from '@angular/core';
import { HostBinding, Directive, Injectable, EventEmitter, inject, ChangeDetectorRef, ElementRef, booleanAttribute, ViewChild, ContentChildren, Output, Input, ChangeDetectionStrategy, ViewEncapsulation, Component, Pipe, HostListener, numberAttribute, NgModule } from '@angular/core';
import { BehaviorSubject, Subject, Subscription, takeUntil, combineLatest, debounceTime, distinctUntilChanged } from 'rxjs';
import { EuiTemplateDirective } from '@eui/components/directives';
import * as i1 from '@eui/components/shared';
import { BaseStatesDirective } from '@eui/components/shared';
import * as i1$1 from '@angular/forms';
import { FormArray, FormGroup, FormControl, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { NgTemplateOutlet } from '@angular/common';
import * as i3 from '@eui/components/eui-icon-input';
import { EUI_ICON_INPUT } from '@eui/components/eui-icon-input';
import * as i5 from '@eui/components/eui-input-text';
import { EUI_INPUT_TEXT } from '@eui/components/eui-input-text';
import * as i4 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import * as i1$2 from '@eui/components/eui-input-checkbox';
import { EUI_INPUT_CHECKBOX } from '@eui/components/eui-input-checkbox';
import * as i9 from '@eui/components/eui-dropdown';
import { EuiDropdownComponent, EUI_DROPDOWN } from '@eui/components/eui-dropdown';
import * as i4$1 from '@eui/components/eui-button';
import { EUI_BUTTON } from '@eui/components/eui-button';
import * as i5$1 from '@eui/components/eui-badge';
import { EUI_BADGE } from '@eui/components/eui-badge';
import * as i6 from '@eui/components/eui-feedback-message';
import { EUI_FEEDBACK_MESSAGE } from '@eui/components/eui-feedback-message';
import * as i7 from '@eui/components/eui-select';
import { EUI_SELECT } from '@eui/components/eui-select';
import * as i8 from '@eui/components/eui-label';
import { EUI_LABEL } from '@eui/components/eui-label';
import * as i2 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';

/**
 * @description
 * Directive used to activate the sticky feature on a column of the table.
 */
class EuiTableStickyColumnDirective {
    get stickyClass() {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableStickyColumnDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.12", type: EuiTableStickyColumnDirective, isStandalone: true, selector: "[isStickyColumn]", host: { properties: { "class.eui-table__col--sticky": "this.stickyClass" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableStickyColumnDirective, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: '[isStickyColumn]',
                }]
        }], propDecorators: { stickyClass: [{
                type: HostBinding,
                args: ['class.eui-table__col--sticky']
            }] } });

/**
 * Service to manage the sorting state of columns in a table.
 * Uses a `BehaviorSubject` to store and emit the current sorting values.
 */
class EuiTableSortService {
    constructor() {
        /**
         * BehaviorSubject containing the current sorting information.
         */
        this.sortingParams$ = new BehaviorSubject({ sort: null, order: 'desc' });
        this.multisortParamsChange$ = new BehaviorSubject([]);
        this.multisortParamsSort$ = new BehaviorSubject([]);
        this.multisortParams = [];
    }
    /**
     * Sets the ordering order for a given column
     *
     * @param sort The name of the column to sort.
     * @param order The sorting order (ascending or descending).
     */
    setSort(sort, order) {
        this.sortingParams$.next({ sort: order ? sort : null, order });
        this.multisortParamsSort$.next([]);
        this.multisortParams.forEach((param) => {
            param.position = 0;
            param.order = null;
        });
        this.multisortParamsChange$.next(this.multisortParams);
    }
    /**
     * Sets the ordering on multiple columns.
     *
     * @param multisortParams Name, order and position of the columns in the sort sequence.
     */
    setMultiSortColumns(multisortParams) {
        this.multisortParamsSort$.next(multisortParams);
        this.sortingParams$.next({ sort: null, order: null });
        this.multisortParamsChange$.next(multisortParams);
    }
    /**
     * Add a column to the sorting.
     *
     * @param column The column to add to the sorting.
     */
    addMultisortParam(column) {
        this.multisortParams.push(column);
        this.multisortParamsChange$.next(this.multisortParams);
        if (this.checkIsMultisortable(this.multisortParams)) {
            this.multisortParamsSort$.next(this.multisortParams);
        }
    }
    /**
     * Add a new select to the form displayed in the dropdown to configure the sorting.
     *
     * @param params The current sorting configuration.
     * @returns The form group with the selects.
     */
    toFormGroup(params) {
        const group = new FormArray([]);
        params.forEach((col, index) => {
            const value = this.getValue(params, index);
            if (value) {
                group.push(new FormGroup({ name: new FormControl(value.name), order: new FormControl(value.order) }));
            }
            else {
                group.push(new FormGroup({ name: new FormControl(), order: new FormControl() }));
            }
        });
        return group;
    }
    /**
     * Checks if the params are already used for the sorting.
     *
     * @param multisortParams Params to check.
     * @returns True if the params are found otherwise false.
     */
    checkIsMultisortable(multisortParams) {
        return multisortParams.find((el) => el.order !== null) !== undefined;
    }
    sortParamsAsc(params) {
        return params.sort((a, b) => {
            if (a.position === b.position) {
                return 0;
            }
            if (this.isNullPosition(a.position)) {
                return 1;
            }
            if (this.isNullPosition(b.position)) {
                return -1;
            }
            return a.position < b.position ? -1 : 1;
        });
    }
    isNullPosition(pos) {
        return pos === 0 || pos === null;
    }
    getValue(params, index) {
        const currentCol = params.find((col) => col.position === index + 1);
        return currentCol ? currentCol : null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSortService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSortService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSortService, decorators: [{
            type: Injectable
        }] });

/**
 * Service to manage the selection state of rows in a table.
 * Allows tracking of selected rows and managing selection for individual and multiple rows.
 */
class EuiTableSelectableRowService {
    constructor() {
        /**
         * BehaviorSubject containing the selected rows.
         */
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.selectedRows$ = new BehaviorSubject([]);
        /**
         * BehaviorSubject containing the state of whether all rows are selected.
         */
        this.isAllRowsSelected$ = new BehaviorSubject(false);
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.lastSelectedRow = null;
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.rows = [];
        this.isAllRowsSelected = false;
        this.propId = 'id';
    }
    /**
     * Sets the property name used to identify rows as unique.
     */
    setPropId(value) {
        this.propId = value;
    }
    /**
     * Gets the current property name used to identify rows.
     */
    getPropId() {
        return this.propId;
    }
    /**
     * Selects a row.
     *
     * @param row Row to select.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    addSelectedRow(row) {
        if (this.selectedRows$.value.indexOf(row) === -1) {
            this.selectedRows$.next([...this.selectedRows$.value, row]);
        }
        this.isAllRowsSelected$.next(this.selectedRows$.value.length === this.rows.length);
        this.isAllRowsSelected = this.selectedRows$.value.length === this.rows.length;
        this.lastSelectedRow = row;
    }
    /**
     * Selects a set of rows.
     *
     * @param rows Rows to select.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    addSelectedRows(rows) {
        const selected = rows.filter((row) => !this.selectedRows$.value.includes(row));
        this.selectedRows$.next([...this.selectedRows$.value, ...selected]);
        this.isAllRowsSelected$.next(this.selectedRows$.value.length === this.rows.length);
        this.isAllRowsSelected = this.selectedRows$.value.length === this.rows.length;
        this.lastSelectedRow = rows[rows.length - 1];
    }
    /**
     * Unselects a row.
     *
     * @param row Row to unselect.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    removeSelectedRow(row) {
        const value = this.selectedRows$.value.filter((selected) => selected[this.propId] !== row[this.propId]);
        this.selectedRows$.next(value);
        this.isAllRowsSelected$.next(false);
        this.isAllRowsSelected = false;
    }
    /**
     * Registers a row as selectable.
     *
     * @param row Row to register.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    addRow(row) {
        if (row && !this.rows.find((r) => r[this.propId] === row[this.propId])) {
            this.rows.push(row);
            this.isAllRowsSelected$.next(false);
            this.isAllRowsSelected = false;
            if (this.rows.length > this.selectedRows$.value.length && this.isAllRowsSelected) {
                this.isAllRowsSelected$.next(false);
                this.isAllRowsSelected = false;
            }
            if (this.rows.length <= this.selectedRows$.value.length && this.rows.every((r) => this.selectedRows$.value.includes(r))) {
                this.isAllRowsSelected$.next(true);
                this.isAllRowsSelected = true;
            }
        }
    }
    /**
     * Registers a set of rows as selectable.
     *
     * @param rows Set of rows to register.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    addRows(rows) {
        rows.forEach((row) => {
            this.addRow(row);
        });
    }
    /**
     * Unregisters all rows.
     */
    resetRows() {
        this.rows = [];
    }
    /**
     * Selects a set of rows.
     *
     * @param rows Rows to select.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    selectRows(rows) {
        this.selectedRows$.next([...rows]);
        this.isAllRowsSelected$.next(this.rows.length > 0 && this.rows.length === this.selectedRows$.value.length);
        this.isAllRowsSelected = this.rows.length > 0 && this.rows.length === this.selectedRows$.value.length;
        this.lastSelectedRow = rows[rows.length - 1];
    }
    /**
     * Select all rows.
     */
    selectAllRows() {
        this.selectedRows$.next([...this.rows]);
        this.isAllRowsSelected$.next(true);
        this.isAllRowsSelected = true;
        this.lastSelectedRow = this.rows[this.rows.length - 1];
    }
    /**
     * Unselect all rows.
     */
    unselectAllRows() {
        this.selectedRows$.next([]);
        this.isAllRowsSelected$.next(false);
        this.isAllRowsSelected = false;
        this.lastSelectedRow = null;
    }
    /**
     * Unselect all rows.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getRows() {
        return this.rows;
    }
    /**
     * Gets the last selected row.
     *
     * @returns The last selected row.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getLastSelectedRow() {
        return this.lastSelectedRow;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSelectableRowService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSelectableRowService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSelectableRowService, decorators: [{
            type: Injectable
        }] });

class MultisortParam {
    constructor(name, order, position) {
        this.order = 'desc';
        Object.assign(this, { name, order, position });
    }
}

/**
 * @description
 * The `eui-table` component has been built to offer various requested features including fast performance and excellent level of control over tabular presentation of data.
 *
 * The eui-table is quite simple of usage and requires :
 *     - rows : the data value input as an array of objects, usually fetched from a service (data payload),
 *     - view : this is the template for the presentation with its various options such as the search filter, the paginator, sortable columns, etc.
 *
 */
class EuiTableComponent {
    constructor() {
        /**
         * Data to display in the table.
         */
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.rows = [];
        /**
         * Unicity criteria of the data.
         *
         * @default 'id'
         */
        this.propId = 'id';
        /**
         * e2e attribute.
         *
         * @default 'eui-table'
         */
        this.e2eAttr = 'eui-table';
        /**
         * In combination with `isDataSelectable`. Rows to be selected by default.
         */
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.preselectedRows = [];
        /**
         * Whether a loading spinner is displayed in the table.
         *
         * @default false
         */
        this.loading = false;
        /**
         * Whether the table uses async data.
         * In this configuration, the backend manages pagination, filtering, and sorting.
         *
         * When data are async, paginator and filter must not be bound to the eui-table component like in another sample.
         *
         * @default false
         */
        this.asyncTable = false;
        /**
         * @deprecated
         * Not used anymore. Will be removed in the next major version.
         */
        this.paginable = false;
        /**
         * Whether the table is responsive.
         *
         * @default false
         */
        this.euiTableResponsive = false;
        this.euiTableFixedLayout = false;
        /**
         * Whether the table has draggable rows.
         *
         * @default false
         */
        this.euiTableDraggable = false;
        this.euiTableCards = false;
        /**
         * @deprecated
         * Has been deprecated to align with Design System
         */
        this.euiTableBordered = false;
        /**
         * Whether the table use compact design.
         *
         * @default false
         */
        this.euiTableCompact = false;
        /**
         * Whether the table header is sticky.
         * To use the eui-table sticky feature and control the scrolling overflow,
         * we recommend wrapping the table with the provided eui-table-v2__scrollable-wrapper class and set your custom table width and/or height.
         *
         * @default false
         */
        this.hasStickyHeader = false;
        /**
         * Whether the table col is sticky.
         * To use the eui-table sticky feature and control the scrolling overflow,
         * we recommend wrapping the table with the provided eui-table-v2__scrollable-wrapper class and set your custom table width and/or height.
         *
         * Only the first or latest columns can be sticky.
         *
         * @default false
         */
        this.hasStickyColumns = false;
        /**
         * Whether the 'select all' checkbox in the header will select ONLY items in the current page.
         *
         * If `false`, all items across the pages will be selected.
         *
         * @default false
         */
        this.isSelectOnlyVisibleRows = false;
        /**
         * Whether the cols can be reordered.
         *
         * @default false
         */
        this.isColsOrderable = false;
        /**
         * Whether the cells have a hover effect.
         *
         * @default false
         */
        this.isHoverable = false;
        /**
         * In combination with `isSelectable` on a row. Event emitted when the selection changes with an array of data.
         */
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.selectedRows = new EventEmitter();
        /**
         * In combination with `sortable` on the cols. Event emitted when the sort changes with the property displayed in the col and the order as `ASC` or `DESC`.
         */
        this.sortChange = new EventEmitter();
        /**
         * In combination with `sortable` & `isMultiSortable` on the cols. Event emitted when the sort changes with the property displayed in the col and the order as `ASC` or `DESC`.
         */
        this.multiSortChange = new EventEmitter();
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.rowsRendered = [];
        this.page = 0;
        this.pageSize = 0;
        this.showStickyHeader = false;
        this.filteredRows = [];
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.rowsSrc = null;
        this.destroy$ = new Subject();
        this.tableFeaturesHandlerSubscription = new Subscription();
        this.selectRowsFeatureHandlerSubscription = new Subscription();
        this.stickyFeatureHandlerIndex = 0;
        this.euiTableSortService = inject(EuiTableSortService);
        this.cd = inject(ChangeDetectorRef);
        this.euiTableSelectableRowService = inject(EuiTableSelectableRowService);
        this.elementRef = inject(ElementRef);
        this.baseStatesDirective = inject(BaseStatesDirective);
    }
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses() {
        return [
            this.baseStatesDirective.getCssClasses('eui-table'),
            this.euiTableResponsive ? 'eui-table--responsive' : '',
            this.euiTableFixedLayout ? 'eui-table--fixed-layout' : '',
            this.euiTableBordered ? 'eui-table--bordered' : '',
            this.euiTableCompact ? 'eui-table--compact' : '',
            this.euiTableDraggable ? 'eui-table--draggable' : '',
            this.euiTableCards ? 'eui-table-cards' : '',
            this.hasStickyHeader ? 'eui-table--sticky-header' : '',
            this.hasStickyColumns ? 'eui-table--sticky-columns' : '',
            this.isColsOrderable ? 'eui-table--cols-orderable' : '',
            this.isHoverable ? 'eui-table--hoverable' : '',
            this.loading ? 'eui-table__loading' : '',
        ]
            .join(' ')
            .trim();
    }
    ngOnChanges(c) {
        if (!this.rows) {
            this.rows = [];
        }
        this.euiTableSelectableRowService.setPropId(this.propId);
        if (c && c.rows && c.rows.firstChange === false) {
            this.tableFeaturesHandlerSubscription.unsubscribe();
            // Go to first page only if length of data has changed. To avoid user to be on a page that no longer exist in case of filtering.
            const lengthChanged = this.rowsSrc.length !== c.rows.currentValue.length;
            this.rowsSrc = [...c.rows.currentValue];
            if (this.paginator && lengthChanged) {
                this.paginator.goFirstPage();
            }
            if (!this.asyncTable) {
                this.euiTableSelectableRowService.resetRows();
                this.euiTableSelectableRowService.addRows(c.rows.currentValue);
                this.tableFeaturesHandler();
            }
            else {
                this.euiTableSelectableRowService.resetRows();
                this.euiTableSelectableRowService.addRows(c.rows.currentValue);
            }
        }
        if (c && c.preselectedRows && c.preselectedRows.firstChange === false) {
            this.euiTableSelectableRowService.selectRows(this.preselectedRows);
        }
        if (c && c.paginator?.currentValue) {
            this.paginator.setLength(this.rows.length);
            if (!c.paginator?.isFirstChange()) {
                this.paginator.goFirstPage();
            }
        }
        else {
            // this.rows can be changed anytime, then this else can be executed at that time, testing this.paginator allows to make sure
            // the user whants to disable pagination or change the datasource
            if (!this.paginator) {
                this.rowsRendered = this.rowsSrc ? this.rowsSrc : [...this.rows];
                this.page = 0;
            }
        }
    }
    ngOnInit() {
        this.rowsSrc = [...this.rows];
    }
    ngAfterContentInit() {
        this.templates.forEach((item) => {
            if (item.getType() === 'header') {
                this.headerTemplate = item.template;
            }
            if (item.getType() === 'body') {
                this.bodyTemplate = item.template;
            }
            if (item.getType() === 'footer') {
                this.footerTemplate = item.template;
            }
            if (item.getType() === 'emptyMessage') {
                this.emptyMessageTemplate = item.template;
            }
            if (item.getType() === 'caption') {
                this.captionTemplate = item.template;
            }
        });
    }
    ngAfterViewInit() {
        if (!this.asyncTable) {
            this.tableFeaturesHandlerSubscription.unsubscribe();
            this.tableFeaturesHandler();
        }
        this.euiTableSortService.sortingParams$
            .pipe(takeUntil(this.destroy$))
            .subscribe((sortingParams) => {
            setTimeout(() => {
                this.sortChange.emit({ sort: sortingParams.sort, order: sortingParams.order });
            });
        });
        this.euiTableSortService.multisortParamsSort$.pipe(takeUntil(this.destroy$)).subscribe((multiSortParams) => {
            setTimeout(() => {
                this.multiSortChange.emit(multiSortParams.filter((el) => el.position > 0));
            });
        });
        this.selectRowsFeatureHandler();
        setTimeout(() => {
            this.euiTableSelectableRowService.selectRows(this.preselectedRows);
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
    /**
     * Select all rows
     */
    selectAllRows() {
        this.euiTableSelectableRowService.selectAllRows();
    }
    /**
     * Unselect all rows
     */
    unselectAllRows() {
        this.euiTableSelectableRowService.unselectAllRows();
    }
    /**
     * Selects a set of rows.
     *
     * @param rows Rows to select.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    selectRows(rows) {
        this.euiTableSelectableRowService.selectRows(rows);
    }
    /**
     * Filters the table's data based on a string declared in `EuiTableFilterComponent`
     *
     * @param filter String to filter the data
     * @param r Array of data to filter
     * @returns The set of data matching the filter
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    filterRows(filter, r) {
        const rows = filter
            ? r.filter((row) => {
                const matching = this.getProps(row, filter).filter((p) => p.match === true);
                return matching?.length > 0;
            })
            : r;
        this.euiTableSelectableRowService.resetRows();
        this.euiTableSelectableRowService.addRows(rows);
        this.filteredRows = rows;
        return rows;
    }
    /**
     * Sort the table's data.
     *
     * @param sort The sort property and order.
     */
    setSort(sort, order) {
        this.euiTableSortService.setSort(sort, order);
    }
    /**
     * Calcultates the position of columns that are sticky.
     */
    stickyFeatureHandler() {
        const timeout = this.stickyFeatureHandlerIndex === 0 ? 250 : 0;
        setTimeout(() => {
            const bodyTrItems = Array.from(this.tbodyRef.nativeElement.querySelectorAll('tr'));
            const containerWidth = this.elementRef.nativeElement?.parentElement?.clientWidth || 0;
            if (this.theadRef) {
                const thItems = Array.from(this.theadRef.nativeElement.querySelectorAll('.eui-table__col--sticky'));
                // Reset left & right position
                thItems.forEach((th) => {
                    th.style.left = null;
                    th.style.right = null;
                });
                // Sticky First Cols & Last Cols
                const thItemsStickyFirstCol = thItems.filter((th) => th.offsetLeft + th.clientWidth < containerWidth);
                const thItemsStickyLastCol = thItems.filter((th) => th.offsetLeft + th.clientWidth > containerWidth);
                thItemsStickyFirstCol.forEach((th, i) => {
                    const w = thItemsStickyFirstCol[i - 1]?.clientWidth;
                    const l = parseInt(thItemsStickyFirstCol[i - 1]?.style.left, 10);
                    th.style.left = (i === 0 ? 0 : w + l) + 'px';
                    if (i + 1 === thItemsStickyFirstCol.length) {
                        th.classList.add('eui-table__col--sticky-shadowed-first');
                    }
                });
                thItemsStickyLastCol.reverse().forEach((th, i) => {
                    const w = thItemsStickyLastCol[i - 1]?.clientWidth;
                    const r = parseInt(thItemsStickyLastCol[i - 1]?.style.right, 10);
                    th.style.right = (i === 0 ? 0 : w + r) + 'px';
                    if (i + 1 === thItemsStickyLastCol.length) {
                        th.classList.add('eui-table__col--sticky-shadowed-last');
                    }
                });
            }
            bodyTrItems.forEach((tr) => {
                const tdItems = Array.from(tr.querySelectorAll('.eui-table__col--sticky'));
                tdItems.forEach((td) => {
                    td.style.left = null;
                    td.style.right = null;
                });
            });
            bodyTrItems.forEach((tr) => {
                const tdItems = Array.from(tr.querySelectorAll('.eui-table__col--sticky'));
                // Sticky First Cols
                const tdItemsStickyFirstCol = tdItems.filter((td) => td.offsetLeft + td.clientWidth < containerWidth);
                tdItemsStickyFirstCol.forEach((td, i) => {
                    const w = tdItemsStickyFirstCol[i - 1]?.clientWidth;
                    const l = parseInt(tdItemsStickyFirstCol[i - 1]?.style.left, 10);
                    td.style.left = (i === 0 ? 0 : w + l) + 'px';
                    if (i + 1 === tdItemsStickyFirstCol.length) {
                        td.classList.add('eui-table__col--sticky-shadowed-first');
                    }
                });
                // Sticky Last Cols
                const tdItemsStickyLastCol = tdItems.filter((td) => td.offsetLeft + td.clientWidth > containerWidth);
                tdItemsStickyLastCol.reverse().forEach((td, i) => {
                    const w = tdItemsStickyLastCol[i - 1]?.clientWidth;
                    const r = parseInt(tdItemsStickyLastCol[i - 1]?.style.right, 10);
                    td.style.right = (i === 0 ? 0 : w + r) + 'px';
                    if (i + 1 === tdItemsStickyLastCol.length) {
                        td.classList.add('eui-table__col--sticky-shadowed-last');
                    }
                });
            });
            if (this.tfootRef) {
                const tdItems = Array.from(this.tfootRef.nativeElement.querySelectorAll('.eui-table__col--sticky'));
                // Reset left & right position
                tdItems.forEach((th) => {
                    th.style.left = null;
                    th.style.right = null;
                });
                // Sticky First Cols & Last Cols
                const tdItemsStickyFirstCol = tdItems.filter((td) => td.offsetLeft + td.clientWidth < containerWidth);
                const tdItemsStickyLastCol = tdItems.filter((td) => td.offsetLeft + td.clientWidth > containerWidth);
                tdItemsStickyFirstCol.forEach((td, i) => {
                    const w = tdItemsStickyFirstCol[i - 1]?.clientWidth;
                    const l = parseInt(tdItemsStickyFirstCol[i - 1]?.style.left, 10);
                    td.style.left = (i === 0 ? 0 : w + l) + 'px';
                    if (i + 1 === tdItemsStickyFirstCol.length) {
                        td.classList.add('eui-table__col--sticky-shadowed-first');
                    }
                });
                tdItemsStickyLastCol.reverse().forEach((td, i) => {
                    const w = tdItemsStickyLastCol[i - 1]?.clientWidth;
                    const r = parseInt(tdItemsStickyLastCol[i - 1]?.style.right, 10);
                    td.style.right = (i === 0 ? 0 : w + r) + 'px';
                    if (i + 1 === tdItemsStickyLastCol.length) {
                        td.classList.add('eui-table__col--sticky-shadowed-last');
                    }
                });
            }
        }, timeout);
        this.stickyFeatureHandlerIndex++;
    }
    /**
     * Handles table features such as sorting, filtering, and pagination before rendering.
     */
    tableFeaturesHandler() {
        this.tableFeaturesHandlerSubscription = combineLatest([
            this.euiTableSortService.sortingParams$,
            this.paginator ? this.paginator.page$ : new BehaviorSubject(null),
            this.filter ? this.filter.filter$ : new BehaviorSubject(null),
            this.euiTableSortService.multisortParamsSort$,
        ])
            .pipe(takeUntil(this.destroy$))
            .subscribe(([sortingParams, pagination, filter, multisortParams]) => {
            let r = [...this.rowsSrc];
            if (sortingParams.order !== null && sortingParams.sort !== null) {
                const multisort = [];
                multisort.push(new MultisortParam(sortingParams.sort, sortingParams.order, 1));
                r = this.doMultiSort(multisort, r);
            }
            if (multisortParams.length > 0) {
                const sortableColumns = multisortParams.filter((col) => col.order !== null);
                if (sortableColumns.length > 0) {
                    r = this.doMultiSort(sortableColumns, r);
                }
            }
            r = this.filterRows(filter, r);
            if (this.paginator) {
                this.paginator.setLength(r.length);
                r = this.paginateRows(pagination, r);
            }
            this.rowsRendered = r;
            this.stickyFeatureHandler();
            if (this.isSelectOnlyVisibleRows) {
                this.euiTableSelectableRowService.resetRows();
                this.euiTableSelectableRowService.unselectAllRows();
                this.euiTableSelectableRowService.addRows(this.rowsRendered);
            }
            this.cd.detectChanges();
        });
    }
    /**
     * Handles multi-sorting
     *
     * @param multisortParams Multi-sorting criterias
     * @param r Data to sort
     * @returns An array of data sorted
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    doMultiSort(multisortParams, r) {
        r = this.multiSortRows(multisortParams, 1, r);
        return r;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    multiSortRows(multisortParams, currentPosition, r) {
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        let rows = null;
        const colParams = multisortParams.find((col) => col.position === currentPosition);
        if (colParams.order === 'desc') {
            // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            rows = r.sort((a, b) => {
                if (this.isColumnSortable(a, b, multisortParams, currentPosition)) {
                    return this.sortTwoRowsDesc(a, b, colParams.name);
                }
                else {
                    return 0;
                }
            });
        }
        else {
            // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            rows = r.sort((a, b) => {
                if (this.isColumnSortable(a, b, multisortParams, currentPosition)) {
                    return this.sortTwoRowsAsc(a, b, colParams.name);
                }
                else {
                    return 0;
                }
            });
        }
        if (multisortParams.length === currentPosition) {
            return rows;
        }
        else {
            return this.multiSortRows(multisortParams, ++currentPosition, rows);
        }
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    isColumnSortable(a, b, multisortParams, currentPosition) {
        if (currentPosition === 1)
            return true;
        const colParams = multisortParams.find((col) => col.position === currentPosition - 1);
        const aCol = this.getObjPropValue(a, colParams.name);
        // typeof this.getObjProp(a, colParams.name) === 'string'
        //     ? this.getObjProp(a, colParams.name).toLowerCase()
        //     : this.getObjProp(a, colParams.name);
        const bCol = this.getObjPropValue(b, colParams.name);
        // typeof this.getObjProp(b, colParams.name) === 'string'
        //     ? this.getObjProp(b, colParams.name).toLowerCase()
        //     : this.getObjProp(b, colParams.name);
        if (aCol !== bCol) {
            return false;
        }
        else {
            if (currentPosition - 1 === 1) {
                return true;
            }
            else {
                return this.isColumnSortable(a, b, multisortParams, --currentPosition);
            }
        }
    }
    //This function is to do the sorting the table with the combination of 0,null and text in descending order.
    //getObjPropValue is to get the object property value
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    sortTwoRowsDesc(a, b, colName) {
        const aSortOn = this.getObjPropValue(a, colName);
        const bSortOn = this.getObjPropValue(b, colName);
        if ((aSortOn === null || aSortOn === undefined) && bSortOn) {
            return 1;
        }
        else if (aSortOn && (bSortOn === null || bSortOn === undefined)) {
            return -1;
        }
        else if ((aSortOn === null || aSortOn === undefined) && (bSortOn === null || bSortOn === undefined)) {
            return 0;
        }
        else if ((aSortOn === null || aSortOn === undefined) && bSortOn === 0) {
            return 1;
        }
        else if (aSortOn === 0 && (bSortOn === null || bSortOn === undefined)) {
            return -1;
        }
        else {
            return aSortOn < bSortOn ? 1 : aSortOn > bSortOn ? -1 : 0;
        }
    }
    /**
     * This function is to do the sorting the table with the combination of 0,null and text in ascending order.
     * getObjPropValue is to get the object property value
     *
     * @param a First row to sort
     * @param b Second row to sort
     * @param colName Sort criteria
     * @returns Result of the sorting
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    sortTwoRowsAsc(a, b, colName) {
        const aSortOn = this.getObjPropValue(a, colName);
        const bSortOn = this.getObjPropValue(b, colName);
        if ((aSortOn === null || aSortOn === undefined) && bSortOn) {
            return -1;
        }
        else if (aSortOn && (bSortOn === null || bSortOn === undefined)) {
            return 1;
        }
        else if ((aSortOn === null || aSortOn === undefined) && (bSortOn === null || bSortOn === undefined)) {
            return 0;
        }
        else if ((aSortOn === null || aSortOn === undefined) && bSortOn === 0) {
            return -1;
        }
        else if (aSortOn === 0 && (bSortOn === null || bSortOn === undefined)) {
            return 1;
        }
        else {
            return aSortOn < bSortOn ? -1 : aSortOn > bSortOn ? 1 : 0;
        }
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getObjPropValue(obj, prop) {
        const value = this.getObjProp(obj, prop);
        return typeof value === 'string' ? value.toLowerCase() : value;
    }
    /**
     * Handles the selection of rows.
     */
    selectRowsFeatureHandler() {
        this.selectRowsFeatureHandlerSubscription = this.euiTableSelectableRowService.selectedRows$
            .pipe(takeUntil(this.destroy$))
            // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            .subscribe((selected) => {
            this.selectedRows.emit(selected);
        });
    }
    /**
     * Get the properties of the object matching the filter string.
     *
     * @param obj Obj to extract the property from.
     * @param filter String to search in the properties.
     * @returns An array of properties matching the filter.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getProps(obj, filter) {
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const isObject = (val) => val && typeof val === 'object';
        const addDelimiter = (a, b) => (a && a !== '0' ? `${a}.${b}` : b);
        const props = [];
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const paths = (pathObj = {}, head = '') => Object.entries(pathObj).reduce((product, [key, value]) => {
            const fullPath = addDelimiter(head, key);
            // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const match = (v) => v &&
                typeof v !== 'object' &&
                v
                    ?.toString()
                    .toLowerCase()
                    .indexOf(filter?.trim().toLowerCase()) !== -1;
            if (key !== '0' && typeof value !== 'object') {
                props.push({ key: addDelimiter(head, key), match: match(value), value });
            }
            return isObject(value) ? product.concat(paths(value, fullPath)) : product.concat(fullPath);
        }, []);
        paths(obj);
        return props;
    }
    /**
     * Slices the data array based on the pagination event.
     *
     * @param pagination Object containing the page, the page size, and the total number of pages.
     * @param r Array of data to paginate.
     * @returns The sliced array to render.
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    paginateRows(pagination, r) {
        this.page = pagination.page;
        this.pageSize = pagination.pageSize;
        return r.slice(this.page * this.pageSize, this.page * this.pageSize + this.pageSize);
    }
    /**
     * Get a property of an object based on the path.
     *
     * @param obj Row to extract the property from.
     * @param prop Path of the property to extract.
     * @returns The value of the property
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getObjProp(obj, prop) {
        return prop ? prop.split('.').reduce((prev, curr) => (prev ? prev[curr] : null), obj || self) : null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiTableComponent, isStandalone: true, selector: "eui-table, table[euiTable]", inputs: { rows: "rows", propId: "propId", e2eAttr: "e2eAttr", paginator: "paginator", filter: "filter", preselectedRows: "preselectedRows", loading: ["loading", "loading", booleanAttribute], asyncTable: ["asyncTable", "asyncTable", booleanAttribute], paginable: ["paginable", "paginable", booleanAttribute], euiTableResponsive: ["euiTableResponsive", "euiTableResponsive", booleanAttribute], euiTableFixedLayout: ["euiTableFixedLayout", "euiTableFixedLayout", booleanAttribute], euiTableDraggable: ["euiTableDraggable", "euiTableDraggable", booleanAttribute], euiTableCards: ["euiTableCards", "euiTableCards", booleanAttribute], euiTableBordered: ["euiTableBordered", "euiTableBordered", booleanAttribute], euiTableCompact: ["euiTableCompact", "euiTableCompact", booleanAttribute], hasStickyHeader: ["hasStickyHeader", "hasStickyHeader", booleanAttribute], hasStickyColumns: ["hasStickyColumns", "hasStickyColumns", booleanAttribute], isSelectOnlyVisibleRows: ["isSelectOnlyVisibleRows", "isSelectOnlyVisibleRows", booleanAttribute], isColsOrderable: ["isColsOrderable", "isColsOrderable", booleanAttribute], isHoverable: ["isHoverable", "isHoverable", booleanAttribute] }, outputs: { selectedRows: "selectedRows", sortChange: "sortChange", multiSortChange: "multiSortChange" }, host: { properties: { "class": "this.cssClasses" } }, providers: [EuiTableSortService, EuiTableSelectableRowService], queries: [{ propertyName: "templates", predicate: EuiTemplateDirective }], viewQueries: [{ propertyName: "theadRef", first: true, predicate: ["theadRef"], descendants: true }, { propertyName: "tbodyRef", first: true, predicate: ["tbodyRef"], descendants: true }, { propertyName: "tfootRef", first: true, predicate: ["tfootRef"], descendants: true }], usesOnChanges: true, hostDirectives: [{ directive: i1.BaseStatesDirective }], ngImport: i0, template: "@if (captionTemplate) {\n    <caption>\n        <ng-template [ngTemplateOutlet]=\"captionTemplate\"></ng-template>\n    </caption>\n}\n@if (headerTemplate) {\n    <thead #theadRef>\n        <ng-template [ngTemplateOutlet]=\"headerTemplate\"></ng-template>\n    </thead>\n}\n@if (bodyTemplate) {\n    <tbody #tbodyRef>\n        @for (row of rowsRendered; let i = $index; track $index) {\n            <ng-template\n                [ngTemplateOutlet]=\"bodyTemplate\"\n                [ngTemplateOutletContext]=\"{ $implicit: row, index: i + page * pageSize }\">\n            </ng-template>\n        }\n\n        @if (emptyMessageTemplate && rowsRendered.length === 0) {\n            <ng-template [ngTemplateOutlet]=\"emptyMessageTemplate\"></ng-template>\n        }\n    </tbody>\n}\n@if (footerTemplate) {\n    <tfoot #tfootRef>\n        <ng-template [ngTemplateOutlet]=\"footerTemplate\"></ng-template>\n    </tfoot>\n}\n", styles: [".eui-19 .eui-table__scrollable-wrapper{overflow:auto;will-change:transform}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar{display:inherit;height:10px;width:10px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-table__scrollable-wrapper{scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-table__orderable-cols-preview{background-color:var(--eui-c-neutral-lightest);border-color:transparent;padding:calc(var(--eui-s-m) - 2px) var(--eui-s-s);cursor:move;opacity:.7}.eui-19 .eui-table{--eui-table-background-color: var(--eui-c-white);--eui-table-text-color: var(--eui-c-text);--eui-table-selected-row-background-color: var(--eui-c-active-bg);--eui-table-highlighted-background-color: var(--eui-c-accent);--eui-table-hover-background-color: var(--eui-c-active-bg);--eui-table-bordered-color: var(--eui-c-neutral-lightest);--eui-table-loading-position: 50%;background-color:var(--eui-table-background-color);border-collapse:collapse;border-spacing:0;color:var(--eui-table-text-color);display:table;-webkit-overflow-scrolling:touch;position:relative;width:auto}.eui-19 .eui-table thead>tr>th,.eui-19 .eui-table tbody>tr>td,.eui-19 .eui-table tfoot>tr>td{vertical-align:middle}.eui-19 .eui-table--bordered{box-shadow:var(--eui-sh-1)}.eui-19 .eui-table--bordered td,.eui-19 .eui-table--bordered th{border:var(--eui-bw-xs) solid var(--eui-table-bordered-color)}.eui-19 .eui-table.eui-table--compact thead tr th{padding:var(--eui-s-s)}.eui-19 .eui-table.eui-table--compact tbody tr{height:calc(2 * var(--eui-s-m))}.eui-19 .eui-table.eui-table--compact tbody tr td{padding:0 var(--eui-s-s)}.eui-19 .eui-table--responsive{width:100%}.eui-19 .eui-table--fixed-layout{table-layout:fixed}.eui-19 .eui-table--highlighted{background-color:var(--eui-table-highlighted-background-color);text-decoration:none}.eui-19 .eui-table--hoverable tbody tr:hover,.eui-19 .eui-table--hoverable tbody tr:hover td{background-color:var(--eui-table-hover-background-color)!important}.eui-19 .eui-table--hoverable tbody tr:hover td:hover{background-color:var(--eui-c-info-lightest)!important}.eui-19 .eui-table--cols-orderable .cdk-drag-placeholder{background-color:var(--eui-c-white);color:var(--eui-c-info);cursor:move;opacity:1}.eui-19 .eui-table--cols-orderable tr{display:table-row}.eui-19 .eui-table--cols-orderable tr th{cursor:move}.eui-19 .eui-table__actions-column{text-align:center;width:calc(15 * var(--eui-s-m))}.eui-19 .eui-table.eui-table__loading:before{animation:.8s linear infinite spin;border:8px solid transparent;border-radius:var(--eui-br-max);border-top-color:var(--eui-c-s-primary-base);content:\"\";display:block;height:80px;left:50%;margin:-40px 0 0 -40px;position:absolute;top:var(--eui-table-loading-position);width:80px;z-index:1000001}.eui-19 .eui-table.eui-table__loading tbody{opacity:var(--eui-o-50)}.eui-19 .eui-table thead tr.eui-table__columns-filter th{background-color:var(--eui-c-neutral-bg-light);position:relative;font:var(--eui-f-m)}.eui-19 .eui-table thead tr th{background-color:var(--eui-c-neutral-bg-light);padding:var(--eui-s-m) var(--eui-s-s);text-align:left;font:var(--eui-f-m-bold)}.eui-19 .eui-table thead tr th .eui-resizable .eui-resizable-icon__container{transform:translateY(calc(var(--eui-s-l) + 2px + 2px))}.eui-19 .eui-table thead tr th.eui-table__sortable-col .eui-table__sortable-col-content{align-items:center;display:inline-flex;position:relative;vertical-align:middle;white-space:nowrap}.eui-19 .eui-table thead tr th.eui-table__sortable-col--disabled{cursor:default}.eui-19 .eui-table thead tr th .eui-table__sortable-icon-button{margin-left:var(--eui-s-2xs)}.eui-19 .eui-table thead tr th.eui-table__cell-select{color:var(--eui-c-neutral-light);width:auto}.eui-19 .eui-table thead tr th.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table thead tr th.eui-table__cell-select .eui-table__cell-select--indeterminated{position:absolute;right:50%;top:var(--eui-s-s);transform:translate(50%)}.eui-19 .eui-table tbody tr{border-top:1px solid var(--eui-c-divider);height:calc(3 * var(--eui-s-m))}.eui-19 .eui-table tbody tr.eui-table__row--selected,.eui-19 .eui-table tbody tr.eui-table__row--selected td{background-color:var(--eui-table-selected-row-background-color)!important}.eui-19 .eui-table tbody tr:not(.eui-table-expandable-row):nth-child(odd){background-color:var(--eui-c-bg)}.eui-19 .eui-table tbody tr:not(.eui-table-expandable-row):nth-child(odd) td{background-color:var(--eui-c-bg)}.eui-19 .eui-table tbody tr td{padding:var(--eui-s-xs) var(--eui-s-s);vertical-align:middle}.eui-19 .eui-table tbody tr td.eui-table__cell-select{color:var(--eui-c-neutral-light);width:auto}.eui-19 .eui-table tbody tr td.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table tbody tr:nth-of-type(odd){background-color:var(--eui-c-white)}.eui-19 .eui-table tbody tr:nth-of-type(2n){background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table tbody tr:nth-of-type(2n) td{background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table tfoot tr{border-bottom:1px solid var(--eui-c-divider);border-top:1px solid var(--eui-c-divider)}.eui-19 .eui-table tfoot tr td{padding:var(--eui-s-s);vertical-align:middle}.eui-19 .eui-table__sticky-container{overflow:auto;will-change:transform}.eui-19 .eui-table__sticky-container::-webkit-scrollbar{display:inherit;height:8px;width:8px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table__sticky-container::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-table__sticky-container::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-table__sticky-container::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-table__sticky-container{scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-table--sticky-header thead tr th{position:sticky;top:0;z-index:8}.eui-19 .eui-table--sticky-columns .eui-table__col--sticky{position:sticky}.eui-19 .eui-table--sticky-columns th.eui-table__col--sticky{z-index:9}.eui-19 .eui-table--sticky-columns th.eui-table__col--sticky.eui-table__col--sticky-shadowed-first{box-shadow:inset -5px 0 8px -8px #0003}.eui-19 .eui-table--sticky-columns th.eui-table__col--sticky.eui-table__col--sticky-shadowed-last{box-shadow:inset 5px 0 8px -8px #0003}.eui-19 .eui-table--sticky-columns td.eui-table__col--sticky{z-index:8}.eui-19 .eui-table--sticky-columns td.eui-table__col--sticky.eui-table__col--sticky-shadowed-first{box-shadow:inset -5px 0 8px -8px #0003}.eui-19 .eui-table--sticky-columns td.eui-table__col--sticky.eui-table__col--sticky-shadowed-last{box-shadow:inset 5px 0 8px -8px #0003}@media screen and (max-width: 767px){.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive{width:100%!important}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive thead,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tbody,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tfoot,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive th,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive td,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tr{display:block}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive thead tr{left:-9999px;position:absolute;top:-9999px}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tr{height:auto}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive td{border:var(--eui-bw-none);border-bottom:1px solid var(--eui-c-neutral-bg-light);padding-left:50%;position:relative;text-align:left!important}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive td:before{color:var(--eui-c-neutral-light);content:attr(data-col-label);left:var(--eui-s-xs);padding-right:var(--eui-s-xs);position:absolute;width:45%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;font:var(--eui-f-m-bold)}.eui-19 .eui-table:not(.eui-table-cards) .actionsColumn,.eui-19 .eui-table:not(.eui-table-cards) .actions-column{justify-content:flex-start;text-align:left;width:100%}.eui-19 .eui-table__sticky-container{height:auto!important;width:auto!important}.eui-19 .eui-table--sticky-columns th,.eui-19 .eui-table--sticky-columns td,.eui-19 .eui-table--sticky-columns th .eui-table__col--sticky,.eui-19 .eui-table--sticky-columns td .eui-table__col--sticky{width:auto;z-index:auto}.eui-19 .eui-table--sticky-columns th .eui-table__col--sticky.eui-table__col--sticky-shadowed-first,.eui-19 .eui-table--sticky-columns th .eui-table__col--sticky.eui-table__col--sticky-shadowed-last,.eui-19 .eui-table--sticky-columns td .eui-table__col--sticky.eui-table__col--sticky-shadowed-first,.eui-19 .eui-table--sticky-columns td .eui-table__col--sticky.eui-table__col--sticky-shadowed-last{box-shadow:none!important}.eui-19 .eui-table--sticky-columns tfoot tr td:empty{display:none!important}}.eui-19 .eui-table__filter{align-items:center;display:flex;justify-content:flex-end;position:relative}.eui-19 .eui-table__filter--responsive{width:100%}.eui-19 .eui-table__filter-input{padding-left:var(--eui-s-3xl)!important}@media screen and (max-width: 767px){.eui-19 .eui-table__filter--responsive{display:block;width:100%}}.eui-19 .eui-table__draggable-preview--no-preview.cdk-drag-preview{display:none}.eui-19 .eui-table--draggable tr.eui-table__draggable-preview--no-placeholder{opacity:1}.eui-19 .eui-table--draggable tr:hover{background-color:var(--eui-c-accent-bg-light)}.eui-19 .eui-table--draggable td .cdk-drop-list{flex-direction:column}.eui-19 .eui-table-cards{background-color:transparent;display:flex;flex-direction:column;overflow:hidden;width:100%}.eui-19 .eui-table-cards thead{width:100%}.eui-19 .eui-table-cards thead tr{align-items:center;height:auto}.eui-19 .eui-table-cards thead tr th{position:relative;vertical-align:middle;width:100%}.eui-19 .eui-table-cards thead tr th.eui-table__cell-select{padding:var(--eui-s-s) var(--eui-s-m);width:auto}.eui-19 .eui-table-cards thead tr th.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table-cards tbody{width:100%}.eui-19 .eui-table-cards tbody tr{align-items:center;border-top:0;display:flex;height:auto;width:100%}.eui-19 .eui-table-cards tbody tr.eui-table__row--selected .eui-card:first-child{--eui-card-header-background-color: var(--eui-table-selected-row-background-color)}.eui-19 .eui-table-cards tbody tr td{position:relative;vertical-align:middle;width:100%}.eui-19 .eui-table-cards tbody tr td.eui-table__cell-select{padding:var(--eui-s-s) var(--eui-s-m);width:auto}.eui-19 .eui-table-cards tbody tr td.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table-cards tbody tr:hover{background-color:transparent}.eui-19 .eui-table-cards tbody tr:not(.eui-table-expandable-row):nth-child(odd){background-color:transparent}.eui-19 .eui-table-cards tbody tr:nth-of-type(2n){background-color:transparent}.eui-19 .eui-table-cards tbody tr:nth-of-type(2n):hover:not(.eui-table__row--selected){background-color:transparent}.eui-19 .eui-table-cards tbody tr:nth-of-type(odd):hover:not(.eui-table__row--selected){background-color:transparent}\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-table, table[euiTable]', encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, providers: [EuiTableSortService, EuiTableSelectableRowService], hostDirectives: [
                        {
                            directive: BaseStatesDirective,
                            inputs: [],
                        },
                    ], imports: [
                        NgTemplateOutlet,
                    ], template: "@if (captionTemplate) {\n    <caption>\n        <ng-template [ngTemplateOutlet]=\"captionTemplate\"></ng-template>\n    </caption>\n}\n@if (headerTemplate) {\n    <thead #theadRef>\n        <ng-template [ngTemplateOutlet]=\"headerTemplate\"></ng-template>\n    </thead>\n}\n@if (bodyTemplate) {\n    <tbody #tbodyRef>\n        @for (row of rowsRendered; let i = $index; track $index) {\n            <ng-template\n                [ngTemplateOutlet]=\"bodyTemplate\"\n                [ngTemplateOutletContext]=\"{ $implicit: row, index: i + page * pageSize }\">\n            </ng-template>\n        }\n\n        @if (emptyMessageTemplate && rowsRendered.length === 0) {\n            <ng-template [ngTemplateOutlet]=\"emptyMessageTemplate\"></ng-template>\n        }\n    </tbody>\n}\n@if (footerTemplate) {\n    <tfoot #tfootRef>\n        <ng-template [ngTemplateOutlet]=\"footerTemplate\"></ng-template>\n    </tfoot>\n}\n", styles: [".eui-19 .eui-table__scrollable-wrapper{overflow:auto;will-change:transform}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar{display:inherit;height:10px;width:10px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-table__scrollable-wrapper::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-table__scrollable-wrapper{scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-table__orderable-cols-preview{background-color:var(--eui-c-neutral-lightest);border-color:transparent;padding:calc(var(--eui-s-m) - 2px) var(--eui-s-s);cursor:move;opacity:.7}.eui-19 .eui-table{--eui-table-background-color: var(--eui-c-white);--eui-table-text-color: var(--eui-c-text);--eui-table-selected-row-background-color: var(--eui-c-active-bg);--eui-table-highlighted-background-color: var(--eui-c-accent);--eui-table-hover-background-color: var(--eui-c-active-bg);--eui-table-bordered-color: var(--eui-c-neutral-lightest);--eui-table-loading-position: 50%;background-color:var(--eui-table-background-color);border-collapse:collapse;border-spacing:0;color:var(--eui-table-text-color);display:table;-webkit-overflow-scrolling:touch;position:relative;width:auto}.eui-19 .eui-table thead>tr>th,.eui-19 .eui-table tbody>tr>td,.eui-19 .eui-table tfoot>tr>td{vertical-align:middle}.eui-19 .eui-table--bordered{box-shadow:var(--eui-sh-1)}.eui-19 .eui-table--bordered td,.eui-19 .eui-table--bordered th{border:var(--eui-bw-xs) solid var(--eui-table-bordered-color)}.eui-19 .eui-table.eui-table--compact thead tr th{padding:var(--eui-s-s)}.eui-19 .eui-table.eui-table--compact tbody tr{height:calc(2 * var(--eui-s-m))}.eui-19 .eui-table.eui-table--compact tbody tr td{padding:0 var(--eui-s-s)}.eui-19 .eui-table--responsive{width:100%}.eui-19 .eui-table--fixed-layout{table-layout:fixed}.eui-19 .eui-table--highlighted{background-color:var(--eui-table-highlighted-background-color);text-decoration:none}.eui-19 .eui-table--hoverable tbody tr:hover,.eui-19 .eui-table--hoverable tbody tr:hover td{background-color:var(--eui-table-hover-background-color)!important}.eui-19 .eui-table--hoverable tbody tr:hover td:hover{background-color:var(--eui-c-info-lightest)!important}.eui-19 .eui-table--cols-orderable .cdk-drag-placeholder{background-color:var(--eui-c-white);color:var(--eui-c-info);cursor:move;opacity:1}.eui-19 .eui-table--cols-orderable tr{display:table-row}.eui-19 .eui-table--cols-orderable tr th{cursor:move}.eui-19 .eui-table__actions-column{text-align:center;width:calc(15 * var(--eui-s-m))}.eui-19 .eui-table.eui-table__loading:before{animation:.8s linear infinite spin;border:8px solid transparent;border-radius:var(--eui-br-max);border-top-color:var(--eui-c-s-primary-base);content:\"\";display:block;height:80px;left:50%;margin:-40px 0 0 -40px;position:absolute;top:var(--eui-table-loading-position);width:80px;z-index:1000001}.eui-19 .eui-table.eui-table__loading tbody{opacity:var(--eui-o-50)}.eui-19 .eui-table thead tr.eui-table__columns-filter th{background-color:var(--eui-c-neutral-bg-light);position:relative;font:var(--eui-f-m)}.eui-19 .eui-table thead tr th{background-color:var(--eui-c-neutral-bg-light);padding:var(--eui-s-m) var(--eui-s-s);text-align:left;font:var(--eui-f-m-bold)}.eui-19 .eui-table thead tr th .eui-resizable .eui-resizable-icon__container{transform:translateY(calc(var(--eui-s-l) + 2px + 2px))}.eui-19 .eui-table thead tr th.eui-table__sortable-col .eui-table__sortable-col-content{align-items:center;display:inline-flex;position:relative;vertical-align:middle;white-space:nowrap}.eui-19 .eui-table thead tr th.eui-table__sortable-col--disabled{cursor:default}.eui-19 .eui-table thead tr th .eui-table__sortable-icon-button{margin-left:var(--eui-s-2xs)}.eui-19 .eui-table thead tr th.eui-table__cell-select{color:var(--eui-c-neutral-light);width:auto}.eui-19 .eui-table thead tr th.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table thead tr th.eui-table__cell-select .eui-table__cell-select--indeterminated{position:absolute;right:50%;top:var(--eui-s-s);transform:translate(50%)}.eui-19 .eui-table tbody tr{border-top:1px solid var(--eui-c-divider);height:calc(3 * var(--eui-s-m))}.eui-19 .eui-table tbody tr.eui-table__row--selected,.eui-19 .eui-table tbody tr.eui-table__row--selected td{background-color:var(--eui-table-selected-row-background-color)!important}.eui-19 .eui-table tbody tr:not(.eui-table-expandable-row):nth-child(odd){background-color:var(--eui-c-bg)}.eui-19 .eui-table tbody tr:not(.eui-table-expandable-row):nth-child(odd) td{background-color:var(--eui-c-bg)}.eui-19 .eui-table tbody tr td{padding:var(--eui-s-xs) var(--eui-s-s);vertical-align:middle}.eui-19 .eui-table tbody tr td.eui-table__cell-select{color:var(--eui-c-neutral-light);width:auto}.eui-19 .eui-table tbody tr td.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table tbody tr:nth-of-type(odd){background-color:var(--eui-c-white)}.eui-19 .eui-table tbody tr:nth-of-type(2n){background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table tbody tr:nth-of-type(2n) td{background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table tfoot tr{border-bottom:1px solid var(--eui-c-divider);border-top:1px solid var(--eui-c-divider)}.eui-19 .eui-table tfoot tr td{padding:var(--eui-s-s);vertical-align:middle}.eui-19 .eui-table__sticky-container{overflow:auto;will-change:transform}.eui-19 .eui-table__sticky-container::-webkit-scrollbar{display:inherit;height:8px;width:8px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-table__sticky-container::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-table__sticky-container::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-table__sticky-container::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-table__sticky-container{scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-table--sticky-header thead tr th{position:sticky;top:0;z-index:8}.eui-19 .eui-table--sticky-columns .eui-table__col--sticky{position:sticky}.eui-19 .eui-table--sticky-columns th.eui-table__col--sticky{z-index:9}.eui-19 .eui-table--sticky-columns th.eui-table__col--sticky.eui-table__col--sticky-shadowed-first{box-shadow:inset -5px 0 8px -8px #0003}.eui-19 .eui-table--sticky-columns th.eui-table__col--sticky.eui-table__col--sticky-shadowed-last{box-shadow:inset 5px 0 8px -8px #0003}.eui-19 .eui-table--sticky-columns td.eui-table__col--sticky{z-index:8}.eui-19 .eui-table--sticky-columns td.eui-table__col--sticky.eui-table__col--sticky-shadowed-first{box-shadow:inset -5px 0 8px -8px #0003}.eui-19 .eui-table--sticky-columns td.eui-table__col--sticky.eui-table__col--sticky-shadowed-last{box-shadow:inset 5px 0 8px -8px #0003}@media screen and (max-width: 767px){.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive{width:100%!important}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive thead,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tbody,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tfoot,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive th,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive td,.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tr{display:block}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive thead tr{left:-9999px;position:absolute;top:-9999px}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive tr{height:auto}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive td{border:var(--eui-bw-none);border-bottom:1px solid var(--eui-c-neutral-bg-light);padding-left:50%;position:relative;text-align:left!important}.eui-19 .eui-table:not(.eui-table-cards).eui-table--responsive td:before{color:var(--eui-c-neutral-light);content:attr(data-col-label);left:var(--eui-s-xs);padding-right:var(--eui-s-xs);position:absolute;width:45%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;font:var(--eui-f-m-bold)}.eui-19 .eui-table:not(.eui-table-cards) .actionsColumn,.eui-19 .eui-table:not(.eui-table-cards) .actions-column{justify-content:flex-start;text-align:left;width:100%}.eui-19 .eui-table__sticky-container{height:auto!important;width:auto!important}.eui-19 .eui-table--sticky-columns th,.eui-19 .eui-table--sticky-columns td,.eui-19 .eui-table--sticky-columns th .eui-table__col--sticky,.eui-19 .eui-table--sticky-columns td .eui-table__col--sticky{width:auto;z-index:auto}.eui-19 .eui-table--sticky-columns th .eui-table__col--sticky.eui-table__col--sticky-shadowed-first,.eui-19 .eui-table--sticky-columns th .eui-table__col--sticky.eui-table__col--sticky-shadowed-last,.eui-19 .eui-table--sticky-columns td .eui-table__col--sticky.eui-table__col--sticky-shadowed-first,.eui-19 .eui-table--sticky-columns td .eui-table__col--sticky.eui-table__col--sticky-shadowed-last{box-shadow:none!important}.eui-19 .eui-table--sticky-columns tfoot tr td:empty{display:none!important}}.eui-19 .eui-table__filter{align-items:center;display:flex;justify-content:flex-end;position:relative}.eui-19 .eui-table__filter--responsive{width:100%}.eui-19 .eui-table__filter-input{padding-left:var(--eui-s-3xl)!important}@media screen and (max-width: 767px){.eui-19 .eui-table__filter--responsive{display:block;width:100%}}.eui-19 .eui-table__draggable-preview--no-preview.cdk-drag-preview{display:none}.eui-19 .eui-table--draggable tr.eui-table__draggable-preview--no-placeholder{opacity:1}.eui-19 .eui-table--draggable tr:hover{background-color:var(--eui-c-accent-bg-light)}.eui-19 .eui-table--draggable td .cdk-drop-list{flex-direction:column}.eui-19 .eui-table-cards{background-color:transparent;display:flex;flex-direction:column;overflow:hidden;width:100%}.eui-19 .eui-table-cards thead{width:100%}.eui-19 .eui-table-cards thead tr{align-items:center;height:auto}.eui-19 .eui-table-cards thead tr th{position:relative;vertical-align:middle;width:100%}.eui-19 .eui-table-cards thead tr th.eui-table__cell-select{padding:var(--eui-s-s) var(--eui-s-m);width:auto}.eui-19 .eui-table-cards thead tr th.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table-cards tbody{width:100%}.eui-19 .eui-table-cards tbody tr{align-items:center;border-top:0;display:flex;height:auto;width:100%}.eui-19 .eui-table-cards tbody tr.eui-table__row--selected .eui-card:first-child{--eui-card-header-background-color: var(--eui-table-selected-row-background-color)}.eui-19 .eui-table-cards tbody tr td{position:relative;vertical-align:middle;width:100%}.eui-19 .eui-table-cards tbody tr td.eui-table__cell-select{padding:var(--eui-s-s) var(--eui-s-m);width:auto}.eui-19 .eui-table-cards tbody tr td.eui-table__cell-select .eui-table__cell-select-checkbox-container{display:flex}.eui-19 .eui-table-cards tbody tr:hover{background-color:transparent}.eui-19 .eui-table-cards tbody tr:not(.eui-table-expandable-row):nth-child(odd){background-color:transparent}.eui-19 .eui-table-cards tbody tr:nth-of-type(2n){background-color:transparent}.eui-19 .eui-table-cards tbody tr:nth-of-type(2n):hover:not(.eui-table__row--selected){background-color:transparent}.eui-19 .eui-table-cards tbody tr:nth-of-type(odd):hover:not(.eui-table__row--selected){background-color:transparent}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], rows: [{
                type: Input
            }], propId: [{
                type: Input
            }], e2eAttr: [{
                type: Input
            }], paginator: [{
                type: Input
            }], filter: [{
                type: Input
            }], preselectedRows: [{
                type: Input
            }], loading: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], asyncTable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], paginable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiTableResponsive: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiTableFixedLayout: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiTableDraggable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiTableCards: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiTableBordered: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiTableCompact: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasStickyHeader: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasStickyColumns: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isSelectOnlyVisibleRows: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isColsOrderable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isHoverable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], selectedRows: [{
                type: Output
            }], sortChange: [{
                type: Output
            }], multiSortChange: [{
                type: Output
            }], templates: [{
                type: ContentChildren,
                args: [EuiTemplateDirective]
            }], theadRef: [{
                type: ViewChild,
                args: ['theadRef']
            }], tbodyRef: [{
                type: ViewChild,
                args: ['tbodyRef']
            }], tfootRef: [{
                type: ViewChild,
                args: ['tfootRef']
            }] } });

/**
 * @description
 * Component used to activate the expandable feature on a row of the table.
 */
class EuiTableExpandableRowComponent {
    constructor() {
        this.string = 'eui-table-expandable-row';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableExpandableRowComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.12", type: EuiTableExpandableRowComponent, isStandalone: true, selector: "tr[euiTableExpandableRow]", host: { properties: { "class": "this.string" } }, ngImport: i0, template: '<ng-content/>', isInline: true }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableExpandableRowComponent, decorators: [{
            type: Component,
            args: [{
                    // eslint-disable-next-line
                    selector: 'tr[euiTableExpandableRow]',
                    template: '<ng-content/>',
                }]
        }], propDecorators: { string: [{
                type: HostBinding,
                args: ['class']
            }] } });

/**
 * @description
 * Component used with `eui-table` to add a filter feature to the table.
 */
class EuiTableFilterComponent {
    constructor() {
        /**
         * Event emitted when the value of the input changes.
         */
        this.filterChange = new EventEmitter();
        this.filter$ = new BehaviorSubject(null);
        this.autoSearch = false;
        this.destroy$ = new Subject();
        this.baseStatesDirective = inject(BaseStatesDirective);
    }
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses() {
        return [this.baseStatesDirective.getCssClasses('eui-table__filter')].join(' ').trim();
    }
    ngOnInit() {
        this.form = new FormGroup({
            filter: new FormControl(null),
        });
        this.form.get('filter').valueChanges.pipe(debounceTime(500), distinctUntilChanged(), takeUntil(this.destroy$)).subscribe((value) => {
            this.setFilter(value);
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
    /**
     * Set the filter value and emit the change event.
     *
     * @param value Value of the input.
     */
    setFilter(value) {
        this.filter$.next(value);
        this.filterChange.emit(value);
        this.form.get('filter').setValue(value);
    }
    /**
     * Reset the filter and emit the change event.
     */
    resetFilter() {
        this.setFilter(null);
        this.form.reset();
        this.filterInput.nativeElement.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableFilterComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "16.1.0", version: "19.2.12", type: EuiTableFilterComponent, isStandalone: true, selector: "eui-table-filter", inputs: { placeholder: "placeholder", autoSearch: ["autoSearch", "autoSearch", booleanAttribute] }, outputs: { filterChange: "filterChange" }, host: { properties: { "class": "this.cssClasses" } }, viewQueries: [{ propertyName: "filterInput", first: true, predicate: ["filterInput"], descendants: true, read: ElementRef }], hostDirectives: [{ directive: i1.BaseStatesDirective }], ngImport: i0, template: "<div class=\"eui-table__filter\">\n    <form [formGroup]=\"form\">\n        <eui-icon-input>\n            <eui-icon-svg icon=\"search:outline\" fillColor=\"neutral-lighter\" aria-label=\"Search Icon\"></eui-icon-svg>\n            <input #filterInput\n                euiClearable\n                euiInputText\n                class=\"eui-table__filter-input\"\n                formControlName=\"filter\"\n                [attr.aria-label]=\"form.get('filter').value ? form.get('filter').value : placeholder\"\n                placeholder=\"{{ placeholder }}\" />\n        </eui-icon-input>\n    </form>\n</div>\n", dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1$1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1$1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1$1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i3.EuiIconInputComponent, selector: "eui-icon-input", inputs: ["euiIconPositionStart", "euiIconPositionEnd"] }, { kind: "component", type: i4.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i5.EuiInputTextComponent, selector: "input[euiInputText]", inputs: ["isInvalid"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableFilterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-table-filter', encapsulation: ViewEncapsulation.None, hostDirectives: [
                        {
                            directive: BaseStatesDirective,
                            inputs: [],
                        },
                    ], imports: [
                        FormsModule,
                        ReactiveFormsModule,
                        ...EUI_ICON_INPUT,
                        ...EUI_ICON,
                        ...EUI_INPUT_TEXT,
                    ], template: "<div class=\"eui-table__filter\">\n    <form [formGroup]=\"form\">\n        <eui-icon-input>\n            <eui-icon-svg icon=\"search:outline\" fillColor=\"neutral-lighter\" aria-label=\"Search Icon\"></eui-icon-svg>\n            <input #filterInput\n                euiClearable\n                euiInputText\n                class=\"eui-table__filter-input\"\n                formControlName=\"filter\"\n                [attr.aria-label]=\"form.get('filter').value ? form.get('filter').value : placeholder\"\n                placeholder=\"{{ placeholder }}\" />\n        </eui-icon-input>\n    </form>\n</div>\n" }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], placeholder: [{
                type: Input
            }], filterChange: [{
                type: Output
            }], filterInput: [{
                type: ViewChild,
                args: ['filterInput', { read: ElementRef }]
            }], autoSearch: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

/**
 * @description
 * Pipe used to highlight the matching string in the data of the table when used with filter feature.
 *
 * @example
 * ```
 * <td><span [innerHTML]="row.year | euiTableHighlightFilter: strFilter"></span></td>
 *
 * strFilter = '19'
 * ```
 */
class EuiTableHighlightFilterPipe {
    /**
     * Wrap a matching string with a span element with a class name in the data of the table
     *
     * @param value Data displayed in a cell.
     * @param strFilter Search string to highlight.
     * @param className CSS class to add to the span element. Default: 'eui-table--highlighted'
     * @returns
     */
    transform(value, strFilter, className = 'eui-table--highlighted') {
        if (!value)
            return '';
        if (!strFilter || strFilter.length === 0)
            return value;
        const generateVariants = (str) => {
            const variants = new Set([str]);
            for (let j = 1; j <= 3; j++) {
                for (const separator of ['.', ',', ' ']) {
                    let newVariant = str;
                    let i = j;
                    while (i < newVariant.length) {
                        newVariant = newVariant.slice(0, i) + separator + newVariant.slice(i);
                        i += 4;
                    }
                    variants.add(newVariant);
                }
            }
            return Array.from(variants);
        };
        const isNumber = (str) => !isNaN(Number(str)) && str.trim() !== '';
        const variants = isNumber(strFilter) ? generateVariants(strFilter) : [strFilter];
        const regex = new RegExp(`(${variants.map(v => v.replace(/[.*+?^${}()|[\]\\]/g, '\\$&')).join('|')})`, 'gi');
        return value.toString().replace(regex, `<span class="${className}">$1</span>`);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableHighlightFilterPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiTableHighlightFilterPipe, isStandalone: true, name: "euiTableHighlightFilter" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableHighlightFilterPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'euiTableHighlightFilter',
                }]
        }] });

/**
 * @description
 * Component used internally by `eui-table-v2` to add a 'select all' checkbox in the header of the table.
 */
class EuiTableSelectableHeaderComponent {
    constructor() {
        this.isCheckedIndeterminate = false;
        /**
         * Whether a "select all" feature is available in the header.
         *
         * @default false
         */
        this.isSelectableHeader = true;
        this.isChecked = false;
        this.destroy$ = new Subject();
        this.euiTableSelectableRowService = inject(EuiTableSelectableRowService);
    }
    ngOnInit() {
        this.euiTableSelectableRowService.isAllRowsSelected$.pipe(takeUntil(this.destroy$)).subscribe((selected) => {
            this.isChecked = selected;
            if (this.checkbox) {
                this.checkbox.nativeElement.checked = selected;
            }
            if (!selected && this.euiTableSelectableRowService.selectedRows$.value.length > 0) {
                this.isCheckedIndeterminate = true;
            }
            else {
                this.isCheckedIndeterminate = false;
            }
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
    /**
     * Handle the change of the selected status.
     *
     * @param value true when checked otherwise false.
     */
    toggleCheckedState(value) {
        this.isChecked = value;
        if (this.isChecked) {
            this.euiTableSelectableRowService.selectAllRows();
        }
        else {
            this.euiTableSelectableRowService.unselectAllRows();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSelectableHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiTableSelectableHeaderComponent, isStandalone: true, selector: "tr[isSelectableHeader]", inputs: { isSelectableHeader: ["isSelectableHeader", "isSelectableHeader", booleanAttribute], isChecked: ["isChecked", "isChecked", booleanAttribute] }, viewQueries: [{ propertyName: "checkbox", first: true, predicate: ["checkbox"], descendants: true }], ngImport: i0, template: "@if (isSelectableHeader) {\n    <th class=\"eui-table__cell-select\">\n        <div class=\"eui-table__cell-select-checkbox-container\">\n            @if (!isChecked && !isCheckedIndeterminate) {\n                <input aria-label=\"Unchecked\" euiInputCheckBox checked=\"false\" (click)=\"toggleCheckedState(true)\" />\n            }\n            @if (isCheckedIndeterminate) {\n                <input aria-label=\"Indeterminate\" euiInputCheckBox indeterminate (click)=\"toggleCheckedState(false)\" />\n            }\n            @if (isChecked && !isCheckedIndeterminate) {\n                <input aria-label=\"Checked\" euiInputCheckBox checked=\"true\" (click)=\"toggleCheckedState(false)\" />\n            }\n        </div>\n    </th>\n}\n\n<ng-content />\n", dependencies: [{ kind: "component", type: i1$2.EuiInputCheckboxComponent, selector: "input[euiInputCheckBox]", inputs: ["indeterminate", "isInvalid", "checked"], outputs: ["indeterminateChange"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSelectableHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tr[isSelectableHeader]', imports: [
                        ...EUI_INPUT_CHECKBOX,
                    ], template: "@if (isSelectableHeader) {\n    <th class=\"eui-table__cell-select\">\n        <div class=\"eui-table__cell-select-checkbox-container\">\n            @if (!isChecked && !isCheckedIndeterminate) {\n                <input aria-label=\"Unchecked\" euiInputCheckBox checked=\"false\" (click)=\"toggleCheckedState(true)\" />\n            }\n            @if (isCheckedIndeterminate) {\n                <input aria-label=\"Indeterminate\" euiInputCheckBox indeterminate (click)=\"toggleCheckedState(false)\" />\n            }\n            @if (isChecked && !isCheckedIndeterminate) {\n                <input aria-label=\"Checked\" euiInputCheckBox checked=\"true\" (click)=\"toggleCheckedState(false)\" />\n            }\n        </div>\n    </th>\n}\n\n<ng-content />\n" }]
        }], propDecorators: { checkbox: [{
                type: ViewChild,
                args: ['checkbox']
            }], isSelectableHeader: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isChecked: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

/**
 * @description
 * Component used internally by `eui-table` to make a row selectable.
 */
class EuiTableSelectableRowComponent {
    constructor() {
        /**
         * Wheter the row is selected.
         *
         * @default false
         */
        this.isChecked = false;
        /**
         * Wheter the selection can be done with the keyboard.
         *
         * @default false
         */
        this.isKeyboardSelectable = false;
        this.propId = 'id';
        this.destroy$ = new Subject();
        this.euiTableSelectableRowService = inject(EuiTableSelectableRowService);
    }
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses() {
        return ['eui-table__row', this.isSelectable ? 'eui-table__row--selectable' : '', this.isChecked ? 'eui-table__row--selected' : '']
            .join(' ')
            .trim();
    }
    /**
     * Keyboard event handler for selecting rows.
     *
     * @param event Keyboard event
     */
    onClickRow(event) {
        if (this.isKeyboardSelectable && this.isSelectable) {
            if (event.ctrlKey) {
                if (!this.isChecked) {
                    this.euiTableSelectableRowService.addSelectedRow(this.isSelectable);
                }
                else {
                    this.euiTableSelectableRowService.removeSelectedRow(this.isSelectable);
                }
            }
            else if (event.shiftKey) {
                const rows = this.euiTableSelectableRowService.getRows();
                const lastSelectedRow = this.euiTableSelectableRowService.getLastSelectedRow();
                const lastSelectedRowPosition = rows.indexOf(lastSelectedRow);
                const position = rows.indexOf(this.isSelectable);
                const range = lastSelectedRowPosition > position
                    ? rows.slice(position, lastSelectedRowPosition + 1)
                    : rows.slice(lastSelectedRowPosition, position + 1);
                this.euiTableSelectableRowService.addSelectedRows(range);
                window.getSelection().empty();
            }
            else {
                this.euiTableSelectableRowService.selectRows([this.isSelectable]);
            }
        }
    }
    ngOnChanges() {
        if (this.isSelectable) {
            this.propId = this.euiTableSelectableRowService.getPropId();
            this.isChecked = this.euiTableSelectableRowService.selectedRows$.value.find((s) => s[this.propId] === this.isSelectable[this.propId])
                ? true
                : false;
        }
    }
    ngOnInit() {
        this.euiTableSelectableRowService.selectedRows$.pipe(takeUntil(this.destroy$)).subscribe((selected) => {
            this.isChecked = selected.filter((s) => s[this.propId] === this.isSelectable[this.propId]).length > 0;
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
    /**
     * Handle the change of the selected status.
     *
     * @param e Change Event
     */
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    toggleCheckedState(e) {
        if (!this.isChecked) {
            this.euiTableSelectableRowService.addSelectedRow(this.isSelectable);
        }
        else {
            this.euiTableSelectableRowService.removeSelectedRow(this.isSelectable);
        }
        e.preventDefault();
        e.stopPropagation();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSelectableRowComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiTableSelectableRowComponent, isStandalone: true, selector: "tr[isSelectable]", inputs: { isSelectable: "isSelectable", isChecked: ["isChecked", "isChecked", booleanAttribute], isKeyboardSelectable: ["isKeyboardSelectable", "isKeyboardSelectable", booleanAttribute] }, host: { listeners: { "click": "onClickRow($event)" }, properties: { "class": "this.cssClasses" } }, usesOnChanges: true, ngImport: i0, template: "@if (isSelectable) {\n    <td class=\"eui-table__cell-select\">\n        <div class=\"eui-table__cell-select-checkbox-container\">\n            @if (isChecked) {\n                <input aria-label=\"default checkbox checked\" euiInputCheckBox checked=\"true\" (click)=\"toggleCheckedState($event)\" />\n            }\n            @if (!isChecked) {\n                <input aria-label=\"default checkbox unchecked\" euiInputCheckBox checked=\"false\" (click)=\"toggleCheckedState($event)\" />\n            }\n        </div>\n    </td>\n}\n<ng-content />\n", dependencies: [{ kind: "component", type: i1$2.EuiInputCheckboxComponent, selector: "input[euiInputCheckBox]", inputs: ["indeterminate", "isInvalid", "checked"], outputs: ["indeterminateChange"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSelectableRowComponent, decorators: [{
            type: Component,
            args: [{ selector: 'tr[isSelectable]', imports: [
                        ...EUI_INPUT_CHECKBOX,
                    ], template: "@if (isSelectable) {\n    <td class=\"eui-table__cell-select\">\n        <div class=\"eui-table__cell-select-checkbox-container\">\n            @if (isChecked) {\n                <input aria-label=\"default checkbox checked\" euiInputCheckBox checked=\"true\" (click)=\"toggleCheckedState($event)\" />\n            }\n            @if (!isChecked) {\n                <input aria-label=\"default checkbox unchecked\" euiInputCheckBox checked=\"false\" (click)=\"toggleCheckedState($event)\" />\n            }\n        </div>\n    </td>\n}\n<ng-content />\n" }]
        }], propDecorators: { isSelectable: [{
                type: Input
            }], isChecked: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isKeyboardSelectable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], onClickRow: [{
                type: HostListener,
                args: ['click', ['$event']]
            }] } });

/**
 * @description
 * Component used internally by `eui-table` to make a column sortable.
 */
class EuiTableSortableColComponent {
    constructor() {
        this.sortOrder = 'desc';
        /**
         * Whether the column is multi-sorted by default.
         *
         * @default false
         */
        this.defaultMultiOrder = null;
        /**
         * Whether the column is sorted by default.
         *
         * @default false
         */
        this.defaultOrder = false;
        /**
         * Whether the sort is disabled on the column.
         *
         * @default false
         */
        this.sortDisabled = false;
        /**
         * Whether the sorting of the column can be cumulated with the one of other column.
         *
         * @default false
         */
        this.isMultiSortable = false;
        this.order = 'desc';
        this.multisortParams = [];
        this.currentMultiSortPosition = 0;
        this.error = false;
        this.destroy$ = new Subject();
        this.euiTableSortService = inject(EuiTableSortService);
    }
    /**
     * @description
     * Computes and returns the CSS classes for the component based on its current state.
     *
     * @returns {string} Space-separated string of CSS class names
     */
    get cssClasses() {
        return ['eui-table__sortable-col', this.sortDisabled ? 'eui-table__sortable-col--disabled' : ''].join(' ').trim();
    }
    ngOnInit() {
        if (this.isMultiSortable && !this.sortDisabled) {
            if (this.defaultMultiOrder > 0 && this.sortOrder) {
                this.euiTableSortService.addMultisortParam(new MultisortParam(this.sortOn, this.sortOrder, this.defaultMultiOrder));
            }
            else {
                this.euiTableSortService.addMultisortParam(new MultisortParam(this.sortOn, null, 0));
            }
        }
        combineLatest([this.euiTableSortService.sortingParams$, this.euiTableSortService.multisortParamsChange$])
            .pipe(takeUntil(this.destroy$))
            .subscribe(([sortingParams, multisortParams]) => {
            if (!this.isMultiSortable) {
                if (sortingParams.sort !== this.sortOn) {
                    this.order = null;
                }
                else {
                    this.order = sortingParams.order;
                }
            }
            else {
                this.multisortParams = [...multisortParams];
                this.form = new FormGroup({ columns: this.euiTableSortService.toFormGroup(multisortParams) });
                if (sortingParams.order !== null && sortingParams.sort !== null) {
                    this.currentMultiSortPosition = 0;
                    if (sortingParams.sort !== this.sortOn) {
                        this.order = null;
                    }
                    else {
                        return;
                    }
                }
                else {
                    this.setCurrentMultisortPosition(multisortParams);
                }
            }
        });
        if (this.defaultOrder) {
            this.order = this.sortOrder;
            this.euiTableSortService.setSort(this.sortOn, this.order);
        }
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
    get columns() {
        return this.form.controls['columns'];
    }
    /**
     * Handles the click event on the sortable column.
     */
    click() {
        if (!this.sortDisabled) {
            if (this.order === 'asc') {
                this.order = 'desc';
            }
            else if (this.order === 'desc') {
                this.order = null;
            }
            else if (this.order === null) {
                this.order = 'asc';
            }
            this.euiTableSortService.setSort(this.sortOn, this.order);
        }
    }
    /**
     * Handles the click event on the multi-sortable column.
     */
    onClickMultisortOrder(index, order) {
        this.form.get('columns').controls[index - 1].get('order').patchValue(order);
    }
    onOpenDropdown() {
        this.error = false;
    }
    getOrderByIndex(index) {
        return this.form.get('columns').controls[index].get('order').value;
    }
    onCancelMultiSort() {
        this.dropdown.closeDropdown();
    }
    onSubmitMultiSort() {
        const arr = [];
        this.form.get('columns').controls.forEach((el) => {
            if (el.get('name').value && el.get('order').value) {
                arr.push({ name: el.get('name').value, order: el.get('order').value });
            }
        });
        if (this.checkValidForSorting(arr)) {
            this.multisortParams.map((el) => this.setSortableParams(el, arr));
            this.euiTableSortService.setMultiSortColumns(this.multisortParams);
            this.dropdown.closeDropdown();
        }
        else {
            this.error = true;
        }
    }
    setSortableParams(el, arr) {
        const currElArr = arr.find((item) => item.name === el.name);
        if (currElArr) {
            const index = arr.findIndex((item) => item.name === el.name);
            el.order = currElArr.order;
            el.position = index + 1;
        }
        else {
            el.order = null;
            el.position = 0;
        }
        return el;
    }
    setCurrentMultisortPosition(multisortParams) {
        const currentColumn = multisortParams.find((el) => el.name === this.sortOn);
        if (currentColumn) {
            this.order = currentColumn.order;
            this.currentMultiSortPosition = currentColumn.position;
        }
        else {
            this.order = null;
            this.currentMultiSortPosition = 0;
        }
    }
    checkValidForSorting(arr) {
        if (arr.length === 0) {
            return false;
        }
        return arr.find((el) => !this.isElementUniqueName(arr, el)) === undefined;
    }
    isElementUniqueName(arr, el) {
        return arr.filter((col) => col.name === el.name).length === 1;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSortableColComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiTableSortableColComponent, isStandalone: true, selector: "th[sortable]", inputs: { sortOn: "sortOn", sortOrder: "sortOrder", defaultMultiOrder: ["defaultMultiOrder", "defaultMultiOrder", numberAttribute], defaultOrder: ["defaultOrder", "defaultOrder", booleanAttribute], sortDisabled: ["sortDisabled", "sortDisabled", booleanAttribute], isMultiSortable: ["isMultiSortable", "isMultiSortable", booleanAttribute] }, host: { properties: { "class": "this.cssClasses" } }, viewQueries: [{ propertyName: "dropdown", first: true, predicate: EuiDropdownComponent, descendants: true }], ngImport: i0, template: "<!-- TODO v19 - remove all eui-u utility classes usage -->\n\n<div class=\"eui-table__sortable-col-content\">\n    <ng-content></ng-content>\n    @if (!sortDisabled) {\n        <button type=\"button\" euiSizeS euiButton euiIconButton euiBasicButton class=\"eui-table__sortable-icon-button\" (click)=\"click()\">\n            @if (!order) {\n                <eui-icon-svg icon=\"swap-vertical:outline\" fillColor=\"neutral-lighter\" [aria-label]=\"'eui.euitable.NO-SORTING-ICON' | translate\"></eui-icon-svg>\n            }\n            @if (order === 'asc') {\n                <eui-icon-svg icon=\"arrow-up:outline\" fillColor=\"primary\" [aria-label]=\"'eui.euitable.ASCENDING-ICON' | translate\"></eui-icon-svg>\n            }\n            @if (order === 'desc') {\n                <eui-icon-svg icon=\"arrow-down:outline\" fillColor=\"primary\" [aria-label]=\"'eui.euitable.DESCENDING-ICON' | translate\"></eui-icon-svg>\n            }\n        </button>\n    }\n    @if (isMultiSortable) {\n        <ng-template [ngTemplateOutlet]=\"sortDropdown\"></ng-template>\n    }\n</div>\n<ng-template #sortDropdown let-index>\n    <eui-dropdown [hasClosedOnClickInside]=\"false\">\n        <button type=\"button\" euiButton euiBasicButton euiRounded euiIconButton euiSizeS [euiDisabled]=\"sortDisabled\" (click)=\"onOpenDropdown()\">\n            <span euiBadge euiPrimary euiOutline>{{ currentMultiSortPosition }}</span>\n        </button>\n        <eui-dropdown-content>\n            <div class=\"eui-u-pt-xs eui-u-pl-s\">\n                <small>{{ 'eui.euitable.CHOOSE-SORT-ORDER' | translate }}</small>\n            </div>\n            @if (form) {\n                <form [formGroup]=\"form\">\n                    <ng-container formArrayName=\"columns\">\n                        @for (columnForm of columns.controls; let i = $index; track $index) {\n                            <div class=\"eui-u-flex eui-u-p-s\" [formGroup]=\"form.get('columns')['controls'][i]\">\n                                <span euiLabel class=\"eui-u-mr-s\">{{ i + 1 }}</span>\n                                <select euiSelect euiSizeS formControlName=\"name\" class=\"eui-u-mr-s\">\n                                    <option value=\"\"></option>\n                                    @for (column of multisortParams; track $index) {\n                                        <option [value]=\"column.name\">{{ column.name }}</option>\n                                    }\n                                </select>\n                                @if (!getOrderByIndex(i)) {\n                                    <button type=\"button\" euiSizeS euiSecondary euiButton euiIconButton euiBasicButton (click)=\"onClickMultisortOrder(i + 1, 'asc')\">\n                                        <eui-icon-svg icon=\"swap-vertical:outline\" [aria-label]=\"'eui.euitable.NO-SORTING-ICON' | translate\"></eui-icon-svg>\n                                    </button>\n                                }\n                                @if (getOrderByIndex(i) === 'asc') {\n                                    <button type=\"button\" euiSizeS euiPrimary euiButton euiIconButton euiBasicButton (click)=\"onClickMultisortOrder(i + 1, 'desc')\">\n                                        <eui-icon-svg icon=\"arrow-up:outline\" [aria-label]=\"'eui.euitable.ASCENDING-ICON' | translate\"></eui-icon-svg>\n                                    </button>\n                                }\n                                @if (getOrderByIndex(i) === 'desc') {\n                                    <button type=\"button\" euiSizeS euiPrimary euiButton euiIconButton euiBasicButton (click)=\"onClickMultisortOrder(i + 1, null)\">\n                                        <eui-icon-svg icon=\"arrow-down:outline\" [aria-label]=\"'eui.euitable.DESCENDING-ICON' | translate\"></eui-icon-svg>\n                                    </button>\n                                }\n                            </div>\n                        }\n                    </ng-container>\n                </form>\n            }\n            @if (error) {\n                <p class=\"eui-u-mt-none eui-u-mb-none eui-u-ml-s\">\n                    <eui-feedback-message euiDanger>{{ 'eui.euitable.WRONG-SORT-PARAMS' | translate }}</eui-feedback-message>\n                </p>\n            }\n            <div class=\"eui-u-flex eui-u-flex-justify-content-between eui-u-p-s\">\n                <button type=\"button\" euiButton euiSizeS euiSecondary (click)=\"onCancelMultiSort()\">{{ 'eui.CANCEL' | translate }}</button>\n                <button type=\"button\" euiButton euiSizeS euiPrimary (click)=\"onSubmitMultiSort()\">{{ 'eui.APPLY' | translate }}</button>\n            </div>\n        </eui-dropdown-content>\n    </eui-dropdown>\n</ng-template>\n", dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1$1.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i1$1.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$1.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i1$1.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i1$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i1$1.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i1$1.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "directive", type: i1$1.FormArrayName, selector: "[formArrayName]", inputs: ["formArrayName"] }, { kind: "ngmodule", type: TranslateModule }, { kind: "pipe", type: i2.TranslatePipe, name: "translate" }, { kind: "component", type: i4.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i4$1.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }, { kind: "component", type: i5$1.EuiBadgeComponent, selector: "div[euiBadge], span[euiBadge], eui-badge", inputs: ["e2eAttr", "aria-label", "maxCharCount", "charReplacement", "euiIconBadge", "euiDottedBadge"] }, { kind: "component", type: i6.EuiFeedbackMessageComponent, selector: "eui-feedback-message", inputs: ["isMuted"] }, { kind: "component", type: i7.EuiSelectComponent, selector: "select[euiSelect]", inputs: ["placeholder", "readonly", "isInvalid"] }, { kind: "directive", type: i7.EuiNgSelectOptionDirective, selector: "option:not([eclSelectOption]):not([eclMultiselectOption]), option[euiOption]", inputs: ["selected", "label", "ngValue"] }, { kind: "directive", type: i7.EuiSelectControlValueAccessor, selector: "select:not([multiple])[formControlName][euiSelect],select:not([multiple])[formControl][euiSelect],select:not([multiple])[ngModel][euiSelect]", inputs: ["placeholder"] }, { kind: "directive", type: i7.EuiSelectMultipleOption, selector: "option, option[euiOption]", inputs: ["ngValue", "value"] }, { kind: "component", type: i8.EuiLabelComponent, selector: "label[euiLabel], span[euiLabel], div[euiLabel], a[euiLabel], eui-label,               label[euiSublabel], span[euiSublabel], div[euiSublabel], a[euiSublabel], eui-sublabel", inputs: ["euiRequired", "euiReadonly", "euiSublabel"] }, { kind: "component", type: i9.EuiDropdownComponent, selector: "eui-dropdown", inputs: ["e2eAttr", "tabIndex", "width", "height", "position", "subDropdownPosition", "isBlock", "isDropDownRightAligned", "hasClosedOnClickInside", "isLabelUpdatedFromSelectedItem", "isExpandOnHover", "hasTabNavigation", "isRightClickEnabled", "euiDisabled"], outputs: ["expand"] }, { kind: "directive", type: i9.EuiDropdownContentDirective, selector: "eui-dropdown-content" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableSortableColComponent, decorators: [{
            type: Component,
            args: [{ selector: 'th[sortable]', imports: [
                        NgTemplateOutlet,
                        FormsModule,
                        ReactiveFormsModule,
                        TranslateModule,
                        ...EUI_ICON,
                        ...EUI_BUTTON,
                        ...EUI_BADGE,
                        ...EUI_FEEDBACK_MESSAGE,
                        ...EUI_SELECT,
                        ...EUI_LABEL,
                        ...EUI_DROPDOWN,
                    ], template: "<!-- TODO v19 - remove all eui-u utility classes usage -->\n\n<div class=\"eui-table__sortable-col-content\">\n    <ng-content></ng-content>\n    @if (!sortDisabled) {\n        <button type=\"button\" euiSizeS euiButton euiIconButton euiBasicButton class=\"eui-table__sortable-icon-button\" (click)=\"click()\">\n            @if (!order) {\n                <eui-icon-svg icon=\"swap-vertical:outline\" fillColor=\"neutral-lighter\" [aria-label]=\"'eui.euitable.NO-SORTING-ICON' | translate\"></eui-icon-svg>\n            }\n            @if (order === 'asc') {\n                <eui-icon-svg icon=\"arrow-up:outline\" fillColor=\"primary\" [aria-label]=\"'eui.euitable.ASCENDING-ICON' | translate\"></eui-icon-svg>\n            }\n            @if (order === 'desc') {\n                <eui-icon-svg icon=\"arrow-down:outline\" fillColor=\"primary\" [aria-label]=\"'eui.euitable.DESCENDING-ICON' | translate\"></eui-icon-svg>\n            }\n        </button>\n    }\n    @if (isMultiSortable) {\n        <ng-template [ngTemplateOutlet]=\"sortDropdown\"></ng-template>\n    }\n</div>\n<ng-template #sortDropdown let-index>\n    <eui-dropdown [hasClosedOnClickInside]=\"false\">\n        <button type=\"button\" euiButton euiBasicButton euiRounded euiIconButton euiSizeS [euiDisabled]=\"sortDisabled\" (click)=\"onOpenDropdown()\">\n            <span euiBadge euiPrimary euiOutline>{{ currentMultiSortPosition }}</span>\n        </button>\n        <eui-dropdown-content>\n            <div class=\"eui-u-pt-xs eui-u-pl-s\">\n                <small>{{ 'eui.euitable.CHOOSE-SORT-ORDER' | translate }}</small>\n            </div>\n            @if (form) {\n                <form [formGroup]=\"form\">\n                    <ng-container formArrayName=\"columns\">\n                        @for (columnForm of columns.controls; let i = $index; track $index) {\n                            <div class=\"eui-u-flex eui-u-p-s\" [formGroup]=\"form.get('columns')['controls'][i]\">\n                                <span euiLabel class=\"eui-u-mr-s\">{{ i + 1 }}</span>\n                                <select euiSelect euiSizeS formControlName=\"name\" class=\"eui-u-mr-s\">\n                                    <option value=\"\"></option>\n                                    @for (column of multisortParams; track $index) {\n                                        <option [value]=\"column.name\">{{ column.name }}</option>\n                                    }\n                                </select>\n                                @if (!getOrderByIndex(i)) {\n                                    <button type=\"button\" euiSizeS euiSecondary euiButton euiIconButton euiBasicButton (click)=\"onClickMultisortOrder(i + 1, 'asc')\">\n                                        <eui-icon-svg icon=\"swap-vertical:outline\" [aria-label]=\"'eui.euitable.NO-SORTING-ICON' | translate\"></eui-icon-svg>\n                                    </button>\n                                }\n                                @if (getOrderByIndex(i) === 'asc') {\n                                    <button type=\"button\" euiSizeS euiPrimary euiButton euiIconButton euiBasicButton (click)=\"onClickMultisortOrder(i + 1, 'desc')\">\n                                        <eui-icon-svg icon=\"arrow-up:outline\" [aria-label]=\"'eui.euitable.ASCENDING-ICON' | translate\"></eui-icon-svg>\n                                    </button>\n                                }\n                                @if (getOrderByIndex(i) === 'desc') {\n                                    <button type=\"button\" euiSizeS euiPrimary euiButton euiIconButton euiBasicButton (click)=\"onClickMultisortOrder(i + 1, null)\">\n                                        <eui-icon-svg icon=\"arrow-down:outline\" [aria-label]=\"'eui.euitable.DESCENDING-ICON' | translate\"></eui-icon-svg>\n                                    </button>\n                                }\n                            </div>\n                        }\n                    </ng-container>\n                </form>\n            }\n            @if (error) {\n                <p class=\"eui-u-mt-none eui-u-mb-none eui-u-ml-s\">\n                    <eui-feedback-message euiDanger>{{ 'eui.euitable.WRONG-SORT-PARAMS' | translate }}</eui-feedback-message>\n                </p>\n            }\n            <div class=\"eui-u-flex eui-u-flex-justify-content-between eui-u-p-s\">\n                <button type=\"button\" euiButton euiSizeS euiSecondary (click)=\"onCancelMultiSort()\">{{ 'eui.CANCEL' | translate }}</button>\n                <button type=\"button\" euiButton euiSizeS euiPrimary (click)=\"onSubmitMultiSort()\">{{ 'eui.APPLY' | translate }}</button>\n            </div>\n        </eui-dropdown-content>\n    </eui-dropdown>\n</ng-template>\n" }]
        }], propDecorators: { dropdown: [{
                type: ViewChild,
                args: [EuiDropdownComponent]
            }], sortOn: [{
                type: Input
            }], sortOrder: [{
                type: Input
            }], defaultMultiOrder: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], defaultOrder: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], sortDisabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isMultiSortable: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], cssClasses: [{
                type: HostBinding,
                args: ['class']
            }] } });

/**
 * @description
 * Module that provides the EuiTable component and its dependencies
 *
 * @deprecated Use {@link EUI_TABLE} instead
 */
class EuiTableModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiTableModule, imports: [EuiTableComponent,
            EuiTableSortableColComponent,
            EuiTableFilterComponent,
            EuiTableSelectableRowComponent,
            EuiTableSelectableHeaderComponent,
            EuiTableExpandableRowComponent,
            EuiTableHighlightFilterPipe,
            EuiTableStickyColumnDirective,
            EuiTemplateDirective], exports: [EuiTableComponent,
            EuiTableSortableColComponent,
            EuiTableFilterComponent,
            EuiTableSelectableRowComponent,
            EuiTableSelectableHeaderComponent,
            EuiTableExpandableRowComponent,
            EuiTableHighlightFilterPipe,
            EuiTableStickyColumnDirective,
            EuiTemplateDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableModule, imports: [EuiTableSortableColComponent,
            EuiTableFilterComponent,
            EuiTableSelectableRowComponent,
            EuiTableSelectableHeaderComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        EuiTableComponent,
                        EuiTableSortableColComponent,
                        EuiTableFilterComponent,
                        EuiTableSelectableRowComponent,
                        EuiTableSelectableHeaderComponent,
                        EuiTableExpandableRowComponent,
                        EuiTableHighlightFilterPipe,
                        EuiTableStickyColumnDirective,
                        EuiTemplateDirective,
                    ],
                    exports: [
                        EuiTableComponent,
                        EuiTableSortableColComponent,
                        EuiTableFilterComponent,
                        EuiTableSelectableRowComponent,
                        EuiTableSelectableHeaderComponent,
                        EuiTableExpandableRowComponent,
                        EuiTableHighlightFilterPipe,
                        EuiTableStickyColumnDirective,
                        EuiTemplateDirective,
                    ],
                }]
        }] });

const EUI_TABLE = [
    EuiTableComponent,
    EuiTableSortableColComponent,
    EuiTableFilterComponent,
    EuiTableSelectableRowComponent,
    EuiTableSelectableHeaderComponent,
    EuiTableExpandableRowComponent,
    EuiTableHighlightFilterPipe,
    EuiTableStickyColumnDirective,
    EuiTemplateDirective,
];

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_TABLE, EuiTableComponent, EuiTableExpandableRowComponent, EuiTableFilterComponent, EuiTableHighlightFilterPipe, EuiTableModule, EuiTableSelectableHeaderComponent, EuiTableSelectableRowComponent, EuiTableSortableColComponent, EuiTableStickyColumnDirective };
//# sourceMappingURL=eui-components-eui-table.mjs.map
