import * as i0 from '@angular/core';
import { EventEmitter, inject, ChangeDetectorRef, booleanAttribute, Output, Input, ViewChild, HostBinding, ViewEncapsulation, ChangeDetectionStrategy, Component, NgModule, ElementRef, Renderer2, ContentChild, Directive, forwardRef } from '@angular/core';
import * as i4 from '@angular/router';
import { RouterModule } from '@angular/router';
import { FormsModule, NG_VALUE_ACCESSOR } from '@angular/forms';
import * as i5 from '@eui/components/eui-input-checkbox';
import { EUI_INPUT_CHECKBOX } from '@eui/components/eui-input-checkbox';
import * as i6 from '@eui/components/eui-button';
import { EUI_BUTTON } from '@eui/components/eui-button';
import * as i7 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import * as i8 from '@eui/components/eui-label';
import { EUI_LABEL } from '@eui/components/eui-label';
import * as i9 from '@eui/components/eui-badge';
import { EUI_BADGE } from '@eui/components/eui-badge';
import * as i10 from '@eui/components/eui-chip';
import { EUI_CHIP } from '@eui/components/eui-chip';
import * as i11 from '@eui/components/eui-dropdown';
import { EUI_DROPDOWN, EuiDropdownComponent } from '@eui/components/eui-dropdown';
import * as i3 from '@angular/cdk/tree';
import { NestedTreeControl, CdkTreeModule } from '@angular/cdk/tree';
import { ArrayDataSource, SelectionModel } from '@angular/cdk/collections';
import * as i1 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';
import * as i2 from '@angular/cdk/scrolling';
import { ScrollDispatcher, ScrollingModule, CdkScrollable } from '@angular/cdk/scrolling';
import { debounceTime } from 'rxjs';
import { NgIf, NgSwitch, NgFor, NgTemplateOutlet } from '@angular/common';

// eslint-disable-next-line prefer-arrow/prefer-arrow-functions
function uxTreeNodesMetaDataMapper(oldTree) {
    return oldTree.map((item) => {
        if (item?.typeClass === 'default') {
            // default typeClass will be
            item.typeClass = 'secondary';
        }
        if (item?.badgeLabel) {
            // default typeClass will be
            if (item?.badges?.length > 0) {
                item.badges.push({ label: item?.badgeLabel, typeClass: 'secondary' });
            }
            else {
                item.badges = [{ label: item?.badgeLabel, typeClass: 'secondary' }];
            }
        }
        return {
            node: {
                treeContentBlock: {
                    label: item.label,
                    typeLabel: item.typeLabel,
                    typeClass: item.typeLabel && !item.typeClass ? 'secondary' : item.typeClass,
                    tooltipLabel: item.tooltipLabel,
                    url: item.url,
                    urlExternal: item.urlExternal,
                    urlExternalTarget: item.urlExternal && item.urlExternalTarget ? item.urlExternalTarget : undefined,
                    badges: item.badges,
                    metadata: item.metadata,
                },
            },
            children: item.children ? uxTreeNodesMetaDataMapper(item.children) : undefined,
        };
    });
}
class EuiTreePagination {
    constructor(data, startPage, renderedPageCount, perPage) {
        this.data = data;
        this.setCurrentStartPage(startPage);
        this.renderedPageCount = renderedPageCount;
        this.totalItems = this.data.length;
        this.perPage = perPage;
        this.totalPages = Math.ceil(this.totalItems / this.perPage);
    }
    paginateNext() {
        if (this.startPage < this.totalPages) {
            this.startPage += 1;
        }
        return this.getViewData();
    }
    paginatePrev() {
        if (this.startPage > 1) {
            this.startPage -= 1;
        }
        return this.getViewData();
    }
    getCurrentStartPage() {
        return this.startPage;
    }
    setCurrentStartPage(startPage) {
        this.startPage = startPage;
    }
    isAtMax() {
        return this.totalPages < this.startPage + this.renderedPageCount;
    }
    getViewData() {
        const startIndex = (this.startPage - 1) * this.perPage;
        const endIndex = startIndex + this.perPage * this.renderedPageCount;
        const pageData = structuredClone(this.data).slice(startIndex, endIndex);
        return {
            startPage: this.startPage,
            data: pageData,
        };
    }
}
class CustomNodeSelectFnHelper {
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    constructor(compInstance) {
        this.compInstance = compInstance;
    }
    select(path, isChecked) {
        this.compInstance.silentSelect(path, isChecked);
    }
    getParents(path) {
        return this.compInstance.getParentPaths(path);
    }
    getTreeItem(path) {
        return this.compInstance.getTreeItem(path);
    }
    getSelectionRecursiveState(path) {
        return this.compInstance.getRunTimeSelectionRecursiveState(path);
    }
}

/**
 * @description
 * The eui-tree can be used to display hierarchy data with optional added behavior inside node templates and interactions
 * that could affect the rendered data such as expand, collapse, direct actions, extra menu actions, etc.
 *
 */
class EuiTreeComponent {
    constructor() {
        this.e2eAttr = 'eui-tree';
        /**
         * Icon to display when a node is closed
         *
         * @default 'chevron-forward:sharp'
         */
        this.expandedSvgIconClass = 'chevron-forward:sharp';
        /**
         * Icon to display when a node is opened
         *
         * @default 'chevron-down:sharp'
         */
        this.collapsedSvgIconClass = 'chevron-down:sharp';
        /**
         * Whether the full node display can be clicked to toggle the node.
         *
         * @default false
         */
        this.isClickTogglingNode = false;
        /**
         * Whether multiple nodes can be selected.
         *
         * @default false
         */
        this.isMultiselect = false;
        /**
         * Whether only one node can be selected. Select one will unselect the previous selected.
         *
         * @default false
         */
        this.isSingleSelect = false;
        /**
         * In combination with `isMultiselect`. Whether the selection of a node will automatically select its children.
         *
         * @default false
         */
        this.isRecursiveSelection = false;
        /**
         * In combination with `isMultiselect`. Whether the selection of all children will automatically select the parent.
         *
         * @default true
         */
        this.isRecursiveParentSelection = true;
        /**
         * Whether the links are underlined on hiver in the tree.
         *
         * @default true
         */
        this.showUnderlinedLinks = false;
        /**
         * Whether the lines are displayed on the left of nodes.
         *
         * @default true
         */
        this.showLines = true;
        /**
         * Whether i18n key can be passed to be translated with `TranslateService`.
         *
         * @default true
         */
        this.autoTranslate = true;
        /**
         * Whether all parents till the selected are highlighted in bold.
         *
         * @default false
         */
        this.highlightPath = false;
        this.selectionChange = new EventEmitter();
        this.nodeClick = new EventEmitter();
        this.nodeToggle = new EventEmitter();
        this.uid = Math.floor(Math.random() * 1000000000).toString();
        this.changeDetectorRef = inject(ChangeDetectorRef);
        this.scrollDispatcher = inject(ScrollDispatcher);
        this.hasChild = (_, item) => !!item?.children && item?.children?.length >= 0;
    }
    get cssClasses() {
        return this.getCssClasses();
    }
    ngOnInit() {
        this.initTree();
    }
    ngOnChanges(changes) {
        if (changes['nodes']?.currentValue !== changes['nodes']?.previousValue) {
            this.renderTree = false;
            this.initTree();
            if (this.treeComponentInstance) {
                this.treeComponentInstance?.renderNodeChanges([]);
                this.treeComponentInstance?.renderNodeChanges(this.treeDataRunTime);
            }
        }
    }
    ngOnDestroy() {
        if (this.selectionModelSubs) {
            this.selectionModelSubs.unsubscribe();
        }
        if (this.scrollDispatcherSubs) {
            this.scrollDispatcherSubs.unsubscribe();
        }
    }
    getSelection() {
        return this._selection;
    }
    getProcessedNodes() {
        return this.processedNodes;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    trackBy(index, item) {
        return item.path;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    trackByControl(item) {
        return item;
    }
    getTreeItem(path) {
        const indexArr = this.resolvePath(path);
        let nodeArr = this.processedNodes;
        let node;
        if (nodeArr && Array.isArray(nodeArr)) {
            indexArr?.forEach((pathIndex, index) => {
                if (index < indexArr.length - 1) {
                    nodeArr = nodeArr && nodeArr[pathIndex]?.children;
                }
                else {
                    node = nodeArr[pathIndex];
                }
            });
        }
        return node;
    }
    expandAll() {
        this.cdkTreeControl.expandAll();
        this.changeDetectorRef.markForCheck();
    }
    expandAt(path) {
        this.getParentPaths(path).reverse().forEach((parentPath) => {
            this.cdkTreeControl.expand(this.getRunTimeTreeItem(parentPath));
        });
        this.cdkTreeControl.expand(this.getRunTimeTreeItem(path));
        this.changeDetectorRef.detectChanges();
    }
    collapseAll() {
        this.cdkTreeControl.collapseAll();
        this.changeDetectorRef.markForCheck();
    }
    filterTerm(filterInput, filterKey, showChildrenOfMatchedItems) {
        if (filterInput !== '' && filterInput !== null && typeof filterInput !== 'undefined') {
            this.treeDataRunTime = this.filterTreeData(structuredClone(this.treeDataRunTimeBackup), filterKey || 'label', filterInput, showChildrenOfMatchedItems);
            this.treeDataRunTime = this.applyRunTimeLastItems(this.treeDataRunTime);
            this.cdkArrayDataSource = new ArrayDataSource(this.treeDataRunTime);
            this.cdkTreeControl = new NestedTreeControl((node) => node?.children, { trackBy: this.trackByControl });
            this.cdkTreeControl.dataNodes = this.treeDataRunTime;
            this.renderTree = false;
            this.changeDetectorRef.detectChanges();
            this.renderTree = true;
            this.changeDetectorRef.detectChanges();
            this.expandMatched(this.treeDataRunTime);
            // this.expandAll();
        }
        else {
            this.treeDataRunTime = structuredClone(this.treeDataRunTimeBackup);
            this.cdkArrayDataSource = new ArrayDataSource(this.treeDataRunTime);
            this.cdkTreeControl = new NestedTreeControl((node) => node?.children, { trackBy: this.trackByControl });
            this.cdkTreeControl.dataNodes = this.treeDataRunTime;
            this.renderTree = false;
            this.changeDetectorRef.detectChanges();
            this.renderTree = true;
            this.changeDetectorRef.detectChanges();
            this.expandAll();
        }
    }
    setAllSelection(isChecked) {
        this.tempSelectionModel = new SelectionModel(true, this.selectionModel.selected, true, (a, b) => a?.path === b?.path);
        this.setIsCheckedForAll(this.treeDataRunTime, isChecked);
        this.selectionModel.setSelection(...this.tempSelectionModel.selected);
        this.changeDetectorRef.markForCheck();
    }
    updateTreeItem(givenTreeItem, path) {
        const treeItem = structuredClone(givenTreeItem);
        if (treeItem && path) {
            this.tempSelectionModel = new SelectionModel(true, this.selectionModel.selected, true, (a, b) => a?.path === b?.path);
            this.setTreeData(path, this.processInputs([treeItem])[0]);
            const pathArr = path.split('.');
            const index = parseInt(pathArr.pop(), 10);
            const treeItemRuntime = this.calculateRunTimeState(treeItem, index, pathArr.join('.'));
            if (treeItemRuntime?.children?.length > 0) {
                treeItemRuntime.children = this.applyRunTimeLastItems(treeItemRuntime.children);
            }
            this.setTreeDataRunTimeBackup(path, treeItemRuntime);
            this.setTreeDataRunTime(path, treeItemRuntime);
            // itemRecursiveSelectionState
            const itemRecursiveSelectionState = this.calculateItemSelectionRecursiveState(treeItem);
            this.setRunTimeSelectionRecursiveStateTree(path, itemRecursiveSelectionState);
            this.syncStateChangesAtPath(path);
            if (this.cdkTreeControl.isExpanded(treeItemRuntime) && !treeItem.node.isExpanded) {
                this.cdkTreeControl.toggle(treeItemRuntime);
            }
            else if (!this.cdkTreeControl.isExpanded(treeItemRuntime) && treeItem.node.isExpanded) {
                this.cdkTreeControl.expand(treeItemRuntime);
            }
            this.renderInitialExpand(this.getRunTimeTreeItem(path)?.children);
            this.getInitialSelection(this.getRunTimeTreeItem(path)?.children)?.forEach((runTimeItem) => {
                this.selectTreeItem(this.getRunTimeBackupTreeItem(runTimeItem.path));
            });
            this.selectionModel.setSelection(...this.tempSelectionModel.selected);
            // Rendering
            this.changeDetectorRef.detectChanges();
            this.treeComponentInstance.renderNodeChanges([]);
            this.treeComponentInstance.renderNodeChanges(this.treeDataRunTime);
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    onNodeClick(treeRunTimeItem, e) {
        if (!this.isMultiselect || e.pointerId !== -1) {
            this.nodeClick.emit(this.getTreeItem(treeRunTimeItem?.path));
        }
        if (this.isClickTogglingNode) {
            this.cdkTreeControl.toggle(treeRunTimeItem);
            this.onNodeToggle(treeRunTimeItem);
        }
    }
    onNodeToggle(treeRunTimeItem) {
        this.getTreeItem(treeRunTimeItem?.path).node.isExpanded = this.cdkTreeControl.isExpanded(treeRunTimeItem);
        this.nodeToggle.emit(this.getTreeItem(treeRunTimeItem?.path));
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    nodeSelected(evt, path) {
        const item = this.getTreeItem(path);
        const runTimeBackupTreeItem = this.getRunTimeBackupTreeItem(path);
        const renderedRunTimeTreeItem = this.getRunTimeTreeItem(path);
        const node = item?.node;
        this.tempSelectionModel = new SelectionModel(true, this.selectionModel.selected, true, (a, b) => a?.path === b?.path);
        // console.log(path,item,runTimeTreeItem, renderedRunTimeTreeItem);
        if (this.customNodeSelectFn) {
            this.customNodeSelectFn(path, evt.target.checked, item, new CustomNodeSelectFnHelper(this));
            this.selectionModel.setSelection(...this.tempSelectionModel.selected);
        }
        else if (!node?.selectConfig?.singleSelect) {
            node.isSelected = evt.target.checked;
            node.isIndeterminate = false;
            // If the node is recursive it sets every children with the change.
            if (renderedRunTimeTreeItem?.children && renderedRunTimeTreeItem?.children?.length > 0) {
                if (node?.selectConfig?.recursive) {
                    // console.log(renderedRunTimeTreeItem);
                    this.setIsCheckedForAll(renderedRunTimeTreeItem?.children, evt.target.checked);
                }
            }
            this.setRunTimeSelectionRecursiveStateTree(path, this.calculateItemSelectionRecursiveState(structuredClone(this.getTreeItem(path))));
            if (renderedRunTimeTreeItem?.children && renderedRunTimeTreeItem?.children?.length >= 0) {
                if (node?.selectConfig?.recursive) {
                    // this.setIsCheckedForAll(renderedRunTimeTreeItem?.children, evt.target.checked);
                    this.runStateChangesForAll(renderedRunTimeTreeItem?.children);
                }
                this.treeComponentInstance?.renderNodeChanges([]);
                this.treeComponentInstance?.renderNodeChanges(this.treeDataRunTime);
            }
            this.syncStateChangesAtPath(path);
            if (this.getTreeItem(path).node.isSelected) {
                this.selectTreeItem(runTimeBackupTreeItem);
            }
            else {
                this.deselectTreeItem(runTimeBackupTreeItem);
            }
            const nodePathsSeq = this.getParentPaths(path);
            if (nodePathsSeq.length > 0) {
                nodePathsSeq.forEach((nodePath) => {
                    const treeItem = this.getTreeItem(nodePath);
                    const childStates = this.getRunTimeSelectionRecursiveState(nodePath).children.map((_) => _.selectionRecursiveState);
                    this.updateRunTimeSelectionRecursiveState(nodePath, this.decideSelectionRecursiveState(childStates, treeItem.node?.isSelected, treeItem.node?.selectConfig?.recursive, treeItem.node?.selectConfig?.noAutoSelectParent));
                    this.syncStateChangesAtPath(nodePath);
                });
                this.changeDetectorRef.detectChanges();
            }
            else {
                this.changeDetectorRef.detectChanges();
            }
            this.selectionModel.setSelection(...this.tempSelectionModel.selected);
        }
        else {
            const prevItem = this.selectionModel.selected[0];
            if (evt.target.checked) {
                if (prevItem) {
                    this.getTreeItem(prevItem.path).node.isSelected = false;
                    this.selectionModel.deselect(prevItem);
                }
                item.node.isSelected = true;
                this.selectionModel.select(runTimeBackupTreeItem);
            }
            else {
                item.node.isSelected = false;
                this.selectionModel.deselect(runTimeBackupTreeItem);
            }
            if (this.highlightPath) {
                if (evt.target.checked && prevItem) {
                    const prevItemNodePathsSeq = this.getParentPaths(prevItem.path);
                    if (prevItemNodePathsSeq.length > 0) {
                        prevItemNodePathsSeq.forEach((nodePath) => {
                            this.updateRunTimeSelectionRecursiveState(nodePath, 'allNotSelected');
                            this.syncStateChangesAtPath(nodePath);
                        });
                    }
                }
                const nodePathsSeq = this.getParentPaths(path);
                if (nodePathsSeq?.length > 0) {
                    nodePathsSeq.forEach((nodePath) => {
                        this.updateRunTimeSelectionRecursiveState(nodePath, evt.target.checked ? 'indeterminate' : 'allNotSelected');
                        this.syncStateChangesAtPath(nodePath);
                    });
                    this.changeDetectorRef.detectChanges();
                }
            }
        }
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    onSelectFn(path) {
        if (this.getTreeItem(path)?.node?.selectable) {
            const nodeSelected = this.nodeSelected.bind(this);
            // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            return (evt) => nodeSelected(evt, path);
        }
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        return (evt) => {
            console.warn('treeItemModel.node.selectable is false, you can not implement onSelect');
        };
    }
    getRunTimeSelectionRecursiveState(path) {
        const indexArr = this.resolvePath(path);
        let nodeArr = this.runTimeSelectionRecursiveState;
        let node;
        indexArr?.forEach((pathIndex, index) => {
            if (index < indexArr.length - 1) {
                nodeArr = nodeArr[pathIndex]?.children;
            }
            else {
                node = nodeArr[pathIndex];
            }
        });
        return node;
    }
    initTree() {
        if (this.nodes) {
            this._isMultiLevel = this.checkIfMultiLevel(this.nodes);
            this.processedNodes = this.processInputs(structuredClone(this.nodes));
            this.treeDataRunTime = this.createTreeDataRuntime(this.processedNodes);
            this.treeDataRunTime = this.applyRunTimeLastItems(this.treeDataRunTime);
            this.runTimeSelectionRecursiveState = this.createRunTimeSelectionRecursiveState(this.processedNodes);
            this.treeDataRunTimeBackup = structuredClone(this.treeDataRunTime);
            // todo It should be configurable, 800, 2 and 400 are hard coded right now
            if (this.treeDataRunTimeBackup.length > 800) {
                this.treePagination = new EuiTreePagination(this.treeDataRunTimeBackup, 1, 2, 400);
                const paginatedData = this.treePagination.getViewData().data;
                this.cdkArrayDataSource = new ArrayDataSource(paginatedData);
                this.cdkTreeControl = new NestedTreeControl((node) => node?.children, {
                    trackBy: this.trackByControl,
                });
                this.cdkTreeControl.dataNodes = paginatedData;
                this.runScrollListener();
            }
            else {
                this.cdkArrayDataSource = new ArrayDataSource(this.treeDataRunTime);
                this.cdkTreeControl = new NestedTreeControl((node) => node?.children, {
                    trackBy: this.trackByControl,
                });
                this.cdkTreeControl.dataNodes = this.treeDataRunTime;
            }
            this.renderInitialExpand(this.treeDataRunTime);
            this.selectionModel = new SelectionModel(true, this.getInitialSelection(this.treeDataRunTime), true, (a, b) => a?.path === b?.path);
            this._selection = [...this.selectionModel.selected]?.map((item) => this.getTreeItem(item?.path));
            this.renderTree = true;
            if (this.selectionModelSubs) {
                this.selectionModelSubs.unsubscribe();
            }
            this.selectionModelSubs = this.selectionModel.changed.pipe(debounceTime(1)).subscribe((sc) => {
                const selectionChange = {
                    added: sc.added.map((_) => this.getTreeItem(_.path)),
                    removed: sc.removed.map((_) => this.getTreeItem(_.path)),
                    selection: [...this.selectionModel.selected].map((item) => this.getTreeItem(item.path)),
                };
                this._selection = selectionChange.selection;
                this.selectionChange.emit(selectionChange);
            });
            this.changeDetectorRef.markForCheck();
        }
    }
    processInputs(treeData) {
        if (this.isMultiselect) {
            treeData = this.overrideTreeDataModelForSelection(treeData, this.isRecursiveSelection, !this.isRecursiveParentSelection);
        }
        if (this.isSingleSelect) {
            treeData = this.overrideTreeDataModelForSelection(treeData, false, false, true);
        }
        return treeData;
    }
    overrideTreeDataModelForSelection(nodeArr, isRecursive, noAutoSelectParent, singleSelect) {
        return nodeArr?.map((item, index) => {
            if (item?.children && item.children.length > 0) {
                return {
                    ...item,
                    node: {
                        ...item.node,
                        selectable: typeof item?.node?.selectable === 'undefined' ? true : item?.node?.selectable,
                        // isSelected: false,
                        // isIndeterminate: false,
                        selectConfig: {
                            ...item.node.selectConfig,
                            recursive: typeof item?.node?.selectConfig?.recursive === 'undefined'
                                ? !!isRecursive
                                : item?.node?.selectConfig?.recursive,
                            noAutoSelectParent: typeof item?.node?.selectConfig?.noAutoSelectParent === 'undefined'
                                ? noAutoSelectParent
                                : item?.node?.selectConfig?.noAutoSelectParent,
                            singleSelect: typeof item?.node?.selectConfig?.singleSelect === 'undefined'
                                ? singleSelect
                                : item?.node?.selectConfig?.singleSelect,
                        },
                    },
                    children: this.overrideTreeDataModelForSelection(item.children, isRecursive, noAutoSelectParent, singleSelect),
                };
            }
            else {
                return {
                    ...item,
                    node: {
                        ...item.node,
                        selectable: typeof item?.node?.selectable === 'undefined' ? true : item?.node?.selectable,
                        selectConfig: {
                            ...item.node?.selectConfig,
                            singleSelect: typeof item?.node?.selectConfig?.singleSelect === 'undefined'
                                ? singleSelect
                                : item?.node?.selectConfig?.singleSelect,
                        },
                    },
                };
            }
        });
    }
    runScrollListener() {
        /* if (this.scrollDispatcherSubs) { todo
            this.scrollDispatcherSubs.unsubscribe();
        }*/
        this.scrollDispatcherSubs = this.scrollDispatcher.scrolled().subscribe((scrollable) => {
            if (scrollable && this.checkIfCurrentScrollable(scrollable)) {
                const isAtBottom = scrollable?.getElementRef().nativeElement.scrollTop + scrollable?.getElementRef().nativeElement.clientHeight >=
                    scrollable?.getElementRef().nativeElement.scrollHeight;
                const isAtTop = scrollable?.getElementRef().nativeElement.scrollTop === 0;
                // console.log('Element:', this.cdkScrollableRef.getElementRef());
                if (isAtBottom && !this.treePagination.isAtMax()) {
                    if (this.nodes.length > 0) {
                        this.treeDataRunTime = this.treePagination.paginateNext().data;
                        this.treeDataRunTime = this.applyRunTimeLastItems(this.treeDataRunTime);
                        this.cdkArrayDataSource = new ArrayDataSource(this.treeDataRunTime);
                        this.cdkTreeControl = new NestedTreeControl((node) => node?.children, {
                            trackBy: this.trackByControl,
                        });
                        this.cdkTreeControl.dataNodes = this.treeDataRunTime;
                        this.renderTree = false;
                        this.changeDetectorRef.detectChanges();
                        this.renderTree = true;
                        this.changeDetectorRef.detectChanges();
                        this.expandAll();
                        const totalHeight = scrollable.measureScrollOffset('bottom') + scrollable.measureScrollOffset('top');
                        const viewportHeight = scrollable.getElementRef().nativeElement.clientHeight;
                        const positionToScroll = totalHeight - viewportHeight;
                        scrollable.scrollTo({ top: positionToScroll / 2 });
                    }
                }
                else if (isAtTop && this.treePagination.getCurrentStartPage() > 1) {
                    if (this.nodes.length > 0) {
                        this.treeDataRunTime = this.treePagination.paginatePrev().data;
                        this.treeDataRunTime = this.applyRunTimeLastItems(this.treeDataRunTime);
                        this.cdkArrayDataSource = new ArrayDataSource(this.treeDataRunTime);
                        this.cdkTreeControl = new NestedTreeControl((node) => node?.children, {
                            trackBy: this.trackByControl,
                        });
                        this.cdkTreeControl.dataNodes = this.treeDataRunTime;
                        this.renderTree = false;
                        this.changeDetectorRef.detectChanges();
                        this.renderTree = true;
                        this.changeDetectorRef.detectChanges();
                        this.expandAll();
                        const totalHeight = scrollable.measureScrollOffset('bottom') + scrollable.measureScrollOffset('top');
                        const viewportHeight = scrollable.getElementRef().nativeElement.clientHeight;
                        const positionToScroll = totalHeight - viewportHeight;
                        scrollable.scrollTo({ top: positionToScroll / 2 + viewportHeight });
                    }
                }
            }
        });
    }
    getSelectionIndexOfItem(runTimeTreeItem) {
        return this.selectionModel.selected.findIndex((i) => i?.path === runTimeTreeItem?.path);
    }
    // todo re-think about the access from custom on node select helper
    silentSelect(path, isChecked) {
        const runtimeBackupTreeItem = this.getRunTimeBackupTreeItem(path);
        const treeItem = this.getTreeItem(path);
        const node = treeItem.node;
        if (node?.selectable) {
            node.isSelected = isChecked;
            node.isIndeterminate = false;
            if (isChecked) {
                this.tempSelectionModel.select(runtimeBackupTreeItem);
            }
            else {
                this.tempSelectionModel.deselect(runtimeBackupTreeItem);
            }
        }
    }
    selectTreeItem(runTimeBackupTreeItem) {
        this.tempSelectionModel.select(runTimeBackupTreeItem);
    }
    deselectTreeItem(runTimeTreeItem) {
        this.tempSelectionModel.deselect(runTimeTreeItem);
    }
    createTreeDataRuntime(nodes) {
        return structuredClone(nodes)?.map((item, index) => {
            return this.calculateRunTimeState(item, index);
        });
    }
    applyRunTimeLastItems(items) {
        return items?.map((item, index) => {
            if (item?.children) {
                return {
                    ...item,
                    last: items.length === index + 1 ? true : undefined,
                    children: item.children?.length > 0 ? this.applyRunTimeLastItems(item.children) : item?.children,
                };
            }
            else {
                return {
                    ...item,
                    last: items.length === index + 1 ? true : undefined,
                };
            }
        });
    }
    createRunTimeSelectionRecursiveState(nodes) {
        return structuredClone(nodes)?.map((item) => this.calculateItemSelectionRecursiveState({ ...item }));
    }
    // Creating run time state which includes children selection state for selection tree.
    calculateItemSelectionRecursiveState(treeItem) {
        const childrenSelectionRecursive = [];
        if (treeItem.children && treeItem.children.length > 0) {
            treeItem.children.forEach((child, index) => {
                childrenSelectionRecursive[index] = this.calculateItemSelectionRecursiveState(child);
            });
        }
        const childStates = childrenSelectionRecursive.map((_) => _.selectionRecursiveState);
        const itemState = treeItem.node.selectable ? this.decideSelectionRecursiveState(childStates, treeItem.node.isSelected, treeItem.node?.selectConfig?.recursive, treeItem.node?.selectConfig?.noAutoSelectParent) : undefined;
        return {
            selectionRecursiveState: itemState,
            children: childrenSelectionRecursive,
        };
    }
    decideSelectionRecursiveState(childStates = [], isSelected, recursive, noAutoSelectParent) {
        let itemState = 'indeterminate';
        if (isSelected && childStates.filter((childStates) => childStates).every((state) => state === 'allSelected')) {
            itemState = 'allSelected';
        }
        else if (!isSelected && childStates.filter((childStates) => childStates).every((state) => state === 'allNotSelected')) {
            itemState = 'allNotSelected';
        }
        else if (recursive && childStates.filter((childStates) => childStates).every((state) => state === 'allSelected') && !isSelected && !noAutoSelectParent) {
            itemState = 'allSelected';
        }
        else if (recursive && childStates.filter((childStates) => childStates).every((state) => state === 'allNotSelected') && isSelected) {
            itemState = 'allNotSelected';
        }
        return itemState;
    }
    syncStateChangesAtPath(nodePath) {
        const treeItem = this.getTreeItem(nodePath);
        const runTimeBackupTreeItem = this.getRunTimeBackupTreeItem(nodePath);
        const runTimeSelectionRecursiveItem = this.getRunTimeSelectionRecursiveState(nodePath);
        if (treeItem?.node?.selectable && treeItem.node?.selectConfig?.recursive) {
            if (!treeItem.node?.selectConfig?.noAutoSelectParent) {
                treeItem.node = {
                    ...treeItem.node,
                    isSelected: runTimeSelectionRecursiveItem.selectionRecursiveState === 'allSelected',
                    isIndeterminate: runTimeSelectionRecursiveItem.selectionRecursiveState === 'indeterminate',
                };
            }
            else {
                treeItem.node = {
                    ...treeItem.node,
                    isSelected: treeItem.node.isSelected && runTimeSelectionRecursiveItem.selectionRecursiveState === 'allSelected',
                    isIndeterminate: runTimeSelectionRecursiveItem.selectionRecursiveState === 'indeterminate' ||
                        (!treeItem.node.isSelected && runTimeSelectionRecursiveItem.selectionRecursiveState === 'allSelected'),
                };
            }
            // console.log(treeItem, treeItem.node.treeContentBlock.label, 'isSelected:' + treeItem.node.isSelected, 'isIndeterminate:' + treeItem.node.isIndeterminate);
            if (treeItem.node.isSelected === true && !this.selectionModel.isSelected(runTimeBackupTreeItem)) {
                this.selectTreeItem(runTimeBackupTreeItem);
            }
            else if (treeItem.node.isSelected === false && this.selectionModel.isSelected(runTimeBackupTreeItem)) {
                this.deselectTreeItem(runTimeBackupTreeItem);
            }
        }
    }
    setTreeData(path, item) {
        const indexArr = this.resolvePath(path);
        let itemArr = this.processedNodes;
        indexArr?.forEach((pathIndex, index) => {
            if (index < indexArr.length - 1) {
                itemArr = itemArr[pathIndex]?.children;
            }
            else {
                itemArr[pathIndex] = item;
            }
        });
    }
    setTreeDataRunTimeBackup(path, item) {
        const indexArr = this.resolvePath(path);
        let itemArr = this.treeDataRunTimeBackup;
        indexArr.forEach((pathIndex, index) => {
            if (index < indexArr.length - 1) {
                itemArr = itemArr[pathIndex]?.children;
            }
            else {
                itemArr[pathIndex] = item;
            }
        });
    }
    setTreeDataRunTime(path, item) {
        const oldItem = this.getRunTimeTreeItem(path);
        if (oldItem) {
            Object.keys(item)?.forEach(key => {
                oldItem[key] = item[key];
            });
        }
    }
    setRunTimeSelectionRecursiveStateTree(path, item) {
        const indexArr = this.resolvePath(path);
        let itemArr = this.runTimeSelectionRecursiveState;
        indexArr.forEach((pathIndex, index) => {
            if (index < indexArr.length - 1) {
                itemArr = itemArr[pathIndex]?.children;
            }
            else {
                itemArr[pathIndex] = item;
            }
        });
    }
    updateRunTimeSelectionRecursiveState(path, selectionRecursiveState) {
        const indexArr = this.resolvePath(path);
        let itemArr = this.runTimeSelectionRecursiveState;
        indexArr.forEach((pathIndex, index) => {
            if (index < indexArr.length - 1) {
                itemArr = itemArr[pathIndex]?.children;
            }
            else {
                itemArr[pathIndex] = {
                    ...itemArr[pathIndex],
                    selectionRecursiveState,
                };
            }
        });
    }
    setIsCheckedForAll(nodeArr, isChecked) {
        nodeArr.forEach((runTimeItem, index) => {
            const runtimeBackupTreeItem = this.getRunTimeBackupTreeItem(runTimeItem.path);
            const treeItem = this.getTreeItem(runTimeItem.path);
            const node = treeItem.node;
            if (node?.selectable) {
                node.isSelected = isChecked;
                node.isIndeterminate = false;
                if (isChecked) {
                    this.selectTreeItem(runtimeBackupTreeItem);
                }
                else {
                    this.deselectTreeItem(runtimeBackupTreeItem);
                }
            }
            if (runTimeItem?.children?.length > 0) {
                this.setIsCheckedForAll(nodeArr[index].children, isChecked);
            }
        });
    }
    runStateChangesForAll(nodeArr) {
        nodeArr?.forEach((runTimeItem, index) => {
            if (runTimeItem?.children?.length >= 0) {
                this.runStateChangesForAll(nodeArr[index].children);
                this.syncSelectionAtPath(runTimeItem);
            }
        });
    }
    syncSelectionAtPath(runTimeTreeItem) {
        // It is here for the filter edge case.
        this.syncStateChangesAtPath(runTimeTreeItem.path);
        // Sets isSelected change on the control.
        if (this.getTreeItem(runTimeTreeItem.path).node.isSelected) {
            this.selectTreeItem(this.getRunTimeBackupTreeItem(runTimeTreeItem.path));
        }
        else {
            this.deselectTreeItem(this.getRunTimeBackupTreeItem(runTimeTreeItem.path));
        }
    }
    resolvePath(path) {
        return path?.split('.').map((index) => parseInt(index, 10));
    }
    getParentPaths(path) {
        const pathArr = path.split('.');
        const hasParent = pathArr.length > 1;
        // Sets the hasParent If there is a parent, and removes the last element form pathArr.
        if (hasParent) {
            pathArr.pop();
            // Calculates parent path
            const parentPath = pathArr.join('.');
            // Creating node index sequence f.e If path is '1.2' it will be [1,2]
            const nodeIndexSeq = parentPath.split('.').map((indexStr) => parseInt(indexStr, 10));
            // Calculating the node paths array to be re-calculated from bottom to top
            const nodePathsSeq = [];
            nodeIndexSeq.forEach((nodeIndex, index) => {
                nodePathsSeq[index] = nodeIndexSeq.slice(0, index + 1).join('.');
            });
            return nodePathsSeq.reverse();
        }
        else {
            return [];
        }
    }
    calculateRunTimeState(treeItem, index, parentPath) {
        const runTimeTreeItem = {
            path: parentPath ? parentPath + '.' + index : index.toString(),
            index,
        };
        if (treeItem.children && treeItem.children.length >= 0) {
            runTimeTreeItem.children = [];
            treeItem.children.forEach((child, treeItemIndex) => {
                runTimeTreeItem.children[treeItemIndex] = this.calculateRunTimeState(child, treeItemIndex, runTimeTreeItem.path);
            });
        }
        return runTimeTreeItem;
    }
    filterTreeData(runTimeTreeData, key = 'label', filterStr, showChildren, show) {
        return runTimeTreeData.filter((runTimeItem) => {
            const targetData = this.getTreeItem(runTimeItem.path).node.treeContentBlock[key];
            if (targetData && this.normalizedStr(targetData)?.includes(this.normalizedStr(filterStr))) {
                if (runTimeItem?.children?.length > 0) {
                    runTimeItem.children = this.filterTreeData(runTimeItem.children, key, filterStr, showChildren, showChildren);
                }
                Object.assign(runTimeItem, { matched: true });
                // runTimeItem.matched = true;
                return true;
            }
            else if (runTimeItem?.children?.length > 0) {
                runTimeItem.children = this.filterTreeData(runTimeItem.children, key, filterStr, showChildren, show);
                runTimeItem.children = runTimeItem.children.length > 0 ? runTimeItem.children : undefined;
                return runTimeItem?.children?.length > 0 || show;
            }
            else {
                return show;
            }
        });
    }
    normalizedStr(str) {
        return str
            .toLowerCase()
            .normalize('NFD')
            .replace(/[\u0300-\u036f]/g, '');
    }
    getInitialSelection(nodes) {
        const selection = [];
        this.scanSelection(nodes, selection);
        return selection;
    }
    scanSelection(nodes, selection) {
        nodes?.forEach((item) => {
            if (this.getTreeItem(item.path).node?.selectable && this.getTreeItem(item.path).node.isSelected) {
                selection.push(item);
            }
            if (item?.children?.length > 0) {
                this.scanSelection(item.children, selection);
            }
        });
    }
    renderInitialExpand(nodes) {
        nodes?.forEach((item) => {
            if (item?.children?.length > 0) {
                this.renderInitialExpand(item.children);
            }
            if (typeof this.getTreeItem(item.path).node.isExpanded !== 'undefined') {
                if (this.getTreeItem(item.path).node.isExpanded && !this.cdkTreeControl.isExpanded(item)) {
                    this.expandAt(item.path);
                }
                else if (!this.getTreeItem(item.path).node.isExpanded && this.cdkTreeControl.isExpanded(item)) {
                    this.cdkTreeControl.collapse(item);
                }
            }
        });
    }
    expandMatched(nodes) {
        nodes.forEach((item) => {
            if (item.matched) {
                const parentPath = this.getParentPaths(item.path)[0];
                if (parentPath) {
                    let parentTreeItem = this.getTreeItem(parentPath);
                    parentTreeItem = {
                        ...parentTreeItem,
                        node: {
                            ...parentTreeItem.node,
                            isExpanded: true,
                        },
                    };
                    //  node.isExpanded = true;
                    // console.log("here", parentTreeItem.node.treeContentBlock.label, parentPath, item);
                    this.expandAt(parentPath);
                }
            }
            if (item?.children?.length > 0) {
                this.expandMatched(item.children);
            }
        });
    }
    getRunTimeTreeItem(path) {
        return this.findRunTimeTreeItem(this.treeDataRunTime, path);
    }
    findRunTimeTreeItem(treeDataRunTime, path) {
        for (const runTimeItem of treeDataRunTime) {
            if (runTimeItem.path === path) {
                return runTimeItem;
            }
            else if (runTimeItem?.children?.length > 0) {
                const found = this.findRunTimeTreeItem(runTimeItem.children, path);
                if (found) {
                    return found;
                }
            }
        }
        return null;
    }
    getRunTimeBackupTreeItem(path) {
        const indexArr = this.resolvePath(path);
        let nodeArr = this.treeDataRunTimeBackup;
        let node;
        if (nodeArr && Array.isArray(nodeArr)) {
            indexArr?.forEach((pathIndex, index) => {
                if (index < indexArr.length - 1) {
                    nodeArr = nodeArr && nodeArr[pathIndex]?.children;
                }
                else {
                    node = nodeArr[pathIndex];
                }
            });
        }
        return node;
    }
    getCssClasses() {
        return [
            'eui-tree',
            this.isMultiselect ? 'eui-tree--multiselect' : '',
            this._isMultiLevel ? 'eui-tree--with-children' : '',
            this.showLines ? 'eui-tree--show-lines' : '',
        ]
            .join(' ')
            .trim();
    }
    checkIfMultiLevel(tree) {
        let isMultiLevel = false;
        tree.forEach((item) => {
            if (item?.children?.length >= 0) {
                isMultiLevel = true;
            }
        });
        return isMultiLevel;
    }
    checkIfCurrentScrollable(scrolled) {
        return scrolled.getElementRef().nativeElement === this.cdkScrollableRef.getElementRef().nativeElement;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "16.1.0", version: "19.2.12", type: EuiTreeComponent, isStandalone: true, selector: "eui-tree", inputs: { e2eAttr: "e2eAttr", nodes: "nodes", nodeTemplateRef: "nodeTemplateRef", nodeContentMetadataTemplateRef: "nodeContentMetadataTemplateRef", rightContextMenuTemplateRef: "rightContextMenuTemplateRef", customNodeSelectFn: "customNodeSelectFn", expandedSvgIconClass: "expandedSvgIconClass", collapsedSvgIconClass: "collapsedSvgIconClass", isClickTogglingNode: ["isClickTogglingNode", "isClickTogglingNode", booleanAttribute], isMultiselect: ["isMultiselect", "isMultiselect", booleanAttribute], isSingleSelect: ["isSingleSelect", "isSingleSelect", booleanAttribute], isRecursiveSelection: ["isRecursiveSelection", "isRecursiveSelection", booleanAttribute], isRecursiveParentSelection: ["isRecursiveParentSelection", "isRecursiveParentSelection", booleanAttribute], showUnderlinedLinks: ["showUnderlinedLinks", "showUnderlinedLinks", booleanAttribute], showLines: ["showLines", "showLines", booleanAttribute], autoTranslate: ["autoTranslate", "autoTranslate", booleanAttribute], highlightPath: ["highlightPath", "highlightPath", booleanAttribute] }, outputs: { selectionChange: "selectionChange", nodeClick: "nodeClick", nodeToggle: "nodeToggle" }, host: { properties: { "class": "this.cssClasses", "attr.data-e2e": "this.e2eAttr" } }, viewQueries: [{ propertyName: "cdkScrollableRef", first: true, predicate: ["cdkScrollableRef"], descendants: true, read: CdkScrollable }, { propertyName: "treeComponentInstance", first: true, predicate: ["treeComponentInstance"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<div class=\"eui-ul-rep eui-tree__wrapper\" cdkScrollable #cdkScrollableRef>\n    <cdk-tree\n        #treeComponentInstance\n        [dataSource]=\"cdkArrayDataSource\"\n        [treeControl]=\"cdkTreeControl\"\n        [trackBy]=\"trackBy\"\n        *ngIf=\"renderTree\"\n        class=\"eui-cdk-tree\">\n        <!-- There are two states of generic cdk-nested-tree-node declarations.\n        First one is without child. No sub rendering.\n        -->\n        <cdk-nested-tree-node *cdkTreeNodeDef=\"let treeRunTimeItemModel\" class=\"eui-cdk-nested-tree-node\">\n            <div *ngIf=\"treeRunTimeItemModel\"\n                class=\"eui-li-rep eui-tree-node\"\n                [class.eui-tree-node--first]=\"treeRunTimeItemModel?.path === '0'\"\n                [class.eui-tree-node--last]=\"treeRunTimeItemModel.last\"\n                title=\"{{\n                    getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.tooltipLabel ||\n                        getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.label\n                }}\">\n                <div class=\"eui-tree-node-wrapper\"\n                     (click)=\"onNodeClick(treeRunTimeItemModel, $event)\">\n                    <div class=\"eui-tree-node-wrapper__container\">\n                        <!--\n                        Renders node in default or provided template's context.\n                        Generates onSelect with onSelectFn for developers to send the events from their custom check events.\n                        Provides id to be used on generic template\n                        -->\n                        <ng-container\n                            [ngTemplateOutlet]=\"nodeTemplateRef || nodeTemplateDefault\"\n                            [ngTemplateOutletContext]=\"{\n                                $implicit: getTreeItem(treeRunTimeItemModel?.path)?.node,\n                                onSelect: onSelectFn(treeRunTimeItemModel.path),\n                                id: uid + treeRunTimeItemModel.path,\n                                path: treeRunTimeItemModel.path\n                            }\">\n                        </ng-container>\n                    </div>\n                </div>\n            </div>\n        </cdk-nested-tree-node>\n        <!-- This is the tree node template for expandable nodes -->\n        <cdk-nested-tree-node\n            *cdkTreeNodeDef=\"let treeRunTimeItemModel; when: hasChild\"\n            class=\"eui-cdk-nested-tree-node eui-cdk-nested-tree-node--with-child\">\n            <div\n                class=\"eui-li-rep eui-tree-node eui-tree-node--with-child\"\n                [class.eui-tree-node--first]=\"treeRunTimeItemModel?.path === '0'\"\n                [class.eui-tree-node--last]=\"treeRunTimeItemModel.last\"\n                *ngIf=\"treeRunTimeItemModel\"\n                title=\"{{\n                    getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.tooltipLabel ||\n                        getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.label\n                }}\">\n                <div\n                    class=\"eui-tree-node-wrapper\">\n                    <!--Here wraps the node, and listen for node clicks.-->\n                    <div (click)=\"onNodeClick(treeRunTimeItemModel, $event)\" class=\"eui-tree-node-wrapper__container\">\n                        <!-- Expand/collapse action button -->\n                        <button\n                            euiButton\n                            euiIconButton\n                            euiBasicButton\n                            euiRounded\n                            euiSizeS\n                            type=\"button\"\n                            [attr.aria-label]=\"'Toggle ' + getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.label\"\n                            (click)=\"onNodeToggle(treeRunTimeItemModel)\"\n                            cdkTreeNodeToggle\n                            class=\"eui-tree-node__button\">\n                            <eui-icon-svg\n                                *ngIf=\"!cdkTreeControl.isExpanded(treeRunTimeItemModel)\"\n                                [icon]=\"expandedSvgIconClass\"></eui-icon-svg>\n                            <eui-icon-svg\n                                *ngIf=\"cdkTreeControl.isExpanded(treeRunTimeItemModel)\"\n                                [icon]=\"collapsedSvgIconClass\"></eui-icon-svg>\n                        </button>\n                        <!--\n                        Renders node in default or provided template's context.\n                        Generates onSelect with onSelectFn for developers to send the events from their custom check events.\n                        Provides id to be used on generic template\n                        -->\n                        <ng-container\n                            [ngTemplateOutlet]=\"nodeTemplateRef || nodeTemplateDefault\"\n                            [ngTemplateOutletContext]=\"{\n                                $implicit: getTreeItem(treeRunTimeItemModel.path)?.node,\n                                onSelect: onSelectFn(treeRunTimeItemModel.path),\n                                id: uid + treeRunTimeItemModel.path,\n                                path: treeRunTimeItemModel.path,\n                                children: getTreeItem(treeRunTimeItemModel?.path)?.children\n                            }\">\n                        </ng-container>\n                    </div>\n                </div>\n                <!--uses cdkTreeNodeOutlet to render children nodes, CdkTreeControl is used to control isExpanded state.-->\n                <div class=\"eui-ul-rep eui-tree-node\" role=\"group\" *ngIf=\"cdkTreeControl.isExpanded(treeRunTimeItemModel)\">\n                    <ng-container cdkTreeNodeOutlet></ng-container>\n                </div>\n            </div>\n        </cdk-nested-tree-node>\n    </cdk-tree>\n</div>\n\n<ng-template #nodeTemplateDefault let-node let-onSelect=\"onSelect\" let-id=\"id\" let-path=\"path\">\n    <ng-container *ngIf=\"node\">\n        <div class=\"eui-tree-node-wrapper__container-left\" [class.eui-tree-node-wrapper__container-left--selected]=\"node?.isSelected\">\n            <!--input checkbox area-->\n            <input\n                euiInputCheckBox\n                *ngIf=\"node && node.selectable\"\n                type=\"checkbox\"\n                id=\"{{ id }}\"\n                [checked]=\"!!node?.isSelected\"\n                [indeterminate]=\"!!node?.isIndeterminate\"\n                (change)=\"onSelect($event)\" />\n\n            <!--icon area-->\n            <ng-container *ngIf=\"node?.treeContentBlock?.iconSvgName\">\n                <eui-icon-svg\n                    icon=\"{{ node?.treeContentBlock?.iconSvgName }}\"\n                    fillColor=\"{{ node?.treeContentBlock?.iconTypeClass || 'neutral' }}\"\n                    size=\"s\"\n                    class=\"eui-u-mr-xs\">\n                </eui-icon-svg>\n            </ng-container>\n\n            <!--chips area-->\n            <ng-container *ngIf=\"node?.treeContentBlock?.chips\">\n                <eui-chip\n                    *ngFor=\"let chip of node.treeContentBlock.chips\"\n                    euiSizeS\n                    [euiVariant]=\"chip.typeClass || 'secondary'\"\n                    [euiOutline]=\"chip.isOutline\"\n                    class=\"eui-chip--rounded eui-u-mr-xs\">\n                    <span euiLabel>{{ chip.label }}</span>\n                </eui-chip>\n            </ng-container>\n\n            <!--badge (typeLabel & typeClass) area-->\n            <ng-container *ngIf=\"node?.treeContentBlock?.typeLabel\" [ngSwitch]=\"node?.treeContentBlock?.typeClass\">\n                <eui-badge euiSizeM [euiVariant]=\"node?.treeContentBlock?.typeClass || 'primary'\" class=\"eui-u-flex-no-shrink eui-u-mr-xs\">\n                    {{ node?.treeContentBlock?.typeLabel }}\n                </eui-badge>\n            </ng-container>\n        </div>\n\n        <!--label area-->\n        <div class=\"eui-tree-node-wrapper__container-middle\">\n            <label\n                *ngIf=\"!node?.treeContentBlock?.url && !node?.treeContentBlock?.urlExternal\"\n                euiLabel\n                for=\"{{ id }}\"\n                class=\"eui-u-text-truncate eui-u-p-2xs\"\n                [class.eui-label--selected]=\"\n                    highlightPath\n                        ? getRunTimeSelectionRecursiveState(path)?.selectionRecursiveState === 'indeterminate' || node?.isSelected\n                        : node?.isSelected\n                \"\n                [class.eui-u-cursor-pointer]=\"node?.selectable\">\n                {{ autoTranslate ? (node?.treeContentBlock?.label | translate) : node?.treeContentBlock?.label }}\n            </label>\n            <label *ngIf=\"node?.treeContentBlock?.url\" euiLabel for=\"{{ id }}\" class=\"eui-u-text-truncate eui-u-p-2xs\">\n                <a\n                    class=\"eui-u-text-link\"\n                    [class.eui-u-text-link-standalone]=\"!showUnderlinedLinks\"\n                    [routerLink]=\"node?.treeContentBlock?.url\">\n                    {{ autoTranslate ? (node?.treeContentBlock?.label | translate) : node?.treeContentBlock?.label }}\n                </a>\n            </label>\n            <label *ngIf=\"node?.treeContentBlock?.urlExternal\" euiLabel for=\"{{ id }}\" class=\"eui-u-text-truncate eui-u-p-2xs\">\n                <a\n                    class=\"eui-u-text-link-external\"\n                    [class.eui-u-text-link-external-standalone]=\"!showUnderlinedLinks\"\n                    href=\"{{ node?.treeContentBlock?.urlExternal }}\"\n                    target=\"{{ node?.treeContentBlock?.urlExternalTarget || 'blank' }}\">\n                    {{ autoTranslate ? (node?.treeContentBlock?.label | translate) : node?.treeContentBlock?.label }}\n                </a>\n            </label>\n        </div>\n\n        <div *ngIf=\"node?.treeContentBlock?.rightContent\" class=\"eui-tree-node-wrapper__container-right\">\n            <!--badges area-->\n            <ng-container *ngFor=\"let badge of node.treeContentBlock.rightContent?.badges\">\n                <eui-badge euiOutline [euiVariant]=\"badge.typeClass || 'secondary'\" class=\"eui-u-ml-xs\">\n                    <span euiLabel>{{ badge.label }}</span>\n                </eui-badge>\n            </ng-container>\n\n            <!--chips area-->\n            <ng-container *ngFor=\"let chip of node.treeContentBlock.rightContent?.chips\">\n                <eui-chip\n                    euiSizeS\n                    [euiVariant]=\"chip.typeClass || 'secondary'\"\n                    [euiOutline]=\"chip.isOutline\"\n                    class=\"eui-chip--rounded eui-u-mb-none eui-u-ml-xs\">\n                    <span euiLabel>{{ chip.label }}</span>\n                </eui-chip>\n            </ng-container>\n\n            <!--Context menu-->\n            <ng-container *ngIf=\"node.treeContentBlock.rightContent?.contextMenuMetaData && rightContextMenuTemplateRef\">\n                <eui-dropdown class=\"eui-u-ml-xs\">\n                    <button euiButton euiSizeS euiRounded euiIconButton euiBasicButton euiSecondary [attr.aria-label]=\"'Options menu'\">\n                        <eui-icon-svg icon=\"ellipsis-vertical:sharp\"></eui-icon-svg>\n                    </button>\n                    <eui-dropdown-content>\n                        <ng-template\n                            [ngTemplateOutlet]=\"rightContextMenuTemplateRef\"\n                            [ngTemplateOutletContext]=\"{\n                                $implicit: node?.treeContentBlock?.rightContent?.contextMenuMetaData,\n                                metadata: node?.treeContentBlock?.rightContent?.contextMenuMetaData\n                            }\">\n                        </ng-template>\n                    </eui-dropdown-content>\n                </eui-dropdown>\n            </ng-container>\n        </div>\n\n        <!--metadata, uses the help of ng template to generate dynamic expand variable without handling state -->\n        <ng-container\n            *ngIf=\"node.treeContentBlock?.metadata && nodeContentMetadataTemplateRef\"\n            [ngTemplateOutlet]=\"nodeContentMetadataContainer\"\n            [ngTemplateOutletContext]=\"{\n                $implicit: { expanded: false }\n            }\" />\n        <ng-template #nodeContentMetadataContainer let-metaDataContainer>\n            <button\n                euiButton\n                euiBasicButton\n                euiIconButton\n                euiRounded\n                euiSizeS\n                type=\"button\"\n                aria-label=\"expand collapse tree item\"\n                (click)=\"metaDataContainer.expanded = !metaDataContainer.expanded\">\n                <eui-icon-svg [icon]=\"metaDataContainer.expanded ? 'chevron-down:sharp' : 'chevron-forward:sharp'\"></eui-icon-svg>\n            </button>\n            <div *ngIf=\"metaDataContainer.expanded\" class=\"eui-tree-node__metacontent\">\n                <!--passing metadata of the node content to provided template-ref:nodeContentMetadataTemplateRef-->\n                <ng-template\n                    [ngTemplateOutlet]=\"nodeContentMetadataTemplateRef\"\n                    [ngTemplateOutletContext]=\"{\n                        $implicit: node?.treeContentBlock?.metadata,\n                        metadata: node?.treeContentBlock?.metadata\n                    }\">\n                </ng-template>\n            </div>\n        </ng-template>\n    </ng-container>\n</ng-template>\n", styles: [".eui-19 .eui-tree{display:flex;overflow-x:hidden;overflow-y:auto;position:relative;width:100%}.eui-19 .eui-tree .eui-tree__wrapper{display:flex;list-style:none;margin:0;overflow-y:auto;padding:var(--eui-s-2xs);position:relative;width:100%}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar{display:inherit;height:8px;width:8px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-tree .eui-tree__wrapper{scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree{display:flex;flex-direction:column;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node{display:flex;width:auto}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node:not(.eui-cdk-nested-tree-node--with-child){padding-inline-start:var(--eui-s-xl)}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node--with-child{display:flex;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node{display:flex;flex-direction:column;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node__metacontent{display:flex}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node__button{margin-left:calc(-3 * var(--eui-s-2xs))}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper{align-items:center;display:flex;min-height:var(--eui-s-2xl);width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper:hover{background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container{align-items:center;display:flex;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container-left{align-items:center;display:flex;justify-content:flex-start}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container-middle{align-items:center;display:flex;justify-content:flex-start;overflow:hidden;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container-right{align-items:center;display:flex;justify-content:flex-end;margin-left:auto}.eui-19 .eui-tree:not(.eui-tree--with-children) .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node{padding-inline-start:2px}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-ul-rep{padding-inline-start:var(--eui-s-2xs)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-ul-rep:before{border-left:1px solid var(--eui-c-divider);content:\"\";height:calc(100% - var(--eui-s-m) - var(--eui-s-xl));position:absolute;top:var(--eui-s-xl)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-ul-rep:first-child:before{height:calc(100% - var(--eui-s-m) - var(--eui-s-2xs));top:0}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep{padding-inline-start:var(--eui-s-s);position:relative}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep:before:not(.eui-tree-node--first){border-top:1px solid var(--eui-c-divider);content:\"\";display:block;height:0;left:0;position:absolute;top:var(--eui-s-m);width:var(--eui-s-xl)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep.eui-tree-node:not(.eui-tree-node--with-child):before{position:relative;left:0;display:inline-flex;width:var(--eui-s-2xl);border-bottom:1px solid var(--eui-c-divider);content:\"\";margin-left:calc(-2 * var(--eui-s-l) + var(--eui-s-2xs));top:var(--eui-s-m)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep.eui-tree-node.eui-tree-node--with-child:before{position:absolute;left:calc(1 * var(--eui-s-2xl) + var(--eui-s-2xs));display:inline-flex;width:var(--eui-s-xs);border-bottom:1px solid var(--eui-c-divider);border-left:1px solid var(--eui-c-divider);content:\"\";margin-left:calc(-2 * var(--eui-s-l) + var(--eui-s-2xs));top:calc(.85 * var(--eui-s-l))}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep.eui-tree-node--last:before{height:auto;top:var(--eui-s-m)}.eui-19 .eui-tree:not(.eui-tree--show-lines) .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node:not(.eui-cdk-nested-tree-node--with-child){padding-inline-start:var(--eui-s-3xl)}.eui-19 .eui-tree:not(.eui-tree--show-lines).eui-tree--with-children div.eui-ul-rep{padding-inline-start:var(--eui-s-m)}.eui-19 .eui-dropdown-content .eui-tree.eui-tree--show-lines.eui-tree--with-children{padding-inline-start:var(--eui-s-xs)}\n"], dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "ngmodule", type: FormsModule }, { kind: "ngmodule", type: TranslateModule }, { kind: "pipe", type: i1.TranslatePipe, name: "translate" }, { kind: "ngmodule", type: ScrollingModule }, { kind: "directive", type: i2.CdkScrollable, selector: "[cdk-scrollable], [cdkScrollable]" }, { kind: "ngmodule", type: CdkTreeModule }, { kind: "directive", type: i3.CdkNestedTreeNode, selector: "cdk-nested-tree-node", exportAs: ["cdkNestedTreeNode"] }, { kind: "directive", type: i3.CdkTreeNodeDef, selector: "[cdkTreeNodeDef]", inputs: ["cdkTreeNodeDefWhen"] }, { kind: "directive", type: i3.CdkTreeNodeToggle, selector: "[cdkTreeNodeToggle]", inputs: ["cdkTreeNodeToggleRecursive"] }, { kind: "component", type: i3.CdkTree, selector: "cdk-tree", inputs: ["dataSource", "treeControl", "levelAccessor", "childrenAccessor", "trackBy", "expansionKey"], exportAs: ["cdkTree"] }, { kind: "directive", type: i3.CdkTreeNodeOutlet, selector: "[cdkTreeNodeOutlet]" }, { kind: "ngmodule", type: RouterModule }, { kind: "directive", type: i4.RouterLink, selector: "[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "state", "info", "relativeTo", "preserveFragment", "skipLocationChange", "replaceUrl", "routerLink"] }, { kind: "component", type: i5.EuiInputCheckboxComponent, selector: "input[euiInputCheckBox]", inputs: ["indeterminate", "isInvalid", "checked"], outputs: ["indeterminateChange"] }, { kind: "component", type: i6.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }, { kind: "component", type: i7.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i8.EuiLabelComponent, selector: "label[euiLabel], span[euiLabel], div[euiLabel], a[euiLabel], eui-label,               label[euiSublabel], span[euiSublabel], div[euiSublabel], a[euiSublabel], eui-sublabel", inputs: ["euiRequired", "euiReadonly", "euiSublabel"] }, { kind: "component", type: i9.EuiBadgeComponent, selector: "div[euiBadge], span[euiBadge], eui-badge", inputs: ["e2eAttr", "aria-label", "maxCharCount", "charReplacement", "euiIconBadge", "euiDottedBadge"] }, { kind: "component", type: i10.EuiChipComponent, selector: "eui-chip, span[euiChip], li[euiChip]", inputs: ["ariaLabel", "e2eAttr", "euiInternalId", "tooltipMessage", "id", "data", "isChipRemovable", "isSquared", "isFilled"], outputs: ["remove"] }, { kind: "component", type: i11.EuiDropdownComponent, selector: "eui-dropdown", inputs: ["e2eAttr", "tabIndex", "width", "height", "position", "subDropdownPosition", "isBlock", "isDropDownRightAligned", "hasClosedOnClickInside", "isLabelUpdatedFromSelectedItem", "isExpandOnHover", "hasTabNavigation", "isRightClickEnabled", "euiDisabled"], outputs: ["expand"] }, { kind: "directive", type: i11.EuiDropdownContentDirective, selector: "eui-dropdown-content" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-tree', changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [
                        NgIf,
                        NgSwitch,
                        NgFor,
                        NgTemplateOutlet,
                        FormsModule,
                        TranslateModule,
                        ScrollingModule,
                        CdkTreeModule,
                        RouterModule,
                        ...EUI_INPUT_CHECKBOX,
                        ...EUI_BUTTON,
                        ...EUI_ICON,
                        ...EUI_LABEL,
                        ...EUI_BADGE,
                        ...EUI_CHIP,
                        ...EUI_DROPDOWN,
                    ], template: "<div class=\"eui-ul-rep eui-tree__wrapper\" cdkScrollable #cdkScrollableRef>\n    <cdk-tree\n        #treeComponentInstance\n        [dataSource]=\"cdkArrayDataSource\"\n        [treeControl]=\"cdkTreeControl\"\n        [trackBy]=\"trackBy\"\n        *ngIf=\"renderTree\"\n        class=\"eui-cdk-tree\">\n        <!-- There are two states of generic cdk-nested-tree-node declarations.\n        First one is without child. No sub rendering.\n        -->\n        <cdk-nested-tree-node *cdkTreeNodeDef=\"let treeRunTimeItemModel\" class=\"eui-cdk-nested-tree-node\">\n            <div *ngIf=\"treeRunTimeItemModel\"\n                class=\"eui-li-rep eui-tree-node\"\n                [class.eui-tree-node--first]=\"treeRunTimeItemModel?.path === '0'\"\n                [class.eui-tree-node--last]=\"treeRunTimeItemModel.last\"\n                title=\"{{\n                    getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.tooltipLabel ||\n                        getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.label\n                }}\">\n                <div class=\"eui-tree-node-wrapper\"\n                     (click)=\"onNodeClick(treeRunTimeItemModel, $event)\">\n                    <div class=\"eui-tree-node-wrapper__container\">\n                        <!--\n                        Renders node in default or provided template's context.\n                        Generates onSelect with onSelectFn for developers to send the events from their custom check events.\n                        Provides id to be used on generic template\n                        -->\n                        <ng-container\n                            [ngTemplateOutlet]=\"nodeTemplateRef || nodeTemplateDefault\"\n                            [ngTemplateOutletContext]=\"{\n                                $implicit: getTreeItem(treeRunTimeItemModel?.path)?.node,\n                                onSelect: onSelectFn(treeRunTimeItemModel.path),\n                                id: uid + treeRunTimeItemModel.path,\n                                path: treeRunTimeItemModel.path\n                            }\">\n                        </ng-container>\n                    </div>\n                </div>\n            </div>\n        </cdk-nested-tree-node>\n        <!-- This is the tree node template for expandable nodes -->\n        <cdk-nested-tree-node\n            *cdkTreeNodeDef=\"let treeRunTimeItemModel; when: hasChild\"\n            class=\"eui-cdk-nested-tree-node eui-cdk-nested-tree-node--with-child\">\n            <div\n                class=\"eui-li-rep eui-tree-node eui-tree-node--with-child\"\n                [class.eui-tree-node--first]=\"treeRunTimeItemModel?.path === '0'\"\n                [class.eui-tree-node--last]=\"treeRunTimeItemModel.last\"\n                *ngIf=\"treeRunTimeItemModel\"\n                title=\"{{\n                    getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.tooltipLabel ||\n                        getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.label\n                }}\">\n                <div\n                    class=\"eui-tree-node-wrapper\">\n                    <!--Here wraps the node, and listen for node clicks.-->\n                    <div (click)=\"onNodeClick(treeRunTimeItemModel, $event)\" class=\"eui-tree-node-wrapper__container\">\n                        <!-- Expand/collapse action button -->\n                        <button\n                            euiButton\n                            euiIconButton\n                            euiBasicButton\n                            euiRounded\n                            euiSizeS\n                            type=\"button\"\n                            [attr.aria-label]=\"'Toggle ' + getTreeItem(treeRunTimeItemModel?.path)?.node?.treeContentBlock?.label\"\n                            (click)=\"onNodeToggle(treeRunTimeItemModel)\"\n                            cdkTreeNodeToggle\n                            class=\"eui-tree-node__button\">\n                            <eui-icon-svg\n                                *ngIf=\"!cdkTreeControl.isExpanded(treeRunTimeItemModel)\"\n                                [icon]=\"expandedSvgIconClass\"></eui-icon-svg>\n                            <eui-icon-svg\n                                *ngIf=\"cdkTreeControl.isExpanded(treeRunTimeItemModel)\"\n                                [icon]=\"collapsedSvgIconClass\"></eui-icon-svg>\n                        </button>\n                        <!--\n                        Renders node in default or provided template's context.\n                        Generates onSelect with onSelectFn for developers to send the events from their custom check events.\n                        Provides id to be used on generic template\n                        -->\n                        <ng-container\n                            [ngTemplateOutlet]=\"nodeTemplateRef || nodeTemplateDefault\"\n                            [ngTemplateOutletContext]=\"{\n                                $implicit: getTreeItem(treeRunTimeItemModel.path)?.node,\n                                onSelect: onSelectFn(treeRunTimeItemModel.path),\n                                id: uid + treeRunTimeItemModel.path,\n                                path: treeRunTimeItemModel.path,\n                                children: getTreeItem(treeRunTimeItemModel?.path)?.children\n                            }\">\n                        </ng-container>\n                    </div>\n                </div>\n                <!--uses cdkTreeNodeOutlet to render children nodes, CdkTreeControl is used to control isExpanded state.-->\n                <div class=\"eui-ul-rep eui-tree-node\" role=\"group\" *ngIf=\"cdkTreeControl.isExpanded(treeRunTimeItemModel)\">\n                    <ng-container cdkTreeNodeOutlet></ng-container>\n                </div>\n            </div>\n        </cdk-nested-tree-node>\n    </cdk-tree>\n</div>\n\n<ng-template #nodeTemplateDefault let-node let-onSelect=\"onSelect\" let-id=\"id\" let-path=\"path\">\n    <ng-container *ngIf=\"node\">\n        <div class=\"eui-tree-node-wrapper__container-left\" [class.eui-tree-node-wrapper__container-left--selected]=\"node?.isSelected\">\n            <!--input checkbox area-->\n            <input\n                euiInputCheckBox\n                *ngIf=\"node && node.selectable\"\n                type=\"checkbox\"\n                id=\"{{ id }}\"\n                [checked]=\"!!node?.isSelected\"\n                [indeterminate]=\"!!node?.isIndeterminate\"\n                (change)=\"onSelect($event)\" />\n\n            <!--icon area-->\n            <ng-container *ngIf=\"node?.treeContentBlock?.iconSvgName\">\n                <eui-icon-svg\n                    icon=\"{{ node?.treeContentBlock?.iconSvgName }}\"\n                    fillColor=\"{{ node?.treeContentBlock?.iconTypeClass || 'neutral' }}\"\n                    size=\"s\"\n                    class=\"eui-u-mr-xs\">\n                </eui-icon-svg>\n            </ng-container>\n\n            <!--chips area-->\n            <ng-container *ngIf=\"node?.treeContentBlock?.chips\">\n                <eui-chip\n                    *ngFor=\"let chip of node.treeContentBlock.chips\"\n                    euiSizeS\n                    [euiVariant]=\"chip.typeClass || 'secondary'\"\n                    [euiOutline]=\"chip.isOutline\"\n                    class=\"eui-chip--rounded eui-u-mr-xs\">\n                    <span euiLabel>{{ chip.label }}</span>\n                </eui-chip>\n            </ng-container>\n\n            <!--badge (typeLabel & typeClass) area-->\n            <ng-container *ngIf=\"node?.treeContentBlock?.typeLabel\" [ngSwitch]=\"node?.treeContentBlock?.typeClass\">\n                <eui-badge euiSizeM [euiVariant]=\"node?.treeContentBlock?.typeClass || 'primary'\" class=\"eui-u-flex-no-shrink eui-u-mr-xs\">\n                    {{ node?.treeContentBlock?.typeLabel }}\n                </eui-badge>\n            </ng-container>\n        </div>\n\n        <!--label area-->\n        <div class=\"eui-tree-node-wrapper__container-middle\">\n            <label\n                *ngIf=\"!node?.treeContentBlock?.url && !node?.treeContentBlock?.urlExternal\"\n                euiLabel\n                for=\"{{ id }}\"\n                class=\"eui-u-text-truncate eui-u-p-2xs\"\n                [class.eui-label--selected]=\"\n                    highlightPath\n                        ? getRunTimeSelectionRecursiveState(path)?.selectionRecursiveState === 'indeterminate' || node?.isSelected\n                        : node?.isSelected\n                \"\n                [class.eui-u-cursor-pointer]=\"node?.selectable\">\n                {{ autoTranslate ? (node?.treeContentBlock?.label | translate) : node?.treeContentBlock?.label }}\n            </label>\n            <label *ngIf=\"node?.treeContentBlock?.url\" euiLabel for=\"{{ id }}\" class=\"eui-u-text-truncate eui-u-p-2xs\">\n                <a\n                    class=\"eui-u-text-link\"\n                    [class.eui-u-text-link-standalone]=\"!showUnderlinedLinks\"\n                    [routerLink]=\"node?.treeContentBlock?.url\">\n                    {{ autoTranslate ? (node?.treeContentBlock?.label | translate) : node?.treeContentBlock?.label }}\n                </a>\n            </label>\n            <label *ngIf=\"node?.treeContentBlock?.urlExternal\" euiLabel for=\"{{ id }}\" class=\"eui-u-text-truncate eui-u-p-2xs\">\n                <a\n                    class=\"eui-u-text-link-external\"\n                    [class.eui-u-text-link-external-standalone]=\"!showUnderlinedLinks\"\n                    href=\"{{ node?.treeContentBlock?.urlExternal }}\"\n                    target=\"{{ node?.treeContentBlock?.urlExternalTarget || 'blank' }}\">\n                    {{ autoTranslate ? (node?.treeContentBlock?.label | translate) : node?.treeContentBlock?.label }}\n                </a>\n            </label>\n        </div>\n\n        <div *ngIf=\"node?.treeContentBlock?.rightContent\" class=\"eui-tree-node-wrapper__container-right\">\n            <!--badges area-->\n            <ng-container *ngFor=\"let badge of node.treeContentBlock.rightContent?.badges\">\n                <eui-badge euiOutline [euiVariant]=\"badge.typeClass || 'secondary'\" class=\"eui-u-ml-xs\">\n                    <span euiLabel>{{ badge.label }}</span>\n                </eui-badge>\n            </ng-container>\n\n            <!--chips area-->\n            <ng-container *ngFor=\"let chip of node.treeContentBlock.rightContent?.chips\">\n                <eui-chip\n                    euiSizeS\n                    [euiVariant]=\"chip.typeClass || 'secondary'\"\n                    [euiOutline]=\"chip.isOutline\"\n                    class=\"eui-chip--rounded eui-u-mb-none eui-u-ml-xs\">\n                    <span euiLabel>{{ chip.label }}</span>\n                </eui-chip>\n            </ng-container>\n\n            <!--Context menu-->\n            <ng-container *ngIf=\"node.treeContentBlock.rightContent?.contextMenuMetaData && rightContextMenuTemplateRef\">\n                <eui-dropdown class=\"eui-u-ml-xs\">\n                    <button euiButton euiSizeS euiRounded euiIconButton euiBasicButton euiSecondary [attr.aria-label]=\"'Options menu'\">\n                        <eui-icon-svg icon=\"ellipsis-vertical:sharp\"></eui-icon-svg>\n                    </button>\n                    <eui-dropdown-content>\n                        <ng-template\n                            [ngTemplateOutlet]=\"rightContextMenuTemplateRef\"\n                            [ngTemplateOutletContext]=\"{\n                                $implicit: node?.treeContentBlock?.rightContent?.contextMenuMetaData,\n                                metadata: node?.treeContentBlock?.rightContent?.contextMenuMetaData\n                            }\">\n                        </ng-template>\n                    </eui-dropdown-content>\n                </eui-dropdown>\n            </ng-container>\n        </div>\n\n        <!--metadata, uses the help of ng template to generate dynamic expand variable without handling state -->\n        <ng-container\n            *ngIf=\"node.treeContentBlock?.metadata && nodeContentMetadataTemplateRef\"\n            [ngTemplateOutlet]=\"nodeContentMetadataContainer\"\n            [ngTemplateOutletContext]=\"{\n                $implicit: { expanded: false }\n            }\" />\n        <ng-template #nodeContentMetadataContainer let-metaDataContainer>\n            <button\n                euiButton\n                euiBasicButton\n                euiIconButton\n                euiRounded\n                euiSizeS\n                type=\"button\"\n                aria-label=\"expand collapse tree item\"\n                (click)=\"metaDataContainer.expanded = !metaDataContainer.expanded\">\n                <eui-icon-svg [icon]=\"metaDataContainer.expanded ? 'chevron-down:sharp' : 'chevron-forward:sharp'\"></eui-icon-svg>\n            </button>\n            <div *ngIf=\"metaDataContainer.expanded\" class=\"eui-tree-node__metacontent\">\n                <!--passing metadata of the node content to provided template-ref:nodeContentMetadataTemplateRef-->\n                <ng-template\n                    [ngTemplateOutlet]=\"nodeContentMetadataTemplateRef\"\n                    [ngTemplateOutletContext]=\"{\n                        $implicit: node?.treeContentBlock?.metadata,\n                        metadata: node?.treeContentBlock?.metadata\n                    }\">\n                </ng-template>\n            </div>\n        </ng-template>\n    </ng-container>\n</ng-template>\n", styles: [".eui-19 .eui-tree{display:flex;overflow-x:hidden;overflow-y:auto;position:relative;width:100%}.eui-19 .eui-tree .eui-tree__wrapper{display:flex;list-style:none;margin:0;overflow-y:auto;padding:var(--eui-s-2xs);position:relative;width:100%}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar{display:inherit;height:8px;width:8px;background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar-thumb{background-color:var(--_eui-scrollbars-foreground-color);border-radius:5rem}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar-thumb:hover{background-color:var(--eui-c-neutral-lighter)}.eui-19 .eui-tree .eui-tree__wrapper::-webkit-scrollbar-track{background-color:var(--eui-c-neutral-bg-light);border-radius:0}@-moz-document url-prefix(){.eui-19 .eui-tree .eui-tree__wrapper{scrollbar-color:var(--eui-c-neutral-lighter) var(--eui-c-neutral-bg-light);scrollbar-width:auto}}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree{display:flex;flex-direction:column;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node{display:flex;width:auto}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node:not(.eui-cdk-nested-tree-node--with-child){padding-inline-start:var(--eui-s-xl)}.eui-19 .eui-tree .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node--with-child{display:flex;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node{display:flex;flex-direction:column;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node__metacontent{display:flex}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node__button{margin-left:calc(-3 * var(--eui-s-2xs))}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper{align-items:center;display:flex;min-height:var(--eui-s-2xl);width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper:hover{background-color:var(--eui-c-neutral-bg-light)}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container{align-items:center;display:flex;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container-left{align-items:center;display:flex;justify-content:flex-start}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container-middle{align-items:center;display:flex;justify-content:flex-start;overflow:hidden;width:100%}.eui-19 .eui-tree .eui-tree__wrapper .eui-tree-node-wrapper__container-right{align-items:center;display:flex;justify-content:flex-end;margin-left:auto}.eui-19 .eui-tree:not(.eui-tree--with-children) .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node{padding-inline-start:2px}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-ul-rep{padding-inline-start:var(--eui-s-2xs)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-ul-rep:before{border-left:1px solid var(--eui-c-divider);content:\"\";height:calc(100% - var(--eui-s-m) - var(--eui-s-xl));position:absolute;top:var(--eui-s-xl)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-ul-rep:first-child:before{height:calc(100% - var(--eui-s-m) - var(--eui-s-2xs));top:0}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep{padding-inline-start:var(--eui-s-s);position:relative}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep:before:not(.eui-tree-node--first){border-top:1px solid var(--eui-c-divider);content:\"\";display:block;height:0;left:0;position:absolute;top:var(--eui-s-m);width:var(--eui-s-xl)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep.eui-tree-node:not(.eui-tree-node--with-child):before{position:relative;left:0;display:inline-flex;width:var(--eui-s-2xl);border-bottom:1px solid var(--eui-c-divider);content:\"\";margin-left:calc(-2 * var(--eui-s-l) + var(--eui-s-2xs));top:var(--eui-s-m)}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep.eui-tree-node.eui-tree-node--with-child:before{position:absolute;left:calc(1 * var(--eui-s-2xl) + var(--eui-s-2xs));display:inline-flex;width:var(--eui-s-xs);border-bottom:1px solid var(--eui-c-divider);border-left:1px solid var(--eui-c-divider);content:\"\";margin-left:calc(-2 * var(--eui-s-l) + var(--eui-s-2xs));top:calc(.85 * var(--eui-s-l))}.eui-19 .eui-tree.eui-tree--show-lines.eui-tree--with-children div.eui-li-rep.eui-tree-node--last:before{height:auto;top:var(--eui-s-m)}.eui-19 .eui-tree:not(.eui-tree--show-lines) .eui-tree__wrapper .eui-cdk-tree .eui-cdk-nested-tree-node:not(.eui-cdk-nested-tree-node--with-child){padding-inline-start:var(--eui-s-3xl)}.eui-19 .eui-tree:not(.eui-tree--show-lines).eui-tree--with-children div.eui-ul-rep{padding-inline-start:var(--eui-s-m)}.eui-19 .eui-dropdown-content .eui-tree.eui-tree--show-lines.eui-tree--with-children{padding-inline-start:var(--eui-s-xs)}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], e2eAttr: [{
                type: HostBinding,
                args: ['attr.data-e2e']
            }, {
                type: Input
            }], nodes: [{
                type: Input
            }], nodeTemplateRef: [{
                type: Input
            }], nodeContentMetadataTemplateRef: [{
                type: Input
            }], rightContextMenuTemplateRef: [{
                type: Input
            }], customNodeSelectFn: [{
                type: Input
            }], expandedSvgIconClass: [{
                type: Input
            }], collapsedSvgIconClass: [{
                type: Input
            }], cdkScrollableRef: [{
                type: ViewChild,
                args: ['cdkScrollableRef', { read: CdkScrollable }]
            }], treeComponentInstance: [{
                type: ViewChild,
                args: ['treeComponentInstance']
            }], isClickTogglingNode: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isMultiselect: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isSingleSelect: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isRecursiveSelection: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isRecursiveParentSelection: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], showUnderlinedLinks: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], showLines: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], autoTranslate: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], highlightPath: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], selectionChange: [{
                type: Output
            }], nodeClick: [{
                type: Output
            }], nodeToggle: [{
                type: Output
            }] } });
/**
 * @description
 * Module that provides the EuiTree component and its dependencies
 */
class EuiTreeModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeModule, imports: [EuiTreeComponent], exports: [EuiTreeComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeModule, imports: [EuiTreeComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        EuiTreeComponent,
                    ],
                    exports: [EuiTreeComponent],
                }]
        }] });

class EuiDropdownTreeDirective {
    constructor() {
        this.changeDetectorRef = inject(ChangeDetectorRef);
        this.hostElement = inject(ElementRef);
        this.renderer = inject(Renderer2);
        this.euiDropdown = inject(EuiDropdownComponent, { host: true });
    }
    ngAfterContentInit() {
        this.buttonLabel = this.createButtonLabel(this.euiTree.getSelection());
        this.euiTree.selectionChange.subscribe((selectionChanges) => {
            this.buttonLabel = this.createButtonLabel(selectionChanges.selection);
            this.buttonViewRef.context.$implicit = this.buttonLabel;
            this.buttonViewRef.detectChanges();
        });
    }
    ngAfterViewInit() {
        if (this.buttonTemplateRef) {
            const triggerContainer = this.hostElement.nativeElement.querySelector('.eui-dropdown__trigger-container');
            if (!triggerContainer) {
                console.error('Could not find the triggerContainer');
                return;
            }
            while (triggerContainer.firstChild) {
                triggerContainer.removeChild(triggerContainer.firstChild);
            }
            this.buttonViewRef = this.buttonTemplateRef.createEmbeddedView({ $implicit: this.buttonLabel });
            this.buttonViewRef.detectChanges();
            this.buttonViewRef.rootNodes.forEach((node) => {
                if (node.nodeType === Node.ELEMENT_NODE) {
                    this.renderer.appendChild(triggerContainer, node);
                }
            });
        }
    }
    createButtonLabel(selection) {
        if (selection?.length > 0) {
            return this.euiTree
                .getSelection()
                ?.map((item) => item.node.treeContentBlock.label)
                .join(',');
        }
        return 'No node selected.';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDropdownTreeDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.12", type: EuiDropdownTreeDirective, isStandalone: true, selector: "eui-dropdown[euiDropdownTree]", inputs: { buttonTemplateRef: "buttonTemplateRef" }, queries: [{ propertyName: "euiTree", first: true, predicate: EuiTreeComponent, descendants: true }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDropdownTreeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'eui-dropdown[euiDropdownTree]',
                }]
        }], propDecorators: { buttonTemplateRef: [{
                type: Input
            }], euiTree: [{
                type: ContentChild,
                args: [EuiTreeComponent, { static: false }]
            }] } });
class EuiDropdownTreeDirectiveModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDropdownTreeDirectiveModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiDropdownTreeDirectiveModule, imports: [EuiDropdownTreeDirective], exports: [EuiDropdownTreeDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDropdownTreeDirectiveModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiDropdownTreeDirectiveModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiDropdownTreeDirective],
                    exports: [EuiDropdownTreeDirective],
                }]
        }] });

class EuiTreeHelper {
    constructor(treeData) {
        this.treeData = treeData;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getPath(value, identifierKey = 'node.treeContentBlock.id') {
        if (typeof value !== 'undefined') {
            const paths = [];
            this.traverse(this.treeData, '', [value], paths, undefined, identifierKey);
            return paths[0];
        }
        return null;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getPaths(values, identifierKey) {
        const paths = [];
        this.traverse(this.treeData, '', values, paths, undefined, identifierKey);
        return paths;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getItems(values, identifierKey) {
        const matchedItems = [];
        this.traverse(this.treeData, '', values, undefined, matchedItems, identifierKey);
        return matchedItems;
    }
    traverse(tree, currentPath, 
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    values, paths, items, identifierKey) {
        for (const [i, item] of tree.entries()) {
            const valueToCheck = identifierKey ? this.getValueAtKey(item, identifierKey) : item;
            if (values.some((v) => this.deepEqual(v, valueToCheck))) {
                if (paths)
                    paths.push(`${currentPath}${i}`);
                if (items)
                    items.push(item);
            }
            if (item.children && item.children.length) {
                this.traverse(item.children, `${currentPath}${i}.`, values, paths, items, identifierKey);
            }
        }
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    getValueAtKey(object, key) {
        const keys = key.split('.');
        let current = object;
        for (const k of keys) {
            if (current[k] !== undefined) {
                current = current[k];
            }
            else {
                return undefined;
            }
        }
        return current;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    deepEqual(obj1, obj2) {
        if (obj1 === obj2) {
            return true;
        }
        if (typeof obj1 !== 'object' || obj1 === null || typeof obj2 !== 'object' || obj2 === null) {
            return false;
        }
        const keys1 = Object.keys(obj1);
        const keys2 = Object.keys(obj2);
        if (keys1.length !== keys2.length) {
            return false;
        }
        for (const key of keys1) {
            if (!keys2.includes(key) || !this.deepEqual(obj1[key], obj2[key])) {
                return false;
            }
        }
        return true;
    }
}

class EuiTreeFormControlDirective {
    constructor() {
        this.tree = inject(EuiTreeComponent, { host: true });
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.euiTreeControlValueSetter = (selection) => {
            return new EuiTreeHelper(this.tree.nodes).getItems(selection.map(item => item.node.treeContentBlock.id), 'node.treeContentBlock.id');
        };
        // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        this.euiTreeControlModelMapper = (model) => {
            return model;
        };
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    writeValue(value) {
        this.tree.setAllSelection(false);
        if (typeof value !== 'undefined' && value !== null && value?.length > 0) {
            const initialItems = this.euiTreeControlModelMapper(value, this.tree.nodes);
            const paths = new EuiTreeHelper(this.tree.nodes).getPaths(initialItems);
            paths.forEach((path) => {
                this.tree.nodeSelected({ target: { checked: true } }, path);
            });
        }
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnChange(fn) {
        this.onChange = fn;
    }
    // TODO: find the correct type or turn into a generic, https://www.typescriptlang.org/docs/handbook/2/generics.html
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    ngAfterContentInit() {
        this.tree.selectionChange.subscribe((selectionChanges) => {
            this.onChange(this.euiTreeControlValueSetter(selectionChanges.selection));
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeFormControlDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.12", type: EuiTreeFormControlDirective, isStandalone: true, selector: "eui-tree[euiTreeFormControl]", inputs: { euiTreeControlValueSetter: "euiTreeControlValueSetter", euiTreeControlModelMapper: "euiTreeControlModelMapper" }, providers: [
            {
                provide: NG_VALUE_ACCESSOR,
                useExisting: forwardRef(() => EuiTreeFormControlDirective),
                multi: true,
            },
        ], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeFormControlDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'eui-tree[euiTreeFormControl]',
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => EuiTreeFormControlDirective),
                            multi: true,
                        },
                    ],
                }]
        }], propDecorators: { euiTreeControlValueSetter: [{
                type: Input
            }], euiTreeControlModelMapper: [{
                type: Input
            }] } });
class EuiTreeFormControlDirectiveModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeFormControlDirectiveModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeFormControlDirectiveModule, imports: [EuiTreeFormControlDirective], exports: [EuiTreeFormControlDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeFormControlDirectiveModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiTreeFormControlDirectiveModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [EuiTreeFormControlDirective],
                    exports: [EuiTreeFormControlDirective],
                }]
        }] });

const EUI_TREE = [
    EuiTreeComponent,
];
// export { EuiTreeComponent as EuiTree } from './eui-tree.component';

/**
 * Generated bundle index. Do not edit.
 */

export { CustomNodeSelectFnHelper, EUI_TREE, EuiDropdownTreeDirective, EuiDropdownTreeDirectiveModule, EuiTreeComponent, EuiTreeFormControlDirective, EuiTreeFormControlDirectiveModule, EuiTreeHelper, EuiTreeModule, EuiTreePagination, uxTreeNodesMetaDataMapper };
//# sourceMappingURL=eui-components-eui-tree.mjs.map
