import * as i0 from '@angular/core';
import { inject, EventEmitter, computed, booleanAttribute, Output, Input, HostBinding, ViewEncapsulation, ChangeDetectionStrategy, Component, ElementRef, HostListener, forwardRef, ContentChildren, ChangeDetectorRef, ViewChild, NgModule } from '@angular/core';
import { UserService } from '@eui/core';
import * as i2 from '@eui/components/eui-icon-button';
import { EUI_ICON_BUTTON } from '@eui/components/eui-icon-button';
import * as i1 from '@eui/components/eui-button';
import { EUI_BUTTON } from '@eui/components/eui-button';
import * as i3 from '@eui/components/eui-icon';
import { EUI_ICON } from '@eui/components/eui-icon';
import * as i4 from '@eui/components/eui-avatar';
import { EUI_AVATAR } from '@eui/components/eui-avatar';
import { FocusKeyManager } from '@angular/cdk/a11y';
import { Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';
import * as i2$1 from '@eui/components/eui-dropdown';
import { EuiDropdownService, EUI_DROPDOWN } from '@eui/components/eui-dropdown';
import * as i1$1 from '@eui/components/shared';
import { BaseStatesDirective } from '@eui/components/shared';
import { NgTemplateOutlet } from '@angular/common';
import * as i5 from '@eui/components/eui-badge';
import { EUI_BADGE } from '@eui/components/eui-badge';

class EuiUserProfileCardComponent {
    constructor() {
        this.userState = inject(UserService).getSignal();
        /**
         * If true, the user is online
         * @deprecated This property is not used anymore
         */
        this.isOnline = true;
        this.impersonateLabel = 'impersonating';
        this.showDetailsLabel = 'Show profile details';
        this.isShowAvatarInitials = false;
        /**
         * If true, the name will be displayed in reverse order (first name, first)
         */
        this.reverseNameOrder = false;
        this.showProfileInfo = new EventEmitter();
        this.closeProfileMenu = new EventEmitter();
    }
    get cssClasses() {
        return 'eui-user-profile-card';
    }
    ngOnInit() {
        this.avatarInitials = computed(() => {
            const firstNameInitial = this.userState().firstName?.substring(0, 1).toUpperCase();
            const lastNameInitial = this.userState().lastName?.substring(0, 1).toUpperCase();
            return this.reverseNameOrder ?
                `${firstNameInitial}${lastNameInitial}`
                : `${lastNameInitial}${firstNameInitial}`;
        });
        this.fullName = computed(() => {
            const user = this.userState();
            const impersonated = this.userState().impersonatingUser;
            const fullName = (user) => {
                return this.reverseNameOrder
                    ? `${user.firstName} ${user.lastName}`
                    : `${user.lastName} ${user.firstName}`;
            };
            return {
                user: fullName(user),
                impersonated: impersonated ? fullName(impersonated) : undefined,
            };
        });
    }
    onShowInfoClick() {
        this.showProfileInfo.emit();
    }
    onClose() {
        this.closeProfileMenu.emit();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileCardComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiUserProfileCardComponent, isStandalone: true, selector: "eui-user-profile-card", inputs: { impersonateLabel: "impersonateLabel", showDetailsLabel: "showDetailsLabel", avatarUrl: "avatarUrl", isShowAvatarInitials: ["isShowAvatarInitials", "isShowAvatarInitials", booleanAttribute], reverseNameOrder: "reverseNameOrder" }, outputs: { showProfileInfo: "showProfileInfo", closeProfileMenu: "closeProfileMenu" }, host: { properties: { "class": "this.cssClasses" } }, ngImport: i0, template: "<div class=\"eui-user-profile-card__main-wrapper\">\n    <div class=\"eui-user-profile-card__avatar-wrapper\">\n        <eui-avatar euiSizeL isFlat>\n            @if (isShowAvatarInitials) {\n                <eui-avatar-text>\n                    {{ avatarInitials() }}\n                </eui-avatar-text>\n            } @else {\n                @if (!avatarUrl) {\n                    <eui-avatar-image></eui-avatar-image>\n                }\n                @if (avatarUrl) {\n                    <eui-avatar-image [imageUrl]=\"avatarUrl\"></eui-avatar-image>\n                }\n            }\n        </eui-avatar>\n    </div>\n    <div class=\"eui-user-profile-card__userInfos\">\n        <div class=\"eui-u-f-xl eui-u-mb-s\">{{ fullName().user }}</div>\n        @if (userState().function) {\n            <div class=\"eui-user-profile-card__userInfos-item\">\n                {{ userState().function }}\n            </div>\n        }\n        @if (userState().organisation && userState().organisation.code) {\n            <div class=\"eui-user-profile-card__userInfos-item\">\n                {{ userState().organisation.code }}\n            </div>\n        }\n    </div>\n    <div class=\"eui-user-profile-card__main-wrapper-right-content\">\n        <eui-icon-button icon=\"close:outline\" size=\"s\" euiRounded (buttonClick)=\"onClose()\"/>\n        <button euiButton euiIconButton euiInfo euiSizeS class=\"eui-u-ml-auto eui-u-mt-m\" tabindex=\"0\" (click)=\"onShowInfoClick()\" title=\"{{ showDetailsLabel }}\">\n            <eui-icon-svg icon=\"information:outline\"></eui-icon-svg>\n        </button>\n    </div>\n</div>\n\n@if (userState()?.impersonatingUser) {\n    <div class=\"eui-user-profile-card__impersonateInfos\">\n        <div>{{ fullName()?.impersonated }}</div>\n        <div class=\"eui-u-mt-2xs\">{{ impersonateLabel }}</div>\n        <div class=\"eui-u-mt-2xs\">\n            <strong>{{ fullName().user }}</strong>\n        </div>\n    </div>\n}\n", dependencies: [{ kind: "component", type: i1.EuiButtonComponent, selector: "button[euiButton], a[euiButton]", inputs: ["e2eAttr", "id", "euiBasicButton", "euiButtonCall", "euiCTAButton", "euiBlockButton", "euiIconButton", "euiAvatarButton", "euiLineWrap", "isCompact", "hasNoFocusRing", "isChecked", "euiDisabled"], outputs: ["buttonClick"] }, { kind: "component", type: i2.EuiIconButtonComponent, selector: "eui-icon-button", inputs: ["icon", "iconUrl", "fillColor", "size", "ariaLabel", "tabindex", "hasNoPadding", "hasFocusHoverColor", "hasFocusHoverBg", "euiRounded", "euiDisabled"], outputs: ["buttonClick"] }, { kind: "component", type: i3.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i4.EuiAvatarComponent, selector: "div[euiAvatar], span[euiAvatar], eui-avatar", inputs: ["e2eAttr", "aria-label", "hasShadow", "isShapeSquare", "isFlat", "hasNoBackground", "isReverse"] }, { kind: "component", type: i4.EuiAvatarTextComponent, selector: "eui-avatar-text" }, { kind: "component", type: i4.EuiAvatarImageComponent, selector: "eui-avatar-image", inputs: ["imageUrl"] }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileCardComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-user-profile-card', changeDetection: ChangeDetectionStrategy.Default, encapsulation: ViewEncapsulation.None, imports: [
                        ...EUI_BUTTON,
                        ...EUI_ICON_BUTTON,
                        ...EUI_ICON,
                        ...EUI_AVATAR,
                    ], template: "<div class=\"eui-user-profile-card__main-wrapper\">\n    <div class=\"eui-user-profile-card__avatar-wrapper\">\n        <eui-avatar euiSizeL isFlat>\n            @if (isShowAvatarInitials) {\n                <eui-avatar-text>\n                    {{ avatarInitials() }}\n                </eui-avatar-text>\n            } @else {\n                @if (!avatarUrl) {\n                    <eui-avatar-image></eui-avatar-image>\n                }\n                @if (avatarUrl) {\n                    <eui-avatar-image [imageUrl]=\"avatarUrl\"></eui-avatar-image>\n                }\n            }\n        </eui-avatar>\n    </div>\n    <div class=\"eui-user-profile-card__userInfos\">\n        <div class=\"eui-u-f-xl eui-u-mb-s\">{{ fullName().user }}</div>\n        @if (userState().function) {\n            <div class=\"eui-user-profile-card__userInfos-item\">\n                {{ userState().function }}\n            </div>\n        }\n        @if (userState().organisation && userState().organisation.code) {\n            <div class=\"eui-user-profile-card__userInfos-item\">\n                {{ userState().organisation.code }}\n            </div>\n        }\n    </div>\n    <div class=\"eui-user-profile-card__main-wrapper-right-content\">\n        <eui-icon-button icon=\"close:outline\" size=\"s\" euiRounded (buttonClick)=\"onClose()\"/>\n        <button euiButton euiIconButton euiInfo euiSizeS class=\"eui-u-ml-auto eui-u-mt-m\" tabindex=\"0\" (click)=\"onShowInfoClick()\" title=\"{{ showDetailsLabel }}\">\n            <eui-icon-svg icon=\"information:outline\"></eui-icon-svg>\n        </button>\n    </div>\n</div>\n\n@if (userState()?.impersonatingUser) {\n    <div class=\"eui-user-profile-card__impersonateInfos\">\n        <div>{{ fullName()?.impersonated }}</div>\n        <div class=\"eui-u-mt-2xs\">{{ impersonateLabel }}</div>\n        <div class=\"eui-u-mt-2xs\">\n            <strong>{{ fullName().user }}</strong>\n        </div>\n    </div>\n}\n" }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], impersonateLabel: [{
                type: Input
            }], showDetailsLabel: [{
                type: Input
            }], avatarUrl: [{
                type: Input
            }], isShowAvatarInitials: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], reverseNameOrder: [{
                type: Input
            }], showProfileInfo: [{
                type: Output
            }], closeProfileMenu: [{
                type: Output
            }] } });

class EuiUserProfileMenuItemComponent {
    constructor() {
        this.class = 'eui-user-profile-menu-item';
        this.tabindex = '-1';
        this.role = 'menuitem';
        this.element = inject(ElementRef);
    }
    focus() {
        this.element.nativeElement.focus();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileMenuItemComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.12", type: EuiUserProfileMenuItemComponent, isStandalone: true, selector: "eui-user-profile-menu-item", host: { properties: { "class": "this.class", "attr.tabindex": "this.tabindex", "attr.role": "this.role" } }, ngImport: i0, template: '<ng-content/>', isInline: true, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileMenuItemComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'eui-user-profile-menu-item',
                    template: '<ng-content/>',
                    encapsulation: ViewEncapsulation.None,
                }]
        }], propDecorators: { class: [{
                type: HostBinding,
                args: ['class']
            }], tabindex: [{
                type: HostBinding,
                args: ['attr.tabindex']
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }] } });

class EuiUserProfileMenuComponent {
    constructor() {
        this.class = 'eui-user-profile-menu';
        this.role = 'menu';
        this.destroy$ = new Subject();
        this.dropdownService = inject(EuiDropdownService);
    }
    onKeydown(event) {
        if (this.focusKeyManager) {
            this.focusKeyManager.onKeydown(event);
        }
    }
    ngAfterContentInit() {
        this.dropdownService.isDropdownOpen.pipe(takeUntil(this.destroy$)).subscribe((isOpen) => {
            if (isOpen) {
                this.focusKeyManager = new FocusKeyManager(this.items).withWrap();
                this.focusKeyManager.setFirstItemActive();
            }
        });
    }
    ngOnDestroy() {
        this.destroy$.next(true);
        this.destroy$.unsubscribe();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileMenuComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.12", type: EuiUserProfileMenuComponent, isStandalone: true, selector: "eui-user-profile-menu", host: { listeners: { "keydown": "onKeydown($event)" }, properties: { "class": "this.class", "attr.role": "this.role" } }, queries: [{ propertyName: "items", predicate: i0.forwardRef(() => EuiUserProfileMenuItemComponent) }], ngImport: i0, template: '<ng-content/>', isInline: true, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileMenuComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'eui-user-profile-menu',
                    template: '<ng-content/>',
                    encapsulation: ViewEncapsulation.None,
                }]
        }], propDecorators: { class: [{
                type: HostBinding
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], items: [{
                type: ContentChildren,
                args: [forwardRef(() => EuiUserProfileMenuItemComponent)]
            }], onKeydown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

class EuiUserProfileComponent {
    constructor() {
        this.welcomeLabel = 'Welcome';
        this.impersonateLabel = 'impersonating';
        this.statusVariant = 'success';
        this.hasMenu = false;
        this.hasWelcomeLabel = true;
        this.isShowAvatarInitials = false;
        this.hasTabNavigation = false;
        this.isReverse = false;
        this.hasToggle = false;
        this.isHeaderUserProfile = false;
        this.isToolbarUserProfile = false;
        this.isShowUserInfos = true;
        this.isMobileOnly = true;
        this.euiStatusSecondary = false;
        this.euiStatusSuccess = false;
        this.euiStatusDanger = false;
        /**
         * If true, the name will be displayed in reverse order (first name, first)
         */
        this.reverseNameOrder = false;
        this.isDropdownOpen = false;
        this.baseStatesDirective = inject(BaseStatesDirective);
        this.unsubscribeSubject$ = new Subject();
        this.elRef = inject(ElementRef);
        this.cd = inject(ChangeDetectorRef);
        this.userService = inject(UserService);
    }
    get cssClasses() {
        return [
            this.baseStatesDirective.getCssClasses('eui-user-profile'),
            this.isReverse ? 'eui-user-profile--reverse' : '',
            this.isShowAvatarInitials ? 'eui-user-profile--initials' : '',
        ].join(' ').trim();
    }
    ngOnInit() {
        this.userState = this.userService.getSignal();
        this.avatarInitials = computed(() => {
            const firstNameInitial = this.userState().firstName?.substring(0, 1).toUpperCase();
            const lastNameInitial = this.userState().lastName?.substring(0, 1).toUpperCase();
            return this.reverseNameOrder ?
                `${firstNameInitial}${lastNameInitial}`
                : `${lastNameInitial}${firstNameInitial}`;
        });
    }
    ngAfterViewInit() {
        this.cd.markForCheck();
        let hasToolbarItemParent = false, toolbar;
        if (this.isToolbarUserProfile) {
            this.baseStatesDirective.euiSizeS = true;
            this.hasMenu = this.hasMenuContent.length !== 0;
        }
        else {
            try {
                hasToolbarItemParent = this.elRef.nativeElement.closest('eui-toolbar-item');
                toolbar = this.elRef.nativeElement.closest('eui-toolbar');
            }
            catch (e) {
                // do nothing
            }
            setTimeout(() => {
                if (hasToolbarItemParent) {
                    this.baseStatesDirective.euiSizeS = true;
                    if (toolbar && toolbar.classList.contains('eui--secondary') || this.baseStatesDirective.euiSecondary) {
                        this.baseStatesDirective.euiSecondary = true;
                    }
                    else {
                        this.baseStatesDirective.euiPrimary = true;
                    }
                }
                if (hasToolbarItemParent || !this.isHeaderUserProfile) {
                    this.hasMenu = this.hasMenuContent.length !== 0;
                }
                if (this.isMobileOnly) {
                    this.baseStatesDirective.euiSizeS = true;
                }
                this.cd.markForCheck();
            });
        }
    }
    ngOnDestroy() {
        this.unsubscribeSubject$.next();
        this.unsubscribeSubject$.complete();
    }
    closeDropdown() {
        this.dropdown.closeDropdown();
        this.isDropdownOpen = false;
    }
    onDropdownExpand(isOpen) {
        this.isDropdownOpen = isOpen;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.12", type: EuiUserProfileComponent, isStandalone: true, selector: "eui-user-profile", inputs: { welcomeLabel: "welcomeLabel", impersonateLabel: "impersonateLabel", avatarUrl: "avatarUrl", subInfos: "subInfos", statusVariant: "statusVariant", hasMenu: ["hasMenu", "hasMenu", booleanAttribute], hasWelcomeLabel: ["hasWelcomeLabel", "hasWelcomeLabel", booleanAttribute], isShowAvatarInitials: ["isShowAvatarInitials", "isShowAvatarInitials", booleanAttribute], hasTabNavigation: ["hasTabNavigation", "hasTabNavigation", booleanAttribute], isReverse: ["isReverse", "isReverse", booleanAttribute], hasToggle: ["hasToggle", "hasToggle", booleanAttribute], isHeaderUserProfile: ["isHeaderUserProfile", "isHeaderUserProfile", booleanAttribute], isToolbarUserProfile: ["isToolbarUserProfile", "isToolbarUserProfile", booleanAttribute], isShowUserInfos: ["isShowUserInfos", "isShowUserInfos", booleanAttribute], isMobileOnly: ["isMobileOnly", "isMobileOnly", booleanAttribute], euiStatusSecondary: ["euiStatusSecondary", "euiStatusSecondary", booleanAttribute], euiStatusSuccess: ["euiStatusSuccess", "euiStatusSuccess", booleanAttribute], euiStatusDanger: ["euiStatusDanger", "euiStatusDanger", booleanAttribute], reverseNameOrder: "reverseNameOrder" }, host: { properties: { "class": "this.cssClasses" } }, providers: [EuiDropdownService], queries: [{ propertyName: "hasMenuContent", predicate: i0.forwardRef(() => EuiUserProfileMenuComponent), descendants: true }], viewQueries: [{ propertyName: "dropdown", first: true, predicate: ["dropdown"], descendants: true }], hostDirectives: [{ directive: i1$1.BaseStatesDirective, inputs: ["euiSizeS", "euiSizeS", "euiSecondary", "euiSecondary", "euiPrimary", "euiPrimary"] }], ngImport: i0, template: "@if (hasMenu) {\n    <eui-dropdown [hasTabNavigation]=\"hasTabNavigation\" width=\"340px\" #dropdown (expand)=\"onDropdownExpand($event)\">\n        <ng-container *ngTemplateOutlet=\"userProfileContent\"/>\n        <eui-dropdown-content>\n            <ng-content/>\n        </eui-dropdown-content>\n    </eui-dropdown>\n} @else {\n    <ng-container *ngTemplateOutlet=\"userProfileContent\"/>\n}\n\n<ng-template #userProfileContent>\n    <button class=\"eui-user-profile-content\" [tabindex]=\"hasMenu ? '0' : '-1'\" [class.eui-user-profile-content--no-menu]=\"!hasMenu\">\n\n        @if (isShowUserInfos) {\n            <div class=\"eui-user-profile__infos\">\n                @if (userState()?.impersonatingUser) {\n                    <div class=\"eui-user-profile__infos-welcome\">\n                        @if (hasWelcomeLabel) {\n                            <span>{{ welcomeLabel }}&nbsp;</span>\n                        }\n                        @if(reverseNameOrder) {\n                            {{ userState()?.impersonatingUser?.firstName }} <strong>{{ userState()?.impersonatingUser?.lastName}}&nbsp;</strong>\n                        } @else {\n                            <strong>{{ userState()?.impersonatingUser?.lastName }}</strong> {{ userState()?.impersonatingUser?.firstName }}\n                        }\n                        <span>{{ impersonateLabel }}</span>\n                    </div>\n                    <div class=\"eui-user-profile__infos-name\">\n                        @if(reverseNameOrder) {\n                            {{ userState()?.firstName }} <strong>{{ userState()?.lastName }}</strong>\n                        } @else {\n                            <strong>{{ userState()?.lastName }}</strong> {{ userState()?.firstName }}\n                        }\n                    </div>\n                    @if (subInfos) {\n                        <div class=\"eui-user-profile__infos-subinfos\">{{ subInfos }}</div>\n                    }\n                } @else {\n                    @if (hasWelcomeLabel) {\n                        <div class=\"eui-user-profile__infos-welcome\">{{ welcomeLabel }}</div>\n                    }\n                    <div class=\"eui-user-profile__infos-name\">\n                        @if(reverseNameOrder) {\n                            {{ userState()?.firstName }} <strong>{{ userState()?.lastName }}</strong>\n                        } @else {\n                            <strong>{{ userState()?.lastName }}</strong> {{ userState()?.firstName }}\n                        }\n                    </div>\n                    @if (subInfos) {\n                        <div class=\"eui-user-profile__infos-subinfos\">{{ subInfos }}</div>\n                    }\n                }\n            </div>\n        }\n\n        <eui-avatar isFlat [euiSizeS]=\"baseStatesDirective.euiSizeS\" [hasShadow]=\"userState()?.impersonatingUser\">\n\n            @if (isShowAvatarInitials) {\n                <eui-avatar-text>{{ avatarInitials() }}</eui-avatar-text>\n            } @else {\n                <eui-avatar-image [imageUrl]=\"avatarUrl\"/>\n            }\n\n            @if (euiStatusSecondary || euiStatusSuccess || euiStatusDanger) {\n                <eui-avatar-badge position=\"bottom\">\n                    @if (euiStatusSuccess) {\n                        <eui-badge euiSuccess euiSizeS euiIconBadge>\n                            <eui-icon-svg icon=\"checkmark:outline\" size=\"xs\"/>\n                        </eui-badge>\n                    } @else if (euiStatusDanger) {\n                        <eui-badge euiDanger euiSizeS euiIconBadge>\n                            <eui-icon-svg icon=\"remove:outline\" size=\"xs\"/>\n                        </eui-badge>\n                    } @else if (euiStatusSecondary) {\n                        <eui-badge euiSecondary euiSizeS euiIconBadge>\n                            <eui-icon-svg icon=\"close-circle:outline\" fillColor=\"neutral\" size=\"xs\"/>\n                        </eui-badge>\n                    }\n                </eui-avatar-badge>\n            }\n        </eui-avatar>\n\n        @if (hasMenu || hasToggle) {\n            @if (isDropdownOpen) {\n                <eui-icon-svg icon=\"chevron-up:sharp\" size=\"xs\" class=\"eui-user-profile__drop-indicator\"/>\n            } @else {\n                <eui-icon-svg icon=\"chevron-down:sharp\" size=\"xs\" class=\"eui-user-profile__drop-indicator\"/>\n            }\n        }\n    </button>\n</ng-template>\n", styles: [".eui-19 .eui-user-profile{display:flex;position:relative}.eui-19 .eui-user-profile-content{align-items:center;background:none;border:var(--eui-bw-none);cursor:pointer;display:flex;padding:var(--eui-s-2xs) 0;gap:var(--eui-s-xs)}.eui-19 .eui-user-profile-content:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-content--no-menu{cursor:default}.eui-19 .eui-user-profile__infos{align-items:flex-end;display:flex;flex-direction:column}.eui-19 .eui-user-profile__infos-container{justify-content:flex-end;align-items:center;display:flex;width:100%}.eui-19 .eui-user-profile__infos-welcome{text-align:right;font:var(--eui-f-xs-compact)}.eui-19 .eui-user-profile__infos-name{color:var(--eui-c-branding);text-align:right;font:var(--eui-f-m-compact)}.eui-19 .eui-user-profile__infos-subinfos{color:var(--eui-c-neutral);text-align:right;font:var(--eui-f-xs-compact)}.eui-19 .eui-user-profile__drop-indicator{margin-left:calc(-1 * var(--eui-s-xs))}.eui-19 .eui--secondary .eui-user-profile__infos-name,.eui-19 .eui--secondary .eui-user-profile__infos-welcome{color:var(--eui-c-neutral)!important}@media screen and (max-width: 767px){.eui-19 .eui-app-shell-header-toolbar-items .eui-user-profile{display:flex}.eui-19 .eui-app .eui-app-toolbar .eui-user-profile__infos{display:none}}@media screen and (min-width: 768px){.eui-19 .eui-app-shell-header-toolbar-items .eui-user-profile{display:none}.eui-19 .is-header-shrink .eui-user-profile{display:flex}}@media screen and (min-width: 768px) and (max-width: 995px){.eui-19 .eui-app .eui-app-toolbar .eui-user-profile__infos{display:none}}.eui-19 .eui-user-profile--primary .eui-user-profile__infos-name{color:var(--eui-c-white)}.eui-19 .eui-user-profile--primary .eui-user-profile__infos-welcome,.eui-19 .eui-user-profile--primary .eui-user-profile__infos-subinfos{color:var(--eui-c-neutral-lightest)}.eui-19 .eui-user-profile--primary .eui-user-profile__drop-indicator svg{fill:var(--eui-c-white);color:var(--eui-c-white)}.eui-19 .eui-user-profile--reverse .eui-user-profile-content{flex-direction:row-reverse}.eui-19 .eui-user-profile--reverse .eui-user-profile__infos{margin-left:var(--eui-s-m)}.eui-19 .eui-user-profile--initials .eui-avatar-wrapper{background-color:var(--eui-c-branding-light)!important}.eui-19 .eui-user-profile--initials .eui-avatar-text{color:var(--eui-c-branding-light-contrast)!important}.eui-19 .eui-user-profile-menu{height:auto;min-width:250px;position:relative}.eui-19 .eui-user-profile-menu-item{align-items:center;border-bottom:1px solid var(--eui-c-divider);cursor:pointer;display:flex;padding:var(--eui-s-xs) var(--eui-s-s);gap:var(--eui-s-xs)}.eui-19 .eui-user-profile-menu-item:focus:not([readonly]){outline:2px solid var(--eui-c-focus)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-menu-item:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-menu-item [tabindex=\"0\"]:focus:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-menu-item:hover{background-color:var(--eui-c-hover);cursor:pointer}.eui-19 .eui-user-profile-menu-item:last-child{border-bottom:0}.eui-19 .eui-user-profile-menu-item a{color:var(--eui-c-text);text-decoration:none}.eui-19 .eui-user-profile-menu-item.link{cursor:pointer}.eui-19 .eui-user-profile-menu-item-right-content{margin-left:auto}.eui-19 .eui-user-profile-card{width:100%}.eui-19 .eui-user-profile-card__main-wrapper{display:flex;flex-direction:row;padding:var(--eui-s-m) var(--eui-s-m) var(--eui-s-m) 0}.eui-19 .eui-user-profile-card__main-wrapper-right-content{display:flex;flex-direction:column;margin-left:auto}.eui-19 .eui-user-profile-card__avatar-wrapper{display:flex}.eui-19 .eui-user-profile-card__userInfos{display:flex;flex-direction:column;padding-left:var(--eui-s-s)}.eui-19 .eui-user-profile-card__userInfos-item{padding-bottom:var(--eui-s-xs)}.eui-19 .eui-user-profile-card__impersonateInfos{background-color:var(--eui-c-neutral-bg-light);padding:var(--eui-s-s)}\n"], dependencies: [{ kind: "directive", type: NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: i2$1.EuiDropdownComponent, selector: "eui-dropdown", inputs: ["e2eAttr", "tabIndex", "width", "height", "position", "subDropdownPosition", "isBlock", "isDropDownRightAligned", "hasClosedOnClickInside", "isLabelUpdatedFromSelectedItem", "isExpandOnHover", "hasTabNavigation", "isRightClickEnabled", "euiDisabled"], outputs: ["expand"] }, { kind: "directive", type: i2$1.EuiDropdownContentDirective, selector: "eui-dropdown-content" }, { kind: "component", type: i3.EuiIconSvgComponent, selector: "eui-icon-svg, span[euiIconSvg], i[euiIconSvg]", inputs: ["icon", "fillColor", "set", "size", "style", "iconUrl", "transform", "euiVariant", "aria-label", "ariaHidden", "focusable", "isLoading", "isInputIcon", "euiStart", "euiEnd"] }, { kind: "component", type: i4.EuiAvatarComponent, selector: "div[euiAvatar], span[euiAvatar], eui-avatar", inputs: ["e2eAttr", "aria-label", "hasShadow", "isShapeSquare", "isFlat", "hasNoBackground", "isReverse"] }, { kind: "component", type: i4.EuiAvatarTextComponent, selector: "eui-avatar-text" }, { kind: "component", type: i4.EuiAvatarImageComponent, selector: "eui-avatar-image", inputs: ["imageUrl"] }, { kind: "component", type: i4.EuiAvatarBadgeComponent, selector: "eui-avatar-badge", inputs: ["isPositionBottom", "position"] }, { kind: "component", type: i5.EuiBadgeComponent, selector: "div[euiBadge], span[euiBadge], eui-badge", inputs: ["e2eAttr", "aria-label", "maxCharCount", "charReplacement", "euiIconBadge", "euiDottedBadge"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eui-user-profile', encapsulation: ViewEncapsulation.None, imports: [
                        NgTemplateOutlet,
                        ...EUI_DROPDOWN,
                        ...EUI_ICON,
                        ...EUI_AVATAR,
                        ...EUI_BADGE,
                    ], hostDirectives: [
                        {
                            directive: BaseStatesDirective,
                            inputs: [
                                'euiSizeS',
                                'euiSecondary',
                                'euiPrimary',
                            ],
                        },
                    ], providers: [EuiDropdownService], template: "@if (hasMenu) {\n    <eui-dropdown [hasTabNavigation]=\"hasTabNavigation\" width=\"340px\" #dropdown (expand)=\"onDropdownExpand($event)\">\n        <ng-container *ngTemplateOutlet=\"userProfileContent\"/>\n        <eui-dropdown-content>\n            <ng-content/>\n        </eui-dropdown-content>\n    </eui-dropdown>\n} @else {\n    <ng-container *ngTemplateOutlet=\"userProfileContent\"/>\n}\n\n<ng-template #userProfileContent>\n    <button class=\"eui-user-profile-content\" [tabindex]=\"hasMenu ? '0' : '-1'\" [class.eui-user-profile-content--no-menu]=\"!hasMenu\">\n\n        @if (isShowUserInfos) {\n            <div class=\"eui-user-profile__infos\">\n                @if (userState()?.impersonatingUser) {\n                    <div class=\"eui-user-profile__infos-welcome\">\n                        @if (hasWelcomeLabel) {\n                            <span>{{ welcomeLabel }}&nbsp;</span>\n                        }\n                        @if(reverseNameOrder) {\n                            {{ userState()?.impersonatingUser?.firstName }} <strong>{{ userState()?.impersonatingUser?.lastName}}&nbsp;</strong>\n                        } @else {\n                            <strong>{{ userState()?.impersonatingUser?.lastName }}</strong> {{ userState()?.impersonatingUser?.firstName }}\n                        }\n                        <span>{{ impersonateLabel }}</span>\n                    </div>\n                    <div class=\"eui-user-profile__infos-name\">\n                        @if(reverseNameOrder) {\n                            {{ userState()?.firstName }} <strong>{{ userState()?.lastName }}</strong>\n                        } @else {\n                            <strong>{{ userState()?.lastName }}</strong> {{ userState()?.firstName }}\n                        }\n                    </div>\n                    @if (subInfos) {\n                        <div class=\"eui-user-profile__infos-subinfos\">{{ subInfos }}</div>\n                    }\n                } @else {\n                    @if (hasWelcomeLabel) {\n                        <div class=\"eui-user-profile__infos-welcome\">{{ welcomeLabel }}</div>\n                    }\n                    <div class=\"eui-user-profile__infos-name\">\n                        @if(reverseNameOrder) {\n                            {{ userState()?.firstName }} <strong>{{ userState()?.lastName }}</strong>\n                        } @else {\n                            <strong>{{ userState()?.lastName }}</strong> {{ userState()?.firstName }}\n                        }\n                    </div>\n                    @if (subInfos) {\n                        <div class=\"eui-user-profile__infos-subinfos\">{{ subInfos }}</div>\n                    }\n                }\n            </div>\n        }\n\n        <eui-avatar isFlat [euiSizeS]=\"baseStatesDirective.euiSizeS\" [hasShadow]=\"userState()?.impersonatingUser\">\n\n            @if (isShowAvatarInitials) {\n                <eui-avatar-text>{{ avatarInitials() }}</eui-avatar-text>\n            } @else {\n                <eui-avatar-image [imageUrl]=\"avatarUrl\"/>\n            }\n\n            @if (euiStatusSecondary || euiStatusSuccess || euiStatusDanger) {\n                <eui-avatar-badge position=\"bottom\">\n                    @if (euiStatusSuccess) {\n                        <eui-badge euiSuccess euiSizeS euiIconBadge>\n                            <eui-icon-svg icon=\"checkmark:outline\" size=\"xs\"/>\n                        </eui-badge>\n                    } @else if (euiStatusDanger) {\n                        <eui-badge euiDanger euiSizeS euiIconBadge>\n                            <eui-icon-svg icon=\"remove:outline\" size=\"xs\"/>\n                        </eui-badge>\n                    } @else if (euiStatusSecondary) {\n                        <eui-badge euiSecondary euiSizeS euiIconBadge>\n                            <eui-icon-svg icon=\"close-circle:outline\" fillColor=\"neutral\" size=\"xs\"/>\n                        </eui-badge>\n                    }\n                </eui-avatar-badge>\n            }\n        </eui-avatar>\n\n        @if (hasMenu || hasToggle) {\n            @if (isDropdownOpen) {\n                <eui-icon-svg icon=\"chevron-up:sharp\" size=\"xs\" class=\"eui-user-profile__drop-indicator\"/>\n            } @else {\n                <eui-icon-svg icon=\"chevron-down:sharp\" size=\"xs\" class=\"eui-user-profile__drop-indicator\"/>\n            }\n        }\n    </button>\n</ng-template>\n", styles: [".eui-19 .eui-user-profile{display:flex;position:relative}.eui-19 .eui-user-profile-content{align-items:center;background:none;border:var(--eui-bw-none);cursor:pointer;display:flex;padding:var(--eui-s-2xs) 0;gap:var(--eui-s-xs)}.eui-19 .eui-user-profile-content:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-content--no-menu{cursor:default}.eui-19 .eui-user-profile__infos{align-items:flex-end;display:flex;flex-direction:column}.eui-19 .eui-user-profile__infos-container{justify-content:flex-end;align-items:center;display:flex;width:100%}.eui-19 .eui-user-profile__infos-welcome{text-align:right;font:var(--eui-f-xs-compact)}.eui-19 .eui-user-profile__infos-name{color:var(--eui-c-branding);text-align:right;font:var(--eui-f-m-compact)}.eui-19 .eui-user-profile__infos-subinfos{color:var(--eui-c-neutral);text-align:right;font:var(--eui-f-xs-compact)}.eui-19 .eui-user-profile__drop-indicator{margin-left:calc(-1 * var(--eui-s-xs))}.eui-19 .eui--secondary .eui-user-profile__infos-name,.eui-19 .eui--secondary .eui-user-profile__infos-welcome{color:var(--eui-c-neutral)!important}@media screen and (max-width: 767px){.eui-19 .eui-app-shell-header-toolbar-items .eui-user-profile{display:flex}.eui-19 .eui-app .eui-app-toolbar .eui-user-profile__infos{display:none}}@media screen and (min-width: 768px){.eui-19 .eui-app-shell-header-toolbar-items .eui-user-profile{display:none}.eui-19 .is-header-shrink .eui-user-profile{display:flex}}@media screen and (min-width: 768px) and (max-width: 995px){.eui-19 .eui-app .eui-app-toolbar .eui-user-profile__infos{display:none}}.eui-19 .eui-user-profile--primary .eui-user-profile__infos-name{color:var(--eui-c-white)}.eui-19 .eui-user-profile--primary .eui-user-profile__infos-welcome,.eui-19 .eui-user-profile--primary .eui-user-profile__infos-subinfos{color:var(--eui-c-neutral-lightest)}.eui-19 .eui-user-profile--primary .eui-user-profile__drop-indicator svg{fill:var(--eui-c-white);color:var(--eui-c-white)}.eui-19 .eui-user-profile--reverse .eui-user-profile-content{flex-direction:row-reverse}.eui-19 .eui-user-profile--reverse .eui-user-profile__infos{margin-left:var(--eui-s-m)}.eui-19 .eui-user-profile--initials .eui-avatar-wrapper{background-color:var(--eui-c-branding-light)!important}.eui-19 .eui-user-profile--initials .eui-avatar-text{color:var(--eui-c-branding-light-contrast)!important}.eui-19 .eui-user-profile-menu{height:auto;min-width:250px;position:relative}.eui-19 .eui-user-profile-menu-item{align-items:center;border-bottom:1px solid var(--eui-c-divider);cursor:pointer;display:flex;padding:var(--eui-s-xs) var(--eui-s-s);gap:var(--eui-s-xs)}.eui-19 .eui-user-profile-menu-item:focus:not([readonly]){outline:2px solid var(--eui-c-focus)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-menu-item:focus-visible:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-menu-item [tabindex=\"0\"]:focus:not([readonly]){outline:2px solid var(--eui-c-focus-visible)!important;outline-offset:-2px!important;transition:none}.eui-19 .eui-user-profile-menu-item:hover{background-color:var(--eui-c-hover);cursor:pointer}.eui-19 .eui-user-profile-menu-item:last-child{border-bottom:0}.eui-19 .eui-user-profile-menu-item a{color:var(--eui-c-text);text-decoration:none}.eui-19 .eui-user-profile-menu-item.link{cursor:pointer}.eui-19 .eui-user-profile-menu-item-right-content{margin-left:auto}.eui-19 .eui-user-profile-card{width:100%}.eui-19 .eui-user-profile-card__main-wrapper{display:flex;flex-direction:row;padding:var(--eui-s-m) var(--eui-s-m) var(--eui-s-m) 0}.eui-19 .eui-user-profile-card__main-wrapper-right-content{display:flex;flex-direction:column;margin-left:auto}.eui-19 .eui-user-profile-card__avatar-wrapper{display:flex}.eui-19 .eui-user-profile-card__userInfos{display:flex;flex-direction:column;padding-left:var(--eui-s-s)}.eui-19 .eui-user-profile-card__userInfos-item{padding-bottom:var(--eui-s-xs)}.eui-19 .eui-user-profile-card__impersonateInfos{background-color:var(--eui-c-neutral-bg-light);padding:var(--eui-s-s)}\n"] }]
        }], propDecorators: { cssClasses: [{
                type: HostBinding,
                args: ['class']
            }], welcomeLabel: [{
                type: Input
            }], impersonateLabel: [{
                type: Input
            }], avatarUrl: [{
                type: Input
            }], subInfos: [{
                type: Input
            }], statusVariant: [{
                type: Input
            }], hasMenu: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasWelcomeLabel: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isShowAvatarInitials: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasTabNavigation: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isReverse: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], hasToggle: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isHeaderUserProfile: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isToolbarUserProfile: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isShowUserInfos: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], isMobileOnly: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiStatusSecondary: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiStatusSuccess: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], euiStatusDanger: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], reverseNameOrder: [{
                type: Input
            }], dropdown: [{
                type: ViewChild,
                args: ['dropdown']
            }], hasMenuContent: [{
                type: ContentChildren,
                args: [forwardRef(() => EuiUserProfileMenuComponent), { descendants: true }]
            }] } });

/**
 * @description
 * Provides components for displaying user profile information and menus.
 *
 * @deprecated Use {@link EUI_USER_PROFILE} instead
 *
 */
class EuiUserProfileModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileModule, imports: [EuiUserProfileComponent,
            EuiUserProfileMenuComponent,
            EuiUserProfileMenuItemComponent,
            EuiUserProfileCardComponent], exports: [EuiUserProfileComponent,
            EuiUserProfileMenuComponent,
            EuiUserProfileMenuItemComponent,
            EuiUserProfileCardComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileModule, imports: [EuiUserProfileComponent,
            EuiUserProfileCardComponent] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.12", ngImport: i0, type: EuiUserProfileModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        EuiUserProfileComponent,
                        EuiUserProfileMenuComponent,
                        EuiUserProfileMenuItemComponent,
                        EuiUserProfileCardComponent,
                    ],
                    exports: [
                        EuiUserProfileComponent,
                        EuiUserProfileMenuComponent,
                        EuiUserProfileMenuItemComponent,
                        EuiUserProfileCardComponent,
                    ],
                }]
        }] });

const EUI_USER_PROFILE = [
    EuiUserProfileComponent,
    EuiUserProfileMenuComponent,
    EuiUserProfileMenuItemComponent,
    EuiUserProfileCardComponent,
];

/**
 * Generated bundle index. Do not edit.
 */

export { EUI_USER_PROFILE, EuiUserProfileCardComponent, EuiUserProfileComponent, EuiUserProfileMenuComponent, EuiUserProfileMenuItemComponent, EuiUserProfileModule };
//# sourceMappingURL=eui-components-eui-user-profile.mjs.map
